from .Base import Item
from enum import StrEnum, auto
from random import choice, randrange


class Book(Item):
    class BookType(StrEnum):
        Children = auto()
        Drama = auto()
        Fiction = auto()
        Horror = auto()
        Humor = auto()
        Mystery = auto()
        Nonfiction = auto()
        Romance = auto()
        SciFi = auto()
        Tome = auto()

    @staticmethod
    def Children():
        c1 = [
            "baby",
            "bear",
            "bird",
            "boy",
            "bunny",
            "cat",
            "caterpillar",
            "chicken",
            "cow",
            "dino",
            "dog",
            "dragon",
            "duck",
            "family",
            "fox",
            "frog",
            "ghost",
            "girl",
            "goat",
            "kid",
            "king",
            "kitten",
            "lion",
            "little bird",
            "little boy",
            "little dragon",
            "little duck",
            "little girl",
            "little prince",
            "little princess",
            "man",
            "mouse",
            "owl",
            "pig",
            "prince",
            "princess",
            "puppy",
            "queen",
            "rabbit",
            "sheep",
            "snowman",
            "tiger",
            "toad",
            "wizard",
            "woman",
        ]
        c2 = [
            "babies",
            "bears",
            "birds",
            "boys",
            "bunnies",
            "cats",
            "chickens",
            "cows",
            "dinos",
            "dogs",
            "dragons",
            "ducks",
            "foxes",
            "frogs",
            "ghosts",
            "girls",
            "goats",
            "kids",
            "kings",
            "kittens",
            "lions",
            "little birds",
            "little dragons",
            "little ducks",
            "mice",
            "owls",
            "pigs",
            "puppies",
            "rabbits",
            "sheep",
            "tigers",
            "toads",
            "wizards",
        ]
        c3 = [
            "adventure",
            "airplane",
            "attic",
            "basement",
            "bed",
            "candle",
            "car",
            "chair",
            "chimney",
            "city",
            "closet",
            "coat",
            "country",
            "cup",
            "curiosity",
            "day",
            "door",
            "field",
            "flower",
            "forest",
            "hat",
            "home",
            "house",
            "lantern",
            "light",
            "mirror",
            "mountain",
            "pocket",
            "river",
            "roof",
            "sands",
            "shield",
            "statue",
            "stories",
            "story",
            "tale",
            "tales",
            "town",
            "train",
            "tree",
            "wand",
            "watch",
            "water",
            "week",
            "window",
        ]
        c4 = [
            "in my house",
            "in my school",
            "in my town",
            "in space",
            "in the forest",
            "in the mountains",
            "in the river",
            "of dreams",
            "of excelsior",
            "of fantasia",
            "of fantasy",
            "of fire",
            "of gold",
            "of life",
            "of magic",
            "of miracles",
            "of my country",
            "of my dreams",
            "of my house",
            "of my imagination",
            "of my land",
            "of mysteries",
            "of mystery",
            "of puzzles",
            "of rain",
            "of rainbows",
            "of riddles",
            "of secrets",
            "of silver",
            "of stone",
            "of sunshine",
            "of the moon",
            "of the stars",
            "of the sun",
            "of tomorrow",
            "of utopia",
            "of wonder",
            "of wood",
            "of yesterday",
            "on the moon",
        ]
        c5 = [
            "a day with",
            "adventure of",
            "afraid of",
            "amazing life of",
            "amazing world of",
            "back to",
            "back with",
            "bewitched by",
            "boring at",
            "brave at",
            "bubble of",
            "careful with",
            "caring for",
            "celebrating with",
            "cleaning at",
            "cleaning with",
            "clumsy at",
            "colors of",
            "cooking with",
            "cool at",
            "crafting with",
            "crazy at",
            "crazy with",
            "cute with",
            "drawing with",
            "enchanted by",
            "fearless with",
            "foolish with",
            "free with",
            "gift from",
            "gift of",
            "giving with",
            "growing up with",
            "growing with",
            "happy with",
            "helping",
            "jealous of",
            "jumping with",
            "learning with",
            "living with",
            "love of",
            "loved by",
            "playing with",
            "present from",
            "present of",
            "puzzling with",
            "reading with",
        ]
        c6 = [
            "fantasy",
            "flowers",
            "leaves",
            "magic",
            "my best friend",
            "my brother",
            "my cat",
            "my cousin",
            "my dad",
            "my dog",
            "my family",
            "my father",
            "my fish",
            "my friend",
            "my home",
            "my house",
            "my imagination",
            "my mom",
            "my mother",
            "my neighbor",
            "my neighbors",
            "my nephew",
            "my new cat",
            "my new clothes",
            "my new dog",
            "my new fish",
            "my new pet",
            "my niece",
            "my pet",
            "my pet dragon",
            "my school",
            "my sister",
            "my town",
            "my village",
            "petals",
            "sticks",
            "the animals",
            "the doctor",
            "the fields",
            "the forest",
            "the hospital",
            "the mountains",
            "the neighbor",
            "the neighbors",
            "the river",
            "the school",
            "the town",
            "water",
        ]
        c7 = [
            "in my house",
            "in my school",
            "in my town",
            "in space",
            "in the forest",
            "in the mountains",
            "in the river",
            "of dreams",
            "of excelsior",
            "of fantasia",
            "of fantasy",
            "of fire",
            "of gold",
            "of life",
            "of magic",
            "of miracles",
            "of my country",
            "of my dreams",
            "of my house",
            "of my imagination",
            "of my land",
            "of mysteries",
            "of mystery",
            "of puzzles",
            "of rain",
            "of rainbows",
            "of riddles",
            "of secrets",
            "of silver",
            "of stone",
            "of sunshine",
            "of the moon",
            "of the stars",
            "of the sun",
            "of tomorrow",
            "of utopia",
            "of wonder",
            "of wood",
            "of yesterday",
            "on the moon",
        ]
        i = randrange(5)
        if i == 0:
            return str(choice(c1) + " " + choice(c4)).title()
        elif i == 1:
            return str(choice(c2) + " " + choice(c4)).title()
        elif i == 2:
            return str(choice(c2) + " " + choice(c2)).title()
        elif i == 3:
            return str(choice(c3) + " " + choice(c7)).title()
        else:
            return str(choice(c5) + " " + choice(c6)).title()

    @staticmethod
    def Drama():
        d1 = [
            "accomplice",
            "agent",
            "ancestor",
            "angel",
            "army",
            "assassin",
            "assistant",
            "baker",
            "bandit",
            "bearer",
            "blacksmith",
            "boy",
            "bringer",
            "builder",
            "butcher",
            "cat",
            "child",
            "collaborator",
            "collector",
            "companion",
            "courier",
            "creator",
            "culler",
            "defender",
            "deputy",
            "descendant",
            "doctor",
            "dog",
            "emissary",
            "enemy",
            "farmer",
            "follower",
            "foreigner",
            "founder",
            "friend",
            "girl",
            "guardian",
            "heir",
            "horse",
            "human",
            "invader",
            "inventor",
            "knight",
            "lord",
            "man",
            "medic",
            "messenger",
            "officer",
            "opponent",
            "patron",
            "peasant",
            "peon",
            "pirate",
            "planner",
            "rat",
            "raven",
            "rebel",
            "savior",
            "scientist",
            "secretary",
            "servant",
            "slave",
            "soldier",
            "spy",
            "stranger",
            "supporter",
            "thief",
            "traitor",
            "vulture",
            "warrior",
            "widow",
            "wife",
            "witch",
            "wolf",
            "woman",
        ]
        d2 = [
            "agents",
            "ancestors",
            "angels",
            "armies",
            "assassins",
            "assistants",
            "bakers",
            "bandits",
            "bearers",
            "blacksmiths",
            "boys",
            "bringers",
            "builders",
            "butchers",
            "children",
            "collectors",
            "companions",
            "couriers",
            "creators",
            "cullers",
            "defenders",
            "deputies",
            "descendants",
            "doctors",
            "emissaries",
            "enemies",
            "farmers",
            "followers",
            "foreigners",
            "founders",
            "friends",
            "girls",
            "guardians",
            "heirs",
            "horses",
            "people",
            "invaders",
            "inventors",
            "knights",
            "lords",
            "men",
            "medics",
            "messengers",
            "officers",
            "opponents",
            "patrons",
            "peasants",
            "peons",
            "pirates",
            "planners",
            "rats",
            "rebels",
            "saviors",
            "scientists",
            "secretaries",
            "servants",
            "slaves",
            "soldiers",
            "spies",
            "strangers",
            "supporters",
            "thieves",
            "traitors",
            "vultures",
            "warriors",
            "widows",
            "wives",
            "witches",
            "wolves",
            "women",
        ]
        d3 = [
            "accidents",
            "anger",
            "annihilation",
            "ascension",
            "bane",
            "beginning",
            "birth",
            "border",
            "boundaries",
            "carnage",
            "castle",
            "cause",
            "certainty",
            "chase",
            "confinement",
            "country",
            "creation",
            "cruelty",
            "culling",
            "death",
            "decay",
            "decisions",
            "demise",
            "design",
            "destruction",
            "dishonor",
            "disruption",
            "edge",
            "effect",
            "element",
            "end",
            "execution",
            "failure",
            "fate",
            "harvest",
            "homes",
            "loss",
            "love",
            "nation",
            "obliteration",
            "origin",
            "perfection",
            "planet",
            "product",
            "result",
            "rise",
            "root",
            "ruination",
            "ruins",
            "scourge",
            "source",
            "undoing",
            "union",
            "unity",
            "vengeance",
            "violence",
            "vision",
        ]
        d4 = [
            "dressed in black",
            "dressed in white",
            "of afflication",
            "of agony",
            "of anguish",
            "of bad news",
            "of breaking hearts",
            "of crime",
            "of damnation",
            "of darkness",
            "of dawn",
            "of desire",
            "of despair",
            "of destruction",
            "of doom",
            "of dread",
            "of dusk",
            "of earth",
            "of eternity",
            "of evil",
            "of fire",
            "of fortune",
            "of freedom",
            "of glory",
            "of gold",
            "of heaven",
            "of hell",
            "of history",
            "of hope",
            "of ice",
            "of insanity",
            "of last rites",
            "of limbo",
            "of misery",
            "of nightmares",
            "of pain",
            "of power",
            "of reality",
            "of remorse",
            "of repentance",
            "of sorrow",
            "of stone",
            "of suffering",
            "of the battle",
            "of the blues",
            "of the curse",
            "of the east",
            "of the eclipse",
            "of the end",
            "of the forest",
            "of the forsaken",
            "of the frontline",
            "of the gods",
            "of the lost ones",
            "of the mountains",
            "of the nation",
            "of the nether",
            "of the night",
            "of the north",
            "of the ocean",
            "of the plague",
            "of the prison",
            "of the river",
            "of the sea",
            "of the south",
            "of the stars",
            "of the stockades",
            "of the void",
            "of the west",
            "of the world",
            "of time",
            "of tomorrow",
            "of twilight",
            "of war",
            "with a goal",
            "with debt",
            "with gold",
            "with guns",
            "with hoods",
            "with horns",
            "with money",
            "with silver hair",
            "with sins",
            "with wings",
            "without a conscience",
            "without a goal",
            "without a head",
            "without a home",
            "without desire",
            "without direction",
            "without duty",
            "without faith",
            "without fear",
            "without honor",
            "without hope",
            "without shame",
            "without sin",
            "without time",
        ]
        d5 = [
            "accepting",
            "admiring",
            "adopting",
            "alarming",
            "altering",
            "answering to",
            "arrival of",
            "avoiding",
            "aware of",
            "battle",
            "battle of",
            "battling",
            "battling in",
            "becoming",
            "begging",
            "begging in",
            "belonging to",
            "bound to",
            "binding to",
            "bleeding at",
            "bleeding in",
            "blinded by",
            "blinded in",
            "blood at",
            "blood in",
            "bravery at",
            "breaking",
            "breath of",
            "call to",
            "calling",
            "changing",
            "chasing",
            "choking in",
            "cleaning up",
            "clinging to",
            "commanding",
            "confessions of",
            "cruelty of",
            "crying in",
            "dead at",
            "dead in",
            "death at",
            "death in",
            "death to",
            "destroying",
            "driving into",
            "eliminating",
            "ending",
            "enter",
            "escape",
            "escaping",
            "facing",
            "fade into",
            "fighting",
            "flee to",
            "flying into",
            "force of",
            "forsaken by",
            "forsaking",
            "frightened of",
            "haunting",
            "hiding",
            "hunted by",
            "hunting",
            "hurt by",
            "hurting",
            "infamous among",
            "jealous of",
            "kicking",
            "killing",
            "laughing at",
            "learning from",
            "life at",
            "life in",
            "listening to",
            "loathing",
            "losing",
            "lurking in",
            "meeting at",
            "meeting in",
            "memories of",
            "memory of",
            "mending",
            "never trust",
            "numb to",
            "pray for",
            "prepare for",
            "preparing for",
            "promises of",
            "remember",
            "robbing",
            "run for",
            "running into",
            "scared of",
            "screams at",
            "screams in",
            "searching at",
            "searching for",
            "searching in",
            "separated at",
            "separated by",
            "separated in",
            "sick of",
            "smiles in",
            "smiles of",
            "songs of",
            "sounds of",
            "starting",
            "trust",
            "weep for",
            "welcome to",
            "whispers in",
            "whispers of",
            "write about",
            "wrong about",
        ]
        d6 = [
            "a storm",
            "dreams",
            "history",
            "my destiny",
            "my dreams",
            "my end",
            "my enemies",
            "my family",
            "my friends",
            "my future",
            "my home",
            "my husband",
            "my leader",
            "my nightmares",
            "my past",
            "my school",
            "my wife",
            "nightmares",
            "secrets",
            "technology",
            "the abyss",
            "the apocolypse",
            "the bridge",
            "the castle",
            "the champions",
            "the city",
            "the commander",
            "the country",
            "the curse",
            "the dark",
            "the darkness",
            "the demons",
            "the depths",
            "the dungeons",
            "the east",
            "the elements",
            "the emperor",
            "the end",
            "the fog",
            "the forest",
            "the future",
            "the graveyard",
            "the guards",
            "the hunter",
            "the jungle",
            "the king",
            "the light",
            "the mayor",
            "the maze",
            "the mines",
            "the mist",
            "the moon",
            "the mountains",
            "the nation",
            "the night",
            "the north",
            "the ocean",
            "the past",
            "the plague",
            "the president",
            "the prison",
            "the prisoner",
            "the prisoners",
            "the river",
            "the sea",
            "the shadows",
            "the ships",
            "the slaves",
            "the soldier",
            "the soldiers",
            "the south",
            "the stars",
            "the sun",
            "the swamp",
            "the town",
            "the traitor",
            "the traitors",
            "the void",
            "the west",
            "the world",
            "time",
        ]
        d7 = [
            "dressed in black",
            "dressed in white",
            "of afflication",
            "of agony",
            "of anguish",
            "of bad news",
            "of breaking hearts",
            "of crime",
            "of damnation",
            "of darkness",
            "of dawn",
            "of desire",
            "of despair",
            "of destruction",
            "of doom",
            "of dread",
            "of dusk",
            "of earth",
            "of eternity",
            "of evil",
            "of fire",
            "of fortune",
            "of freedom",
            "of glory",
            "of gold",
            "of heaven",
            "of hell",
            "of history",
            "of hope",
            "of ice",
            "of insanity",
            "of last rites",
            "of limbo",
            "of misery",
            "of nightmares",
            "of pain",
            "of power",
            "of reality",
            "of remorse",
            "of repentance",
            "of sorrow",
            "of stone",
            "of suffering",
            "of the battle",
            "of the blues",
            "of the curse",
            "of the east",
            "of the eclipse",
            "of the end",
            "of the forest",
            "of the forsaken",
            "of the frontline",
            "of the gods",
            "of the lost ones",
            "of the mountains",
            "of the nation",
            "of the nether",
            "of the night",
            "of the north",
            "of the ocean",
            "of the plague",
            "of the prison",
            "of the river",
            "of the sea",
            "of the south",
            "of the stars",
            "of the stockades",
            "of the void",
            "of the west",
            "of the world",
            "of time",
            "of tomorrow",
            "of twilight",
            "of war",
            "with a goal",
            "with debt",
            "with gold",
            "with guns",
            "with hoods",
            "with horns",
            "with money",
            "with silver hair",
            "with sins",
            "with wings",
            "without a conscience",
            "without a goal",
            "without a head",
            "without a home",
            "without desire",
            "without direction",
            "without duty",
            "without faith",
            "without fear",
            "without honor",
            "without hope",
            "without shame",
            "without sin",
            "without time",
        ]
        i = randrange(5)
        if i == 0:
            return str(choice(d1) + " " + choice(d4)).title()
        elif i == 1:
            return str(choice(d2) + " " + choice(d4)).title()
        elif i == 2:
            return str(choice(d2) + " " + choice(d2)).title()
        elif i == 3:
            return str(choice(d3) + " " + choice(d7)).title()
        else:
            return str(choice(d5) + " " + choice(d6)).title()

    @staticmethod
    def Fiction():
        f1 = [
            "agent",
            "imp",
            "alien",
            "angel",
            "animal",
            "army",
            "assassin",
            "baker",
            "bandit",
            "blacksmith",
            "boy",
            "butcher",
            "butterfly",
            "cat",
            "changeling",
            "child",
            "companion",
            "creator",
            "criminal",
            "cyborg",
            "deceiver",
            "defender",
            "demon",
            "descendant",
            "doctor",
            "dog",
            "dragon",
            "dragonborn",
            "druid",
            "duchess",
            "duke",
            "dwarf",
            "elf",
            "emperor",
            "enchanter",
            "enemy",
            "fairy",
            "fighter",
            "fish",
            "foe",
            "foreigner",
            "friend",
            "gangster",
            "ghost",
            "giant",
            "girl",
            "gnome",
            "goblin",
            "god",
            "goddess",
            "guardian",
            "hawk",
            "heir",
            "hero",
            "hobgoblin",
            "horse",
            "human",
            "hunter",
            "hydra",
            "invader",
            "king",
            "knight",
            "lion",
            "lord",
            "mage",
            "man",
            "medic",
            "mermaid",
            "merman",
            "monk",
            "mouse",
            "necromancer",
            "nymph",
            "officer",
            "ogre",
            "opponent",
            "orc",
            "owl",
            "paladin",
            "parrot",
            "persuer",
            "phantom",
            "pilot",
            "pirate",
            "priest",
            "priestess",
            "protector",
            "queen",
            "rat",
            "raven",
            "rebel",
            "robot",
            "rogue",
            "sage",
            "savior",
            "serpent",
            "shaman",
            "skeleton",
            "slave",
            "snake",
            "soldier",
            "spider",
            "spy",
            "stranger",
            "summoner",
            "swindler",
            "thief",
            "tortoise",
            "traitor",
            "tree",
            "troll",
            "turtle",
            "vampire",
            "vulture",
            "warlock",
            "warrior",
            "werewolf",
            "wife",
            "witch",
            "wizard",
            "wolf",
            "woman",
            "zombie",
        ]
        f2 = [
            "agents",
            "imps",
            "aliens",
            "angels",
            "animals",
            "armies",
            "assassins",
            "bandits",
            "blacksmiths",
            "boys",
            "butchers",
            "cats",
            "children",
            "companions",
            "creators",
            "criminals",
            "cyborgs",
            "deceivers",
            "defenders",
            "demons",
            "descendants",
            "doctors",
            "dogs",
            "dragons",
            "druids",
            "dwarves",
            "elves",
            "enchanters",
            "enemies",
            "fairies",
            "fighters",
            "fish",
            "foes",
            "foreigners",
            "friends",
            "gangsters",
            "ghosts",
            "giants",
            "girls",
            "gnomes",
            "goblins",
            "gods",
            "guardians",
            "heirs",
            "heroes",
            "hobgoblins",
            "horses",
            "humans",
            "hunters",
            "invaders",
            "kings",
            "knights",
            "lions",
            "lords",
            "mages",
            "men",
            "mermaids",
            "mermen",
            "mice",
            "monks",
            "necromancers",
            "nymphs",
            "officers",
            "ogres",
            "orcs",
            "owls",
            "paladins",
            "persuers",
            "phantoms",
            "pilots",
            "pirates",
            "priests",
            "protectors",
            "rats",
            "rebels",
            "robots",
            "rogues",
            "sages",
            "serpents",
            "shamans",
            "skeletons",
            "slaves",
            "snakes",
            "soldiers",
            "spiders",
            "spies",
            "strangers",
            "summoners",
            "swindlers",
            "thieves",
            "traitors",
            "trees",
            "trolls",
            "turtles",
            "vampires",
            "vultures",
            "warlocks",
            "warriors",
            "werewolves",
            "witches",
            "wives",
            "wizards",
            "wolves",
            "women",
            "zombies",
        ]
        f3 = [
            "ancestry",
            "anger",
            "annihilation",
            "ascension",
            "bane",
            "beginning",
            "birth",
            "body",
            "border",
            "bow",
            "burial",
            "carnage",
            "castle",
            "catacomb",
            "chamber",
            "chase",
            "coffin",
            "completion",
            "confinement",
            "construction",
            "country",
            "creation",
            "crossbow",
            "crypt",
            "culling",
            "culmination",
            "curse",
            "death",
            "decay",
            "defeat",
            "demise",
            "destiny",
            "dishonor",
            "disruption",
            "doom",
            "edge",
            "element",
            "enchantment",
            "end",
            "extinction",
            "faction",
            "failure",
            "faith",
            "family",
            "fate",
            "fortune",
            "fruit",
            "future",
            "game",
            "goal",
            "grave",
            "harmony",
            "hatred",
            "honor",
            "hope",
            "imprisonment",
            "inception",
            "influence",
            "inspiration",
            "limit",
            "loss",
            "love",
            "luck",
            "magic",
            "mausoleum",
            "means",
            "misfortune",
            "monument",
            "moon",
            "murder",
            "name",
            "nation",
            "obliteration",
            "origin",
            "palace",
            "perfection",
            "planet",
            "rebirth",
            "reincarnation",
            "renewal",
            "restoration",
            "result",
            "revenge",
            "revival",
            "rise",
            "root",
            "ruination",
            "ruins",
            "scourge",
            "shield",
            "source",
            "spear",
            "spells",
            "spire",
            "staff",
            "star",
            "statue",
            "strife",
            "success",
            "surprise",
            "sword",
            "termination",
            "throne",
            "tomb",
            "tower",
            "tree",
            "union",
            "unity",
            "vengeance",
            "victory",
            "vision",
            "wand",
            "will",
            "world",
        ]
        f4 = [
            "of autumn",
            "of darkness",
            "of dawn",
            "of deception",
            "of demons",
            "of desire",
            "of despair",
            "of destruction",
            "of the rose",
            "of doom",
            "of dread",
            "of dreams",
            "of dusk",
            "of earth",
            "of eternity",
            "of fire",
            "of fortune",
            "of freedom",
            "of glory",
            "of gold",
            "of greatness",
            "of heaven",
            "of hell",
            "of history",
            "of hope",
            "of ice",
            "of infinity",
            "of insanity",
            "of limbo",
            "of magic",
            "of misfortune",
            "of my dreams",
            "of my imagination",
            "of nature",
            "of nightmares",
            "of perfection",
            "of power",
            "of rainbows",
            "of secrets",
            "of shadows",
            "of silver",
            "of snow",
            "of sorrow",
            "of spring",
            "of stone",
            "of summer",
            "of the ancestors",
            "of the ancients",
            "of the banished",
            "of the banner",
            "of the bow",
            "of the broken banner",
            "of the caves",
            "of the curse",
            "of the dagger",
            "of the dungeons",
            "of the east",
            "of the eclipse",
            "of the end",
            "of the era",
            "of the eternal",
            "of the forest",
            "of the forsaken",
            "of the future",
            "of the gods",
            "of the immortals",
            "of the king",
            "of the land",
            "of the light",
            "of the lost ones",
            "of the mountain",
            "of the nation",
            "of the night",
            "of the north",
            "of the ocean",
            "of the past",
            "of the plague",
            "of the prison",
            "of the river",
            "of the sea",
            "of the shadows",
            "of the shield",
            "of the skull",
            "of the solstice",
            "of the south",
            "of the stars",
            "of the stockades",
            "of the sword",
            "of the titans",
            "of the undead",
            "of the void",
            "of the west",
            "of the wind",
            "of the world",
            "of time",
            "of tomorrow",
            "of twilight",
            "of utopia",
            "of water",
            "of whispers",
            "of wind",
            "of winter",
            "of wood",
            "of yesterday",
            "with a goal",
            "with determination",
            "with gold",
            "with honor",
            "with immortality",
            "with money",
            "with pride",
            "with silver",
            "with sins",
            "with strength",
            "with vigor",
            "without a conscience",
            "without a goal",
            "without a home",
            "without a leader",
            "without courage",
            "without desire",
            "without direction",
            "without duty",
            "without faith",
            "without fear",
            "without flaws",
            "without glory",
            "without hate",
            "without honor",
            "without hope",
            "without shame",
            "without sin",
            "without time",
        ]
        f5 = [
            "accepting",
            "admiring",
            "adopting",
            "altering",
            "amusing",
            "answering to",
            "arriving at",
            "avoiding",
            "awakening",
            "bathing in",
            "battle",
            "battle of",
            "battling at",
            "battling in",
            "becoming",
            "begging in",
            "belonging to",
            "bound to",
            "binding to",
            "bleeding at",
            "bleeding in",
            "blinded by",
            "blinded in",
            "blood at",
            "blood in",
            "bravery at",
            "breaking",
            "breath of",
            "call to",
            "calling",
            "challenge of",
            "challenging",
            "changing",
            "chasing",
            "choking in",
            "cleaning up",
            "clinging to",
            "commanding",
            "confessions of",
            "controlling",
            "crying in",
            "dancing in",
            "dead at",
            "dead in",
            "death at",
            "death in",
            "death to",
            "deceiving",
            "delaying",
            "destroying",
            "drinking at",
            "driving into",
            "dwelling in",
            "eating at",
            "eliminating",
            "ending",
            "enhancing",
            "enter",
            "escape",
            "escaping",
            "fade into",
            "faith of",
            "fighting",
            "flee to",
            "flying into",
            "force of",
            "forsaken by",
            "forsaking",
            "going to",
            "growing in",
            "guarded by",
            "guarding",
            "healing",
            "helping",
            "hiding",
            "hunted by",
            "hunting",
            "hurt by",
            "hurting",
            "ignoring",
            "inventing",
            "invited by",
            "jumping into",
            "justice in",
            "kicking",
            "laughing at",
            "leading",
            "learning from",
            "life at",
            "life in",
            "listening to",
            "losing",
            "lurking in",
            "meeting at",
            "meeting in",
            "memory of",
            "mending",
            "never trust",
            "origin of",
            "painting",
            "pleasing",
            "possessed by",
            "praise",
            "praised by",
            "prepare for",
            "preparing for",
            "promises of",
            "punished by",
            "question",
            "raised by",
            "reach of",
            "rejecting",
            "remember",
            "rescue at",
            "rescue in",
            "right about",
            "run for",
            "running in",
            "sailing into",
            "scared at",
            "scared of",
            "screams at",
            "screams in",
            "searching at",
            "searching for",
            "searching in",
            "separated at",
            "separated by",
            "separated in",
            "shelter at",
            "shelter in",
            "signs at",
            "signs in",
            "signs of",
            "smile at",
            "smiles in",
            "songs of",
            "sounds in",
            "sounds of",
            "starting",
            "still breathing in",
            "symbols in",
            "symbols of",
            "taste of",
            "temptations in",
            "temptations of",
            "traces in",
            "travel to",
            "trust",
            "vanish at",
            "vanish in",
            "vanishing into",
            "visiting",
            "walking",
            "weep for",
            "welcome to",
            "whispers in",
            "whispers of",
            "winning",
            "working",
            "write about",
            "wrong about",
        ]
        f6 = [
            "a storm",
            "dreams",
            "eternity",
            "heaven",
            "hell",
            "history",
            "hope",
            "magic",
            "my country",
            "my destiny",
            "my dreams",
            "my end",
            "my enemies",
            "my family",
            "my friends",
            "my future",
            "my home",
            "my leader",
            "my nightmares",
            "my past",
            "nature",
            "nightmares",
            "secrets",
            "shields",
            "spells",
            "swords",
            "the abyss",
            "the ancestors",
            "the angels",
            "the animals",
            "the apocolypse",
            "the beginning",
            "the castle",
            "the catacombs",
            "the caves",
            "the champions",
            "the chasm",
            "the city",
            "the commander",
            "the country",
            "the curse",
            "the dark",
            "the darkness",
            "the demons",
            "the depths",
            "the dungeons",
            "the east",
            "the elements",
            "the emperor",
            "the end",
            "the eternals",
            "the firelands",
            "the fog",
            "the forest",
            "the future",
            "the gods",
            "the graves",
            "the graveyard",
            "the guardians",
            "the heavens",
            "the hills",
            "the home of demons",
            "the hunter",
            "the immortals",
            "the invaders",
            "the jungle",
            "the king",
            "the leaders",
            "the light",
            "the maze",
            "the mist",
            "the moon",
            "the mountains",
            "the nation",
            "the night",
            "the north",
            "the ocean",
            "the past",
            "the phantoms",
            "the pits",
            "the plague",
            "the river",
            "the sea",
            "the shadows",
            "the ships",
            "the skies",
            "the slaves",
            "the south",
            "the swamp",
            "the titans",
            "the tombs",
            "the town",
            "the universe",
            "the void",
            "the west",
            "the world",
            "time",
        ]
        f7 = [
            "of autumn",
            "of darkness",
            "of dawn",
            "of deception",
            "of demons",
            "of desire",
            "of despair",
            "of destruction",
            "of the rose",
            "of doom",
            "of dread",
            "of dreams",
            "of dusk",
            "of earth",
            "of eternity",
            "of fire",
            "of fortune",
            "of freedom",
            "of glory",
            "of gold",
            "of greatness",
            "of heaven",
            "of hell",
            "of history",
            "of hope",
            "of ice",
            "of infinity",
            "of insanity",
            "of limbo",
            "of magic",
            "of misfortune",
            "of my dreams",
            "of my imagination",
            "of nature",
            "of nightmares",
            "of perfection",
            "of power",
            "of rainbows",
            "of secrets",
            "of shadows",
            "of silver",
            "of snow",
            "of sorrow",
            "of spring",
            "of stone",
            "of summer",
            "of the ancestors",
            "of the ancients",
            "of the banished",
            "of the banner",
            "of the bow",
            "of the broken banner",
            "of the caves",
            "of the curse",
            "of the dagger",
            "of the dungeons",
            "of the east",
            "of the eclipse",
            "of the end",
            "of the era",
            "of the eternal",
            "of the forest",
            "of the forsaken",
            "of the future",
            "of the gods",
            "of the immortals",
            "of the king",
            "of the land",
            "of the light",
            "of the lost ones",
            "of the mountain",
            "of the nation",
            "of the night",
            "of the north",
            "of the ocean",
            "of the past",
            "of the plague",
            "of the prison",
            "of the river",
            "of the sea",
            "of the shadows",
            "of the shield",
            "of the skull",
            "of the solstice",
            "of the south",
            "of the stars",
            "of the stockades",
            "of the sword",
            "of the titans",
            "of the undead",
            "of the void",
            "of the west",
            "of the wind",
            "of the world",
            "of time",
            "of tomorrow",
            "of twilight",
            "of utopia",
            "of water",
            "of whispers",
            "of wind",
            "of winter",
            "of wood",
            "of yesterday",
            "with a goal",
            "with determination",
            "with gold",
            "with honor",
            "with immortality",
            "with money",
            "with pride",
            "with silver",
            "with sins",
            "with strength",
            "with vigor",
            "without a conscience",
            "without a goal",
            "without a home",
            "without a leader",
            "without courage",
            "without desire",
            "without direction",
            "without duty",
            "without faith",
            "without fear",
            "without flaws",
            "without glory",
            "without hate",
            "without honor",
            "without hope",
            "without shame",
            "without sin",
            "without time",
        ]
        i = randrange(5)
        if i == 0:
            return str(choice(f1) + " " + choice(f4)).title()
        elif i == 1:
            return str(choice(f2) + " " + choice(f4)).title()
        elif i == 2:
            return str(choice(f2) + " " + choice(f2)).title()
        elif i == 3:
            return str(choice(f3) + " " + choice(f7)).title()
        else:
            return str(choice(f5) + " " + choice(f6)).title()

    @staticmethod
    def Horror():
        h1 = [
            "agent",
            "angel",
            "animal",
            "creature",
            "figure",
            "bat",
            "beast",
            "boy",
            "butcher",
            "cat",
            "child",
            "colleague",
            "cook",
            "crow",
            "demon",
            "devil",
            "doctor",
            "dog",
            "fiend",
            "fish",
            "foreigner",
            "freak",
            "friend",
            "ghost",
            "girl",
            "guest",
            "horror",
            "horse",
            "human",
            "hunter",
            "imp",
            "man",
            "monk",
            "monster",
            "mutant",
            "neighbor",
            "owl",
            "phantom",
            "rat",
            "raven",
            "serpent",
            "shaman",
            "skeleton",
            "skinner",
            "snake",
            "spider",
            "stranger",
            "student",
            "teacher",
            "tree",
            "visitor",
            "vulture",
            "wife",
            "witch",
            "wolf",
            "woman",
            "zombie",
        ]
        h2 = [
            "agents",
            "angels",
            "animals",
            "creatures",
            "figures",
            "bats",
            "beasts",
            "boys",
            "butchers",
            "cats",
            "children",
            "colleagues",
            "cooks",
            "crows",
            "demons",
            "dogs",
            "fiends",
            "fish",
            "foreigners",
            "freaks",
            "friends",
            "ghosts",
            "girls",
            "guests",
            "horrors",
            "horses",
            "humans",
            "hunters",
            "imps",
            "men",
            "monks",
            "monsters",
            "mutants",
            "neighbors",
            "owls",
            "phantoms",
            "rats",
            "serpents",
            "skeletons",
            "snakes",
            "spiders",
            "strangers",
            "students",
            "teachers",
            "trees",
            "visitors",
            "vultures",
            "wives",
            "witches",
            "wolves",
            "women",
            "zombies",
        ]
        h3 = [
            "ambushed",
            "blood",
            "bodies",
            "books",
            "captured",
            "carvings",
            "corruption",
            "temptation",
            "don't go",
            "don't look",
            "drawings",
            "emblems",
            "eyes",
            "fire",
            "footprints",
            "footsteps",
            "giggling",
            "growls",
            "grunts",
            "hands",
            "hidden",
            "laughter",
            "lights",
            "lost",
            "movement",
            "mumbling",
            "music",
            "noises",
            "numbers",
            "paintings",
            "rituals",
            "screams",
            "secrets",
            "shadows",
            "signs",
            "singing",
            "songs",
            "sounds",
            "symbols",
            "trapped",
            "trinkets",
            "vanished",
            "voices",
            "whispers",
            "working",
        ]
        h4 = [
            "asking questions",
            "asks weird questions",
            "at the catacombs",
            "at the crypts",
            "at the graveyard",
            "at the hospital",
            "at the lake",
            "at the museum",
            "at the convention",
            "at the river",
            "at the tombs",
            "behind me",
            "behind the counter",
            "behind the door",
            "behind you",
            "blinking twice",
            "during full moon",
            "during halloween",
            "during lunch",
            "following me",
            "hiding from me",
            "in apartment B",
            "in my closet",
            "in my dreams",
            "in my garden",
            "in my nightmares",
            "in my school",
            "in my street",
            "in the abandoned house",
            "in the antique shop",
            "in the attic",
            "in the basement",
            "in the cabin",
            "in the castle",
            "in the elevator",
            "in the field",
            "in the fog",
            "in the forest",
            "in the lake",
            "in the library",
            "in the mirror",
            "in the mist",
            "in the mountain",
            "in the river",
            "in the store",
            "looking at me",
            "next door",
            "of detention",
            "of hell",
            "of the forest",
            "of the mountain",
            "of the night",
            "of the void",
            "on my roof",
            "on the ceiling",
            "under my bed",
            "who smiles",
            "who stare",
            "with a smile",
            "with black hair",
            "with fire",
            "with rotten skin",
            "with white hair",
            "without a mouth",
            "without a voice",
            "without eyes",
            "without teeth",
        ]
        h5 = [
            "abandoned in",
            "accepting",
            "afraid of",
            "afraid in",
            "alive in",
            "anguished by",
            "aware of",
            "brave until",
            "blinded by",
            "calm until",
            "careful of",
            "cautious of",
            "confused by",
            "corrupted by",
            "corrupted in",
            "crazy in",
            "defiant until",
            "defiant in",
            "brave in",
            "calm in",
            "defenseless in",
            "dead in",
            "evil in",
            "frozen in",
            "frightened in",
            "foolish in",
            "forsaken in",
            "fatal in",
            "growling in",
            "humble in",
            "hurt in",
            "horrified in",
            "hollowed by",
            "hidden in",
            "hidden by",
            "helpless in",
            "haunted in",
            "haunted by",
            "knowing",
            "living in",
            "surviving",
            "lonely in",
            "mad in",
            "miserable until",
            "mortified in",
            "motionless in",
            "mystery in",
            "numb in",
            "oblivious to",
            "oblivious in",
            "pain in",
            "pained by",
            "rotten in",
            "ready for",
            "scared by",
            "scared in",
            "somber until",
            "shaking in",
            "sweating in",
            "tempting until",
            "weeping at",
            "wicked until",
            "wretched in",
        ]
        h6 = [
            "eternity",
            "hell",
            "history",
            "my demise",
            "my dreams",
            "my end",
            "my nightmares",
            "my past",
            "nature",
            "nightmares",
            "secrets",
            "the abyss",
            "the catacombs",
            "the caves",
            "the chasm",
            "the city",
            "the country",
            "the crypts",
            "the dark",
            "the darkness",
            "the depths",
            "the dungeons",
            "the elements",
            "the end",
            "the fog",
            "the forest",
            "the graves",
            "the graveyard",
            "the hills",
            "the jungle",
            "the light",
            "the maze",
            "the mist",
            "the mountains",
            "the night",
            "the north",
            "the ocean",
            "the pits",
            "the river",
            "the sea",
            "the shadows",
            "the swamp",
            "the tombs",
            "the town",
            "the void",
            "time",
        ]
        h7 = [
            "at the catacombs",
            "at the convention",
            "at the crypts",
            "at the graveyard",
            "at the hospital",
            "at the lake",
            "at the museum",
            "at the river",
            "at the tombs",
            "behind me",
            "behind the counter",
            "behind the door",
            "behind you",
            "during full moon",
            "during halloween",
            "during lunch",
            "following me",
            "hiding from me",
            "in apartment B",
            "in my closet",
            "in my dreams",
            "in my garden",
            "in my nightmares",
            "in my school",
            "in my street",
            "in the abandoned house",
            "in the antique shop",
            "in the attic",
            "in the basement",
            "in the cabin",
            "in the castle",
            "in the catacombs",
            "in the convention",
            "in the crypts",
            "in the elevator",
            "in the field",
            "in the fog",
            "in the forest",
            "in the graveyard",
            "in the hospital",
            "in the lake",
            "in the library",
            "in the mirror",
            "in the mist",
            "in the mountain",
            "in the museum",
            "in the river",
            "in the store",
            "in the tombs",
            "next door",
            "on my roof",
            "on the ceiling",
            "under my bed",
        ]
        i = randrange(5)
        if i == 0:
            return str(choice(h1) + " " + choice(h4)).title()
        elif i == 1:
            return str(choice(h2) + " " + choice(h4)).title()
        elif i == 2:
            return str(choice(h2) + " " + choice(h2)).title()
        elif i == 3:
            return str(choice(h3) + " " + choice(h7)).title()
        else:
            return str(choice(h5) + " " + choice(h6)).title()

    @staticmethod
    def Humor():
        u1 = [
            "agent",
            "angel",
            "baker",
            "boy",
            "buffoon",
            "butcher",
            "cat",
            "chicken",
            "child",
            "clown",
            "comedian",
            "companion",
            "criminal",
            "doctor",
            "dog",
            "fish",
            "foreigner",
            "friend",
            "girl",
            "fool",
            "harlequin",
            "horse",
            "hunter",
            "jester",
            "king",
            "knight",
            "lord",
            "man",
            "mime",
            "mouse",
            "officer",
            "parrot",
            "pig",
            "prankster",
            "queen",
            "rat",
            "raven",
            "rebel",
            "robot",
            "serpent",
            "soldier",
            "spider",
            "stranger",
            "thief",
            "wife",
            "woman",
        ]
        u2 = [
            "agent",
            "angel",
            "baker",
            "boy",
            "buffoon",
            "butcher",
            "cat",
            "chicken",
            "child",
            "clown",
            "comedian",
            "companion",
            "criminal",
            "doctor",
            "dog",
            "fish",
            "foreigner",
            "friend",
            "girl",
            "fool",
            "harlequin",
            "horse",
            "hunter",
            "jester",
            "king",
            "knight",
            "lord",
            "man",
            "mime",
            "mouse",
            "officer",
            "parrot",
            "pig",
            "prankster",
            "queen",
            "rat",
            "raven",
            "rebel",
            "robot",
            "serpent",
            "soldier",
            "spider",
            "stranger",
            "thief",
            "wife",
            "woman",
        ]
        u3 = [
            "antics",
            "bags",
            "bliss",
            "buckets",
            "crying",
            "electricity",
            "farts",
            "fire",
            "fools",
            "gags",
            "humor",
            "ignorance",
            "injury",
            "jokes",
            "journeys",
            "laughing",
            "laughter",
            "lyrics",
            "mirrors",
            "mischief",
            "parody",
            "poems",
            "poop",
            "pranks",
            "secrets",
            "smoke",
            "songs",
            "spoofs",
            "stunts",
            "traps",
            "tricking",
            "tricks",
            "trinkets",
            "trouble",
            "trust",
            "whispers",
        ]
        u4 = [
            "of jokes",
            "of gags",
            "of humor",
            "of laughs",
            "of parody",
            "of stunts",
            "with stunts",
            "of tomorrow",
            "of the village",
            "of the city",
            "of the country",
            "from the mountains",
            "from the river",
            "from the forests",
            "without a voice",
            "with big eyes",
            "project",
            "gamble",
            "program",
            "job",
            "design",
            "deal",
            "plan",
            "setup",
            "affair",
            "program",
            "scheme",
            "strategy",
            "adventure",
            "exploit",
            "secret",
            "in the window",
            "in the hallway",
            "in the museum",
            "on my journey",
            "during my travel",
            "arrangement",
            "delusion",
            "wish",
            "puzzle",
            "makeover",
            "during the night",
            "can sing",
            "left me",
            "has been naughty",
            "has a secret life",
            "on a day out",
            "with a hat",
            "mocks me",
            "prophecy",
            "can cook",
            "can dance",
            "and my journey",
            "lives with me",
            "sleeps in my bed",
            "abroad",
            "loves sugar",
            "kicked me out",
            "stalks me",
        ]
        u5 = [
            "accomplishment of",
            "active in",
            "adored by",
            "adventure in",
            "ambition of",
            "ambitious in",
            "amused by",
            "anger of",
            "angry with",
            "blinded by",
            "bliss of",
            "brilliance of",
            "bruises of",
            "charm of",
            "climax of",
            "confused by",
            "confusion of",
            "damage of",
            "damaged by",
            "delight of",
            "devoted to",
            "discretion of",
            "elegance of",
            "embarrassed by",
            "evil of",
            "excited by",
            "excitement of",
            "failing of",
            "favorite of",
            "frozen by",
            "glamour of",
            "glory of",
            "greed of",
            "help of",
            "helped by",
            "hidden by",
            "hunger of",
            "ignorance of",
            "impressed by",
            "intelligence of",
            "intent of",
            "jealous of",
            "love for",
            "love of",
            "luxury of",
            "madness of",
            "mystery of",
            "offense of",
            "pleased by",
            "power of",
            "puzzled by",
            "respect for",
            "shame of",
            "simplicity of",
            "song of",
            "stupidity of",
            "suspicious of",
            "tired of",
            "trust",
            "trust in",
            "victory of",
            "wealth of",
            "weight of",
            "whispers of",
            "word of",
        ]
        u6 = [
            "being lonely",
            "fantasy",
            "fire",
            "her laugh",
            "his laugh",
            "ice",
            "lies",
            "magic",
            "money",
            "my actions",
            "my brother",
            "my design",
            "my friend",
            "my friends",
            "my idea",
            "my intentions",
            "my island",
            "my journey",
            "my memories",
            "my parents",
            "my plan",
            "my pranks",
            "my project",
            "my sister",
            "my system",
            "my teacher",
            "my town",
            "my trick",
            "my village",
            "nature",
            "that boy",
            "that girl",
            "that idiot",
            "the boy",
            "the brothers",
            "the clown",
            "the design",
            "the device",
            "the fool",
            "the girl",
            "the guard",
            "the idea",
            "the idiot",
            "the jester",
            "the job",
            "the joke",
            "the king",
            "the mayor",
            "the maze",
            "the night",
            "the officer",
            "the pants",
            "the plan",
            "the pranks",
            "the president",
            "the project",
            "the sisters",
            "the teacher",
            "the town",
            "the trick",
            "the truth",
            "the universe",
            "the village",
            "traditions",
            "water",
        ]
        u7 = [
            "of jokes",
            "of gags",
            "of humor",
            "of laughs",
            "of parody",
            "of stunts",
            "with stunts",
            "of tomorrow",
            "of the village",
            "of the city",
            "of the country",
            "from the mountains",
            "from the river",
            "from the forests",
            "without a voice",
            "with big eyes",
            "project",
            "gamble",
            "program",
            "job",
            "design",
            "deal",
            "plan",
            "setup",
            "affair",
            "program",
            "scheme",
            "strategy",
            "adventure",
            "exploit",
            "secret",
            "in the window",
            "in the hallway",
            "in the museum",
            "on my journey",
            "during my travel",
            "arrangement",
            "delusion",
            "wish",
            "puzzle",
            "makeover",
            "during the night",
            "can sing",
            "left me",
            "has been naughty",
            "has a secret life",
            "on a day out",
            "with a hat",
            "mocks me",
            "prophecy",
            "can cook",
            "can dance",
            "and my journey",
            "lives with me",
            "sleeps in my bed",
            "abroad",
            "loves sugar",
            "kicked me out",
            "stalks me",
        ]
        i = randrange(5)
        if i == 0:
            return str(choice(u1) + " " + choice(u4)).title()
        elif i == 1:
            return str(choice(u2) + " " + choice(u4)).title()
        elif i == 2:
            return str(choice(u2) + " " + choice(u2)).title()
        elif i == 3:
            return str(choice(u3) + " " + choice(u7)).title()
        else:
            return str(choice(u5) + " " + choice(u6)).title()

    @staticmethod
    def Mystery():
        m1 = [
            "agent",
            "angel",
            "army",
            "assassin",
            "baker",
            "bandit",
            "blacksmith",
            "boy",
            "butcher",
            "butterfly",
            "cat",
            "changeling",
            "companion",
            "criminal",
            "cyborg",
            "defender",
            "doctor",
            "dog",
            "duchess",
            "duke",
            "emperor",
            "enemy",
            "figure",
            "fish",
            "foe",
            "foreigner",
            "friend",
            "gangster",
            "giant",
            "vulture",
            "descendant",
            "heir",
            "child",
            "creator",
            "girl",
            "god",
            "goddess",
            "guardian",
            "hawk",
            "hero",
            "horse",
            "human",
            "invader",
            "king",
            "knight",
            "lion",
            "lord",
            "man",
            "medic",
            "mouse",
            "nymph",
            "officer",
            "opponent",
            "owl",
            "parrot",
            "phantom",
            "pilot",
            "pirate",
            "priest",
            "priestess",
            "queen",
            "rat",
            "raven",
            "hunter",
            "rebel",
            "robot",
            "sage",
            "savior",
            "serpent",
            "slave",
            "snake",
            "soldier",
            "spider",
            "spy",
            "stranger",
            "swindler",
            "thief",
            "tortoise",
            "traitor",
            "tree",
            "turtle",
            "warrior",
            "wife",
            "witch",
            "wolf",
            "woman",
        ]
        m2 = [
            "agents",
            "aliens",
            "armies",
            "assassins",
            "bandits",
            "blacksmiths",
            "boys",
            "butchers",
            "cats",
            "companions",
            "criminals",
            "vultures",
            "descendants",
            "heirs",
            "children",
            "creators",
            "defenders",
            "doctors",
            "dogs",
            "enemies",
            "figures",
            "fish",
            "foes",
            "foreigners",
            "friends",
            "gangsters",
            "giants",
            "girls",
            "gods",
            "guardians",
            "heroes",
            "horses",
            "humans",
            "invaders",
            "kings",
            "knights",
            "lions",
            "lords",
            "men",
            "mice",
            "officers",
            "owls",
            "phantoms",
            "pilots",
            "hunters",
            "pirates",
            "priests",
            "rats",
            "rebels",
            "robots",
            "serpents",
            "slaves",
            "snakes",
            "soldiers",
            "spiders",
            "spies",
            "strangers",
            "swindlers",
            "thieves",
            "traitors",
            "trees",
            "turtles",
            "warriors",
            "wives",
            "witches",
            "wolves",
            "women",
        ]
        m3 = [
            "achievement",
            "admiration",
            "appearance",
            "birth",
            "ceremony",
            "city",
            "clan",
            "relics",
            "clouds",
            "code",
            "country",
            "crash",
            "creed",
            "cult",
            "death",
            "destruction",
            "dream",
            "dreams",
            "enigma",
            "explosion",
            "faith",
            "fantasy",
            "fascination",
            "fog",
            "help",
            "illusion",
            "illusions",
            "key",
            "magic",
            "map",
            "memories",
            "mists",
            "mystery",
            "nightmare",
            "nightmares",
            "oracle",
            "parable",
            "paradox",
            "passage",
            "password",
            "picure",
            "prediction",
            "predictions",
            "puzzle",
            "puzzles",
            "question",
            "rain",
            "rebirth",
            "restoration",
            "revival",
            "riddle",
            "road",
            "rune",
            "runes",
            "seclusion",
            "secret",
            "secrets",
            "sect",
            "town",
            "treasure",
            "village",
            "vision",
            "visions",
            "worship",
        ]
        m4 = [
            "from beyond the grave",
            "in my city",
            "in my country",
            "in my garden",
            "in my house",
            "in my town",
            "in my village",
            "in my yard",
            "in the city",
            "in the forest",
            "in the lake",
            "in the mountains",
            "in the river",
            "of a beast",
            "of a cat",
            "of a creature",
            "of a dog",
            "of a friend",
            "of a man",
            "of a painting",
            "of a person",
            "of a shadow",
            "of a star",
            "of a stranger",
            "of a woman",
            "of an asteroid",
            "of an insect",
            "of animals",
            "of darkness",
            "of history",
            "of light",
            "of nature",
            "of outer space",
            "of shadows",
            "of the caves",
            "of the chasm",
            "of the flowers",
            "of the forest",
            "of the future",
            "of the galaxy",
            "of the lake",
            "of the moon",
            "of the mountain",
            "of the nether",
            "of the ocean",
            "of the past",
            "of the river",
            "of the sea",
            "of the stars",
            "of the sun",
            "of the swamp",
            "of the underground",
            "of the void",
            "of tomorrow",
            "of yesterday",
        ]
        m5 = [
            "abandoned by",
            "accomplishment of",
            "aching for",
            "adventure of",
            "age in",
            "age of",
            "alarmed by",
            "amazed by",
            "amused by",
            "ashamed of",
            "astonished by",
            "aware of",
            "blinded by",
            "bound to",
            "bravery for",
            "broken by",
            "calmed by",
            "caring for",
            "cautious of",
            "celebrate",
            "celebrated by",
            "clueless about",
            "comforted by",
            "confronted by",
            "confused by",
            "conscious of",
            "corrupted by",
            "created by",
            "crushed by",
            "curse of",
            "danger of",
            "deafened by",
            "death by",
            "death of",
            "depths of",
            "disguised by",
            "doubting",
            "enchanted by",
            "enchantment of",
            "enlightened by",
            "essence of",
            "evil of",
            "experiences of",
            "expert in",
            "faith of",
            "flaws of",
            "forsaken by",
            "frozen by",
            "gift of",
            "growing by",
            "guilt of",
            "hated by",
            "hatred of",
            "help of",
            "hidden in",
            "hunger of",
            "idle in",
            "jaded by",
            "love of",
            "loved by",
            "loyal to",
            "luck of",
            "moral of",
            "muted by",
            "nervous in",
            "old in",
            "parallel of",
            "perfume of",
            "price of",
            "prize of",
            "shrouded by",
            "young in",
        ]
        m6 = [
            "a storm",
            "a tower",
            "darkness",
            "dreams",
            "eternity",
            "heaven",
            "hell",
            "history",
            "hope",
            "illusions",
            "light",
            "my actions",
            "my destiny",
            "my dreams",
            "my future",
            "my home",
            "my house",
            "my life",
            "my nightmares",
            "my past",
            "my secrets",
            "my sins",
            "my town",
            "my village",
            "nightmares",
            "the beginning",
            "the black smoke",
            "the caves",
            "the chasm",
            "the cliffs",
            "the dark",
            "the depths",
            "the dungeon",
            "the east",
            "the elements",
            "the end",
            "the fog",
            "the forest",
            "the future",
            "the light",
            "the maze",
            "the mines",
            "the mist",
            "the moon",
            "the mountains",
            "the north",
            "the past",
            "the river",
            "the south",
            "the stars",
            "the sun",
            "the west",
            "the white smoke",
            "the world",
            "time",
            "visions",
        ]
        m7 = [
            "from beyond the grave",
            "in my city",
            "in my country",
            "in my garden",
            "in my house",
            "in my town",
            "in my village",
            "in my yard",
            "in the city",
            "in the forest",
            "in the lake",
            "in the mountains",
            "in the river",
            "of a beast",
            "of a cat",
            "of a creature",
            "of a dog",
            "of a friend",
            "of a man",
            "of a painting",
            "of a person",
            "of a shadow",
            "of a star",
            "of a stranger",
            "of a woman",
            "of an asteroid",
            "of an insect",
            "of animals",
            "of darkness",
            "of history",
            "of light",
            "of nature",
            "of outer space",
            "of shadows",
            "of the caves",
            "of the chasm",
            "of the flowers",
            "of the forest",
            "of the future",
            "of the galaxy",
            "of the lake",
            "of the moon",
            "of the mountain",
            "of the nether",
            "of the ocean",
            "of the past",
            "of the river",
            "of the sea",
            "of the stars",
            "of the sun",
            "of the swamp",
            "of the underground",
            "of the void",
            "of tomorrow",
            "of yesterday",
        ]
        i = randrange(5)
        if i == 0:
            return str(choice(m1) + " " + choice(m4)).title()
        elif i == 1:
            return str(choice(m2) + " " + choice(m4)).title()
        elif i == 2:
            return str(choice(m2) + " " + choice(m2)).title()
        elif i == 3:
            return str(choice(m3) + " " + choice(m7)).title()
        else:
            return str(choice(m5) + " " + choice(m6)).title()

    @staticmethod
    def Nonfiction():
        n1 = [
            "horses",
            "dogs",
            "people",
            "men",
            "women",
            "athletes",
            "children",
            "animals",
            "cats",
            "birds",
            "trees",
            "flowers",
            "insects",
            "fungi",
            "grasses",
            "corals",
            "fish",
            "reptiles",
            "amphibians",
            "rodents",
            "vultures",
            "pests",
            "predators",
            "preys",
            "crustaceans",
            "creatures",
            "angels",
            "devils",
            "demons",
            "freaks",
            "fools",
            "herbs",
            "spices",
            "mice",
            "rats",
            "warriors",
            "ancients",
            "leaders",
            "followers",
            "rulers",
            "kings",
            "queens",
            "emperors",
            "dinosaurs",
            "spirits",
            "friends",
            "enemies",
            "sinners",
            "spiders",
            "snakes",
            "flies",
            "stars",
            "planets",
            "moons",
            "ancestors",
            "politicians",
        ]
        n2 = [
            "horses",
            "dogs",
            "people",
            "men",
            "women",
            "athletes",
            "children",
            "animals",
            "cats",
            "birds",
            "trees",
            "flowers",
            "insects",
            "fungi",
            "grasses",
            "corals",
            "fish",
            "reptiles",
            "amphibians",
            "rodents",
            "vultures",
            "pests",
            "predators",
            "preys",
            "crustaceans",
            "creatures",
            "angels",
            "devils",
            "demons",
            "freaks",
            "fools",
            "herbs",
            "spices",
            "mice",
            "rats",
            "warriors",
            "ancients",
            "leaders",
            "followers",
            "rulers",
            "kings",
            "queens",
            "emperors",
            "dinosaurs",
            "spirits",
            "friends",
            "enemies",
            "sinners",
            "spiders",
            "snakes",
            "flies",
            "stars",
            "planets",
            "moons",
            "ancestors",
            "politicians",
        ]
        n3 = [
            "architecture",
            "art",
            "awards",
            "beaches",
            "books",
            "buildings",
            "candles",
            "capitals",
            "cars",
            "castles",
            "cities",
            "clans",
            "comics",
            "constellations",
            "constructions",
            "cooking",
            "countries",
            "crafting",
            "creations",
            "crimes",
            "currencies",
            "customs",
            "deception",
            "disasters",
            "diseases",
            "drinks",
            "dungeons",
            "education",
            "elements",
            "empires",
            "events",
            "fantasy",
            "farming",
            "farms",
            "festivals",
            "fields",
            "fires",
            "flags",
            "food",
            "furniture",
            "gems",
            "gods",
            "gold",
            "guardians",
            "guilds",
            "harmony",
            "harvest",
            "help",
            "holidays",
            "hope",
            "instruments",
            "iron",
            "languages",
            "love",
            "magic",
            "medicine",
            "miracles",
            "money",
            "monuments",
            "music",
            "nations",
            "nature",
            "ores",
            "paintings",
            "phones",
            "photos",
            "planes",
            "populations",
            "prisons",
            "prophets",
            "resources",
            "robots",
            "schools",
            "science",
            "secrets",
            "shields",
            "ships",
            "sights",
            "signs",
            "silver",
            "sins",
            "societies",
            "spells",
            "statues",
            "swords",
            "technology",
            "towns",
            "traditions",
            "trains",
            "travelling",
            "tv",
            "vehicles",
            "volcanos",
            "wars",
            "waters",
            "wealth",
            "weapons",
            "weather",
            "wonders",
            "working",
        ]
        n4 = [
            "around the world",
            "in the wild",
            "in your garden",
            "of dreams",
            "of heaven",
            "of hell",
            "of history",
            "of magic",
            "of medicine",
            "of our realm",
            "of science",
            "of stone",
            "of technology",
            "of the caves",
            "of the decade",
            "of the depths",
            "of the east",
            "of the fields",
            "of the forest",
            "of the future",
            "of the harvest",
            "of the hunt",
            "of the jungle",
            "of the lakes",
            "of the mountains",
            "of the north",
            "of the oceans",
            "of the past",
            "of the planet",
            "of the revolution",
            "of the rivers",
            "of the seas",
            "of the sky",
            "of the south",
            "of the swamp",
            "of the universe",
            "of the west",
            "of the world",
            "of time",
            "of tomorrow",
            "of yesterday",
            "of your dreams",
            "per continent",
            "per country",
            "per realm",
            "with skills",
            "with style",
            "with tradition",
            "without borders",
            "without limits",
            "without restrictions",
        ]
        n5 = [
            "academics of",
            "admiration of",
            "adoration of",
            "advancement of",
            "adventures of",
            "afraid of",
            "age of",
            "alarmed by",
            "alive in",
            "amazed by",
            "amazing",
            "amused by",
            "amusing",
            "ancient",
            "annual",
            "antique",
            "aromas of",
            "athletics of",
            "awesome",
            "basic",
            "blinded by",
            "bored by",
            "bored of",
            "brave",
            "brilliant",
            "broken",
            "cautious of",
            "classic",
            "clever",
            "colors of",
            "comfort of",
            "confusing",
            "creating",
            "creative",
            "dangers of",
            "demand for",
            "differences of",
            "digital",
            "digitize",
            "elegance of",
            "emotions of",
            "ethics of",
            "excellence of",
            "excellent",
            "expert",
            "experts of",
            "fame of",
            "famous",
            "fantasy of",
            "father of",
            "fears of",
            "flaws of",
            "focus on",
            "fortunes of",
            "friends of",
            "glamor of",
            "grace of",
            "curse of",
            "memory of",
            "dawn of",
            "greed of",
            "happy",
            "harmful",
            "helpful",
            "hidden",
            "honest",
            "honor of",
            "honored by",
            "idolized",
            "infamous",
            "innocence of",
            "intelligence of",
            "intelligent",
            "joy of",
            "known",
            "lasting",
            "life with",
            "limits of",
            "lost",
            "love for",
            "love of",
            "luck of",
            "majestic",
            "misery of",
            "mother of",
            "mysterious",
            "mystery of",
            "nature of",
            "nifty",
            "notable",
            "odd",
            "outlandish",
            "perfume of",
            "political",
            "popular",
            "powerful",
            "precious",
            "prestigious",
            "pure",
            "rare",
            "respect",
            "respect for",
            "safe",
            "scared of",
            "scented",
            "secret",
            "strange",
            "stunning",
            "temptations of",
            "tempted by",
            "the best",
            "united",
            "united as",
            "unusual",
            "wanted",
            "welcome to",
            "wonders of",
        ]
        n6 = [
            "aliens",
            "androids",
            "animals",
            "art",
            "babies",
            "biology",
            "neverland",
            "chemistry",
            "children",
            "cooking",
            "drawing",
            "dreams",
            "earth",
            "education",
            "fantasy",
            "history",
            "imagination",
            "keeping pets",
            "magic",
            "maths",
            "medicine",
            "men",
            "my country",
            "my home",
            "nature",
            "new earth",
            "nightmares",
            "painting",
            "people",
            "pets",
            "physics",
            "robots",
            "science",
            "space",
            "technology",
            "teenagers",
            "the caves",
            "the depths",
            "the forest",
            "the future",
            "the galaxy",
            "the lakes",
            "the lands",
            "the mountains",
            "the oceans",
            "the past",
            "the planet",
            "the rivers",
            "the seas",
            "the swamps",
            "the world",
            "time",
            "time travel",
            "today",
            "tomorrow",
            "women",
            "yesterday",
            "young adults",
            "your family",
            "your garden",
            "your home",
        ]
        n7 = [
            "around the world",
            "in the wild",
            "in your garden",
            "of dreams",
            "of heaven",
            "of hell",
            "of history",
            "of magic",
            "of medicine",
            "of our realm",
            "of science",
            "of stone",
            "of technology",
            "of the caves",
            "of the decade",
            "of the depths",
            "of the east",
            "of the fields",
            "of the forest",
            "of the future",
            "of the harvest",
            "of the hunt",
            "of the jungle",
            "of the lakes",
            "of the mountains",
            "of the north",
            "of the oceans",
            "of the past",
            "of the planet",
            "of the revolution",
            "of the rivers",
            "of the seas",
            "of the sky",
            "of the south",
            "of the swamp",
            "of the universe",
            "of the west",
            "of the world",
            "of time",
            "of tomorrow",
            "of yesterday",
            "of your dreams",
            "per continent",
            "per country",
            "per realm",
            "with skills",
            "with style",
            "with tradition",
            "without borders",
            "without limits",
            "without restrictions",
        ]
        i = randrange(5)
        if i == 0:
            return str(choice(n1) + " " + choice(n4)).title()
        elif i == 1:
            return str(choice(n2) + " " + choice(n4)).title()
        elif i == 2:
            return str(choice(n2) + " " + choice(n2)).title()
        elif i == 3:
            return str(choice(n3) + " " + choice(n7)).title()
        else:
            return str(choice(n5) + " " + choice(n6)).title()

    @staticmethod
    def Romance():
        r1 = [
            "admirer",
            "angel",
            "assistant",
            "beloved",
            "boy",
            "boyfriend",
            "colleague",
            "cook",
            "darling",
            "dear",
            "dearest",
            "duchess",
            "duke",
            "fiance",
            "flame",
            "foreigner",
            "friend",
            "girl",
            "girlfriend",
            "god",
            "goddess",
            "guest",
            "heartthrob",
            "honey",
            "husband",
            "knight",
            "ladylove",
            "love",
            "lovebird",
            "lover",
            "maid",
            "man",
            "mistress",
            "neighbor",
            "nymph",
            "queen",
            "roommate",
            "secret admirer",
            "servant",
            "stranger",
            "suitor",
            "sweetheart",
            "sweetie",
            "truelove",
            "valentine",
            "visitor",
            "wife",
            "woman",
        ]
        r2 = [
            "admirers",
            "angels",
            "assistants",
            "beloved",
            "boys",
            "boyfriends",
            "butterflies",
            "darlings",
            "dears",
            "dearests",
            "foreigners",
            "friends",
            "girls",
            "girlfriends",
            "gods",
            "guests",
            "heartthrobs",
            "honeys",
            "husbands",
            "knights",
            "ladyloves",
            "loves",
            "lovebirds",
            "lovers",
            "men",
            "mistresses",
            "nymphs",
            "queens",
            "roommates",
            "secret admirers",
            "strangers",
            "suitors",
            "sweethearts",
            "sweeties",
            "trueloves",
            "valentines",
            "visitors",
            "wifes",
            "women",
            "servants",
            "neighbors",
            "colleagues",
        ]
        r3 = [
            "accident",
            "beginning",
            "birth",
            "body",
            "chase",
            "choice",
            "climax",
            "completion",
            "creation",
            "destiny",
            "determination",
            "disruption",
            "edge",
            "element",
            "end",
            "evening",
            "fluke",
            "fortune",
            "foundation",
            "fruit",
            "future",
            "game",
            "hug",
            "inspiration",
            "kiss",
            "limit",
            "loss",
            "love",
            "luck",
            "lust",
            "memory",
            "name",
            "night",
            "origin",
            "passion",
            "perfection",
            "reality",
            "restoration",
            "result",
            "rise",
            "romance",
            "root",
            "scent",
            "source",
            "surprise",
            "vision",
            "will",
            "world",
        ]
        r4 = [
            "at my school",
            "at my work",
            "in my town",
            "in the forest",
            "in the mountain",
            "in the night",
            "in the river",
            "of the rose",
            "of bliss",
            "of dawn",
            "of desire",
            "of devotion",
            "of eternity",
            "of fire",
            "of fond memories",
            "of fortune",
            "of freedom",
            "of heaven",
            "of hell",
            "of hope",
            "of insanity",
            "of joy",
            "of love",
            "of lust",
            "of my admiration",
            "of my adoration",
            "of my childhood",
            "of my dreams",
            "of my fascination",
            "of my imagination",
            "of my mind",
            "of paradise",
            "of passion",
            "of perfection",
            "of rainbows",
            "of reality",
            "of romance",
            "of silver",
            "of the evening",
            "of the forest",
            "of the mountains",
            "of the night",
            "of the north",
            "of the ocean",
            "of the river",
            "of the sea",
            "of the solstice",
            "of the south",
            "of the stars",
            "of the west",
            "of tomorrow",
            "of yearning",
            "of yesterday",
            "with a cheeky smile",
            "with a crush",
            "with a hat",
            "with black hair",
            "with blond hair",
            "with blue eyes",
            "with brown hair",
            "with curly hair",
            "with freckles",
            "with funny socks",
            "with green eyes",
            "with hazel eyes",
            "with red hair",
            "with white hair",
            "with wings",
            "without fear",
            "without flaws",
            "without shame",
            "without time",
        ]
        r5 = [
            "accepting",
            "aching for",
            "admiring",
            "adored by",
            "adoring",
            "altering",
            "amusing",
            "answering",
            "assured by",
            "attracted to",
            "avoiding",
            "awakening in",
            "bathing in",
            "becoming",
            "belonging to",
            "bound to",
            "blinded by",
            "breath of",
            "calling",
            "changing",
            "chasing",
            "clinging to",
            "comforted by",
            "confessions of",
            "dancing with",
            "controlling",
            "cuddling",
            "dance of",
            "devoted to",
            "escaping",
            "excited by",
            "exciting",
            "flustered by",
            "frozen by",
            "guarded by",
            "guarding",
            "happy for",
            "helping",
            "hope for",
            "hunted by",
            "hurt by",
            "intelligent",
            "kind",
            "kissing",
            "learning from",
            "listening to",
            "lonely without",
            "losing",
            "loved by",
            "loving",
            "lucky with",
            "memory of",
            "oblivious to",
            "pleasing",
            "possessed by",
            "praise",
            "praised by",
            "prepare for",
            "preparing for",
            "promises of",
            "punished by",
            "rejecting",
            "remember",
            "scared of",
            "searching for",
            "separated by",
            "smile at",
            "songs of",
            "sounds of",
            "strange",
            "symbols of",
            "talk about",
            "talk to",
            "taste of",
            "temptations of",
            "travel to",
            "trust",
            "visited by",
            "visiting",
            "walking",
            "welcome to",
            "whispers in",
            "whispers of",
            "write about",
            "wrong about",
        ]
        r6 = [
            "adoration",
            "affection",
            "dreams",
            "eternity",
            "friendship",
            "her",
            "her friends",
            "her parents",
            "him",
            "his friends",
            "his parents",
            "love",
            "lust",
            "my admirer",
            "my boyfriend",
            "my dreams",
            "my friend",
            "my future",
            "my girl",
            "my girlfriend",
            "my guy",
            "my husband",
            "my man",
            "my nightmares",
            "my past",
            "my secret admirer",
            "my sweetheart",
            "my wife",
            "myself",
            "passion",
            "secrets",
            "the ",
            "the husband",
            "the night",
            "the river",
            "the sea",
            "the shadows",
            "the stars",
            "the stranger",
            "the wife",
            "time",
        ]
        r7 = [
            "at my school",
            "at my work",
            "in my town",
            "in the forest",
            "in the mountain",
            "in the night",
            "in the river",
            "of bliss",
            "of dawn",
            "of desire",
            "of devotion",
            "of eternity",
            "of fire",
            "of fond memories",
            "of fortune",
            "of freedom",
            "of heaven",
            "of hell",
            "of hope",
            "of insanity",
            "of joy",
            "of love",
            "of lust",
            "of my admiration",
            "of my adoration",
            "of my childhood",
            "of my dreams",
            "of my fascination",
            "of my imagination",
            "of my mind",
            "of paradise",
            "of passion",
            "of perfection",
            "of rainbows",
            "of reality",
            "of romance",
            "of silver",
            "of the evening",
            "of the forest",
            "of the mountains",
            "of the night",
            "of the north",
            "of the ocean",
            "of the river",
            "of the sea",
            "of the solstice",
            "of the south",
            "of the stars",
            "of the west",
            "of tomorrow",
            "of yearning",
            "of yesterday",
        ]
        i = randrange(5)
        if i == 0:
            return str(choice(r1) + " " + choice(r4)).title()
        elif i == 1:
            return str(choice(r2) + " " + choice(r4)).title()
        elif i == 2:
            return str(choice(r2) + " " + choice(r2)).title()
        elif i == 3:
            return str(choice(r3) + " " + choice(r7)).title()
        else:
            return str(choice(r5) + " " + choice(r6)).title()

    @staticmethod
    def SciFi():
        s1 = [
            "agent",
            "alien",
            "android",
            "angel",
            "army",
            "assassin",
            "beast",
            "boy",
            "captain",
            "child",
            "clone",
            "commander",
            "creator",
            "creature",
            "cyborg",
            "defender",
            "director",
            "doctor",
            "droid",
            "emperor",
            "enemy",
            "figure",
            "foreigner",
            "friend",
            "girl",
            "guardian",
            "guest",
            "hero",
            "human",
            "hunter",
            "intruder",
            "invader",
            "leader",
            "man",
            "martian",
            "medic",
            "mercenary",
            "officer",
            "pilot",
            "rebel",
            "recruit",
            "robot",
            "soldier",
            "spy",
            "stranger",
            "traitor",
            "veteran",
            "visitor",
            "volunteer",
            "woman",
        ]
        s2 = [
            "agents",
            "aliens",
            "androids",
            "armies",
            "assassins",
            "beasts",
            "boys",
            "captains",
            "children",
            "clones",
            "commanders",
            "creators",
            "creatures",
            "cyborgs",
            "defenders",
            "directors",
            "doctors",
            "droids",
            "emperors",
            "enemies",
            "figures",
            "foreigners",
            "friends",
            "girls",
            "guardians",
            "guests",
            "heroes",
            "humans",
            "hunters",
            "intruders",
            "invaders",
            "leaders",
            "men",
            "martians",
            "medics",
            "mercenaries",
            "officers",
            "pilots",
            "rebels",
            "recruits",
            "robots",
            "soldiers",
            "spies",
            "strangers",
            "traitors",
            "veterans",
            "visitors",
            "volunteers",
            "women",
        ]
        s3 = [
            "ambush",
            "appearance",
            "ascension",
            "battle",
            "beginning",
            "betrayal",
            "birth",
            "border",
            "carnage",
            "carvings",
            "chase",
            "confinement",
            "construction",
            "corruption",
            "creation",
            "culling",
            "death",
            "deception",
            "defeat",
            "demise",
            "destiny",
            "destruction",
            "disruption",
            "doom",
            "edge",
            "element",
            "end",
            "monument",
            "monuments",
            "statue",
            "statues",
            "exploration",
            "extermination",
            "extinction",
            "fate",
            "future",
            "hatred",
            "honor",
            "hope",
            "inception",
            "influence",
            "inspiration",
            "loss",
            "love",
            "monument",
            "moon",
            "murder",
            "nation",
            "obliteration",
            "origin",
            "planet",
            "rebirth",
            "reincarnation",
            "restoration",
            "result",
            "revenge",
            "revival",
            "rise",
            "root",
            "ruins",
            "scourge",
            "signs",
            "source",
            "star",
            "statue",
            "symbols",
            "throne",
            "victory",
            "world",
        ]
        s4 = [
            "of the sun",
            "of the moon",
            "of outer space",
            "on my ship",
            "of the galaxy",
            "of eternity",
            "from outer space",
            "of war",
            "of aliens",
            "of life",
            "of death",
            "of time",
            "of the dead",
            "of darkness",
            "of the void",
            "of the vacuum",
            "of the new world",
            "of earth",
            "of new earth",
            "of the sands",
            "of the ocean",
            "of the crash",
            "of the flight",
            "of the orbit",
            "of space",
            "of the worlds",
            "of the universe",
            "of the future",
            "of the past",
            "of everywhere",
            "of nowhere",
            "of the stars",
            "of stardust",
            "of moondust",
            "with tentacles",
            "with four eyes",
            "with spaceships",
            "with a spaceship",
            "with a UFO",
            "from the UFO",
            "in the news",
            "from the portal",
            "in the portal",
            "in the past",
            "in the future",
            "in the center of the earth",
            "in the beginning of time",
            "of new worlds",
            "of our legacy",
            "of men's legacy",
            "of earth's legacy",
            "of the fallen",
            "of our culture",
            "of honor",
            "of exploration",
            "of our ship",
            "of our destiny",
            "of our future",
            "of the outlands",
            "of sunshine",
            "of mars",
            "on mars",
        ]
        s5 = [
            "abandoned by",
            "abandoned in",
            "abandoned on",
            "admiration for",
            "afraid of",
            "alerted by",
            "alive in",
            "alive on",
            "anxious for",
            "basic",
            "better",
            "blindd by",
            "bored by",
            "broken",
            "caution of",
            "cautious of",
            "celebrating",
            "changed by",
            "closed for",
            "colors of",
            "complexity of",
            "confused by",
            "courage for",
            "crazy of",
            "created by",
            "cultured by",
            "darkness of",
            "defenseless against",
            "demand for",
            "dependent on",
            "devoted to",
            "disguised by",
            "disguised in",
            "elegance of",
            "equality in",
            "equality of",
            "experience in",
            "experience of",
            "failing of",
            "failure of",
            "father of",
            "favor of",
            "fixed in",
            "fortune of",
            "frightened of",
            "frozen by",
            "gift of",
            "glory of",
            "greed of",
            "haunted by",
            "hidden by",
            "hidden in",
            "inspired by",
            "intelligence in",
            "joy of",
            "life after",
            "life in",
            "life with",
            "light of",
            "limits of",
            "lonely in",
            "longing for",
            "lost in",
            "married to",
            "mother of",
            "mystery of",
            "open to",
            "origin of",
            "perfection of",
            "puzzle of",
            "right for",
            "secrets of",
            "security of",
            "serenity of",
            "sins of",
            "stranger to",
            "understanding",
        ]
        s6 = [
            "a new war",
            "a nuclear war",
            "a nuclear winter",
            "a rise of machines",
            "a robot takeover",
            "aliens",
            "androids",
            "droids",
            "electricity",
            "eternity",
            "first contact",
            "moon rocks",
            "moondust",
            "my android servant",
            "my journey",
            "my planet",
            "my space journey",
            "new earth",
            "new technology",
            "orbit",
            "orbital flight",
            "outer space",
            "robotic control",
            "robots",
            "solar flares",
            "space flight",
            "stardust",
            "technolic advancements",
            "technology",
            "the aliens",
            "the armies",
            "the depths",
            "the end",
            "the end of earth",
            "the end of the sun",
            "the eyes",
            "the fog",
            "the galaxy",
            "the guests",
            "the immortals",
            "the intruders",
            "the legends",
            "the machines",
            "the mists",
            "the moon",
            "the new age",
            "the new gods",
            "the new planet",
            "the new world",
            "the ocean",
            "the portal",
            "the revolution",
            "the robotic police",
            "the secrets",
            "the secrets of the ocean",
            "the stars",
            "the sun",
            "the titans",
            "the troopers",
            "the truth",
            "the vacuum",
            "the void",
            "the void of space",
            "time travel",
            "time travellers",
        ]
        s7 = [
            "from outer space",
            "of alien life",
            "of aliens",
            "of darkness",
            "of death",
            "of earth",
            "of earth's legacy",
            "of eternity",
            "of everywhere",
            "of exploration",
            "of honor",
            "of life",
            "of mars",
            "of men's legacy",
            "of moondust",
            "of new earth",
            "of new life",
            "of new worlds",
            "of nowhere",
            "of our culture",
            "of our destiny",
            "of our future",
            "of our legacy",
            "of our ship",
            "of outer space",
            "of robots",
            "of society",
            "of space",
            "of stardust",
            "of sunshine",
            "of the aliens",
            "of the androids",
            "of the crash",
            "of the dead",
            "of the droids",
            "of the faceless ones",
            "of the fallen",
            "of the flight",
            "of the future",
            "of the galaxy",
            "of the intruders",
            "of the invaders",
            "of the moon",
            "of the new order",
            "of the new world",
            "of the ocean",
            "of the orbit",
            "of the outlands",
            "of the past",
            "of the planet",
            "of the sands",
            "of the stars",
            "of the sun",
            "of the universe",
            "of the vacuum",
            "of the void",
            "of the worlds",
            "of time",
            "of war",
            "on mars",
            "on my ship",
        ]
        i = randrange(5)
        if i == 0:
            return str(choice(s1) + " " + choice(s4)).title()
        elif i == 1:
            return str(choice(s2) + " " + choice(s4)).title()
        elif i == 2:
            return str(choice(s2) + " " + choice(s2)).title()
        elif i == 3:
            return str(choice(s3) + " " + choice(s7)).title()
        else:
            return str(choice(s5) + " " + choice(s6)).title()

    @staticmethod
    def Tome():
        t1 = [
            "Alpha",
            "Amnesia",
            "Apostle",
            "Aqua",
            "Ash",
            "Ashes",
            "Ataraxia",
            "Benediction",
            "Blackfire",
            "Blackout",
            "Blazefury",
            "Blazewing",
            "Brilliance",
            "Brilliancy",
            "Brimstone",
            "Celeste",
            "Celestia",
            "Chaos",
            "Chaossong",
            "Clarity",
            "Clemence",
            "Cometfall",
            "Consecration",
            "Contortion",
            "Cosmos",
            "Covergence",
            "Cryptic",
            "Cryptkeeper",
            "Dawn",
            "Dawne",
            "Dawnlight",
            "Daydream",
            "Deathsong",
            "Deluge",
            "Delusion",
            "Dementia",
            "Doombinder",
            "Doomguard",
            "Doomshadow",
            "Doomward",
            "Dragonbane",
            "Dragonfire",
            "Dragonwrath",
            "Draughtbane",
            "Dreambinder",
            "Dreamkiss",
            "Dreamshadow",
            "Dreamsong",
            "Dreamwhisper",
            "Duskshadow",
            "Dusksong",
            "Earthshadow",
            "Earthsong",
            "Ebony",
            "Echo",
            "Eclipse",
            "Endgame",
            "Enigma",
            "Featherfall",
            "Ferallity",
            "Fireweaver",
            "Flamebound",
            "Flameguard",
            "Flameward",
            "Fluke",
            "Flux",
            "Frenzy",
            "Frostbound",
            "Frostguard",
            "Frostward",
            "Fury",
            "Ghost",
            "Glimmer",
            "Grieve",
            "Harmony",
            "Hubris",
            "Hysteria",
            "Inertia",
            "Insanity",
            "Insight",
            "Ivory",
            "Labyrinth",
            "Lament",
            "Lazarus",
            "Lifebender",
            "Lifebinder",
            "Lightbane",
            "Limbo",
            "Lorebinder",
            "Lorekeeper",
            "Lull",
            "Lullaby",
            "Malice",
            "Memoire",
            "Mercy",
            "Midnight",
            "Mirage",
            "Moonbeam",
            "Moonlight",
            "Moonshadow",
            "Moonshard",
            "Mystery",
            "Necrosong",
            "Nemesis",
            "Netherbane",
            "Nethersong",
            "Nexus",
            "Nightfall",
            "Nightkiss",
            "Nightmare",
            "Nimble",
            "Nirvana",
            "Nymph",
            "Oath",
            "Oathkeeper",
            "Oblivion",
            "Omega",
            "Omen",
            "Oracle",
            "Peacesong",
            "Penance",
            "Persuasion",
            "Phantom",
            "Phantomdream",
            "Phantomlight",
            "Phantomsong",
            "Phobia",
            "Pride",
            "Prime",
            "Prophecy",
            "Prudence",
            "Pureheart",
            "Purgatory",
            "Purity",
            "Pursuit",
            "Reflection",
            "Remorse",
            "Requiem",
            "Retribution",
            "Revelation",
            "Riddle",
            "Sanguine",
            "Sapience",
            "Scarlet",
            "Serenity",
            "Shadowbane",
            "Shadowbinder",
            "Shadowbound",
            "Shadowfall",
            "Silence",
            "Silverglow",
            "Silverlight",
            "Sleepwalker",
            "Snowfall",
            "Snowflake",
            "Solarflare",
            "Solarsong",
            "Soulbinder",
            "Souleater",
            "Soulflare",
            "Soulkeeper",
            "Soulshadow",
            "Soulsiphon",
            "Soulsliver",
            "Soulspell",
            "Spark",
            "Spellbinder",
            "Spellbound",
            "Spellkeeper",
            "Spellsong",
            "Stardust",
            "Starfall",
            "Starlight",
            "Stormrage",
            "Sunlight",
            "Supinity",
            "Suspension",
            "Thorn",
            "Torment",
            "Torrent",
            "Trance",
            "Tranquillity",
            "Trinity",
            "Twinkle",
            "Twitch",
            "Valhalla",
            "Verdict",
            "Visage",
            "Void",
            "Whisper",
            "Whispersong",
            "Whisperwind",
            "Willbinder",
            "Windweaver",
        ]
        t2 = [
            "Ancient",
            "Antique",
            "Apocalypse",
            "Apocalyptic",
            "Arcane",
            "Arched",
            "Atuned",
            "Bandit's",
            "Baneful",
            "Banished",
            "Barbarian",
            "Barbaric",
            "Battleworn",
            "Blazefury",
            "Blood Infused",
            "Blood-Forged",
            "Bloodcursed",
            "Bloodied",
            "Bloodlord's",
            "Bloodsurge",
            "Bloodvenom",
            "Bonecarvin",
            "Brutal",
            "Brutality",
            "Burnished",
            "Cataclysm",
            "Cataclysmic",
            "Challenger",
            "Challenger's",
            "Champion",
            "Champion's",
            "Cold-Forged",
            "Conqueror",
            "Conqueror's",
            "Corroded",
            "Corrupted",
            "Crazed",
            "Crying",
            "Cursed",
            "Curved",
            "Dancing",
            "Dark",
            "Darkness",
            "Defender",
            "Defender's",
            "Defiled",
            "Defiling",
            "Deluded",
            "Demonic",
            "Deserted",
            "Desire's",
            "Desolation",
            "Destiny's",
            "Diabolical",
            "Dire",
            "Doom",
            "Doom's",
            "Dragon's",
            "Dragonbreath",
            "Eerie",
            "Enchanted",
            "Engraved",
            "Enlightened",
            "Eternal",
            "Exiled",
            "Extinction",
            "Faith's",
            "Faithful",
            "Fancy",
            "Fearful",
            "Feral",
            "Ferocious",
            "Fierce",
            "Fiery",
            "Fire Infused",
            "Fireguard",
            "Firesoul",
            "Firestorm",
            "Flaming",
            "Flimsy",
            "Forsaken",
            "Fortune's",
            "Foul",
            "Fragile",
            "Frail",
            "Frenzied",
            "Frost",
            "Frozen",
            "Furious",
            "Fusion",
            "Ghastly",
            "Ghost",
            "Ghost-Forged",
            "Ghostly",
            "Gladiator",
            "Gladiator's",
            "Gleaming",
            "Glinting",
            "Greedy",
            "Grieving",
            "Grim",
            "Guard's",
            "Guardian's",
            "Hailstorm",
            "Harmonized",
            "Hateful",
            "Haunted",
            "Heartless",
            "Heinous",
            "Hero",
            "Hero's",
            "Hollow",
            "Holy",
            "Honed",
            "Honor's",
            "Hope's",
            "Hopeless",
            "Howling",
            "Hungering",
            "Improved",
            "Impure",
            "Incarnated",
            "Infused",
            "Inherited",
            "Isolated",
            "Jade Infused",
            "Judgement",
            "Keeper's",
            "Knightly",
            "Knight's",
            "Legionnaire's",
            "Liar's",
            "Lich",
            "Lightning",
            "Lonely",
            "Loyal",
            "Lustful",
            "Lusting",
            "Malevolent",
            "Malicious",
            "Malificent",
            "Malignant",
            "Massive",
            "Mended",
            "Mercenary",
            "Military",
            "Misfortune's",
            "Misty",
            "Moonlit",
            "Mourning",
            "Nightmare",
            "Oathkeeper's",
            "Ominous",
            "Peacekeeper",
            "Peacekeeper's",
            "Phantom",
            "Polished",
            "Possessed",
            "Pride's",
            "Prideful",
            "Primal",
            "Prime",
            "Primitive",
            "Promised",
            "Protector's",
            "Proud",
            "Pure",
            "Putrid",
            "Raging",
            "Recruit's",
            "Refined",
            "Reforged",
            "Reincarnated",
            "Relentless",
            "Remorseful",
            "Renewed",
            "Renovated",
            "Replica",
            "Restored",
            "Retribution",
            "Ritual",
            "Roaring",
            "Ruby Infused",
            "Rune-Forged",
            "Runed",
            "Rusty",
            "Savage",
            "Sentinel",
            "Shadow",
            "Shamanic",
            "Sharpened",
            "Silent",
            "Singed",
            "Singing",
            "Sinister",
            "Skyfall",
            "Smooth",
            "Soldier's",
            "Solitude's",
            "Sorcerer's",
            "Sorrow's",
            "Soul",
            "Soul Infused",
            "Soul-Forged",
            "Soulcursed",
            "Soulless",
            "Spectral",
            "Spectral-Forged",
            "Spiteful",
            "Storm",
            "Storm-Forged",
            "Stormfury",
            "Stormguard",
            "Terror",
            "Thirsting",
            "Thirsty",
            "Thunder",
            "Thunder-Forged",
            "Thunderfury",
            "Thunderguard",
            "Thundersoul",
            "Thunderstorm",
            "Timeworn",
            "Tormented",
            "Trainee's",
            "Treachery's",
            "Twilight",
            "Twilight's",
            "Twisted",
            "Tyrannical",
            "Undead",
            "Unholy",
            "Vanquisher",
            "Vengeance",
            "Vengeful",
            "Venom",
            "Vicious",
            "Victor",
            "Vile",
            "Vindication",
            "Vindicator",
            "Vindictive",
            "Void",
            "Volcanic",
            "Vowed",
            "War",
            "War-Forged",
            "Warden's",
            "Warlord's",
            "Warp",
            "Warped",
            "Warrior",
            "Warrior's",
            "Whistling",
            "Wicked",
            "Wind's",
            "Wind-Forged",
            "Windsong",
            "Woeful",
            "Wrathful",
            "Wretched",
            "Yearning",
            "Zealous",
        ]
        t3 = [
            "Tome",
            "Ledger",
            "Scroll",
            "Book",
            "Grimoire",
            "Compendium",
            "Manual",
            "Handbook",
            "Battletome",
            "Manuscript",
            "Lexicon",
            "Codex",
            "Syllabus",
            "Epitome",
            "Grimoire",
            "Book",
            "Scroll",
            "Tome",
        ]
        t4 = [
            "Tome",
            "Ledger",
            "Scroll",
            "Book",
            "Grimoire",
            "Compendium",
            "Manual",
            "Handbook",
            "Battletome",
            "Manuscript",
            "Lexicon",
            "Codex",
            "Syllabus",
            "Epitome",
            "Grimoire",
            "Book",
            "Scroll",
            "Tome",
            "Allegiance",
            "Annihilation",
            "Betrayer",
            "Bond",
            "Boon",
            "Breaker",
            "Bringer",
            "Bruiser",
            "Call",
            "Champion",
            "Conqueror",
            "Crusader",
            "Cry",
            "Cunning",
            "Dawn",
            "Defender",
            "Defiler",
            "Destroyer",
            "Destruction",
            "Edge",
            "Ender",
            "Executioner",
            "Fan",
            "Favor",
            "Ferocity",
            "Foe",
            "Gift",
            "Glory",
            "Guardian",
            "Heirloom",
            "Hope",
            "Incarnation",
            "Last Hope",
            "Last Stand",
            "Legacy",
            "Memory",
            "Might",
            "Oath",
            "Pact",
            "Pledge",
            "Promise",
            "Prophecy",
            "Protector",
            "Ravager",
            "Reach",
            "Sculptor",
            "Secret",
            "Slayer",
            "Soul",
            "Terror",
            "Token",
            "Touch",
            "Tribute",
            "Vengeance",
            "Voice",
            "Whisper",
            "Wit",
        ]
        t5 = [
            "of Agony",
            "of Ancient Power",
            "of Anguish",
            "of Ashes",
            "of Assassins",
            "of Black Magic",
            "of Blessed Fortune",
            "of Blessings",
            "of Blight",
            "of Blood",
            "of Bloodlust",
            "of Broken Bones",
            "of Broken Dreams",
            "of Broken Families",
            "of Burdens",
            "of Chaos",
            "of Closing Eyes",
            "of Conquered Worlds",
            "of Corruption",
            "of Cruelty",
            "of Cunning",
            "of Dark Magic",
            "of Dark Souls",
            "of Darkness",
            "of Decay",
            "of Deception",
            "of Degradation",
            "of Delusions",
            "of Denial",
            "of Desecration",
            "of Diligence",
            "of Dismay",
            "of Dragonsouls",
            "of Due Diligence",
            "of Echoes",
            "of Ended Dreams",
            "of Ending Hope",
            "of Ending Misery",
            "of Eternal Bloodlust",
            "of Eternal Damnation",
            "of Eternal Glory",
            "of Eternal Justice",
            "of Eternal Rest",
            "of Eternal Sorrow",
            "of Eternal Struggles",
            "of Eternity",
            "of Executions",
            "of Faded Memories",
            "of Fallen Souls",
            "of Fools",
            "of Frost",
            "of Frozen Hells",
            "of Fury",
            "of Giants",
            "of Giantslaying",
            "of Grace",
            "of Grieving Widows",
            "of Hate",
            "of Hatred",
            "of Hell's Games",
            "of Hellish Torment",
            "of Heroes",
            "of Holy Might",
            "of Honor",
            "of Hope",
            "of Horrid Dreams",
            "of Horrors",
            "of Illuminated Dreams",
            "of Illumination",
            "of Immortality",
            "of Inception",
            "of Infinite Trials",
            "of Insanity",
            "of Invocation",
            "of Justice",
            "of Light's Hope",
            "of Lost Comrades",
            "of Lost Hope",
            "of Lost Voices",
            "of Lost Worlds",
            "of Magic",
            "of Mercy",
            "of Misery",
            "of Mountains",
            "of Mourning",
            "of Mystery",
            "of Necromancy",
            "of Nightmares",
            "of Oblivion",
            "of Perdition",
            "of Phantoms",
            "of Power",
            "of Pride",
            "of Pride's Fall",
            "of Putrefaction",
            "of Reckoning",
            "of Redemption",
            "of Regret",
            "of Riddles",
            "of Secrecy",
            "of Secrets",
            "of Shadow Strikes",
            "of Shadows",
            "of Shifting Sands",
            "of Shifting Worlds",
            "of Silence",
            "of Slaughter",
            "of Souls",
            "of Stealth",
            "of Storms",
            "of Subtlety",
            "of Suffering",
            "of Suffering's End",
            "of Summoning",
            "of Terror",
            "of Thunder",
            "of Time-Lost Memories",
            "of Timeless Battles",
            "of Titans",
            "of Torment",
            "of Traitors",
            "of Trembling Hands",
            "of Trials",
            "of Truth",
            "of Twilight's End",
            "of Twisted Visions",
            "of Unholy Blight",
            "of Unholy Might",
            "of Vengeance",
            "of Visions",
            "of Wasted Time",
            "of Widows",
            "of Wizardry",
            "of Woe",
            "of Wraiths",
            "of Zeal",
            "of the Ancients",
            "of the Banished",
            "of the Basilisk",
            "of the Beast",
            "of the Blessed",
            "of the Breaking Storm",
            "of the Brotherhood",
            "of the Burning Sun",
            "of the Caged Mind",
            "of the Cataclysm",
            "of the Champion",
            "of the Claw",
            "of the Corrupted",
            "of the Covenant",
            "of the Crown",
            "of the Damned",
            "of the Daywalker",
            "of the Dead",
            "of the Depth",
            "of the Dreadlord",
            "of the Earth",
            "of the East",
            "of the Emperor",
            "of the Empty Void",
            "of the End",
            "of the Enigma",
            "of the Fallen",
            "of the Falling Sky",
            "of the Flame",
            "of the Forest",
            "of the Forgotten",
            "of the Forsaken",
            "of the Gladiator",
            "of the Harvest",
            "of the Immortal",
            "of the Incoming Storm",
            "of the Insane",
            "of the King",
            "of the Lasting Night",
            "of the Leviathan",
            "of the Light",
            "of the Lion",
            "of the Lionheart",
            "of the Lone Victor",
            "of the Lone Wolf",
            "of the Lost",
            "of the Moon",
            "of the Moonwalker",
            "of the Night Sky",
            "of the Night",
            "of the Nightstalker",
            "of the North",
            "of the Occult",
            "of the Oracle",
            "of the Phoenix",
            "of the Plague",
            "of the Prince",
            "of the Protector",
            "of the Queen",
            "of the Serpent",
            "of the Setting Sun",
            "of the Shadows",
            "of the Sky",
            "of the South",
            "of the Stars",
            "of the Storm",
            "of the Summoner",
            "of the Sun",
            "of the Sunwalker",
            "of the Talon",
            "of the Undying",
            "of the Victor",
            "of the Void",
            "of the West",
            "of the Whispers",
            "of the Wicked",
            "of the Wind",
            "of the Wolf",
            "of the World",
            "of the Wretched",
        ]
        num = randrange(3)
        if num == 0:
            return choice(t1)
        elif num == 1:
            return choice(t2) + " " + choice(t3)
        else:
            return choice(t1) + ", " + choice(t4) + " " + choice(t5)

    @staticmethod
    def generate(genre: BookType = None):
        if genre is None or genre not in Book.BookType:
            genre = choice(list(Book.BookType))

        if genre == Book.BookType.Children:
            return Book.Children()
        elif genre == Book.BookType.Drama:
            return Book.Drama()
        elif genre == Book.BookType.Fiction:
            return Book.Fiction()
        elif genre == Book.BookType.Horror:
            return Book.Horror()
        elif genre == Book.BookType.Humor:
            return Book.Humor()
        elif genre == Book.BookType.Mystery:
            return Book.Mystery()
        elif genre == Book.BookType.Nonfiction:
            return Book.Nonfiction()
        elif genre == Book.BookType.Romance:
            return Book.Romance()
        elif genre == Book.BookType.SciFi:
            return Book.SciFi()
        elif genre == Book.BookType.Tome:
            return Book.Tome()

    def __str__(self):
        return Book.generate()


class Relic(Item):
    class RelicType(StrEnum):
        Armor = auto()
        Book = auto()
        Potion = auto()
        Jewel = auto()
        Other = auto()

    @staticmethod
    def Armor():
        n1 = [
            "Absorbing",
            "Abundance",
            "Acrimony",
            "Affluence",
            "Agony",
            "All-Seeing",
            "Angels",
            "Annihilation",
            "Apathy",
            "Athanasia",
            "Bane",
            "Banishment",
            "Benediction",
            "Betrayal",
            "Binding",
            "Birth",
            "Black Magic",
            "Blessings",
            "Blights",
            "Blinding",
            "Chance",
            "Chaos",
            "Charming",
            "Collapse",
            "Contagion",
            "Corruption",
            "Courage",
            "Curses",
            "Damnation",
            "Darkness",
            "Death",
            "Decadence",
            "Decay",
            "Delirium",
            "Delusion",
            "Dementia",
            "Demons",
            "Depravity",
            "Desire",
            "Destiny",
            "Destruction",
            "Dismay",
            "Divinity",
            "Doom",
            "Downfall",
            "Dread",
            "Dreams",
            "Enigmas",
            "Enthrallment",
            "Eternal Health",
            "Eternal Slumber",
            "Eternity",
            "Evil",
            "Evils",
            "Exiles",
            "Faith",
            "Fate",
            "Fear",
            "Fertility",
            "Fire",
            "Flame",
            "Fortitude",
            "Fortuity",
            "Fortune",
            "Frost",
            "Futures",
            "Genesis",
            "Gluttony",
            "Gold",
            "Grace",
            "Greed",
            "Guardians",
            "Hatred",
            "Healing",
            "Hell",
            "Heroism",
            "Honesty",
            "Hunger",
            "Ice",
            "Immobilizing",
            "Immortality",
            "Immunity",
            "Imperviousness",
            "Infinity",
            "Invincibility",
            "Invisibility",
            "Invocation",
            "Judgment",
            "Justice",
            "Karma",
            "Knowledge",
            "Liberation",
            "Life",
            "Lifeblood",
            "Light",
            "Lightness",
            "Lightning",
            "Longevity",
            "Loyalty",
            "Luck",
            "Luminosity",
            "Lunacy",
            "Lust",
            "Malady",
            "Malediction",
            "Malevolence",
            "Malice",
            "Mania",
            "Massacres",
            "Mending",
            "Metamorphosis",
            "Misery",
            "Misfortune",
            "Mysteries",
            "Nightmares",
            "Oaths",
            "Oblivion",
            "Origins",
            "Pain",
            "Paradise",
            "Paralysis",
            "Passion",
            "Peace",
            "Persecution",
            "Pestilence",
            "Petrification",
            "Potency",
            "Prosperity",
            "Protection",
            "Radiance",
            "Rain",
            "Rebirth",
            "Remedies",
            "Repelling",
            "Resistance",
            "Restoration",
            "Resurrection",
            "Revival",
            "Riches",
            "Riddles",
            "Ruination",
            "Runes",
            "Sanctification",
            "Sanctity",
            "Scorching",
            "Secrets",
            "Seduction",
            "Sentience",
            "Serendipity",
            "Service",
            "Shadows",
            "Shapeshifting",
            "Sight",
            "Silence",
            "Sleep",
            "Solitude",
            "Souls",
            "Specters",
            "Speed",
            "Spellbinding",
            "Spells",
            "Spirits",
            "Spite",
            "Storms",
            "Strength",
            "Summoning",
            "Teleportation",
            "Temptation",
            "Time",
            "Torment",
            "Torture",
            "Toxin",
            "Transformation",
            "Transmutation",
            "Treachery",
            "Truth",
            "Valor",
            "Vengeance",
            "Venom",
            "Vice",
            "Virility",
            "Warding",
            "Wealth",
            "Wisdom",
            "Wishes",
            "Worship",
            "Youth",
            "the Aether",
            "the Cosmos",
            "the Creed",
            "the Crux",
            "the Dead",
            "the Elements",
            "the Gods",
            "the Heavens",
            "the Occult",
            "the Oracle",
            "the Scourge",
            "the Titans",
            "the Void",
        ]
        n2 = [
            "Absorbing",
            "Aethereal",
            "Agony",
            "Alchemy",
            "All-Seeing",
            "Almighty",
            "Anarchy",
            "Angel",
            "Anguish",
            "Annihilation",
            "Archangel",
            "Athanasia",
            "Aurora",
            "Azure",
            "Banishing",
            "Benediction",
            "Binding",
            "Black Magic",
            "Blazing",
            "Blight",
            "Blinding",
            "Bravery",
            "Burning",
            "Celestial",
            "Chaos",
            "Charming",
            "Contagion",
            "Corruption",
            "Curse",
            "Cursed",
            "Damnation",
            "Darkness",
            "Death's",
            "Decay",
            "Decimation",
            "Delirium",
            "Delusion",
            "Dementia",
            "Demon",
            "Demonic",
            "Desire's",
            "Destiny's",
            "Destruction",
            "Devotion",
            "Diabolic",
            "Divine",
            "Divinity's",
            "Dominance",
            "Domination",
            "Dominion",
            "Doom",
            "Dread",
            "Dream",
            "Echo",
            "Eclipse",
            "Elemental",
            "Enigma",
            "Enigmatic",
            "Equinox",
            "Eradication",
            "Eternal",
            "Eternity",
            "Evil",
            "Exile",
            "Exiled",
            "Extinction",
            "Faith's",
            "Fate's",
            "Finality",
            "Fire",
            "Flame",
            "Fortitude",
            "Fortune's",
            "Frost",
            "Genesis",
            "Gold",
            "Golden",
            "Grave",
            "Guardian",
            "Guardian's",
            "Hallowed",
            "Hatred's",
            "Healing",
            "Heavenly",
            "Hell's",
            "Hellish",
            "Hero",
            "Hero's",
            "Holy",
            "Hungering",
            "Ice",
            "Immortal",
            "Immunity",
            "Impurity",
            "Infernal",
            "Infinity",
            "Insanity",
            "Invincibility",
            "Invisibility",
            "Invisible",
            "Isolation",
            "Judging",
            "Judgment",
            "Justice",
            "Karma",
            "Kismet",
            "Liberty",
            "Life",
            "Life's",
            "Lifeblood",
            "Light's",
            "Longevity",
            "Lucky",
            "Lust's",
            "Malady",
            "Malediction",
            "Malevolence",
            "Maniacal",
            "Massacre",
            "Mending",
            "Metamorphosis",
            "Mirage",
            "Misery",
            "Misfortune",
            "Mystery",
            "Necrotic",
            "Nightmare",
            "Obedience",
            "Oblivion",
            "Obsidian",
            "Onyx",
            "Oracle",
            "Pandemonium",
            "Paradise",
            "Paragon",
            "Paralyzing",
            "Paramount",
            "Pestilence",
            "Petrifying",
            "Philosopher's",
            "Primal",
            "Prime",
            "Prosperous",
            "Purity",
            "Rebirth",
            "Resistance",
            "Resolution",
            "Restoration",
            "Resurrection",
            "Rogue",
            "Runed",
            "Sacred",
            "Sanctifying",
            "Scourge",
            "Seduction",
            "Sentient",
            "Seraphic",
            "Serenity",
            "Shade",
            "Shadow",
            "Shapeshifter",
            "Shapeshifter's",
            "Slumber",
            "Solitude's",
            "Soul",
            "Specter",
            "Spellbound",
            "Spirit",
            "Spiritbound",
            "Spite",
            "Storm",
            "Summoning",
            "Supremacy",
            "Teleportation",
            "Teleporting",
            "Temptation",
            "Termination",
            "Thaumaturgy",
            "Thunder",
            "Titan",
            "Torment",
            "Torture",
            "Tranquility",
            "Transformation",
            "Transmutation",
            "Tribute",
            "Triumph",
            "Truth",
            "Twilight",
            "Unholy",
            "Valor",
            "Valor's",
            "Vengeance",
            "Venom",
            "Vice",
            "Virility",
            "Virtue",
            "Void",
            "Warding",
            "Wisdom",
            "Worshop",
        ]
        n3 = [
            "Amulet",
            "Band",
            "Boots",
            "Sandals",
            "Bracelet",
            "Chest",
            "Cloak",
            "Fleece",
            "Gauntlet",
            "Hand",
            "Hide",
            "Mantle",
            "Mask",
            "Ring",
            "Robes",
            "Shield",
        ]
        if randrange(2):
            return choice(n3) + " of " + choice(n1)
        else:
            return choice(n2) + " " + choice(n3)

    @staticmethod
    def Book():
        n1 = [
            "Absorbing",
            "Abundance",
            "Acrimony",
            "Affluence",
            "Agony",
            "All-Seeing",
            "Angels",
            "Annihilation",
            "Apathy",
            "Athanasia",
            "Bane",
            "Banishment",
            "Benediction",
            "Betrayal",
            "Binding",
            "Birth",
            "Black Magic",
            "Blessings",
            "Blights",
            "Blinding",
            "Chance",
            "Chaos",
            "Charming",
            "Collapse",
            "Contagion",
            "Corruption",
            "Courage",
            "Curses",
            "Damnation",
            "Darkness",
            "Death",
            "Decadence",
            "Decay",
            "Delirium",
            "Delusion",
            "Dementia",
            "Demons",
            "Depravity",
            "Desire",
            "Destiny",
            "Destruction",
            "Dismay",
            "Divinity",
            "Doom",
            "Downfall",
            "Dread",
            "Dreams",
            "Enigmas",
            "Enthrallment",
            "Eternal Health",
            "Eternal Slumber",
            "Eternity",
            "Evil",
            "Evils",
            "Exiles",
            "Faith",
            "Fate",
            "Fear",
            "Fertility",
            "Fire",
            "Flame",
            "Fortitude",
            "Fortuity",
            "Fortune",
            "Frost",
            "Futures",
            "Genesis",
            "Gluttony",
            "Gold",
            "Grace",
            "Greed",
            "Guardians",
            "Hatred",
            "Healing",
            "Hell",
            "Heroism",
            "Honesty",
            "Hunger",
            "Ice",
            "Immobilizing",
            "Immortality",
            "Immunity",
            "Imperviousness",
            "Infinity",
            "Invincibility",
            "Invisibility",
            "Invocation",
            "Judgment",
            "Justice",
            "Karma",
            "Knowledge",
            "Liberation",
            "Life",
            "Lifeblood",
            "Light",
            "Lightness",
            "Lightning",
            "Longevity",
            "Loyalty",
            "Luck",
            "Luminosity",
            "Lunacy",
            "Lust",
            "Malady",
            "Malediction",
            "Malevolence",
            "Malice",
            "Mania",
            "Massacres",
            "Mending",
            "Metamorphosis",
            "Misery",
            "Misfortune",
            "Mysteries",
            "Nightmares",
            "Oaths",
            "Oblivion",
            "Origins",
            "Pain",
            "Paradise",
            "Paralysis",
            "Passion",
            "Peace",
            "Persecution",
            "Pestilence",
            "Petrification",
            "Potency",
            "Prosperity",
            "Protection",
            "Radiance",
            "Rain",
            "Rebirth",
            "Remedies",
            "Repelling",
            "Resistance",
            "Restoration",
            "Resurrection",
            "Revival",
            "Riches",
            "Riddles",
            "Ruination",
            "Runes",
            "Sanctification",
            "Sanctity",
            "Scorching",
            "Secrets",
            "Seduction",
            "Sentience",
            "Serendipity",
            "Service",
            "Shadows",
            "Shapeshifting",
            "Sight",
            "Silence",
            "Sleep",
            "Solitude",
            "Souls",
            "Specters",
            "Speed",
            "Spellbinding",
            "Spells",
            "Spirits",
            "Spite",
            "Storms",
            "Strength",
            "Summoning",
            "Teleportation",
            "Temptation",
            "Time",
            "Torment",
            "Torture",
            "Toxin",
            "Transformation",
            "Transmutation",
            "Treachery",
            "Truth",
            "Valor",
            "Vengeance",
            "Venom",
            "Vice",
            "Virility",
            "Warding",
            "Wealth",
            "Wisdom",
            "Wishes",
            "Worship",
            "Youth",
            "the Aether",
            "the Cosmos",
            "the Creed",
            "the Crux",
            "the Dead",
            "the Elements",
            "the Gods",
            "the Heavens",
            "the Occult",
            "the Oracle",
            "the Scourge",
            "the Titans",
            "the Void",
        ]
        n2 = [
            "Absorbing",
            "Aethereal",
            "Agony",
            "Alchemy",
            "All-Seeing",
            "Almighty",
            "Anarchy",
            "Angel",
            "Anguish",
            "Annihilation",
            "Archangel",
            "Athanasia",
            "Aurora",
            "Azure",
            "Banishing",
            "Benediction",
            "Binding",
            "Black Magic",
            "Blazing",
            "Blight",
            "Blinding",
            "Bravery",
            "Burning",
            "Celestial",
            "Chaos",
            "Charming",
            "Contagion",
            "Corruption",
            "Curse",
            "Cursed",
            "Damnation",
            "Darkness",
            "Death's",
            "Decay",
            "Decimation",
            "Delirium",
            "Delusion",
            "Dementia",
            "Demon",
            "Demonic",
            "Desire's",
            "Destiny's",
            "Destruction",
            "Devotion",
            "Diabolic",
            "Divine",
            "Divinity's",
            "Dominance",
            "Domination",
            "Dominion",
            "Doom",
            "Dread",
            "Dream",
            "Echo",
            "Eclipse",
            "Elemental",
            "Enigma",
            "Enigmatic",
            "Equinox",
            "Eradication",
            "Eternal",
            "Eternity",
            "Evil",
            "Exile",
            "Exiled",
            "Extinction",
            "Faith's",
            "Fate's",
            "Finality",
            "Fire",
            "Flame",
            "Fortitude",
            "Fortune's",
            "Frost",
            "Genesis",
            "Gold",
            "Golden",
            "Grave",
            "Guardian",
            "Guardian's",
            "Hallowed",
            "Hatred's",
            "Healing",
            "Heavenly",
            "Hell's",
            "Hellish",
            "Hero",
            "Hero's",
            "Holy",
            "Hungering",
            "Ice",
            "Immortal",
            "Immunity",
            "Impurity",
            "Infernal",
            "Infinity",
            "Insanity",
            "Invincibility",
            "Invisibility",
            "Invisible",
            "Isolation",
            "Judging",
            "Judgment",
            "Justice",
            "Karma",
            "Kismet",
            "Liberty",
            "Life",
            "Life's",
            "Lifeblood",
            "Light's",
            "Longevity",
            "Lucky",
            "Lust's",
            "Malady",
            "Malediction",
            "Malevolence",
            "Maniacal",
            "Massacre",
            "Mending",
            "Metamorphosis",
            "Mirage",
            "Misery",
            "Misfortune",
            "Mystery",
            "Necrotic",
            "Nightmare",
            "Obedience",
            "Oblivion",
            "Obsidian",
            "Onyx",
            "Oracle",
            "Pandemonium",
            "Paradise",
            "Paragon",
            "Paralyzing",
            "Paramount",
            "Pestilence",
            "Petrifying",
            "Philosopher's",
            "Primal",
            "Prime",
            "Prosperous",
            "Purity",
            "Rebirth",
            "Resistance",
            "Resolution",
            "Restoration",
            "Resurrection",
            "Rogue",
            "Runed",
            "Sacred",
            "Sanctifying",
            "Scourge",
            "Seduction",
            "Sentient",
            "Seraphic",
            "Serenity",
            "Shade",
            "Shadow",
            "Shapeshifter",
            "Shapeshifter's",
            "Slumber",
            "Solitude's",
            "Soul",
            "Specter",
            "Spellbound",
            "Spirit",
            "Spiritbound",
            "Spite",
            "Storm",
            "Summoning",
            "Supremacy",
            "Teleportation",
            "Teleporting",
            "Temptation",
            "Termination",
            "Thaumaturgy",
            "Thunder",
            "Titan",
            "Torment",
            "Torture",
            "Tranquility",
            "Transformation",
            "Transmutation",
            "Tribute",
            "Triumph",
            "Truth",
            "Twilight",
            "Unholy",
            "Valor",
            "Valor's",
            "Vengeance",
            "Venom",
            "Vice",
            "Virility",
            "Virtue",
            "Void",
            "Warding",
            "Wisdom",
            "Worshop",
        ]
        n3 = [
            "Book",
            "Grimoire",
            "Inscriptions",
            "Instrument",
            "Letters",
            "Runes",
            "Scroll",
            "Symbols",
            "Tablet",
            "Texts",
            "Slab",
            "Tome",
        ]

        if randrange(2):
            return choice(n3) + " of " + choice(n1)
        else:
            return choice(n2) + " " + choice(n3)

    @staticmethod
    def Potion():
        n1 = [
            "Absorbing",
            "Abundance",
            "Acrimony",
            "Affluence",
            "Agony",
            "All-Seeing",
            "Angels",
            "Annihilation",
            "Apathy",
            "Athanasia",
            "Bane",
            "Banishment",
            "Benediction",
            "Betrayal",
            "Binding",
            "Birth",
            "Black Magic",
            "Blessings",
            "Blights",
            "Blinding",
            "Chance",
            "Chaos",
            "Charming",
            "Collapse",
            "Contagion",
            "Corruption",
            "Courage",
            "Curses",
            "Damnation",
            "Darkness",
            "Death",
            "Decadence",
            "Decay",
            "Delirium",
            "Delusion",
            "Dementia",
            "Demons",
            "Depravity",
            "Desire",
            "Destiny",
            "Destruction",
            "Dismay",
            "Divinity",
            "Doom",
            "Downfall",
            "Dread",
            "Dreams",
            "Enigmas",
            "Enthrallment",
            "Eternal Health",
            "Eternal Slumber",
            "Eternity",
            "Evil",
            "Evils",
            "Exiles",
            "Faith",
            "Fate",
            "Fear",
            "Fertility",
            "Fire",
            "Flame",
            "Fortitude",
            "Fortuity",
            "Fortune",
            "Frost",
            "Futures",
            "Genesis",
            "Gluttony",
            "Gold",
            "Grace",
            "Greed",
            "Guardians",
            "Hatred",
            "Healing",
            "Hell",
            "Heroism",
            "Honesty",
            "Hunger",
            "Ice",
            "Immobilizing",
            "Immortality",
            "Immunity",
            "Imperviousness",
            "Infinity",
            "Invincibility",
            "Invisibility",
            "Invocation",
            "Judgment",
            "Justice",
            "Karma",
            "Knowledge",
            "Liberation",
            "Life",
            "Lifeblood",
            "Light",
            "Lightness",
            "Lightning",
            "Longevity",
            "Loyalty",
            "Luck",
            "Luminosity",
            "Lunacy",
            "Lust",
            "Malady",
            "Malediction",
            "Malevolence",
            "Malice",
            "Mania",
            "Massacres",
            "Mending",
            "Metamorphosis",
            "Misery",
            "Misfortune",
            "Mysteries",
            "Nightmares",
            "Oaths",
            "Oblivion",
            "Origins",
            "Pain",
            "Paradise",
            "Paralysis",
            "Passion",
            "Peace",
            "Persecution",
            "Pestilence",
            "Petrification",
            "Potency",
            "Prosperity",
            "Protection",
            "Radiance",
            "Rain",
            "Rebirth",
            "Remedies",
            "Repelling",
            "Resistance",
            "Restoration",
            "Resurrection",
            "Revival",
            "Riches",
            "Riddles",
            "Ruination",
            "Runes",
            "Sanctification",
            "Sanctity",
            "Scorching",
            "Secrets",
            "Seduction",
            "Sentience",
            "Serendipity",
            "Service",
            "Shadows",
            "Shapeshifting",
            "Sight",
            "Silence",
            "Sleep",
            "Solitude",
            "Souls",
            "Specters",
            "Speed",
            "Spellbinding",
            "Spells",
            "Spirits",
            "Spite",
            "Storms",
            "Strength",
            "Summoning",
            "Teleportation",
            "Temptation",
            "Time",
            "Torment",
            "Torture",
            "Toxin",
            "Transformation",
            "Transmutation",
            "Treachery",
            "Truth",
            "Valor",
            "Vengeance",
            "Venom",
            "Vice",
            "Virility",
            "Warding",
            "Wealth",
            "Wisdom",
            "Wishes",
            "Worship",
            "Youth",
            "the Aether",
            "the Cosmos",
            "the Creed",
            "the Crux",
            "the Dead",
            "the Elements",
            "the Gods",
            "the Heavens",
            "the Occult",
            "the Oracle",
            "the Scourge",
            "the Titans",
            "the Void",
        ]
        n2 = [
            "Absorbing",
            "Aethereal",
            "Agony",
            "Alchemy",
            "All-Seeing",
            "Almighty",
            "Anarchy",
            "Angel",
            "Anguish",
            "Annihilation",
            "Archangel",
            "Athanasia",
            "Aurora",
            "Azure",
            "Banishing",
            "Benediction",
            "Binding",
            "Black Magic",
            "Blazing",
            "Blight",
            "Blinding",
            "Bravery",
            "Burning",
            "Celestial",
            "Chaos",
            "Charming",
            "Contagion",
            "Corruption",
            "Curse",
            "Cursed",
            "Damnation",
            "Darkness",
            "Death's",
            "Decay",
            "Decimation",
            "Delirium",
            "Delusion",
            "Dementia",
            "Demon",
            "Demonic",
            "Desire's",
            "Destiny's",
            "Destruction",
            "Devotion",
            "Diabolic",
            "Divine",
            "Divinity's",
            "Dominance",
            "Domination",
            "Dominion",
            "Doom",
            "Dread",
            "Dream",
            "Echo",
            "Eclipse",
            "Elemental",
            "Enigma",
            "Enigmatic",
            "Equinox",
            "Eradication",
            "Eternal",
            "Eternity",
            "Evil",
            "Exile",
            "Exiled",
            "Extinction",
            "Faith's",
            "Fate's",
            "Finality",
            "Fire",
            "Flame",
            "Fortitude",
            "Fortune's",
            "Frost",
            "Genesis",
            "Gold",
            "Golden",
            "Grave",
            "Guardian",
            "Guardian's",
            "Hallowed",
            "Hatred's",
            "Healing",
            "Heavenly",
            "Hell's",
            "Hellish",
            "Hero",
            "Hero's",
            "Holy",
            "Hungering",
            "Ice",
            "Immortal",
            "Immunity",
            "Impurity",
            "Infernal",
            "Infinity",
            "Insanity",
            "Invincibility",
            "Invisibility",
            "Invisible",
            "Isolation",
            "Judging",
            "Judgment",
            "Justice",
            "Karma",
            "Kismet",
            "Liberty",
            "Life",
            "Life's",
            "Lifeblood",
            "Light's",
            "Longevity",
            "Lucky",
            "Lust's",
            "Malady",
            "Malediction",
            "Malevolence",
            "Maniacal",
            "Massacre",
            "Mending",
            "Metamorphosis",
            "Mirage",
            "Misery",
            "Misfortune",
            "Mystery",
            "Necrotic",
            "Nightmare",
            "Obedience",
            "Oblivion",
            "Obsidian",
            "Onyx",
            "Oracle",
            "Pandemonium",
            "Paradise",
            "Paragon",
            "Paralyzing",
            "Paramount",
            "Pestilence",
            "Petrifying",
            "Philosopher's",
            "Primal",
            "Prime",
            "Prosperous",
            "Purity",
            "Rebirth",
            "Resistance",
            "Resolution",
            "Restoration",
            "Resurrection",
            "Rogue",
            "Runed",
            "Sacred",
            "Sanctifying",
            "Scourge",
            "Seduction",
            "Sentient",
            "Seraphic",
            "Serenity",
            "Shade",
            "Shadow",
            "Shapeshifter",
            "Shapeshifter's",
            "Slumber",
            "Solitude's",
            "Soul",
            "Specter",
            "Spellbound",
            "Spirit",
            "Spiritbound",
            "Spite",
            "Storm",
            "Summoning",
            "Supremacy",
            "Teleportation",
            "Teleporting",
            "Temptation",
            "Termination",
            "Thaumaturgy",
            "Thunder",
            "Titan",
            "Torment",
            "Torture",
            "Tranquility",
            "Transformation",
            "Transmutation",
            "Tribute",
            "Triumph",
            "Truth",
            "Twilight",
            "Unholy",
            "Valor",
            "Valor's",
            "Vengeance",
            "Venom",
            "Vice",
            "Virility",
            "Virtue",
            "Void",
            "Warding",
            "Wisdom",
            "Worshop",
        ]
        n3 = ["Canopic Jar", "Elixir", "Fountain", "Ichor", "Tincture"]

        if randrange(2):
            return choice(n3) + " of " + choice(n1)
        else:
            return choice(n2) + " " + choice(n3)

    @staticmethod
    def Jewel():
        n1 = [
            "Absorbing",
            "Abundance",
            "Acrimony",
            "Affluence",
            "Agony",
            "All-Seeing",
            "Angels",
            "Annihilation",
            "Apathy",
            "Athanasia",
            "Bane",
            "Banishment",
            "Benediction",
            "Betrayal",
            "Binding",
            "Birth",
            "Black Magic",
            "Blessings",
            "Blights",
            "Blinding",
            "Chance",
            "Chaos",
            "Charming",
            "Collapse",
            "Contagion",
            "Corruption",
            "Courage",
            "Curses",
            "Damnation",
            "Darkness",
            "Death",
            "Decadence",
            "Decay",
            "Delirium",
            "Delusion",
            "Dementia",
            "Demons",
            "Depravity",
            "Desire",
            "Destiny",
            "Destruction",
            "Dismay",
            "Divinity",
            "Doom",
            "Downfall",
            "Dread",
            "Dreams",
            "Enigmas",
            "Enthrallment",
            "Eternal Health",
            "Eternal Slumber",
            "Eternity",
            "Evil",
            "Evils",
            "Exiles",
            "Faith",
            "Fate",
            "Fear",
            "Fertility",
            "Fire",
            "Flame",
            "Fortitude",
            "Fortuity",
            "Fortune",
            "Frost",
            "Futures",
            "Genesis",
            "Gluttony",
            "Gold",
            "Grace",
            "Greed",
            "Guardians",
            "Hatred",
            "Healing",
            "Hell",
            "Heroism",
            "Honesty",
            "Hunger",
            "Ice",
            "Immobilizing",
            "Immortality",
            "Immunity",
            "Imperviousness",
            "Infinity",
            "Invincibility",
            "Invisibility",
            "Invocation",
            "Judgment",
            "Justice",
            "Karma",
            "Knowledge",
            "Liberation",
            "Life",
            "Lifeblood",
            "Light",
            "Lightness",
            "Lightning",
            "Longevity",
            "Loyalty",
            "Luck",
            "Luminosity",
            "Lunacy",
            "Lust",
            "Malady",
            "Malediction",
            "Malevolence",
            "Malice",
            "Mania",
            "Massacres",
            "Mending",
            "Metamorphosis",
            "Misery",
            "Misfortune",
            "Mysteries",
            "Nightmares",
            "Oaths",
            "Oblivion",
            "Origins",
            "Pain",
            "Paradise",
            "Paralysis",
            "Passion",
            "Peace",
            "Persecution",
            "Pestilence",
            "Petrification",
            "Potency",
            "Prosperity",
            "Protection",
            "Radiance",
            "Rain",
            "Rebirth",
            "Remedies",
            "Repelling",
            "Resistance",
            "Restoration",
            "Resurrection",
            "Revival",
            "Riches",
            "Riddles",
            "Ruination",
            "Runes",
            "Sanctification",
            "Sanctity",
            "Scorching",
            "Secrets",
            "Seduction",
            "Sentience",
            "Serendipity",
            "Service",
            "Shadows",
            "Shapeshifting",
            "Sight",
            "Silence",
            "Sleep",
            "Solitude",
            "Souls",
            "Specters",
            "Speed",
            "Spellbinding",
            "Spells",
            "Spirits",
            "Spite",
            "Storms",
            "Strength",
            "Summoning",
            "Teleportation",
            "Temptation",
            "Time",
            "Torment",
            "Torture",
            "Toxin",
            "Transformation",
            "Transmutation",
            "Treachery",
            "Truth",
            "Valor",
            "Vengeance",
            "Venom",
            "Vice",
            "Virility",
            "Warding",
            "Wealth",
            "Wisdom",
            "Wishes",
            "Worship",
            "Youth",
            "the Aether",
            "the Cosmos",
            "the Creed",
            "the Crux",
            "the Dead",
            "the Elements",
            "the Gods",
            "the Heavens",
            "the Occult",
            "the Oracle",
            "the Scourge",
            "the Titans",
            "the Void",
        ]
        n2 = [
            "Absorbing",
            "Aethereal",
            "Agony",
            "Alchemy",
            "All-Seeing",
            "Almighty",
            "Anarchy",
            "Angel",
            "Anguish",
            "Annihilation",
            "Archangel",
            "Athanasia",
            "Aurora",
            "Azure",
            "Banishing",
            "Benediction",
            "Binding",
            "Black Magic",
            "Blazing",
            "Blight",
            "Blinding",
            "Bravery",
            "Burning",
            "Celestial",
            "Chaos",
            "Charming",
            "Contagion",
            "Corruption",
            "Curse",
            "Cursed",
            "Damnation",
            "Darkness",
            "Death's",
            "Decay",
            "Decimation",
            "Delirium",
            "Delusion",
            "Dementia",
            "Demon",
            "Demonic",
            "Desire's",
            "Destiny's",
            "Destruction",
            "Devotion",
            "Diabolic",
            "Divine",
            "Divinity's",
            "Dominance",
            "Domination",
            "Dominion",
            "Doom",
            "Dread",
            "Dream",
            "Echo",
            "Eclipse",
            "Elemental",
            "Enigma",
            "Enigmatic",
            "Equinox",
            "Eradication",
            "Eternal",
            "Eternity",
            "Evil",
            "Exile",
            "Exiled",
            "Extinction",
            "Faith's",
            "Fate's",
            "Finality",
            "Fire",
            "Flame",
            "Fortitude",
            "Fortune's",
            "Frost",
            "Genesis",
            "Gold",
            "Golden",
            "Grave",
            "Guardian",
            "Guardian's",
            "Hallowed",
            "Hatred's",
            "Healing",
            "Heavenly",
            "Hell's",
            "Hellish",
            "Hero",
            "Hero's",
            "Holy",
            "Hungering",
            "Ice",
            "Immortal",
            "Immunity",
            "Impurity",
            "Infernal",
            "Infinity",
            "Insanity",
            "Invincibility",
            "Invisibility",
            "Invisible",
            "Isolation",
            "Judging",
            "Judgment",
            "Justice",
            "Karma",
            "Kismet",
            "Liberty",
            "Life",
            "Life's",
            "Lifeblood",
            "Light's",
            "Longevity",
            "Lucky",
            "Lust's",
            "Malady",
            "Malediction",
            "Malevolence",
            "Maniacal",
            "Massacre",
            "Mending",
            "Metamorphosis",
            "Mirage",
            "Misery",
            "Misfortune",
            "Mystery",
            "Necrotic",
            "Nightmare",
            "Obedience",
            "Oblivion",
            "Obsidian",
            "Onyx",
            "Oracle",
            "Pandemonium",
            "Paradise",
            "Paragon",
            "Paralyzing",
            "Paramount",
            "Pestilence",
            "Petrifying",
            "Philosopher's",
            "Primal",
            "Prime",
            "Prosperous",
            "Purity",
            "Rebirth",
            "Resistance",
            "Resolution",
            "Restoration",
            "Resurrection",
            "Rogue",
            "Runed",
            "Sacred",
            "Sanctifying",
            "Scourge",
            "Seduction",
            "Sentient",
            "Seraphic",
            "Serenity",
            "Shade",
            "Shadow",
            "Shapeshifter",
            "Shapeshifter's",
            "Slumber",
            "Solitude's",
            "Soul",
            "Specter",
            "Spellbound",
            "Spirit",
            "Spiritbound",
            "Spite",
            "Storm",
            "Summoning",
            "Supremacy",
            "Teleportation",
            "Teleporting",
            "Temptation",
            "Termination",
            "Thaumaturgy",
            "Thunder",
            "Titan",
            "Torment",
            "Torture",
            "Tranquility",
            "Transformation",
            "Transmutation",
            "Tribute",
            "Triumph",
            "Truth",
            "Twilight",
            "Unholy",
            "Valor",
            "Valor's",
            "Vengeance",
            "Venom",
            "Vice",
            "Virility",
            "Virtue",
            "Void",
            "Warding",
            "Wisdom",
            "Worshop",
        ]
        n3 = ["Crown", "Tiara", "Circlet", "Gem", "Necklace", "Stone"]

        if randrange(2):
            return choice(n3) + " of " + choice(n1)
        else:
            return choice(n2) + " " + choice(n3)

    @staticmethod
    def Other():
        n1 = [
            "Absorbing",
            "Abundance",
            "Acrimony",
            "Affluence",
            "Agony",
            "All-Seeing",
            "Angels",
            "Annihilation",
            "Apathy",
            "Athanasia",
            "Bane",
            "Banishment",
            "Benediction",
            "Betrayal",
            "Binding",
            "Birth",
            "Black Magic",
            "Blessings",
            "Blights",
            "Blinding",
            "Chance",
            "Chaos",
            "Charming",
            "Collapse",
            "Contagion",
            "Corruption",
            "Courage",
            "Curses",
            "Damnation",
            "Darkness",
            "Death",
            "Decadence",
            "Decay",
            "Delirium",
            "Delusion",
            "Dementia",
            "Demons",
            "Depravity",
            "Desire",
            "Destiny",
            "Destruction",
            "Dismay",
            "Divinity",
            "Doom",
            "Downfall",
            "Dread",
            "Dreams",
            "Enigmas",
            "Enthrallment",
            "Eternal Health",
            "Eternal Slumber",
            "Eternity",
            "Evil",
            "Evils",
            "Exiles",
            "Faith",
            "Fate",
            "Fear",
            "Fertility",
            "Fire",
            "Flame",
            "Fortitude",
            "Fortuity",
            "Fortune",
            "Frost",
            "Futures",
            "Genesis",
            "Gluttony",
            "Gold",
            "Grace",
            "Greed",
            "Guardians",
            "Hatred",
            "Healing",
            "Hell",
            "Heroism",
            "Honesty",
            "Hunger",
            "Ice",
            "Immobilizing",
            "Immortality",
            "Immunity",
            "Imperviousness",
            "Infinity",
            "Invincibility",
            "Invisibility",
            "Invocation",
            "Judgment",
            "Justice",
            "Karma",
            "Knowledge",
            "Liberation",
            "Life",
            "Lifeblood",
            "Light",
            "Lightness",
            "Lightning",
            "Longevity",
            "Loyalty",
            "Luck",
            "Luminosity",
            "Lunacy",
            "Lust",
            "Malady",
            "Malediction",
            "Malevolence",
            "Malice",
            "Mania",
            "Massacres",
            "Mending",
            "Metamorphosis",
            "Misery",
            "Misfortune",
            "Mysteries",
            "Nightmares",
            "Oaths",
            "Oblivion",
            "Origins",
            "Pain",
            "Paradise",
            "Paralysis",
            "Passion",
            "Peace",
            "Persecution",
            "Pestilence",
            "Petrification",
            "Potency",
            "Prosperity",
            "Protection",
            "Radiance",
            "Rain",
            "Rebirth",
            "Remedies",
            "Repelling",
            "Resistance",
            "Restoration",
            "Resurrection",
            "Revival",
            "Riches",
            "Riddles",
            "Ruination",
            "Runes",
            "Sanctification",
            "Sanctity",
            "Scorching",
            "Secrets",
            "Seduction",
            "Sentience",
            "Serendipity",
            "Service",
            "Shadows",
            "Shapeshifting",
            "Sight",
            "Silence",
            "Sleep",
            "Solitude",
            "Souls",
            "Specters",
            "Speed",
            "Spellbinding",
            "Spells",
            "Spirits",
            "Spite",
            "Storms",
            "Strength",
            "Summoning",
            "Teleportation",
            "Temptation",
            "Time",
            "Torment",
            "Torture",
            "Toxin",
            "Transformation",
            "Transmutation",
            "Treachery",
            "Truth",
            "Valor",
            "Vengeance",
            "Venom",
            "Vice",
            "Virility",
            "Warding",
            "Wealth",
            "Wisdom",
            "Wishes",
            "Worship",
            "Youth",
            "the Aether",
            "the Cosmos",
            "the Creed",
            "the Crux",
            "the Dead",
            "the Elements",
            "the Gods",
            "the Heavens",
            "the Occult",
            "the Oracle",
            "the Scourge",
            "the Titans",
            "the Void",
        ]
        n2 = [
            "Absorbing",
            "Aethereal",
            "Agony",
            "Alchemy",
            "All-Seeing",
            "Almighty",
            "Anarchy",
            "Angel",
            "Anguish",
            "Annihilation",
            "Archangel",
            "Athanasia",
            "Aurora",
            "Azure",
            "Banishing",
            "Benediction",
            "Binding",
            "Black Magic",
            "Blazing",
            "Blight",
            "Blinding",
            "Bravery",
            "Burning",
            "Celestial",
            "Chaos",
            "Charming",
            "Contagion",
            "Corruption",
            "Curse",
            "Cursed",
            "Damnation",
            "Darkness",
            "Death's",
            "Decay",
            "Decimation",
            "Delirium",
            "Delusion",
            "Dementia",
            "Demon",
            "Demonic",
            "Desire's",
            "Destiny's",
            "Destruction",
            "Devotion",
            "Diabolic",
            "Divine",
            "Divinity's",
            "Dominance",
            "Domination",
            "Dominion",
            "Doom",
            "Dread",
            "Dream",
            "Echo",
            "Eclipse",
            "Elemental",
            "Enigma",
            "Enigmatic",
            "Equinox",
            "Eradication",
            "Eternal",
            "Eternity",
            "Evil",
            "Exile",
            "Exiled",
            "Extinction",
            "Faith's",
            "Fate's",
            "Finality",
            "Fire",
            "Flame",
            "Fortitude",
            "Fortune's",
            "Frost",
            "Genesis",
            "Gold",
            "Golden",
            "Grave",
            "Guardian",
            "Guardian's",
            "Hallowed",
            "Hatred's",
            "Healing",
            "Heavenly",
            "Hell's",
            "Hellish",
            "Hero",
            "Hero's",
            "Holy",
            "Hungering",
            "Ice",
            "Immortal",
            "Immunity",
            "Impurity",
            "Infernal",
            "Infinity",
            "Insanity",
            "Invincibility",
            "Invisibility",
            "Invisible",
            "Isolation",
            "Judging",
            "Judgment",
            "Justice",
            "Karma",
            "Kismet",
            "Liberty",
            "Life",
            "Life's",
            "Lifeblood",
            "Light's",
            "Longevity",
            "Lucky",
            "Lust's",
            "Malady",
            "Malediction",
            "Malevolence",
            "Maniacal",
            "Massacre",
            "Mending",
            "Metamorphosis",
            "Mirage",
            "Misery",
            "Misfortune",
            "Mystery",
            "Necrotic",
            "Nightmare",
            "Obedience",
            "Oblivion",
            "Obsidian",
            "Onyx",
            "Oracle",
            "Pandemonium",
            "Paradise",
            "Paragon",
            "Paralyzing",
            "Paramount",
            "Pestilence",
            "Petrifying",
            "Philosopher's",
            "Primal",
            "Prime",
            "Prosperous",
            "Purity",
            "Rebirth",
            "Resistance",
            "Resolution",
            "Restoration",
            "Resurrection",
            "Rogue",
            "Runed",
            "Sacred",
            "Sanctifying",
            "Scourge",
            "Seduction",
            "Sentient",
            "Seraphic",
            "Serenity",
            "Shade",
            "Shadow",
            "Shapeshifter",
            "Shapeshifter's",
            "Slumber",
            "Solitude's",
            "Soul",
            "Specter",
            "Spellbound",
            "Spirit",
            "Spiritbound",
            "Spite",
            "Storm",
            "Summoning",
            "Supremacy",
            "Teleportation",
            "Teleporting",
            "Temptation",
            "Termination",
            "Thaumaturgy",
            "Thunder",
            "Titan",
            "Torment",
            "Torture",
            "Tranquility",
            "Transformation",
            "Transmutation",
            "Tribute",
            "Triumph",
            "Truth",
            "Twilight",
            "Unholy",
            "Valor",
            "Valor's",
            "Vengeance",
            "Venom",
            "Vice",
            "Virility",
            "Virtue",
            "Void",
            "Warding",
            "Wisdom",
            "Worshop",
        ]
        n3 = [
            "Arch",
            "Ark",
            "Box",
            "Canopic Chest",
            "Cube",
            "Cup",
            "Cylinder",
            "Disc",
            "Chalice",
            "Goblet",
            "Door",
            "Feather",
            "Fruit",
            "Grail",
            "Horn",
            "Jar",
            "Key",
            "Lamp",
            "Microlith",
            "Mirror",
            "Monolith",
            "Pillar",
            "Rod",
            "Root",
            "Seal",
            "Shard",
            "Skull",
            "Statue",
            "Statuette",
            "Urn",
        ]

        if randrange(2):
            return choice(n3) + " of " + choice(n1)
        else:
            return choice(n2) + " " + choice(n3)

    @staticmethod
    def generate(classification=None):
        n1 = [
            "Absorbing",
            "Abundance",
            "Acrimony",
            "Affluence",
            "Agony",
            "All-Seeing",
            "Angels",
            "Annihilation",
            "Apathy",
            "Athanasia",
            "Bane",
            "Banishment",
            "Benediction",
            "Betrayal",
            "Binding",
            "Birth",
            "Black Magic",
            "Blessings",
            "Blights",
            "Blinding",
            "Chance",
            "Chaos",
            "Charming",
            "Collapse",
            "Contagion",
            "Corruption",
            "Courage",
            "Curses",
            "Damnation",
            "Darkness",
            "Death",
            "Decadence",
            "Decay",
            "Delirium",
            "Delusion",
            "Dementia",
            "Demons",
            "Depravity",
            "Desire",
            "Destiny",
            "Destruction",
            "Dismay",
            "Divinity",
            "Doom",
            "Downfall",
            "Dread",
            "Dreams",
            "Enigmas",
            "Enthrallment",
            "Eternal Health",
            "Eternal Slumber",
            "Eternity",
            "Evil",
            "Evils",
            "Exiles",
            "Faith",
            "Fate",
            "Fear",
            "Fertility",
            "Fire",
            "Flame",
            "Fortitude",
            "Fortuity",
            "Fortune",
            "Frost",
            "Futures",
            "Genesis",
            "Gluttony",
            "Gold",
            "Grace",
            "Greed",
            "Guardians",
            "Hatred",
            "Healing",
            "Hell",
            "Heroism",
            "Honesty",
            "Hunger",
            "Ice",
            "Immobilizing",
            "Immortality",
            "Immunity",
            "Imperviousness",
            "Infinity",
            "Invincibility",
            "Invisibility",
            "Invocation",
            "Judgment",
            "Justice",
            "Karma",
            "Knowledge",
            "Liberation",
            "Life",
            "Lifeblood",
            "Light",
            "Lightness",
            "Lightning",
            "Longevity",
            "Loyalty",
            "Luck",
            "Luminosity",
            "Lunacy",
            "Lust",
            "Malady",
            "Malediction",
            "Malevolence",
            "Malice",
            "Mania",
            "Massacres",
            "Mending",
            "Metamorphosis",
            "Misery",
            "Misfortune",
            "Mysteries",
            "Nightmares",
            "Oaths",
            "Oblivion",
            "Origins",
            "Pain",
            "Paradise",
            "Paralysis",
            "Passion",
            "Peace",
            "Persecution",
            "Pestilence",
            "Petrification",
            "Potency",
            "Prosperity",
            "Protection",
            "Radiance",
            "Rain",
            "Rebirth",
            "Remedies",
            "Repelling",
            "Resistance",
            "Restoration",
            "Resurrection",
            "Revival",
            "Riches",
            "Riddles",
            "Ruination",
            "Runes",
            "Sanctification",
            "Sanctity",
            "Scorching",
            "Secrets",
            "Seduction",
            "Sentience",
            "Serendipity",
            "Service",
            "Shadows",
            "Shapeshifting",
            "Sight",
            "Silence",
            "Sleep",
            "Solitude",
            "Souls",
            "Specters",
            "Speed",
            "Spellbinding",
            "Spells",
            "Spirits",
            "Spite",
            "Storms",
            "Strength",
            "Summoning",
            "Teleportation",
            "Temptation",
            "Time",
            "Torment",
            "Torture",
            "Toxin",
            "Transformation",
            "Transmutation",
            "Treachery",
            "Truth",
            "Valor",
            "Vengeance",
            "Venom",
            "Vice",
            "Virility",
            "Warding",
            "Wealth",
            "Wisdom",
            "Wishes",
            "Worship",
            "Youth",
            "the Aether",
            "the Cosmos",
            "the Creed",
            "the Crux",
            "the Dead",
            "the Elements",
            "the Gods",
            "the Heavens",
            "the Occult",
            "the Oracle",
            "the Scourge",
            "the Titans",
            "the Void",
        ]
        n2 = [
            "Absorbing",
            "Aethereal",
            "Agony",
            "Alchemy",
            "All-Seeing",
            "Almighty",
            "Anarchy",
            "Angel",
            "Anguish",
            "Annihilation",
            "Archangel",
            "Athanasia",
            "Aurora",
            "Azure",
            "Banishing",
            "Benediction",
            "Binding",
            "Black Magic",
            "Blazing",
            "Blight",
            "Blinding",
            "Bravery",
            "Burning",
            "Celestial",
            "Chaos",
            "Charming",
            "Contagion",
            "Corruption",
            "Curse",
            "Cursed",
            "Damnation",
            "Darkness",
            "Death's",
            "Decay",
            "Decimation",
            "Delirium",
            "Delusion",
            "Dementia",
            "Demon",
            "Demonic",
            "Desire's",
            "Destiny's",
            "Destruction",
            "Devotion",
            "Diabolic",
            "Divine",
            "Divinity's",
            "Dominance",
            "Domination",
            "Dominion",
            "Doom",
            "Dread",
            "Dream",
            "Echo",
            "Eclipse",
            "Elemental",
            "Enigma",
            "Enigmatic",
            "Equinox",
            "Eradication",
            "Eternal",
            "Eternity",
            "Evil",
            "Exile",
            "Exiled",
            "Extinction",
            "Faith's",
            "Fate's",
            "Finality",
            "Fire",
            "Flame",
            "Fortitude",
            "Fortune's",
            "Frost",
            "Genesis",
            "Gold",
            "Golden",
            "Grave",
            "Guardian",
            "Guardian's",
            "Hallowed",
            "Hatred's",
            "Healing",
            "Heavenly",
            "Hell's",
            "Hellish",
            "Hero",
            "Hero's",
            "Holy",
            "Hungering",
            "Ice",
            "Immortal",
            "Immunity",
            "Impurity",
            "Infernal",
            "Infinity",
            "Insanity",
            "Invincibility",
            "Invisibility",
            "Invisible",
            "Isolation",
            "Judging",
            "Judgment",
            "Justice",
            "Karma",
            "Kismet",
            "Liberty",
            "Life",
            "Life's",
            "Lifeblood",
            "Light's",
            "Longevity",
            "Lucky",
            "Lust's",
            "Malady",
            "Malediction",
            "Malevolence",
            "Maniacal",
            "Massacre",
            "Mending",
            "Metamorphosis",
            "Mirage",
            "Misery",
            "Misfortune",
            "Mystery",
            "Necrotic",
            "Nightmare",
            "Obedience",
            "Oblivion",
            "Obsidian",
            "Onyx",
            "Oracle",
            "Pandemonium",
            "Paradise",
            "Paragon",
            "Paralyzing",
            "Paramount",
            "Pestilence",
            "Petrifying",
            "Philosopher's",
            "Primal",
            "Prime",
            "Prosperous",
            "Purity",
            "Rebirth",
            "Resistance",
            "Resolution",
            "Restoration",
            "Resurrection",
            "Rogue",
            "Runed",
            "Sacred",
            "Sanctifying",
            "Scourge",
            "Seduction",
            "Sentient",
            "Seraphic",
            "Serenity",
            "Shade",
            "Shadow",
            "Shapeshifter",
            "Shapeshifter's",
            "Slumber",
            "Solitude's",
            "Soul",
            "Specter",
            "Spellbound",
            "Spirit",
            "Spiritbound",
            "Spite",
            "Storm",
            "Summoning",
            "Supremacy",
            "Teleportation",
            "Teleporting",
            "Temptation",
            "Termination",
            "Thaumaturgy",
            "Thunder",
            "Titan",
            "Torment",
            "Torture",
            "Tranquility",
            "Transformation",
            "Transmutation",
            "Tribute",
            "Triumph",
            "Truth",
            "Twilight",
            "Unholy",
            "Valor",
            "Valor's",
            "Vengeance",
            "Venom",
            "Vice",
            "Virility",
            "Virtue",
            "Void",
            "Warding",
            "Wisdom",
            "Worshop",
        ]
        n3 = []
        if classification is None or classification not in Relic.RelicType:
            classification = choice(list(Relic.RelicType))

        if classification == Relic.RelicType.Armor:
            n3 = [
                "Amulet",
                "Band",
                "Boots",
                "Sandals",
                "Bracelet",
                "Chest",
                "Cloak",
                "Fleece",
                "Gauntlet",
                "Hand",
                "Hide",
                "Mantle",
                "Mask",
                "Ring",
                "Robes",
                "Shield",
            ]
        elif classification == Relic.RelicType.Book:
            n3 = [
                "Book",
                "Grimoire",
                "Inscriptions",
                "Instrument",
                "Letters",
                "Runes",
                "Scroll",
                "Symbols",
                "Tablet",
                "Texts",
                "Slab",
                "Tome",
            ]
        elif classification == Relic.RelicType.Potion:
            n3 = ["Canopic Jar", "Elixir", "Fountain", "Ichor", "Tincture"]
        elif classification == Relic.RelicType.Jewel:
            n3 = ["Crown", "Tiara", "Circlet", "Gem", "Necklace", "Stone"]
        elif classification == Relic.RelicType.Other:
            n3 = [
                "Arch",
                "Ark",
                "Box",
                "Canopic Chest",
                "Cube",
                "Cup",
                "Cylinder",
                "Disc",
                "Chalice",
                "Goblet",
                "Door",
                "Feather",
                "Fruit",
                "Grail",
                "Horn",
                "Jar",
                "Key",
                "Lamp",
                "Microlith",
                "Mirror",
                "Monolith",
                "Pillar",
                "Rod",
                "Root",
                "Seal",
                "Shard",
                "Skull",
                "Statue",
                "Statuette",
                "Urn",
            ]

        if randrange(2):
            return choice(n3) + " of " + choice(n1)
        else:
            return choice(n2) + " " + choice(n3)


class Weapon(Item):
    class WeaponType(StrEnum):
        Axe = auto()
        Bow = auto()
        Dagger = auto()
        Hammer = auto()
        Mace = auto()
        Spear = auto()
        Sword = auto()

    @staticmethod
    def Axe():
        var1 = [
            "Abomination",
            "Agatha",
            "Allegiance",
            "Alpha",
            "Amnesia",
            "Anduril",
            "Anger's Edge",
            "Apocalypse",
            "Armageddon",
            "Arondite",
            "Ash",
            "Ashes",
            "Ashrune",
            "Betrayal",
            "Betrayer",
            "Blackout",
            "Blazefury",
            "Blazeguard",
            "Blight's Plight",
            "Blind Justice",
            "Blinkstrike",
            "Bloodfury",
            "Bloodmoon",
            "Bloodquench",
            "Bloodrage",
            "Bloodspiller",
            "Bloodweep",
            "Bone Warden",
            "Braindead",
            "Broken Promise",
            "Brutality",
            "Brutalizer",
            "Cataclysm",
            "Catastrophe",
            "Celeste",
            "Chance",
            "Chaos",
            "Chasm",
            "Chieftain",
            "Comet",
            "Cometfall",
            "Convergence",
            "Corpsemaker",
            "Corruption",
            "Crescent Moon",
            "Crimson",
            "Cutting Response",
            "Cyclone",
            "Darkness",
            "Dawn",
            "Dawn's Edge",
            "Dawnbreaker",
            "Daytime",
            "Deathbringer",
            "Deathraze",
            "Deathspade",
            "Decimation",
            "Desolation",
            "Despair",
            "Destiny",
            "Devastation",
            "Devine",
            "Devotion",
            "Devourer",
            "Divine Light",
            "Dominance",
            "Dominion",
            "Doom",
            "Doom's Edge",
            "Doomblade",
            "Doombringer",
            "Due Diligence",
            "Dusk's Edge",
            "Early Retirement",
            "Earthquake",
            "Echo",
            "Eclipse",
            "Edge of Death",
            "Edge of Eternity",
            "Edge of Infinity",
            "Edge of Life",
            "Edge of Madness",
            "Edge of Misery",
            "Edge of Reason",
            "Edge of Ruin",
            "Edge of Time",
            "Emergency",
            "Endbringer",
            "Enigma",
            "Epilogue",
            "Eternal Rest",
            "Eternity",
            "Extermination",
            "Extinction",
            "Faithkeeper",
            "Fate",
            "Finality",
            "Fleshrender",
            "Freak's Bite",
            "Frenzy",
            "Frostbite",
            "Frostwind",
            "Fury",
            "Fury's Gaze",
            "Gatecrasher",
            "Ghost Reaver",
            "Ghostwalker",
            "Glimmer",
            "Godslayer",
            "Grieving Blade",
            "Guillotine",
            "Gutrender",
            "Harbinger",
            "Harvester",
            "Hatred",
            "Hatred's Blade",
            "Heartseeker",
            "Hell's Scream",
            "Hellfire",
            "Hellreaver",
            "Homage",
            "Honor's Call",
            "Hope's Edge",
            "Hope's End",
            "Humongous",
            "Hurricane",
            "Infamy",
            "Infinity",
            "Interrogator",
            "Justice",
            "Justifier",
            "King's Defender",
            "King's Legacy",
            "Kinslayer",
            "Knight's Fall",
            "Knight's Honor",
            "Knightfall",
            "Lament",
            "Last Chance",
            "Last Laugh",
            "Last Rites",
            "Last Words",
            "Lazarus",
            "Legacy",
            "Legionaire",
            "Life's Limit",
            "Light's Bane",
            "Lightbane",
            "Lightbringer",
            "Lightning",
            "Limbo",
            "Magma",
            "Malice",
            "Maneater",
            "Massacre",
            "Mercy",
            "Midnight",
            "Misery's Edge",
            "Misery's End",
            "Monsoon",
            "Mooncleaver",
            "Mournblade",
            "Narcoleptic",
            "Nethersbane",
            "Night's Edge",
            "Night's Fall",
            "Nightbane",
            "Nightfall",
            "Nighttime",
            "Nirvana",
            "Oathbreaker",
            "Oathkeeper",
            "Oblivion",
            "Old Age",
            "Omega",
            "Orbit",
            "Orenmir",
            "Party Pooper",
            "Peacekeeper",
            "Peacemaker",
            "Pendulum",
            "Perfect Storm",
            "Persuasion",
            "Piece Maker",
            "Piety",
            "Pork-Chopper",
            "Pride",
            "Prophecy",
            "Purifier",
            "Rage",
            "Ragnarok",
            "Rapture",
            "Reaper",
            "Reaper's Toll",
            "Reckoning",
            "Red Dwarf",
            "Reign",
            "Remorse",
            "Requiem",
            "Retirement",
            "Righteous Might",
            "Rigormortis",
            "Rising Tide",
            "Savagery",
            "Scar",
            "Scourgeborne",
            "Second Chance",
            "Seism",
            "Severance",
            "Shadow Strike",
            "Shadow's Edge",
            "Shadowfury",
            "Shadowmoon",
            "Shadowsteel",
            "Silence",
            "Skullcleaver",
            "Skullcrusher",
            "Slice of Life",
            "Soul Breaker",
            "Soul Reaper",
            "Spinefall",
            "Stalker",
            "Storm",
            "Storm Breaker",
            "Storm-Weaver",
            "Stormbringer",
            "Stormcaller",
            "Stormedge",
            "Stormrider",
            "Supernova",
            "Supremacy",
            "Suspension",
            "Swan Song",
            "Termination",
            "The Ambassador",
            "The Chancellor",
            "The Chief",
            "The Decapitator",
            "The End",
            "The Facelifter",
            "The Light",
            "The Minotaur",
            "The Oculus",
            "The Oracle",
            "The Sundering",
            "The Void",
            "The Warden",
            "Thunder",
            "Treachery",
            "Tremor",
            "Trickster",
            "Trickster's Edge",
            "Trinity",
            "Twisted",
            "Typhoon",
            "Ubiquity",
            "Undoing",
            "Vacancy",
            "Valkyrie",
            "Vanquisher",
            "Vengeance",
            "Warbringer",
            "Warmonger",
            "Whirlwind",
            "Wicked",
            "Widow Maker",
            "Willbreaker",
            "Windreaper",
            "Windslicer",
            "Winter's Bite",
            "Wit's End",
            "Witherbrand",
            "Wolf",
            "Worldbreaker",
            "Worldcarver",
            "Worldslayer",
        ]
        var2 = [
            "Ancient",
            "Antique",
            "Apocalypse",
            "Apocalyptic",
            "Arcane",
            "Arched",
            "Atuned",
            "Bandit's",
            "Baneful",
            "Banished",
            "Barbarian",
            "Barbaric",
            "Battleworn",
            "Blazefury",
            "Blood Infused",
            "Blood-Forged",
            "Bloodcursed",
            "Bloodied",
            "Bloodlord's",
            "Bloodsurge",
            "Bloodvenom",
            "Bonecarvin",
            "Brutal",
            "Brutality",
            "Burnished",
            "Cataclysm",
            "Cataclysmic",
            "Challenger",
            "Challenger's",
            "Champion",
            "Champion's",
            "Cold-Forged",
            "Conqueror",
            "Conqueror's",
            "Corroded",
            "Corrupted",
            "Crazed",
            "Crying",
            "Cursed",
            "Curved",
            "Dancing",
            "Dark",
            "Darkness",
            "Defender",
            "Defender's",
            "Defiled",
            "Defiling",
            "Deluded",
            "Demonic",
            "Deserted",
            "Desire's",
            "Desolation",
            "Destiny's",
            "Diabolical",
            "Dire",
            "Doom",
            "Doom's",
            "Dragon's",
            "Dragonbreath",
            "Eerie",
            "Enchanted",
            "Engraved",
            "Enlightened",
            "Eternal",
            "Exiled",
            "Extinction",
            "Faith's",
            "Faithful",
            "Fancy",
            "Fearful",
            "Feral",
            "Ferocious",
            "Fierce",
            "Fiery",
            "Fire Infused",
            "Fireguard",
            "Firesoul",
            "Firestorm",
            "Flaming",
            "Flimsy",
            "Forsaken",
            "Fortune's",
            "Foul",
            "Fragile",
            "Frail",
            "Frenzied",
            "Frost",
            "Frozen",
            "Furious",
            "Fusion",
            "Ghastly",
            "Ghost",
            "Ghost-Forged",
            "Ghostly",
            "Gladiator",
            "Gladiator's",
            "Gleaming",
            "Glinting",
            "Greedy",
            "Grieving",
            "Grim",
            "Guard's",
            "Guardian's",
            "Hailstorm",
            "Harmonized",
            "Hateful",
            "Haunted",
            "Heartless",
            "Heinous",
            "Hero",
            "Hero's",
            "Hollow",
            "Holy",
            "Honed",
            "Honor's",
            "Hope's",
            "Hopeless",
            "Howling",
            "Hungering",
            "Improved",
            "Impure",
            "Incarnated",
            "Infused",
            "Inherited",
            "Isolated",
            "Jade Infused",
            "Judgement",
            "Keeper's",
            "Knightly",
            "Knight's",
            "Legionnaire's",
            "Liar's",
            "Lich",
            "Lightning",
            "Lonely",
            "Loyal",
            "Lustful",
            "Lusting",
            "Malevolent",
            "Malicious",
            "Malificent",
            "Malignant",
            "Massive",
            "Mended",
            "Mercenary",
            "Military",
            "Misfortune's",
            "Misty",
            "Moonlit",
            "Mourning",
            "Nightmare",
            "Oathkeeper's",
            "Ominous",
            "Peacekeeper",
            "Peacekeeper's",
            "Phantom",
            "Polished",
            "Possessed",
            "Pride's",
            "Prideful",
            "Primal",
            "Prime",
            "Primitive",
            "Promised",
            "Protector's",
            "Proud",
            "Pure",
            "Putrid",
            "Raging",
            "Recruit's",
            "Refined",
            "Reforged",
            "Reincarnated",
            "Relentless",
            "Remorseful",
            "Renewed",
            "Renovated",
            "Replica",
            "Restored",
            "Retribution",
            "Ritual",
            "Roaring",
            "Ruby Infused",
            "Rune-Forged",
            "Runed",
            "Rusty",
            "Savage",
            "Sentinel",
            "Shadow",
            "Shamanic",
            "Sharpened",
            "Silent",
            "Singed",
            "Singing",
            "Sinister",
            "Skyfall",
            "Smooth",
            "Soldier's",
            "Solitude's",
            "Sorcerer's",
            "Sorrow's",
            "Soul",
            "Soul Infused",
            "Soul-Forged",
            "Soulcursed",
            "Soulless",
            "Spectral",
            "Spectral-Forged",
            "Spiteful",
            "Storm",
            "Storm-Forged",
            "Stormfury",
            "Stormguard",
            "Terror",
            "Thirsting",
            "Thirsty",
            "Thunder",
            "Thunder-Forged",
            "Thunderfury",
            "Thunderguard",
            "Thundersoul",
            "Thunderstorm",
            "Timeworn",
            "Tormented",
            "Trainee's",
            "Treachery's",
            "Twilight",
            "Twilight's",
            "Twisted",
            "Tyrannical",
            "Undead",
            "Unholy",
            "Vanquisher",
            "Vengeance",
            "Vengeful",
            "Venom",
            "Vicious",
            "Victor",
            "Vile",
            "Vindication",
            "Vindicator",
            "Vindictive",
            "Void",
            "Volcanic",
            "Vowed",
            "War",
            "War-Forged",
            "Warden's",
            "Warlord's",
            "Warp",
            "Warped",
            "Warrior",
            "Warrior's",
            "Whistling",
            "Wicked",
            "Wind's",
            "Wind-Forged",
            "Windsong",
            "Woeful",
            "Wrathful",
            "Wretched",
            "Yearning",
            "Zealous",
        ]
        var3 = [
            "Adamantite",
            "Bone",
            "Bronze",
            "Bronzed",
            "Ivory",
            "Ebon",
            "Glass",
            "Golden",
            "Iron",
            "Ironbark",
            "Mithril",
            "Obsidian",
            "Silver",
            "Skeletal",
            "Steel",
            "Titanium",
        ]
        var4 = [
            "Battle Axe",
            "Chopper",
            "Axe",
            "Edge",
            "Crescent",
            "Cleaver",
            "Greataxe",
            "Dualblade",
            "Broadaxe",
            "Reaver",
            "War Axe",
            "Ravager",
            "Maul",
        ]
        var5 = [
            "Allegiance",
            "Annihilation",
            "Axe",
            "Battle Axe",
            "Betrayer",
            "Bond",
            "Boon",
            "Breaker",
            "Bringer",
            "Broadaxe",
            "Butcher",
            "Call",
            "Carver",
            "Champion",
            "Chopper",
            "Cleaver",
            "Conqueror",
            "Crescent",
            "Crusader",
            "Cry",
            "Cunning",
            "Dark Blade",
            "Dawn",
            "Defender",
            "Defiler",
            "Destroyer",
            "Doomblade",
            "Dualblade",
            "Edge",
            "Ender",
            "Etcher",
            "Executioner",
            "Favor",
            "Ferocity",
            "Foe",
            "Gift",
            "Glory",
            "Greataxe",
            "Guardian",
            "Heirloom",
            "Hope",
            "Incarnation",
            "Jaws",
            "Last Hope",
            "Last Stand",
            "Legacy",
            "Maul",
            "Memory",
            "Might",
            "Oath",
            "Pact",
            "Pledge",
            "Promise",
            "Prophecy",
            "Protector",
            "Ravager",
            "Razor",
            "Reach",
            "Reaper",
            "Reaver",
            "Runed Blade",
            "Sculptor",
            "Secret",
            "Slayer",
            "Slicer",
            "Soul",
            "Terror",
            "Token",
            "Tribute",
            "Vengeance",
            "Voice",
            "War Axe",
            "Warblade",
            "Whisper",
            "Wit",
        ]
        var6 = [
            "of Agony",
            "of Ancient Power",
            "of Anguish",
            "of Ashes",
            "of Assassins",
            "of Black Magic",
            "of Blessed Fortune",
            "of Blessings",
            "of Blight",
            "of Blood",
            "of Bloodlust",
            "of Broken Bones",
            "of Broken Dreams",
            "of Broken Families",
            "of Burdens",
            "of Chaos",
            "of Closing Eyes",
            "of Conquered Worlds",
            "of Corruption",
            "of Cruelty",
            "of Cunning",
            "of Dark Magic",
            "of Dark Souls",
            "of Darkness",
            "of Decay",
            "of Deception",
            "of Degradation",
            "of Delusions",
            "of Denial",
            "of Desecration",
            "of Diligence",
            "of Dismay",
            "of Dragonsouls",
            "of Due Diligence",
            "of Echoes",
            "of Ended Dreams",
            "of Ending Hope",
            "of Ending Misery",
            "of Eternal Bloodlust",
            "of Eternal Damnation",
            "of Eternal Glory",
            "of Eternal Justice",
            "of Eternal Rest",
            "of Eternal Sorrow",
            "of Eternal Struggles",
            "of Eternity",
            "of Executions",
            "of Faded Memories",
            "of Fallen Souls",
            "of Fools",
            "of Frost",
            "of Frozen Hells",
            "of Fury",
            "of Giants",
            "of Giantslaying",
            "of Grace",
            "of Grieving Widows",
            "of Hate",
            "of Hatred",
            "of Hell's Games",
            "of Hellish Torment",
            "of Heroes",
            "of Holy Might",
            "of Honor",
            "of Hope",
            "of Horrid Dreams",
            "of Horrors",
            "of Illuminated Dreams",
            "of Illumination",
            "of Immortality",
            "of Inception",
            "of Infinite Trials",
            "of Insanity",
            "of Invocation",
            "of Justice",
            "of Light's Hope",
            "of Lost Comrades",
            "of Lost Hope",
            "of Lost Voices",
            "of Lost Worlds",
            "of Magic",
            "of Mercy",
            "of Misery",
            "of Mountains",
            "of Mourning",
            "of Mystery",
            "of Necromancy",
            "of Nightmares",
            "of Oblivion",
            "of Perdition",
            "of Phantoms",
            "of Power",
            "of Pride",
            "of Pride's Fall",
            "of Putrefaction",
            "of Reckoning",
            "of Redemption",
            "of Regret",
            "of Riddles",
            "of Secrecy",
            "of Secrets",
            "of Shadow Strikes",
            "of Shadows",
            "of Shifting Sands",
            "of Shifting Worlds",
            "of Silence",
            "of Slaughter",
            "of Souls",
            "of Stealth",
            "of Storms",
            "of Subtlety",
            "of Suffering",
            "of Suffering's End",
            "of Summoning",
            "of Terror",
            "of Thunder",
            "of Time-Lost Memories",
            "of Timeless Battles",
            "of Titans",
            "of Torment",
            "of Traitors",
            "of Trembling Hands",
            "of Trials",
            "of Truth",
            "of Twilight's End",
            "of Twisted Visions",
            "of Unholy Blight",
            "of Unholy Might",
            "of Vengeance",
            "of Visions",
            "of Wasted Time",
            "of Widows",
            "of Wizardry",
            "of Woe",
            "of Wraiths",
            "of Zeal",
            "of the Ancients",
            "of the Banished",
            "of the Basilisk",
            "of the Beast",
            "of the Blessed",
            "of the Breaking Storm",
            "of the Brotherhood",
            "of the Burning Sun",
            "of the Caged Mind",
            "of the Cataclysm",
            "of the Champion",
            "of the Claw",
            "of the Corrupted",
            "of the Covenant",
            "of the Crown",
            "of the Damned",
            "of the Daywalker",
            "of the Dead",
            "of the Depth",
            "of the Dreadlord",
            "of the Earth",
            "of the East",
            "of the Emperor",
            "of the Empty Void",
            "of the End",
            "of the Enigma",
            "of the Fallen",
            "of the Falling Sky",
            "of the Flame",
            "of the Forest",
            "of the Forgotten",
            "of the Forsaken",
            "of the Gladiator",
            "of the Harvest",
            "of the Immortal",
            "of the Incoming Storm",
            "of the Insane",
            "of the King",
            "of the Lasting Night",
            "of the Leviathan",
            "of the Light",
            "of the Lion",
            "of the Lionheart",
            "of the Lone Victor",
            "of the Lone Wolf",
            "of the Lost",
            "of the Moon",
            "of the Moonwalker",
            "of the Night Sky",
            "of the Night",
            "of the Nightstalker",
            "of the North",
            "of the Occult",
            "of the Oracle",
            "of the Phoenix",
            "of the Plague",
            "of the Prince",
            "of the Protector",
            "of the Queen",
            "of the Serpent",
            "of the Setting Sun",
            "of the Shadows",
            "of the Sky",
            "of the South",
            "of the Stars",
            "of the Storm",
            "of the Summoner",
            "of the Sun",
            "of the Sunwalker",
            "of the Talon",
            "of the Undying",
            "of the Victor",
            "of the Void",
            "of the West",
            "of the Whispers",
            "of the Wicked",
            "of the Wind",
            "of the Wolf",
            "of the World",
            "of the Wretched",
        ]
        var7 = [
            "Abomination",
            "Agatha",
            "Allegiance",
            "Alpha",
            "Amnesia",
            "Anduril",
            "Anger's Edge",
            "Apocalypse",
            "Armageddon",
            "Arondite",
            "Ash",
            "Ashes",
            "Ashrune",
            "Betrayal",
            "Betrayer",
            "Blackout",
            "Blazefury",
            "Blazeguard",
            "Blind Justice",
            "Blinkstrike",
            "Bloodfury",
            "Bloodmoon",
            "Bloodquench",
            "Bloodrage",
            "Bloodspiller",
            "Bloodweep",
            "Bone Warden",
            "Braindead",
            "Broken Promise",
            "Brutality",
            "Brutalizer",
            "Cataclysm",
            "Catastrophe",
            "Celeste",
            "Chance",
            "Chaos",
            "Chasm",
            "Chieftain",
            "Comet",
            "Cometfall",
            "Convergence",
            "Corpsemaker",
            "Corruption",
            "Crescent Moon",
            "Crimson",
            "Cyclone",
            "Darkness",
            "Dawn",
            "Dawn's Edge",
            "Dawnbreaker",
            "Daytime",
            "Deathbringer",
            "Deathraze",
            "Deathspade",
            "Decimation",
            "Desolation",
            "Despair",
            "Destiny",
            "Devastation",
            "Devine",
            "Devotion",
            "Devourer",
            "Divine Light",
            "Dominance",
            "Dominion",
            "Doom",
            "Doomblade",
            "Doombringer",
            "Due Diligence",
            "Earthquake",
            "Echo",
            "Eclipse",
            "Emergency",
            "Endbringer",
            "Enigma",
            "Epilogue",
            "Eternal Rest",
            "Eternity",
            "Extermination",
            "Extinction",
            "Faithkeeper",
            "Fate",
            "Finality",
            "Fleshrender",
            "Freak's Bite",
            "Frenzy",
            "Frostbite",
            "Frostwind",
            "Fury",
            "Fury's Gaze",
            "Gatecrasher",
            "Ghost Reaver",
            "Ghostwalker",
            "Glimmer",
            "Godslayer",
            "Guillotine",
            "Gutrender",
            "Harbinger",
            "Harvester",
            "Hatred",
            "Heartseeker",
            "Hell's Scream",
            "Hellfire",
            "Hellreaver",
            "Homage",
            "Honor's Call",
            "Hope's Edge",
            "Hope's End",
            "Humongous",
            "Hurricane",
            "Infamy",
            "Infinity",
            "Interrogator",
            "Justice",
            "Justifier",
            "King's Defender",
            "King's Legacy",
            "Kinslayer",
            "Knight's Fall",
            "Knight's Honor",
            "Knightfall",
            "Lament",
            "Last Chance",
            "Last Laugh",
            "Last Rites",
            "Last Words",
            "Lazarus",
            "Legacy",
            "Legionaire",
            "Life's Limit",
            "Light's Bane",
            "Lightbane",
            "Lightbringer",
            "Lightning",
            "Limbo",
            "Magma",
            "Malice",
            "Maneater",
            "Massacre",
            "Mercy",
            "Midnight",
            "Misery's Edge",
            "Misery's End",
            "Monsoon",
            "Mooncleaver",
            "Mournblade",
            "Narcoleptic",
            "Nethersbane",
            "Night's Edge",
            "Night's Fall",
            "Nightbane",
            "Nightfall",
            "Nighttime",
            "Nirvana",
            "Oathbreaker",
            "Oathkeeper",
            "Oblivion",
            "Old Age",
            "Omega",
            "Orbit",
            "Orenmir",
            "Party Pooper",
            "Peacekeeper",
            "Peacemaker",
            "Pendulum",
            "Perfect Storm",
            "Persuasion",
            "Piece Maker",
            "Piety",
            "Pork-Chopper",
            "Pride",
            "Prophecy",
            "Purifier",
            "Rage",
            "Ragnarok",
            "Rapture",
            "Reaper",
            "Reaper's Toll",
            "Reckoning",
            "Red Dwarf",
            "Reign",
            "Remorse",
            "Requiem",
            "Retirement",
            "Rigormortis",
            "Rising Tide",
            "Savagery",
            "Scar",
            "Scourgeborne",
            "Second Chance",
            "Seism",
            "Severance",
            "Shadow Strike",
            "Shadow's Edge",
            "Shadowfury",
            "Shadowmoon",
            "Shadowsteel",
            "Silence",
            "Skullcleaver",
            "Skullcrusher",
            "Slice of Life",
            "Soul Breaker",
            "Soul Reaper",
            "Spinefall",
            "Stalker",
            "Storm",
            "Storm Breaker",
            "Storm-Weaver",
            "Stormbringer",
            "Stormcaller",
            "Stormedge",
            "Stormrider",
            "Supernova",
            "Supremacy",
            "Suspension",
            "Swan Song",
            "Termination",
            "The Ambassador",
            "The Chancellor",
            "The Chief",
            "The Decapitator",
            "The End",
            "The Facelifter",
            "The Light",
            "The Minotaur",
            "The Oculus",
            "The Oracle",
            "The Sundering",
            "The Void",
            "The Warden",
            "Thunder",
            "Treachery",
            "Tremor",
            "Trickster",
            "Trinity",
            "Twisted",
            "Typhoon",
            "Ubiquity",
            "Undoing",
            "Vacancy",
            "Valkyrie",
            "Vanquisher",
            "Vengeance",
            "Warbringer",
            "Warmonger",
            "Whirlwind",
            "Wicked",
            "Widow Maker",
            "Willbreaker",
            "Windreaper",
            "Windslicer",
            "Winter's Bite",
            "Wit's End",
            "Witherbrand",
            "Wolf",
            "Worldbreaker",
            "Worldcarver",
            "Worldslayer",
        ]

        num = randrange(4)
        if num == 0:
            return choice(var1).title()
        elif num == 1:
            return choice(var2) + " " + choice(var4)
        elif num == 2:
            return choice(var2) + " " + choice(var3) + " " + choice(var4)
        elif num == 3:
            return choice(var7) + " " + choice(var5) + " " + choice(var6)

    @staticmethod
    def Bow():
        var1 = [
            "Hornet's Sting",
            "Blackened Sky",
            "Darkened Sky",
            "Steel Hail",
            "Archangel",
            "Archdemon",
            "Arcus",
            "Armadillo",
            "Armageddon",
            "Arrowsong",
            "Arrowspike",
            "Avalance",
            "Back Pain",
            "Backsnipe",
            "Ballista",
            "Barrage",
            "Beesting",
            "Betrayal",
            "Betrayal's Sting",
            "Bolt",
            "Bolt Action",
            "Bon Voyage",
            "Bristleblitz",
            "Bullseye",
            "Calamity",
            "Chimera",
            "Clutch",
            "Comet",
            "Courier",
            "Crier",
            "Curvey",
            "Cyclone",
            "Dash",
            "Dead Air",
            "Death's Kiss",
            "Death's Sigh",
            "Death's Whisper",
            "Decimate",
            "Deliverance",
            "Deluge",
            "Destiny's Song",
            "Devil's Kiss",
            "Devil's Recurve",
            "Devil's Sting",
            "Devil's Whisper",
            "Doomcaster",
            "Drawback",
            "Drawling",
            "Drawstring",
            "Dream Catcher",
            "Eagle",
            "Eagle Strike",
            "Emily's Curve",
            "Euthanasia",
            "Eye of Eternity",
            "Eye of Fidelity",
            "Eye of Precision",
            "Eye of Truth",
            "Falling Star",
            "Featherdraw",
            "Final Breath",
            "Final Voyage",
            "Final Whisper",
            "Final Whistle",
            "Firestarter",
            "Fling",
            "Flux",
            "Fury",
            "Gargoyle",
            "Graviton",
            "Hailstorm",
            "Hamstring",
            "Hamstrung",
            "Harbinger",
            "Hatred's Sting",
            "Hawkeye",
            "Heartbeat",
            "Heartpiercer",
            "Heartstriker",
            "Heartstring",
            "Hedgehog",
            "Hell's Whistle",
            "High-Strung",
            "Hooty Tooty Aim and Shooty",
            "Hope's End",
            "Hornet",
            "Huntress",
            "Hurricane",
            "Hush",
            "Imminent Doom",
            "Impending Doom",
            "Irk",
            "Jugular",
            "Kiss of Death",
            "Lash",
            "Last Kiss",
            "Last Vision",
            "Last Whisper",
            "Lightning",
            "Lightning Strike",
            "Long Shot",
            "Messenger",
            "Meteor",
            "Meteor Strike",
            "Midge",
            "Mirage",
            "Misery's End",
            "Molten Fury",
            "Mosquito",
            "Needle Shooter",
            "Needle Threader",
            "Netherstrand",
            "Penetrator",
            "Perfidy",
            "Phantom",
            "Phantom Strike",
            "Phoenix",
            "Pierce",
            "Pinch",
            "Pique",
            "Pluck",
            "Porcupine",
            "Precise",
            "Precision",
            "Prickle",
            "Prophet",
            "Puncture",
            "Quickstrike",
            "Quillshooter",
            "Quintain",
            "Rain Maker",
            "Razorsong",
            "Razorwind",
            "Recurve",
            "Rigormortis",
            "Salvation",
            "Scorpio",
            "Scorpion",
            "Scorpion Sting",
            "Shadow Strike",
            "Shadow's Bane",
            "Shadow's Strike",
            "Shatter Storm",
            "Shooting Star",
            "Shriek",
            "Silent Messenger",
            "Silentsong",
            "Siren's Call",
            "Siren's Cry",
            "Siren's Song",
            "Sky Piercer",
            "Skyfire",
            "Snatch",
            "Snipe",
            "Snitch",
            "Soulstring",
            "Special Delivery",
            "Spitfire",
            "Splinter",
            "Splintermark",
            "Squawk",
            "Squirm",
            "Star's Fury",
            "Starshot",
            "Starstruck",
            "Sting",
            "Stormsong",
            "Striker's Mark",
            "Stryker",
            "Sudden Death",
            "Surprise",
            "Swiftwind",
            "Swoosh",
            "Talonstrike",
            "Tempest",
            "The Ambassador",
            "The Messenger",
            "Thunder",
            "Thunderstrike",
            "Tiebreaker",
            "Tranquility",
            "Trophy Chord",
            "Trophy Gatherer",
            "Trophy Mark",
            "Truestrike",
            "Tweak",
            "Twisted",
            "Twister",
            "Twitch",
            "Typhoon",
            "Valkyrie",
            "Vehement Chord",
            "Venomstrike",
            "Viper",
            "Vixen",
            "Vulture",
            "Warsong",
            "Wasp",
            "Wasp's Sting",
            "Whelm",
            "Whisper",
            "Whisperwind",
            "Windbreaker",
            "Windforce",
            "Windlass",
            "Windrunner",
            "Windstalker",
            "Windtalker",
            "WithDraw",
        ]
        var2 = [
            "Advanced",
            "Amber Infused",
            "Ancient",
            "Anguish'",
            "Annihilation",
            "Antique",
            "Arcane",
            "Arched",
            "Archer's",
            "Assassination",
            "Atuned",
            "Bandit's",
            "Baneful",
            "Banished",
            "Barbarian",
            "Barbaric",
            "Battleworn",
            "Blazefury",
            "Blessed",
            "Blood Infused",
            "Bloodcursed",
            "Bloodied",
            "Bloodlord's",
            "Bloodsurge",
            "Bloodvenom",
            "Bone Crushing",
            "Bowman's",
            "Brutal",
            "Brutality",
            "Burnished",
            "Cataclysm",
            "Cataclysmic",
            "Charmed",
            "Corrupted",
            "Crazed",
            "Crying",
            "Cursed",
            "Curved",
            "Dancing",
            "Defiled",
            "Deluded",
            "Demonic",
            "Deserted",
            "Desire's",
            "Desolation",
            "Destiny's",
            "Dire",
            "Doom",
            "Doom's",
            "Dragon's",
            "Dragonbreath",
            "Dreadful",
            "Ebon",
            "Eerie",
            "Enchanted",
            "Engraved",
            "Eternal",
            "Ethereal",
            "Executing",
            "Exiled",
            "Expert's",
            "Extinction",
            "Faith's",
            "Faithful",
            "Fancy",
            "Fearful",
            "Feather-Wrapped",
            "Featherdraw",
            "Feral",
            "Fierce",
            "Fiery",
            "Fine",
            "Firestorm",
            "Flimsy",
            "Forsaken",
            "Fortune's",
            "Fragile",
            "Frail",
            "Frenzied",
            "Frost",
            "Frozen",
            "Furious",
            "Fusion",
            "Ghastly",
            "Ghostly",
            "Gladiator",
            "Gladiator's",
            "Grieving",
            "Guard's",
            "Guardian's",
            "Hateful",
            "Haunted",
            "Heavy",
            "Hollow",
            "Holy",
            "Honed",
            "Honor's",
            "Hope's",
            "Hopeless",
            "Howling",
            "Hungering",
            "Improved",
            "Incarnated",
            "Infused",
            "Inherited",
            "Isolated",
            "Jade Infused",
            "Judgement",
            "Liar's",
            "Lich",
            "Lightning",
            "Lonely",
            "Loyal",
            "Lustful",
            "Lusting",
            "Mage's",
            "Malevolent",
            "Malicious",
            "Malignant",
            "Massive",
            "Master Hunter's",
            "Mended",
            "Mercenary",
            "Military",
            "Misfortune's",
            "Mourning",
            "Nightmare",
            "Nightstalker",
            "Ominous",
            "Peacekeeper",
            "Phantom",
            "Possessed",
            "Pride's",
            "Prideful",
            "Primitive",
            "Promised",
            "Protector's",
            "Proud",
            "Ranger's",
            "Recruit's",
            "Reincarnated",
            "Relentless",
            "Remorseful",
            "Renewed",
            "Renovated",
            "Replica",
            "Restored",
            "Retribution",
            "Ritual",
            "Roaring",
            "Savage",
            "Oathkeeper's",
            "Shadow",
            "Shadowleaf",
            "Shrieking",
            "Silent",
            "Singed",
            "Singing",
            "Sinister",
            "Skullforge",
            "Skyfall",
            "Smooth",
            "Solitude's",
            "Sorrow's",
            "Soul",
            "Soul Infused",
            "Soulcursed",
            "Soulless",
            "Spectral",
            "Spiteful",
            "Storm",
            "Storm's",
            "Stormfury",
            "Stormguard",
            "Stout",
            "Striker's",
            "Sturdy",
            "Terror",
            "Thirsting",
            "Thirsty",
            "Thunder",
            "Thunderfury",
            "Thunderguard",
            "Thundersoul",
            "Timeworn",
            "Tormented",
            "Tracking",
            "Trainee's",
            "Trapper's",
            "Treachery's",
            "Twilight",
            "Twilight's",
            "Twisted",
            "Tyrannical",
            "Undead",
            "Unholy",
            "Vengeance",
            "Vengeful",
            "Venom",
            "Vicious",
            "Vindication",
            "Vindictive",
            "Void",
            "Volcanic",
            "Vowed",
            "War-Forged",
            "Warlord's",
            "Warp",
            "Warped",
            "Warsong",
            "Well Crafted",
            "Whistling",
            "Wicked",
            "Wind's",
            "Windsong",
            "Woeful",
            "Wrathful",
            "Wretched",
            "Yearning",
            "Yielding",
            "Zealous",
        ]
        var3 = [
            "Ashwood",
            "Bone",
            "Bronzed",
            "Driftwood",
            "Ebon",
            "Hardwood",
            "Iron",
            "Ironbark",
            "Maple",
            "Oak",
            "Redwood",
            "Skeletal",
            "Steel",
            "Titanium",
            "Warpwood",
            "Willow",
            "Yew",
        ]
        var4 = [
            "Longbow",
            "Shortbow",
            "Crossbow",
            "Speargun",
            "Launcher",
            "Repeater",
            "Shooter",
            "Crossfire",
            "Bolter",
            "Heavy Crossbow",
            "Arbalest",
            "Piercer",
            "Striker",
            "Warbow",
            "Chord",
            "Recurve",
            "Bow",
            "Compound Bow",
            "Hunting Bow",
            "Warp-Bow",
            "Flatbow",
            "Reflex Bow",
            "Composite Bow",
            "Compound Crossbow",
            "Straight Bow",
            "Self Bow",
        ]
        var5 = [
            "Annihilation",
            "Arbalest",
            "Arch",
            "Betrayer",
            "Bite",
            "Bolter",
            "Bond",
            "Boon",
            "Bow",
            "Breaker",
            "Bringer",
            "Call",
            "Champion",
            "Chord",
            "Composite Bow",
            "Compound Bow",
            "Crescent",
            "Crook",
            "Crossbow",
            "Crossfire",
            "Cry",
            "Cunning",
            "Curve",
            "Dawn",
            "Defiler",
            "Destroyer",
            "Eclipse",
            "Ellipse",
            "Ender",
            "Etcher",
            "Executioner",
            "Eye",
            "Favor",
            "Ferocity",
            "Flatbow",
            "Foe",
            "Gift",
            "Glory",
            "Guardian",
            "Heavy Crossbow",
            "Heirloom",
            "Hope",
            "Hunting Bow",
            "Incarnation",
            "Kiss",
            "Last Hope",
            "Last Stand",
            "Launcher",
            "Legacy",
            "Longbow",
            "Memory",
            "Might",
            "Oath",
            "Pact",
            "Piercer",
            "Pique",
            "Pledge",
            "Poke",
            "Prick",
            "Promise",
            "Protector",
            "Ravager",
            "Reach",
            "Recurve",
            "Reflex Bow",
            "Repeater",
            "Savagery",
            "Secret",
            "Self Bow",
            "Shooter",
            "Shortbow",
            "Skewer",
            "Soul",
            "Speargun",
            "Spike",
            "Spine",
            "Straight Bow",
            "Striker",
            "String",
            "Terror",
            "Token",
            "Tribute",
            "Vengeance",
            "Voice",
            "Warbow",
            "Warp-Bow",
            "Whisper",
            "Wit",
        ]
        var6 = [
            "of Agony",
            "of Ancient Power",
            "of Anguish",
            "of Ashes",
            "of Assassins",
            "of Black Magic",
            "of Blessed Fortune",
            "of Blessings",
            "of Blight",
            "of Blood",
            "of Bloodlust",
            "of Broken Bones",
            "of Broken Dreams",
            "of Broken Families",
            "of Burdens",
            "of Chaos",
            "of Closing Eyes",
            "of Conquered Worlds",
            "of Corruption",
            "of Cruelty",
            "of Cunning",
            "of Dark Magic",
            "of Dark Souls",
            "of Darkness",
            "of Decay",
            "of Deception",
            "of Degradation",
            "of Delusions",
            "of Denial",
            "of Desecration",
            "of Diligence",
            "of Dismay",
            "of Dragonsouls",
            "of Due Diligence",
            "of Echoes",
            "of Ended Dreams",
            "of Ending Hope",
            "of Ending Misery",
            "of Eternal Bloodlust",
            "of Eternal Damnation",
            "of Eternal Glory",
            "of Eternal Justice",
            "of Eternal Rest",
            "of Eternal Sorrow",
            "of Eternal Struggles",
            "of Eternity",
            "of Executions",
            "of Faded Memories",
            "of Fallen Souls",
            "of Fools",
            "of Frost",
            "of Frozen Hells",
            "of Fury",
            "of Giants",
            "of Giantslaying",
            "of Grace",
            "of Grieving Widows",
            "of Hate",
            "of Hatred",
            "of Hell's Games",
            "of Hellish Torment",
            "of Heroes",
            "of Holy Might",
            "of Honor",
            "of Hope",
            "of Horrid Dreams",
            "of Horrors",
            "of Illuminated Dreams",
            "of Illumination",
            "of Immortality",
            "of Inception",
            "of Infinite Trials",
            "of Insanity",
            "of Invocation",
            "of Justice",
            "of Light's Hope",
            "of Lost Comrades",
            "of Lost Hope",
            "of Lost Voices",
            "of Lost Worlds",
            "of Magic",
            "of Mercy",
            "of Misery",
            "of Mountains",
            "of Mourning",
            "of Mystery",
            "of Necromancy",
            "of Nightmares",
            "of Oblivion",
            "of Perdition",
            "of Phantoms",
            "of Power",
            "of Pride",
            "of Pride's Fall",
            "of Putrefaction",
            "of Reckoning",
            "of Redemption",
            "of Regret",
            "of Riddles",
            "of Secrecy",
            "of Secrets",
            "of Shadow Strikes",
            "of Shadows",
            "of Shifting Sands",
            "of Shifting Worlds",
            "of Silence",
            "of Slaughter",
            "of Souls",
            "of Stealth",
            "of Storms",
            "of Subtlety",
            "of Suffering",
            "of Suffering's End",
            "of Summoning",
            "of Terror",
            "of Thunder",
            "of Time-Lost Memories",
            "of Timeless Battles",
            "of Titans",
            "of Torment",
            "of Traitors",
            "of Trembling Hands",
            "of Trials",
            "of Truth",
            "of Twilight's End",
            "of Twisted Visions",
            "of Unholy Blight",
            "of Unholy Might",
            "of Vengeance",
            "of Visions",
            "of Wasted Time",
            "of Widows",
            "of Wizardry",
            "of Woe",
            "of Wraiths",
            "of Zeal",
            "of the Ancients",
            "of the Banished",
            "of the Basilisk",
            "of the Beast",
            "of the Blessed",
            "of the Breaking Storm",
            "of the Brotherhood",
            "of the Burning Sun",
            "of the Caged Mind",
            "of the Cataclysm",
            "of the Champion",
            "of the Claw",
            "of the Corrupted",
            "of the Covenant",
            "of the Crown",
            "of the Damned",
            "of the Daywalker",
            "of the Dead",
            "of the Depth",
            "of the Dreadlord",
            "of the Earth",
            "of the East",
            "of the Emperor",
            "of the Empty Void",
            "of the End",
            "of the Enigma",
            "of the Fallen",
            "of the Falling Sky",
            "of the Flame",
            "of the Forest",
            "of the Forgotten",
            "of the Forsaken",
            "of the Gladiator",
            "of the Harvest",
            "of the Immortal",
            "of the Incoming Storm",
            "of the Insane",
            "of the King",
            "of the Lasting Night",
            "of the Leviathan",
            "of the Light",
            "of the Lion",
            "of the Lionheart",
            "of the Lone Victor",
            "of the Lone Wolf",
            "of the Lost",
            "of the Moon",
            "of the Moonwalker",
            "of the Night Sky",
            "of the Night",
            "of the Nightstalker",
            "of the North",
            "of the Occult",
            "of the Oracle",
            "of the Phoenix",
            "of the Plague",
            "of the Prince",
            "of the Protector",
            "of the Queen",
            "of the Serpent",
            "of the Setting Sun",
            "of the Shadows",
            "of the Sky",
            "of the South",
            "of the Stars",
            "of the Storm",
            "of the Summoner",
            "of the Sun",
            "of the Sunwalker",
            "of the Talon",
            "of the Undying",
            "of the Victor",
            "of the Void",
            "of the West",
            "of the Whispers",
            "of the Wicked",
            "of the Wind",
            "of the Wolf",
            "of the World",
            "of the Wretched",
        ]
        var7 = [
            "Archangel",
            "Archdemon",
            "Arcus",
            "Armadillo",
            "Armageddon",
            "Arrowsong",
            "Arrowspike",
            "Avalance",
            "Back Pain",
            "Backsnipe",
            "Ballista",
            "Barrage",
            "Beesting",
            "Betrayal",
            "Betrayal's Sting",
            "Bolt",
            "Bon Voyage",
            "Bristleblitz",
            "Bullseye",
            "Calamity",
            "Chimera",
            "Clutch",
            "Comet",
            "Courier",
            "Crier",
            "Curvey",
            "Cyclone",
            "Dash",
            "Dead Air",
            "Death's Kiss",
            "Death's Sigh",
            "Death's Whisper",
            "Decimate",
            "Deliverance",
            "Deluge",
            "Destiny's Song",
            "Devil's Kiss",
            "Devil's Recurve",
            "Devil's Sting",
            "Devil's Whisper",
            "Doomcaster",
            "Drawback",
            "Drawling",
            "Drawstring",
            "Dream Catcher",
            "Eagle",
            "Eagle Strike",
            "Emily's Curve",
            "Euthanasia",
            "Falling Star",
            "Featherdraw",
            "Firestarter",
            "Fling",
            "Flux",
            "Fury",
            "Gargoyle",
            "Graviton",
            "Hailstorm",
            "Hamstring",
            "Hamstrung",
            "Harbinger",
            "Hatred's Sting",
            "Hawkeye",
            "Heartbeat",
            "Heartpiercer",
            "Heartstriker",
            "Heartstring",
            "Hedgehog",
            "Hell's Whistle",
            "High-Strung",
            "Hope's End",
            "Hornet",
            "Huntress",
            "Hurricane",
            "Hush",
            "Irk",
            "Jugular",
            "Kiss of Death",
            "Lash",
            "Lightning",
            "Long Shot",
            "Messenger",
            "Meteor",
            "Midge",
            "Mirage",
            "Misery's End",
            "Molten Fury",
            "Mosquito",
            "Netherstrand",
            "Penetrator",
            "Perfidy",
            "Phantom",
            "Phantom Strike",
            "Phoenix",
            "Pierce",
            "Pinch",
            "Pique",
            "Pluck",
            "Porcupine",
            "Precise",
            "Precision",
            "Prickle",
            "Prophet",
            "Puncture",
            "Quickstrike",
            "Quintain",
            "Rain Maker",
            "Razorsong",
            "Razorwind",
            "Recurve",
            "Rigormortis",
            "Salvation",
            "Scorpio",
            "Scorpion",
            "Shadow Strike",
            "Shooting Star",
            "Shriek",
            "Silent Messenger",
            "Silentsong",
            "Siren's Call",
            "Siren's Cry",
            "Siren's Song",
            "Sky Piercer",
            "Skyfire",
            "Snatch",
            "Snipe",
            "Snitch",
            "Soulstring",
            "Spitfire",
            "Splinter",
            "Splintermark",
            "Squawk",
            "Squirm",
            "Star's Fury",
            "Starshot",
            "Starstruck",
            "Sting",
            "Stormsong",
            "Stryker",
            "Surprise",
            "Swiftwind",
            "Swoosh",
            "Talonstrike",
            "Tempest",
            "The Ambassador",
            "The Messenger",
            "Thunder",
            "Thunderstrike",
            "Tiebreaker",
            "Tranquility",
            "Truestrike",
            "Tweak",
            "Twisted",
            "Twister",
            "Twitch",
            "Typhoon",
            "Valkyrie",
            "Venomstrike",
            "Viper",
            "Vixen",
            "Vulture",
            "Warsong",
            "Wasp",
            "Whelm",
            "Whisper",
            "Whisperwind",
            "Windbreaker",
            "Windforce",
            "Windlass",
            "Windrunner",
            "Windstalker",
            "Windtalker",
            "WithDraw",
        ]

        num = randrange(4)
        if num == 0:
            return choice(var1).title()
        elif num == 1:
            return choice(var2) + " " + choice(var4)
        elif num == 2:
            return choice(var2) + " " + choice(var3) + " " + choice(var4)
        elif num == 3:
            return choice(var7) + " " + choice(var5) + " " + choice(var6)

    @staticmethod
    def Dagger():
        var1 = [
            "Tie Breaker",
            "Redemption",
            "Laceration",
            "Forever",
            "Silver Slicer",
            "Eternity",
            "Goodbye",
            "Abyssal Shard",
            "Aetherius",
            "Agatha",
            "Wyrmtooth",
            "Alpha",
            "Amnesia",
            "Amnesty",
            "Anarchy",
            "Anduril",
            "Anger's Tear",
            "Angerfang",
            "Apocalypse",
            "Armageddon",
            "Ashrune",
            "Backtwister",
            "Barb",
            "Betrayal",
            "Betrayer",
            "Blackfang",
            "Blackout",
            "Blacktalon",
            "Blade of a Thousand Cuts",
            "Blazefury",
            "Blind Justice",
            "Blindstrike",
            "Blink",
            "Blinkstrike",
            "Blood Weeper",
            "Bloodquench",
            "Bloodsipper",
            "Bloodweep",
            "Bonescraper",
            "Bonespike",
            "Brainpicker",
            "Broken Promise",
            "Brutality",
            "Cataclysm",
            "Catastrophe",
            "Celeste",
            "Chaos",
            "Chisel",
            "Cometfell",
            "Convergence",
            "Crisscross",
            "Crucifix",
            "Darkheart",
            "Darkness",
            "Dawn",
            "Death's Bite",
            "Death's Kiss",
            "Death's Sting",
            "Deathraze",
            "Decimation",
            "Dementia",
            "Desolation",
            "Despair",
            "Destiny's Song",
            "Devine",
            "Dirge",
            "Dissector",
            "Divinity",
            "Doomblade",
            "Doombringer",
            "Doomspike",
            "Dragonclaw",
            "Dragonfang",
            "Dragontooth",
            "Draughtbane",
            "Due Diligence",
            "Dustbringer",
            "Ebony",
            "Echo",
            "Eclipse",
            "Edge of Eternity",
            "Edge of Insanity",
            "Edge of Time",
            "Endbringer",
            "Enigma",
            "Epilogue",
            "Eternal Rest",
            "Extinction",
            "Faithkeeper",
            "Fate",
            "Fear",
            "Felstriker",
            "Fleshrender",
            "Fleshshaper",
            "Flicker",
            "Frenzy",
            "Frightalon",
            "Fury",
            "Garotte",
            "Ghost Reaver",
            "Ghost Shard",
            "Ghostwalker",
            "Gladius",
            "Glimmer",
            "Grasscutter",
            "Grieving Blade",
            "Gutrender",
            "Gutwrencher",
            "Harmony",
            "Hatred's Bite",
            "Heartpierce",
            "Heartrazor",
            "Heartseeker",
            "Heartshiver",
            "Heartstriker",
            "Hell's Scream",
            "Hellfire",
            "Hollow Silence",
            "Honor's Call",
            "Hope's End",
            "Hysteria",
            "Icefall",
            "Incision",
            "Infamy",
            "Infinity",
            "Insanity",
            "Interrogator",
            "Ivory",
            "Justice",
            "Kingsbane",
            "Kingsfall",
            "Kinslayer",
            "Knight's Fall",
            "Knightfall",
            "Lament",
            "Last Rites",
            "Last Words",
            "Lazarus",
            "Lifedrinker",
            "Lightbane",
            "Lightning",
            "Limbo",
            "Lobotomizer",
            "Loyalty",
            "Lynch",
            "Maelstrom",
            "Malice",
            "Mangler",
            "Massacre",
            "Mercy",
            "Meteor",
            "Midnight",
            "Moonlight",
            "Mournblade",
            "Murder",
            "Mutilator",
            "Nail",
            "Narcoleptic",
            "Needle",
            "Nemesis",
            "Nethersbane",
            "Night's Edge",
            "Night's Fall",
            "Nightbane",
            "Nightbite",
            "Nightcrackle",
            "Nightfall",
            "Nightkiss",
            "Nimble",
            "Nirvana",
            "Oathbreaker",
            "Oathkeeper",
            "Oblivion",
            "Omega",
            "Omen",
            "Peacekeeper",
            "Persuasion",
            "Phantom",
            "Phantom Shard",
            "Phantomstrike",
            "Phobia",
            "Piece Maker",
            "Prick",
            "Purify",
            "Quicksilver",
            "Rage",
            "Ragespike",
            "Reaper",
            "Reckoning",
            "Remorse",
            "Requiem",
            "Riddle",
            "Rigormortis",
            "Sacrifice",
            "Sanguine",
            "Savagery",
            "Scalpel",
            "Scar",
            "Scarlet",
            "Seethe",
            "Severance",
            "Shadow Strike",
            "Shadowbite",
            "Shadowfall",
            "Shadowkiss",
            "Shadowrazor",
            "Shadowshiver",
            "Shadowsong",
            "Silence",
            "Silencer",
            "Silver Saber",
            "Silverlight",
            "Siphon",
            "Slander",
            "Slice of Life",
            "Solarflare",
            "Spiderfang",
            "Spike",
            "Spineripper",
            "Spiritsever",
            "Spiteblade",
            "Stalker",
            "Starlight",
            "Starshard",
            "Stickler",
            "Sting",
            "Stinger",
            "Storm",
            "Stormbringer",
            "Stormcaller",
            "Stormtip",
            "Striker",
            "Sun Strike",
            "Sunflare",
            "Sunshard",
            "Suspension",
            "Swan Song",
            "Teaser",
            "The Black Blade",
            "The End",
            "The Facelifter",
            "The Sleeper",
            "The Stake",
            "The Unmaker",
            "The Void",
            "Thorn",
            "Thunder",
            "Timeslicer",
            "Toothpick",
            "Torment",
            "Treachery",
            "Trickster",
            "Trinity",
            "Twilight",
            "Twinkle",
            "Twister",
            "Twitch",
            "Tyrhung",
            "Valkyrie",
            "Vengeance",
            "Venom",
            "Venombite",
            "Venomkiss",
            "Venomshank",
            "Venomtip",
            "Warmonger",
            "Widow Maker",
            "Widowkiller",
            "Widowmaker",
            "Winterthorn",
        ]
        var2 = [
            "Ancient",
            "Anguish'",
            "Annihilation",
            "Antique",
            "Apocalypse",
            "Apocalyptic",
            "Arcane",
            "Arched",
            "Assassination",
            "Atuned",
            "Bandit's",
            "Baneful",
            "Banished",
            "Barbarian",
            "Barbaric",
            "Battleworn",
            "Blazefury",
            "Blood Infused",
            "Blood-Forged",
            "Bloodcursed",
            "Bloodied",
            "Bloodlord's",
            "Bloodsurge",
            "Bloodvenom",
            "Bonecarvin",
            "Brutal",
            "Brutality",
            "Burnished",
            "Cataclysm",
            "Cataclysmic",
            "Cold-Forged",
            "Corroded",
            "Corrupted",
            "Crazed",
            "Crying",
            "Cursed",
            "Curved",
            "Dancing",
            "Dark",
            "Darkness",
            "Defiled",
            "Defiling",
            "Deluded",
            "Deserted",
            "Desire's",
            "Desolation",
            "Destiny's",
            "Diabolical",
            "Dire",
            "Doom",
            "Doom's",
            "Dragon's",
            "Eerie",
            "Enchanted",
            "Engraved",
            "Eternal",
            "Executing",
            "Exiled",
            "Extinction",
            "Faith's",
            "Faithful",
            "Fancy",
            "Fearful",
            "Feral",
            "Ferocious",
            "Fierce",
            "Fiery",
            "Fire Infused",
            "Fireguard",
            "Firesoul",
            "Firestorm",
            "Flaming",
            "Flimsy",
            "Forsaken",
            "Fortune's",
            "Foul",
            "Fragile",
            "Frail",
            "Frenzied",
            "Frost",
            "Frozen",
            "Furious",
            "Fusion",
            "Ghastly",
            "Ghost-Forged",
            "Ghostly",
            "Gladiator",
            "Gladiator's",
            "Gleaming",
            "Glinting",
            "Greedy",
            "Grieving",
            "Grim",
            "Guard's",
            "Guardian's",
            "Hailstorm",
            "Hateful",
            "Haunted",
            "Heartless",
            "Heinous",
            "Hollow",
            "Holy",
            "Honed",
            "Honor's",
            "Hope's",
            "Hopeless",
            "Howling",
            "Hungering",
            "Improved",
            "Impure",
            "Incarnated",
            "Infused",
            "Inherited",
            "Isolated",
            "Jade Infused",
            "Judgement",
            "Knightly",
            "Legionnaire's",
            "Liar's",
            "Lich",
            "Lightning",
            "Lonely",
            "Loyal",
            "Lustful",
            "Lusting",
            "Mage's",
            "Malevolent",
            "Malicious",
            "Malificent",
            "Malignant",
            "Massive",
            "Mended",
            "Mercenary",
            "Military",
            "Misfortune's",
            "Misty",
            "Moonlit",
            "Mourning",
            "Nightmare",
            "Oathkeeper's",
            "Ominous",
            "Peacekeeper's",
            "Phantom",
            "Polished",
            "Possessed",
            "Pride's",
            "Prideful",
            "Primitive",
            "Promised",
            "Protector's",
            "Proud",
            "Pure",
            "Putrid",
            "Raging",
            "Recruit's",
            "Reforged",
            "Reincarnated",
            "Relentless",
            "Remorseful",
            "Renewed",
            "Renovated",
            "Replica",
            "Restored",
            "Retribution",
            "Ritual",
            "Roaring",
            "Ruby Infused",
            "Rune-Forged",
            "Rusty",
            "Savage",
            "Shadow",
            "Sharpened",
            "Silent",
            "Singed",
            "Singing",
            "Sinister",
            "Smooth",
            "Solitude's",
            "Sorrow's",
            "Soul",
            "Soul Infused",
            "Soul-Forged",
            "Soulcursed",
            "Soulless",
            "Spectral",
            "Spectral-Forged",
            "Spiteful",
            "Storm",
            "Storm-Forged",
            "Stormfury",
            "Stormguard",
            "Terror",
            "Thirsting",
            "Thirsty",
            "Thunder",
            "Thunder-Forged",
            "Thunderfury",
            "Thunderguard",
            "Thundersoul",
            "Thunderstorm",
            "Timeworn",
            "Tormented",
            "Trainee's",
            "Treachery's",
            "Twilight",
            "Twilight's",
            "Twisted",
            "Tyrannical",
            "Undead",
            "Unholy",
            "Vengeance",
            "Vengeful",
            "Venom",
            "Vicious",
            "Vile",
            "Vindication",
            "Vindictive",
            "Void",
            "Volcanic",
            "Vowed",
            "War-Forged",
            "Warlord's",
            "Warp",
            "Warped",
            "Whistling",
            "Wicked",
            "Wind's",
            "Wind-Forged",
            "Windsong",
            "Woeful",
            "Wrathful",
            "Wretched",
            "Yearning",
            "Zealous",
        ]
        var3 = [
            "Adamantite",
            "Bronze",
            "Copper",
            "Diamond",
            "Ebon",
            "Ebonsteel",
            "Ebony",
            "Glass",
            "Gold",
            "Iron",
            "Ironbark",
            "Ivory",
            "Mithril",
            "Obsidian",
            "Onyx",
            "Phantomsteel",
            "Shadowsteel",
            "Silver",
            "Skeletal",
            "Steel",
        ]
        var4 = [
            "Bayonet",
            "Blade",
            "Carver",
            "Dagger",
            "Deflector",
            "Dirk",
            "Doomblade",
            "Ebonblade",
            "Etcher",
            "Fang",
            "Guardian",
            "Knife",
            "Kris",
            "Mageblade",
            "Piercer",
            "Protector",
            "Quickblade",
            "Razor",
            "Reaver",
            "Sabre",
            "Scalpel",
            "Sculptor",
            "Shanker",
            "Shiv",
            "Shortblade",
            "Shortsword",
            "Skewer",
            "Slicer",
            "Spellblade",
            "Stiletto",
            "Swiftblade",
        ]
        var5 = [
            "Annihilation",
            "Bayonet",
            "Betrayer",
            "Blade",
            "Blessed Blade",
            "Blood Blade",
            "Bond",
            "Boon",
            "Breaker",
            "Bringer",
            "Butcher",
            "Call",
            "Carver",
            "Champion",
            "Conqueror",
            "Crusader",
            "Cry",
            "Cunning",
            "Dagger",
            "Dark Blade",
            "Dawn",
            "Defender",
            "Defiler",
            "Deflector",
            "Destroyer",
            "Dirk",
            "Doomblade",
            "Ebonblade",
            "Edge",
            "Ender",
            "Etcher",
            "Executioner",
            "Fang",
            "Favor",
            "Ferocity",
            "Foe",
            "Gift",
            "Glory",
            "Guardian",
            "Heirloom",
            "Hope",
            "Incarnation",
            "Jaws",
            "Knife",
            "Kris",
            "Last Hope",
            "Last Stand",
            "Legacy",
            "Mageblade",
            "Memory",
            "Might",
            "Oath",
            "Pact",
            "Piercer",
            "Pledge",
            "Promise",
            "Protector",
            "Quickblade",
            "Ravager",
            "Razor",
            "Reach",
            "Reaper",
            "Reaver",
            "Runed Blade",
            "Saber",
            "Sabre",
            "Savagery",
            "Scalpel",
            "Sculptor",
            "Secret",
            "Shanker",
            "Shiv",
            "Shortblade",
            "Skewer",
            "Slayer",
            "Slicer",
            "Soul",
            "Spellblade",
            "Spine",
            "Stiletto",
            "Swiftblade",
            "Terror",
            "Token",
            "Tribute",
            "Vengeance",
            "Voice",
            "Warblade",
            "Whisper",
            "Wit",
        ]
        var6 = [
            "of Agony",
            "of Ancient Power",
            "of Anguish",
            "of Ashes",
            "of Assassins",
            "of Black Magic",
            "of Blessed Fortune",
            "of Blessings",
            "of Blight",
            "of Blood",
            "of Bloodlust",
            "of Broken Bones",
            "of Broken Dreams",
            "of Broken Families",
            "of Burdens",
            "of Chaos",
            "of Closing Eyes",
            "of Conquered Worlds",
            "of Corruption",
            "of Cruelty",
            "of Cunning",
            "of Dark Magic",
            "of Dark Souls",
            "of Darkness",
            "of Decay",
            "of Deception",
            "of Degradation",
            "of Delusions",
            "of Denial",
            "of Desecration",
            "of Dilusion",
            "of Dismay",
            "of Dragonsouls",
            "of Due Diligence",
            "of Echoes",
            "of Ended Dreams",
            "of Ending Hope",
            "of Ending Misery",
            "of Eternal Bloodlust",
            "of Eternal Damnation",
            "of Eternal Glory",
            "of Eternal Justice",
            "of Eternal Rest",
            "of Eternal Sorrow",
            "of Eternal Struggles",
            "of Eternity",
            "of Executions",
            "of Faded Memories",
            "of Fallen Souls",
            "of Fools",
            "of Frost",
            "of Frozen Hells",
            "of Fury",
            "of Giants",
            "of Giantslaying",
            "of Grace",
            "of Grieving Widows",
            "of Hate",
            "of Hatred",
            "of Hell's Games",
            "of Hellish Torment",
            "of Heroes",
            "of Holy Might",
            "of Honor",
            "of Hope",
            "of Horrid Dreams",
            "of Horrors",
            "of Illuminated Dreams",
            "of Illumination",
            "of Immortality",
            "of Inception",
            "of Infinite Trials",
            "of Insanity",
            "of Invocation",
            "of Justice",
            "of Light's Hope",
            "of Lost Comrades",
            "of Lost Hope",
            "of Lost Voices",
            "of Lost Worlds",
            "of Magic",
            "of Mercy",
            "of Misery",
            "of Mountains",
            "of Mourning",
            "of Mystery",
            "of Necromancy",
            "of Nightmares",
            "of Oblivion",
            "of Perdition",
            "of Phantoms",
            "of Power",
            "of Pride",
            "of Pride's Fall",
            "of Putrefaction",
            "of Reckoning",
            "of Redemption",
            "of Regret",
            "of Riddles",
            "of Secrecy",
            "of Secrets",
            "of Shadow Strikes",
            "of Shadows",
            "of Shifting Sands",
            "of Shifting Worlds",
            "of Silence",
            "of Slaughter",
            "of Souls",
            "of Stealth",
            "of Storms",
            "of Subtlety",
            "of Suffering",
            "of Suffering's End",
            "of Summoning",
            "of Terror",
            "of Thunder",
            "of Time-Lost Memories",
            "of Timeless Battles",
            "of Titans",
            "of Torment",
            "of Traitors",
            "of Trembling Hands",
            "of Trials",
            "of Truth",
            "of Twilight's End",
            "of Twisted Visions",
            "of Unholy Blight",
            "of Unholy Might",
            "of Vengeance",
            "of Visions",
            "of Wasted Time",
            "of Widows",
            "of Wizardry",
            "of Woe",
            "of Wraiths",
            "of Zeal",
            "of the Ancients",
            "of the Banished",
            "of the Basilisk",
            "of the Beast",
            "of the Blessed",
            "of the Breaking Storm",
            "of the Brotherhood",
            "of the Burning Sun",
            "of the Caged Mind",
            "of the Cataclysm",
            "of the Champion",
            "of the Claw",
            "of the Corrupted",
            "of the Covenant",
            "of the Crown",
            "of the Damned",
            "of the Daywalker",
            "of the Dead",
            "of the Depth",
            "of the Dreadlord",
            "of the Earth",
            "of the East",
            "of the Emperor",
            "of the Empty Void",
            "of the End",
            "of the Enigma",
            "of the Fallen",
            "of the Falling Sky",
            "of the Flame",
            "of the Forest",
            "of the Forgotten",
            "of the Forsaken",
            "of the Gladiator",
            "of the Harvest",
            "of the Immortal",
            "of the Incoming Storm",
            "of the Insane",
            "of the King",
            "of the Lasting Night",
            "of the Leviathan",
            "of the Light",
            "of the Lion",
            "of the Lionheart",
            "of the Lone Victor",
            "of the Lone Wolf",
            "of the Lost",
            "of the Moon",
            "of the Moonwalker",
            "of the Night Sky",
            "of the Night",
            "of the Nightstalker",
            "of the North",
            "of the Occult",
            "of the Oracle",
            "of the Phoenix",
            "of the Plague",
            "of the Prince",
            "of the Protector",
            "of the Queen",
            "of the Serpent",
            "of the Setting Sun",
            "of the Shadows",
            "of the Sky",
            "of the South",
            "of the Stars",
            "of the Storm",
            "of the Summoner",
            "of the Sun",
            "of the Sunwalker",
            "of the Talon",
            "of the Undying",
            "of the Victor",
            "of the Void",
            "of the West",
            "of the Whispers",
            "of the Wicked",
            "of the Wind",
            "of the Wolf",
            "of the World",
            "of the Wretched",
        ]
        var7 = [
            "Tie Breaker",
            "Laceration",
            "Forever",
            "Silver Slicer",
            "Eternity",
            "Goodbye",
            "Aetherius",
            "Agatha",
            "Alpha",
            "Amnesia",
            "Amnesty",
            "Anarchy",
            "Anduril",
            "Anger's Tear",
            "Angerfang",
            "Apocalypse",
            "Armageddon",
            "Ashrune",
            "Backtwister",
            "Barb",
            "Betrayal",
            "Betrayer",
            "Blackfang",
            "Blackout",
            "Blacktalon",
            "Blazefury",
            "Blind Justice",
            "Blindstrike",
            "Blink",
            "Blinkstrike",
            "Blood Weeper",
            "Bloodquench",
            "Bloodsipper",
            "Bloodweep",
            "Bonescraper",
            "Bonespike",
            "Brainpicker",
            "Broken Promise",
            "Brutality",
            "Cataclysm",
            "Catastrophe",
            "Celeste",
            "Chaos",
            "Chisel",
            "Cometfell",
            "Convergence",
            "Crisscross",
            "Crucifix",
            "Darkheart",
            "Darkness",
            "Dawn",
            "Death's Bite",
            "Death's Kiss",
            "Death's Sting",
            "Deathraze",
            "Decimation",
            "Dementia",
            "Desolation",
            "Despair",
            "Devine",
            "Dirge",
            "Dissector",
            "Divinity",
            "Doomblade",
            "Doombringer",
            "Doomspike",
            "Dragonclaw",
            "Dragonfang",
            "Dragontooth",
            "Draughtbane",
            "Due Diligence",
            "Dustbringer",
            "Echo",
            "Eclipse",
            "Edge of Eternity",
            "Edge of Insanity",
            "Edge of Time",
            "Endbringer",
            "Enigma",
            "Epilogue",
            "Eternal Rest",
            "Extinction",
            "Faithkeeper",
            "Fate",
            "Fear",
            "Felstriker",
            "Fleshrender",
            "Fleshshaper",
            "Flicker",
            "Frenzy",
            "Frightalon",
            "Fury",
            "Garotte",
            "Ghost Reaver",
            "Ghost Shard",
            "Ghostwalker",
            "Glimmer",
            "Gutrender",
            "Gutwrencher",
            "Harmony",
            "Hatred's Bite",
            "Heartpierce",
            "Heartrazor",
            "Heartseeker",
            "Heartshiver",
            "Heartstriker",
            "Hell's Scream",
            "Hellfire",
            "Honor's Call",
            "Hope's End",
            "Hysteria",
            "Icefall",
            "Incision",
            "Infamy",
            "Infinity",
            "Insanity",
            "Interrogator",
            "Ivory",
            "Justice",
            "Kingsbane",
            "Kingsfall",
            "Kinslayer",
            "Knight's Fall",
            "Knightfall",
            "Lament",
            "Last Rites",
            "Last Words",
            "Lazarus",
            "Lifedrinker",
            "Lightbane",
            "Lightning",
            "Limbo",
            "Lobotomizer",
            "Lynch",
            "Maelstrom",
            "Malice",
            "Mangler",
            "Massacre",
            "Mercy",
            "Meteor",
            "Midnight",
            "Moonlight",
            "Mournblade",
            "Murder",
            "Mutilator",
            "Nail",
            "Narcoleptic",
            "Needle",
            "Nemesis",
            "Nethersbane",
            "Night's Edge",
            "Night's Fall",
            "Nightbane",
            "Nightbite",
            "Nightcrackle",
            "Nightfall",
            "Nightkiss",
            "Nimble",
            "Nirvana",
            "Oathbreaker",
            "Oathkeeper",
            "Oblivion",
            "Omega",
            "Omen",
            "Peacekeeper",
            "Persuasion",
            "Phantom",
            "Phantom Shard",
            "Phantomstrike",
            "Phobia",
            "Piece Maker",
            "Prick",
            "Purify",
            "Quicksilver",
            "Rage",
            "Ragespike",
            "Reaper",
            "Reckoning",
            "Remorse",
            "Requiem",
            "Riddle",
            "Rigormortis",
            "Sacrifice",
            "Sanguine",
            "Savagery",
            "Scalpel",
            "Scar",
            "Scarlet",
            "Seethe",
            "Severance",
            "Shadow Strike",
            "Shadowbite",
            "Shadowfall",
            "Shadowkiss",
            "Shadowrazor",
            "Shadowshiver",
            "Shadowsong",
            "Silence",
            "Silencer",
            "Silver Saber",
            "Silverlight",
            "Siphon",
            "Slander",
            "Slice of Life",
            "Solarflare",
            "Spiderfang",
            "Spike",
            "Spineripper",
            "Spiritsever",
            "Spiteblade",
            "Stalker",
            "Starlight",
            "Starshard",
            "Stickler",
            "Sting",
            "Stinger",
            "Storm",
            "Stormbringer",
            "Stormcaller",
            "Stormtip",
            "Striker",
            "Sun Strike",
            "Sunflare",
            "Sunshard",
            "Suspension",
            "Swan Song",
            "Teaser",
            "The Black Blade",
            "The End",
            "The Facelifter",
            "The Sleeper",
            "The Taker",
            "The Undertaker",
            "The Stake",
            "The Unmaker",
            "The Void",
            "Thorn",
            "Thunder",
            "Timeslicer",
            "Toothpick",
            "Torment",
            "Treachery",
            "Trickster",
            "Trinity",
            "Twilight",
            "Twinkle",
            "Twister",
            "Twitch",
            "Tyrhung",
            "Valkyrie",
            "Vengeance",
            "Venom",
            "Venombite",
            "Venomkiss",
            "Venomshank",
            "Venomtip",
            "Warmonger",
            "Widow Maker",
            "Widowkiller",
            "Widowmaker",
            "Winterthorn",
        ]

        num = randrange(4)
        if num == 0:
            return choice(var1).title()
        elif num == 1:
            return choice(var2) + " " + choice(var4)
        elif num == 2:
            return choice(var2) + " " + choice(var3) + " " + choice(var4)
        elif num == 3:
            return choice(var7) + " " + choice(var5) + " " + choice(var6)

    @staticmethod
    def Hammer():
        var1 = [
            "Abomination",
            "Agatha",
            "Agony",
            "Allegiance",
            "Alpha",
            "Amnesia",
            "Anduril",
            "Apocalypse",
            "Armageddon",
            "Arondite",
            "Ash",
            "Ashes",
            "Ashrune",
            "Back Breaker",
            "Battlestar",
            "Betrayal",
            "Betrayer",
            "Blackout",
            "Blazeguard",
            "Blessing",
            "Blind Justice",
            "Bloodfury",
            "Bloodmoon",
            "Bloodquench",
            "Bloodrage",
            "Bloodspiller",
            "Bloodweep",
            "Bone Warden",
            "Bonesnapper",
            "Braindead",
            "Broken Promise",
            "Brutality",
            "Brutalizer",
            "Cataclysm",
            "Catastrophe",
            "Celeste",
            "Chance",
            "Chaos",
            "Chasm",
            "Chieftain",
            "Comet",
            "Cometfall",
            "Concussion",
            "Convergence",
            "Corpsemaker",
            "Corruption",
            "Cosmos",
            "Crash",
            "Crimson",
            "Crush",
            "Cryptmaker",
            "Cyclone",
            "Darkness",
            "Dawn",
            "Dawnbreaker",
            "Daytime",
            "Deathbringer",
            "Deathraze",
            "Decimation",
            "Demise",
            "Desolation",
            "Despair",
            "Destiny",
            "Destruction",
            "Devastation",
            "Devine",
            "Devotion",
            "Devourer",
            "Disturbance",
            "Divine Light",
            "Dominance",
            "Dominion",
            "Doom",
            "Doombringer",
            "Dragonfist",
            "Dragonmaw",
            "Dragonstrike",
            "Due Diligence",
            "Early Retirement",
            "Earthquake",
            "Earthshaker",
            "Earthshaper",
            "Earthwarden",
            "Echo",
            "Eclipse",
            "Emergency",
            "End of Dreams",
            "Endbringer",
            "Enigma",
            "Epilogue",
            "Eternal Rest",
            "Eternity",
            "Eveningstar",
            "Extermination",
            "Extinction",
            "Faithkeeper",
            "Falcon",
            "Falling Star",
            "Fate",
            "Finality",
            "Frenzy",
            "Frostwind",
            "Fury",
            "Fury's Gaze",
            "Galaxy",
            "Gatecrasher",
            "Ghost Reaver",
            "Ghostwalker",
            "Glimmer",
            "Godslayer",
            "Grace",
            "Guiding Star",
            "Harbinger",
            "Harmony",
            "Harvester",
            "Hatred",
            "Heartcrusher",
            "Hell's Scream",
            "Hellfire",
            "Homage",
            "Honor's Call",
            "Hope's End",
            "Humongous",
            "Hurricane",
            "Icebreaker",
            "Infamy",
            "Infinity",
            "Interrogator",
            "Jackhammer",
            "Jawbone",
            "Justice",
            "Justifier",
            "King's Defender",
            "King's Legacy",
            "Kinslayer",
            "Knight's Fall",
            "Knight's Honor",
            "Knightfall",
            "Lament",
            "Last Chance",
            "Last Laugh",
            "Last Rites",
            "Last Word",
            "Last Words",
            "Lazarus",
            "Legacy",
            "Legionaire",
            "Life's Limit",
            "Light's Bane",
            "Lightbane",
            "Lightbringer",
            "Lightning",
            "Limbo",
            "Lockjaw",
            "Magma",
            "Malice",
            "Maneater",
            "Massacre",
            "Mercy",
            "Midnight",
            "Misery's End",
            "Monsoon",
            "Morningstar",
            "Narcoleptic",
            "Nethersbane",
            "Night's Fall",
            "Nightbane",
            "Nightfall",
            "Nightglow",
            "Nightmare",
            "Nighttime",
            "Nirvana",
            "Oathbreaker",
            "Oathkeeper",
            "Oblivion",
            "Old Age",
            "Omega",
            "Orbit",
            "Orenmir",
            "Oxheart",
            "Party Pooper",
            "Patience",
            "Peacekeeper",
            "Peacemaker",
            "Pendulum",
            "Perfect Storm",
            "Persuasion",
            "Piece Maker",
            "Piety",
            "Pride",
            "Prophecy",
            "Punisher",
            "Purifier",
            "Rage",
            "Ragnarok",
            "Rapture",
            "Reaper's Toll",
            "Reckoning",
            "Red Dwarf",
            "Reign",
            "Remorse",
            "Requiem",
            "Retirement",
            "Righteous Might",
            "Rigormortis",
            "Rising Tide",
            "Savagery",
            "Scar",
            "Scourgeborne",
            "Second Chance",
            "Seism",
            "Seismic",
            "Serenity",
            "Severance",
            "Shadowfury",
            "Shadowmoon",
            "Shatterskull",
            "Shooting Star",
            "Silence",
            "Skullcrusher",
            "Soul Breaker",
            "Spinefall",
            "Stalker",
            "Stonefist",
            "Storm",
            "Storm Breaker",
            "Storm-Weaver",
            "Stormbringer",
            "Stormcaller",
            "Stormedge",
            "Stormherald",
            "Stormrider",
            "Sucker Punch",
            "Sundown",
            "Supernova",
            "Supremacy",
            "Suspension",
            "Swan Song",
            "Tank",
            "Tenderiser",
            "Termination",
            "The Ambassador",
            "The Chancellor",
            "The Chief",
            "The End",
            "The Light",
            "The Minotaur",
            "The Oculus",
            "The Oracle",
            "The Sundering",
            "The Void",
            "The Warden",
            "Thunder",
            "Trauma",
            "Treachery",
            "Tremor",
            "Trinity",
            "Twilight",
            "Typhoon",
            "Ubiquity",
            "Undoing",
            "Vacancy",
            "Valkyrie",
            "Vanquisher",
            "Vengeance",
            "Warbringer",
            "Warmonger",
            "Whirlwind",
            "Wicked",
            "Widow Maker",
            "Willbreaker",
            "Winter's Bite",
            "Wit's End",
            "Witherbrand",
            "Wolf",
            "Worldbreaker",
            "Worldcarver",
            "Worldslayer",
        ]
        var2 = [
            "Ancient",
            "Antique",
            "Apocalypse",
            "Apocalyptic",
            "Arcane",
            "Arched",
            "Atuned",
            "Bandit's",
            "Baneful",
            "Banished",
            "Barbarian",
            "Barbaric",
            "Battleworn",
            "Blazefury",
            "Blood Infused",
            "Blood-Forged",
            "Bloodcursed",
            "Bloodied",
            "Bloodlord's",
            "Bloodsurge",
            "Bloodvenom",
            "Bonecarvin",
            "Brutal",
            "Brutality",
            "Burnished",
            "Cataclysm",
            "Cataclysmic",
            "Challenger",
            "Challenger's",
            "Champion",
            "Champion's",
            "Cold-Forged",
            "Conqueror",
            "Conqueror's",
            "Corroded",
            "Corrupted",
            "Crazed",
            "Crying",
            "Cursed",
            "Curved",
            "Dancing",
            "Dark",
            "Darkness",
            "Defender",
            "Defender's",
            "Defiled",
            "Defiling",
            "Deluded",
            "Demonic",
            "Deserted",
            "Desire's",
            "Desolation",
            "Destiny's",
            "Diabolical",
            "Dire",
            "Doom",
            "Doom's",
            "Dragon's",
            "Dragonbreath",
            "Eerie",
            "Enchanted",
            "Engraved",
            "Enlightened",
            "Eternal",
            "Exiled",
            "Extinction",
            "Faith's",
            "Faithful",
            "Fancy",
            "Fearful",
            "Feral",
            "Ferocious",
            "Fierce",
            "Fiery",
            "Fire Infused",
            "Fireguard",
            "Firesoul",
            "Firestorm",
            "Flaming",
            "Flimsy",
            "Forsaken",
            "Fortune's",
            "Foul",
            "Fragile",
            "Frail",
            "Frenzied",
            "Frost",
            "Frozen",
            "Furious",
            "Fusion",
            "Ghastly",
            "Ghost",
            "Ghost-Forged",
            "Ghostly",
            "Gladiator",
            "Gladiator's",
            "Gleaming",
            "Glinting",
            "Greedy",
            "Grieving",
            "Grim",
            "Guard's",
            "Guardian's",
            "Hailstorm",
            "Harmonized",
            "Hateful",
            "Haunted",
            "Heartless",
            "Heinous",
            "Hero",
            "Hero's",
            "Hollow",
            "Holy",
            "Honed",
            "Honor's",
            "Hope's",
            "Hopeless",
            "Howling",
            "Hungering",
            "Improved",
            "Impure",
            "Incarnated",
            "Infused",
            "Inherited",
            "Isolated",
            "Jade Infused",
            "Judgement",
            "Keeper's",
            "Knightly",
            "Knight's",
            "Legionnaire's",
            "Liar's",
            "Lich",
            "Lightning",
            "Lonely",
            "Loyal",
            "Lustful",
            "Lusting",
            "Malevolent",
            "Malicious",
            "Malificent",
            "Malignant",
            "Massive",
            "Mended",
            "Mercenary",
            "Military",
            "Misfortune's",
            "Misty",
            "Moonlit",
            "Mourning",
            "Nightmare",
            "Oathkeeper's",
            "Ominous",
            "Peacekeeper",
            "Peacekeeper's",
            "Phantom",
            "Polished",
            "Possessed",
            "Pride's",
            "Prideful",
            "Primal",
            "Prime",
            "Primitive",
            "Promised",
            "Protector's",
            "Proud",
            "Pure",
            "Putrid",
            "Raging",
            "Recruit's",
            "Refined",
            "Reforged",
            "Reincarnated",
            "Relentless",
            "Remorseful",
            "Renewed",
            "Renovated",
            "Replica",
            "Restored",
            "Retribution",
            "Ritual",
            "Roaring",
            "Ruby Infused",
            "Rune-Forged",
            "Runed",
            "Rusty",
            "Savage",
            "Sentinel",
            "Shadow",
            "Shamanic",
            "Sharpened",
            "Silent",
            "Singed",
            "Singing",
            "Sinister",
            "Skyfall",
            "Smooth",
            "Soldier's",
            "Solitude's",
            "Sorcerer's",
            "Sorrow's",
            "Soul",
            "Soul Infused",
            "Soul-Forged",
            "Soulcursed",
            "Soulless",
            "Spectral",
            "Spectral-Forged",
            "Spiteful",
            "Storm",
            "Storm-Forged",
            "Stormfury",
            "Stormguard",
            "Terror",
            "Thirsting",
            "Thirsty",
            "Thunder",
            "Thunder-Forged",
            "Thunderfury",
            "Thunderguard",
            "Thundersoul",
            "Thunderstorm",
            "Timeworn",
            "Tormented",
            "Trainee's",
            "Treachery's",
            "Twilight",
            "Twilight's",
            "Twisted",
            "Tyrannical",
            "Undead",
            "Unholy",
            "Vanquisher",
            "Vengeance",
            "Vengeful",
            "Venom",
            "Vicious",
            "Victor",
            "Vile",
            "Vindication",
            "Vindicator",
            "Vindictive",
            "Void",
            "Volcanic",
            "Vowed",
            "War",
            "War-Forged",
            "Warden's",
            "Warlord's",
            "Warp",
            "Warped",
            "Warrior",
            "Warrior's",
            "Whistling",
            "Wicked",
            "Wind's",
            "Wind-Forged",
            "Windsong",
            "Woeful",
            "Wrathful",
            "Wretched",
            "Yearning",
            "Zealous",
        ]
        var3 = [
            "Adamantite",
            "Bone",
            "Bronze",
            "Bronzed",
            "Ivory",
            "Ebon",
            "Glass",
            "Golden",
            "Iron",
            "Ironbark",
            "Mithril",
            "Obsidian",
            "Silver",
            "Skeletal",
            "Steel",
            "Titanium",
        ]
        var4 = [
            "Mace",
            "Bludgeon",
            "Maul",
            "Hammer",
            "Mallet",
            "Crusher",
            "Battlehammer",
            "Greathammer",
            "Smasher",
            "Warmace",
            "Hammer",
            "Mace",
            "Scepter",
            "Pummeler",
        ]
        var5 = [
            "Allegiance",
            "Annihilation",
            "Battlehammer",
            "Betrayer",
            "Bludgeon",
            "Bond",
            "Boon",
            "Breaker",
            "Bringer",
            "Bruiser",
            "Butcher",
            "Call",
            "Champion",
            "Conqueror",
            "Crusader",
            "Crusher",
            "Cry",
            "Cunning",
            "Dawn",
            "Defender",
            "Defiler",
            "Destroyer",
            "Disposer",
            "Ender",
            "Executioner",
            "Favor",
            "Ferocity",
            "Foe",
            "Gift",
            "Glory",
            "Greathammer",
            "Guardian",
            "Hammer",
            "Heirloom",
            "Hope",
            "Incarnation",
            "Jaws",
            "Last Hope",
            "Last Stand",
            "Legacy",
            "Mace",
            "Mallet",
            "Masher",
            "Maul",
            "Memory",
            "Might",
            "Oath",
            "Pact",
            "Pledge",
            "Pounder",
            "Promise",
            "Prophecy",
            "Protector",
            "Pummeler",
            "Queller",
            "Ravager",
            "Reach",
            "Reaper",
            "Scepter",
            "Sculptor",
            "Secret",
            "Slayer",
            "Smasher",
            "Soul",
            "Suppressor",
            "Terror",
            "Token",
            "Tribute",
            "Vengeance",
            "Voice",
            "Warmace",
            "Whisper",
            "Wit",
        ]
        var6 = [
            "of Agony",
            "of Ancient Power",
            "of Anguish",
            "of Ashes",
            "of Assassins",
            "of Black Magic",
            "of Blessed Fortune",
            "of Blessings",
            "of Blight",
            "of Blood",
            "of Bloodlust",
            "of Broken Bones",
            "of Broken Dreams",
            "of Broken Families",
            "of Burdens",
            "of Chaos",
            "of Closing Eyes",
            "of Conquered Worlds",
            "of Corruption",
            "of Cruelty",
            "of Cunning",
            "of Dark Magic",
            "of Dark Souls",
            "of Darkness",
            "of Decay",
            "of Deception",
            "of Degradation",
            "of Delusions",
            "of Denial",
            "of Desecration",
            "of Diligence",
            "of Dismay",
            "of Dragonsouls",
            "of Due Diligence",
            "of Echoes",
            "of Ended Dreams",
            "of Ending Hope",
            "of Ending Misery",
            "of Eternal Bloodlust",
            "of Eternal Damnation",
            "of Eternal Glory",
            "of Eternal Justice",
            "of Eternal Rest",
            "of Eternal Sorrow",
            "of Eternal Struggles",
            "of Eternity",
            "of Executions",
            "of Faded Memories",
            "of Fallen Souls",
            "of Fools",
            "of Frost",
            "of Frozen Hells",
            "of Fury",
            "of Giants",
            "of Giantslaying",
            "of Grace",
            "of Grieving Widows",
            "of Hate",
            "of Hatred",
            "of Hell's Games",
            "of Hellish Torment",
            "of Heroes",
            "of Holy Might",
            "of Honor",
            "of Hope",
            "of Horrid Dreams",
            "of Horrors",
            "of Illuminated Dreams",
            "of Illumination",
            "of Immortality",
            "of Inception",
            "of Infinite Trials",
            "of Insanity",
            "of Invocation",
            "of Justice",
            "of Light's Hope",
            "of Lost Comrades",
            "of Lost Hope",
            "of Lost Voices",
            "of Lost Worlds",
            "of Magic",
            "of Mercy",
            "of Misery",
            "of Mountains",
            "of Mourning",
            "of Mystery",
            "of Necromancy",
            "of Nightmares",
            "of Oblivion",
            "of Perdition",
            "of Phantoms",
            "of Power",
            "of Pride",
            "of Pride's Fall",
            "of Putrefaction",
            "of Reckoning",
            "of Redemption",
            "of Regret",
            "of Riddles",
            "of Secrecy",
            "of Secrets",
            "of Shadow Strikes",
            "of Shadows",
            "of Shifting Sands",
            "of Shifting Worlds",
            "of Silence",
            "of Slaughter",
            "of Souls",
            "of Stealth",
            "of Storms",
            "of Subtlety",
            "of Suffering",
            "of Suffering's End",
            "of Summoning",
            "of Terror",
            "of Thunder",
            "of Time-Lost Memories",
            "of Timeless Battles",
            "of Titans",
            "of Torment",
            "of Traitors",
            "of Trembling Hands",
            "of Trials",
            "of Truth",
            "of Twilight's End",
            "of Twisted Visions",
            "of Unholy Blight",
            "of Unholy Might",
            "of Vengeance",
            "of Visions",
            "of Wasted Time",
            "of Widows",
            "of Wizardry",
            "of Woe",
            "of Wraiths",
            "of Zeal",
            "of the Ancients",
            "of the Banished",
            "of the Basilisk",
            "of the Beast",
            "of the Blessed",
            "of the Breaking Storm",
            "of the Brotherhood",
            "of the Burning Sun",
            "of the Caged Mind",
            "of the Cataclysm",
            "of the Champion",
            "of the Claw",
            "of the Corrupted",
            "of the Covenant",
            "of the Crown",
            "of the Damned",
            "of the Daywalker",
            "of the Dead",
            "of the Depth",
            "of the Dreadlord",
            "of the Earth",
            "of the East",
            "of the Emperor",
            "of the Empty Void",
            "of the End",
            "of the Enigma",
            "of the Fallen",
            "of the Falling Sky",
            "of the Flame",
            "of the Forest",
            "of the Forgotten",
            "of the Forsaken",
            "of the Gladiator",
            "of the Harvest",
            "of the Immortal",
            "of the Incoming Storm",
            "of the Insane",
            "of the King",
            "of the Lasting Night",
            "of the Leviathan",
            "of the Light",
            "of the Lion",
            "of the Lionheart",
            "of the Lone Victor",
            "of the Lone Wolf",
            "of the Lost",
            "of the Moon",
            "of the Moonwalker",
            "of the Night Sky",
            "of the Night",
            "of the Nightstalker",
            "of the North",
            "of the Occult",
            "of the Oracle",
            "of the Phoenix",
            "of the Plague",
            "of the Prince",
            "of the Protector",
            "of the Queen",
            "of the Serpent",
            "of the Setting Sun",
            "of the Shadows",
            "of the Sky",
            "of the South",
            "of the Stars",
            "of the Storm",
            "of the Summoner",
            "of the Sun",
            "of the Sunwalker",
            "of the Talon",
            "of the Undying",
            "of the Victor",
            "of the Void",
            "of the West",
            "of the Whispers",
            "of the Wicked",
            "of the Wind",
            "of the Wolf",
            "of the World",
            "of the Wretched",
        ]
        var7 = [
            "Abomination",
            "Agatha",
            "Agony",
            "Allegiance",
            "Alpha",
            "Amnesia",
            "Anduril",
            "Apocalypse",
            "Armageddon",
            "Arondite",
            "Ash",
            "Ashes",
            "Ashrune",
            "Back Breaker",
            "Battlestar",
            "Betrayal",
            "Betrayer",
            "Blackout",
            "Blazeguard",
            "Blessing",
            "Blind Justice",
            "Bloodfury",
            "Bloodmoon",
            "Bloodquench",
            "Bloodrage",
            "Bloodspiller",
            "Bloodweep",
            "Bone Warden",
            "Bonesnapper",
            "Braindead",
            "Broken Promise",
            "Brutality",
            "Brutalizer",
            "Cataclysm",
            "Catastrophe",
            "Celeste",
            "Chance",
            "Chaos",
            "Chasm",
            "Chieftain",
            "Comet",
            "Cometfall",
            "Concussion",
            "Convergence",
            "Corpsemaker",
            "Corruption",
            "Cosmos",
            "Crash",
            "Crimson",
            "Crush",
            "Cryptmaker",
            "Cyclone",
            "Darkness",
            "Dawn",
            "Dawnbreaker",
            "Daytime",
            "Deathbringer",
            "Deathraze",
            "Decimation",
            "Demise",
            "Desolation",
            "Despair",
            "Destiny",
            "Destruction",
            "Devastation",
            "Devine",
            "Devotion",
            "Devourer",
            "Disturbance",
            "Divine Light",
            "Dominance",
            "Dominion",
            "Doom",
            "Doombringer",
            "Dragonfist",
            "Dragonmaw",
            "Dragonstrike",
            "Due Diligence",
            "Earthquake",
            "Earthshaker",
            "Earthshaper",
            "Earthwarden",
            "Echo",
            "Eclipse",
            "Emergency",
            "End of Dreams",
            "Endbringer",
            "Enigma",
            "Epilogue",
            "Eternal Rest",
            "Eternity",
            "Eveningstar",
            "Extermination",
            "Extinction",
            "Faithkeeper",
            "Falcon",
            "Falling Star",
            "Fate",
            "Finality",
            "Frenzy",
            "Frostwind",
            "Fury",
            "Fury's Gaze",
            "Galaxy",
            "Gatecrasher",
            "Ghost Reaver",
            "Ghostwalker",
            "Glimmer",
            "Godslayer",
            "Grace",
            "Guiding Star",
            "Harbinger",
            "Harmony",
            "Harvester",
            "Hatred",
            "Heartcrusher",
            "Hell's Scream",
            "Hellfire",
            "Homage",
            "Honor's Call",
            "Hope's End",
            "Humongous",
            "Hurricane",
            "Icebreaker",
            "Infamy",
            "Infinity",
            "Interrogator",
            "Jackhammer",
            "Jawbone",
            "Justice",
            "Justifier",
            "King's Defender",
            "King's Legacy",
            "Kinslayer",
            "Knight's Fall",
            "Knight's Honor",
            "Knightfall",
            "Lament",
            "Last Chance",
            "Last Laugh",
            "Last Rites",
            "Last Word",
            "Last Words",
            "Lazarus",
            "Legacy",
            "Legionaire",
            "Life's Limit",
            "Light's Bane",
            "Lightbane",
            "Lightbringer",
            "Lightning",
            "Limbo",
            "Lockjaw",
            "Magma",
            "Malice",
            "Maneater",
            "Massacre",
            "Mercy",
            "Midnight",
            "Misery's End",
            "Monsoon",
            "Morningstar",
            "Narcoleptic",
            "Nethersbane",
            "Night's Fall",
            "Nightbane",
            "Nightfall",
            "Nightglow",
            "Nightmare",
            "Nighttime",
            "Nirvana",
            "Oathbreaker",
            "Oathkeeper",
            "Oblivion",
            "Old Age",
            "Omega",
            "Orbit",
            "Orenmir",
            "Oxheart",
            "Party Pooper",
            "Patience",
            "Peacekeeper",
            "Peacemaker",
            "Pendulum",
            "Perfect Storm",
            "Persuasion",
            "Piety",
            "Pride",
            "Prophecy",
            "Punisher",
            "Purifier",
            "Rage",
            "Ragnarok",
            "Rapture",
            "Reckoning",
            "Red Dwarf",
            "Reign",
            "Remorse",
            "Requiem",
            "Retirement",
            "Rigormortis",
            "Rising Tide",
            "Savagery",
            "Seism",
            "Seismic",
            "Serenity",
            "Severance",
            "Shadowfury",
            "Shatterskull",
            "Shooting Star",
            "Silence",
            "Skullcrusher",
            "Soul Breaker",
            "Spinefall",
            "Stalker",
            "Stonefist",
            "Storm",
            "Storm Breaker",
            "Storm-Weaver",
            "Stormbringer",
            "Stormcaller",
            "Stormedge",
            "Stormherald",
            "Stormrider",
            "Sucker Punch",
            "Sundown",
            "Supernova",
            "Supremacy",
            "Suspension",
            "Swan Song",
            "Tank",
            "Tenderiser",
            "Termination",
            "The Ambassador",
            "The Chancellor",
            "The Chief",
            "The End",
            "The Light",
            "The Minotaur",
            "The Oculus",
            "The Oracle",
            "The Sundering",
            "The Void",
            "The Warden",
            "Thunder",
            "Trauma",
            "Treachery",
            "Tremor",
            "Trinity",
            "Twilight",
            "Typhoon",
            "Ubiquity",
            "Undoing",
            "Vacancy",
            "Valkyrie",
            "Vanquisher",
            "Vengeance",
            "Warbringer",
            "Warmonger",
            "Whirlwind",
            "Wicked",
            "Widow Maker",
            "Willbreaker",
            "Winter's Bite",
            "Wit's End",
            "Witherbrand",
            "Wolf",
            "Worldbreaker",
            "Worldcarver",
            "Worldslayer",
        ]

        num = randrange(4)
        if num == 0:
            return choice(var1).title()
        elif num == 1:
            return choice(var2) + " " + choice(var4)
        elif num == 2:
            return choice(var2) + " " + choice(var3) + " " + choice(var4)
        elif num == 3:
            return choice(var7) + " " + choice(var5) + " " + choice(var6)

    @staticmethod
    def Mace():
        var1 = [
            "Morning Glory",
            "Morning Star",
            "Mourning Star",
            "Blackjack",
            "Tresher",
            "Good Morning",
            "Headache",
            "Migraine",
            "Grimace",
            "Macerator",
            "Abomination",
            "Agatha",
            "Agony",
            "Allegiance",
            "Alpha",
            "Amnesia",
            "Anduril",
            "Apocalypse",
            "Armageddon",
            "Arondite",
            "Ash",
            "Ashes",
            "Ashrune",
            "Back Breaker",
            "Battlestar",
            "Betrayal",
            "Betrayer",
            "Blackout",
            "Blazeguard",
            "Blessing",
            "Blind Justice",
            "Bloodfury",
            "Bloodmoon",
            "Bloodquench",
            "Bloodrage",
            "Bloodspiller",
            "Bloodweep",
            "Bone Warden",
            "Bonesnapper",
            "Braindead",
            "Broken Promise",
            "Brutality",
            "Brutalizer",
            "Cataclysm",
            "Catastrophe",
            "Celeste",
            "Chance",
            "Chaos",
            "Chasm",
            "Chieftain",
            "Comet",
            "Cometfall",
            "Concussion",
            "Convergence",
            "Corpsemaker",
            "Corruption",
            "Cosmos",
            "Crash",
            "Crimson",
            "Crush",
            "Cryptmaker",
            "Cyclone",
            "Darkness",
            "Dawn",
            "Dawnbreaker",
            "Daytime",
            "Deathbringer",
            "Deathraze",
            "Decimation",
            "Demise",
            "Desolation",
            "Despair",
            "Destiny",
            "Destruction",
            "Devastation",
            "Devine",
            "Devotion",
            "Devourer",
            "Disturbance",
            "Divine Light",
            "Dominance",
            "Dominion",
            "Doom",
            "Doombringer",
            "Dragonfist",
            "Dragonmaw",
            "Dragonstrike",
            "Due Diligence",
            "Early Retirement",
            "Earthquake",
            "Earthshaker",
            "Earthshaper",
            "Earthwarden",
            "Echo",
            "Eclipse",
            "Emergency",
            "End of Dreams",
            "Endbringer",
            "Enigma",
            "Epilogue",
            "Eternal Rest",
            "Eternity",
            "Eveningstar",
            "Extermination",
            "Extinction",
            "Faithkeeper",
            "Falcon",
            "Falling Star",
            "Fate",
            "Finality",
            "Frenzy",
            "Frostwind",
            "Fury",
            "Fury's Gaze",
            "Galaxy",
            "Gatecrasher",
            "Ghost Reaver",
            "Ghostwalker",
            "Glimmer",
            "Godslayer",
            "Grace",
            "Guiding Star",
            "Harbinger",
            "Harmony",
            "Harvester",
            "Hatred",
            "Heartcrusher",
            "Hell's Scream",
            "Hellfire",
            "Homage",
            "Honor's Call",
            "Hope's End",
            "Humongous",
            "Hurricane",
            "Icebreaker",
            "Infamy",
            "Infinity",
            "Interrogator",
            "Jackhammer",
            "Jawbone",
            "Justice",
            "Justifier",
            "King's Defender",
            "King's Legacy",
            "Kinslayer",
            "Knight's Fall",
            "Knight's Honor",
            "Knightfall",
            "Lament",
            "Last Chance",
            "Last Laugh",
            "Last Rites",
            "Last Word",
            "Last Words",
            "Lazarus",
            "Legacy",
            "Legionaire",
            "Life's Limit",
            "Light's Bane",
            "Lightbane",
            "Lightbringer",
            "Lightning",
            "Limbo",
            "Lockjaw",
            "Magma",
            "Malice",
            "Maneater",
            "Massacre",
            "Mercy",
            "Midnight",
            "Misery's End",
            "Monsoon",
            "Morningstar",
            "Narcoleptic",
            "Nethersbane",
            "Night's Fall",
            "Nightbane",
            "Nightfall",
            "Nightglow",
            "Nightmare",
            "Nighttime",
            "Nirvana",
            "Oathbreaker",
            "Oathkeeper",
            "Oblivion",
            "Old Age",
            "Omega",
            "Orbit",
            "Orenmir",
            "Oxheart",
            "Party Pooper",
            "Patience",
            "Peacekeeper",
            "Peacemaker",
            "Pendulum",
            "Perfect Storm",
            "Persuasion",
            "Piece Maker",
            "Piety",
            "Pride",
            "Prophecy",
            "Punisher",
            "Purifier",
            "Rage",
            "Ragnarok",
            "Rapture",
            "Reaper's Toll",
            "Reckoning",
            "Red Dwarf",
            "Reign",
            "Remorse",
            "Requiem",
            "Retirement",
            "Righteous Might",
            "Rigormortis",
            "Rising Tide",
            "Savagery",
            "Scar",
            "Scourgeborne",
            "Second Chance",
            "Seism",
            "Seismic",
            "Serenity",
            "Severance",
            "Shadowfury",
            "Shadowmoon",
            "Shatterskull",
            "Shooting Star",
            "Silence",
            "Skullcrusher",
            "Soul Breaker",
            "Spinefall",
            "Stalker",
            "Stonefist",
            "Storm",
            "Storm Breaker",
            "Storm-Weaver",
            "Stormbringer",
            "Stormcaller",
            "Stormedge",
            "Stormherald",
            "Stormrider",
            "Sucker Punch",
            "Sundown",
            "Supernova",
            "Supremacy",
            "Suspension",
            "Swan Song",
            "Tank",
            "Tenderiser",
            "Termination",
            "The Ambassador",
            "The Chancellor",
            "The Chief",
            "The End",
            "The Light",
            "The Minotaur",
            "The Oculus",
            "The Oracle",
            "The Sundering",
            "The Void",
            "The Warden",
            "Thunder",
            "Trauma",
            "Treachery",
            "Tremor",
            "Trinity",
            "Twilight",
            "Typhoon",
            "Ubiquity",
            "Undoing",
            "Vacancy",
            "Valkyrie",
            "Vanquisher",
            "Vengeance",
            "Warbringer",
            "Warmonger",
            "Whirlwind",
            "Wicked",
            "Widow Maker",
            "Willbreaker",
            "Winter's Bite",
            "Wit's End",
            "Witherbrand",
            "Wolf",
            "Worldbreaker",
            "Worldcarver",
            "Worldslayer",
        ]
        var2 = [
            "Ancient",
            "Antique",
            "Apocalypse",
            "Apocalyptic",
            "Arcane",
            "Arched",
            "Atuned",
            "Bandit's",
            "Baneful",
            "Banished",
            "Barbarian",
            "Barbaric",
            "Battleworn",
            "Blazefury",
            "Blood Infused",
            "Blood-Forged",
            "Bloodcursed",
            "Bloodied",
            "Bloodlord's",
            "Bloodsurge",
            "Bloodvenom",
            "Bonecarvin",
            "Brutal",
            "Brutality",
            "Burnished",
            "Cataclysm",
            "Cataclysmic",
            "Challenger",
            "Challenger's",
            "Champion",
            "Champion's",
            "Cold-Forged",
            "Conqueror",
            "Conqueror's",
            "Corroded",
            "Corrupted",
            "Crazed",
            "Crying",
            "Cursed",
            "Curved",
            "Dancing",
            "Dark",
            "Darkness",
            "Defender",
            "Defender's",
            "Defiled",
            "Defiling",
            "Deluded",
            "Demonic",
            "Deserted",
            "Desire's",
            "Desolation",
            "Destiny's",
            "Diabolical",
            "Dire",
            "Doom",
            "Doom's",
            "Dragon's",
            "Dragonbreath",
            "Eerie",
            "Enchanted",
            "Engraved",
            "Enlightened",
            "Eternal",
            "Exiled",
            "Extinction",
            "Faith's",
            "Faithful",
            "Fancy",
            "Fearful",
            "Feral",
            "Ferocious",
            "Fierce",
            "Fiery",
            "Fire Infused",
            "Fireguard",
            "Firesoul",
            "Firestorm",
            "Flaming",
            "Flimsy",
            "Forsaken",
            "Fortune's",
            "Foul",
            "Fragile",
            "Frail",
            "Frenzied",
            "Frost",
            "Frozen",
            "Furious",
            "Fusion",
            "Ghastly",
            "Ghost",
            "Ghost-Forged",
            "Ghostly",
            "Gladiator",
            "Gladiator's",
            "Gleaming",
            "Glinting",
            "Greedy",
            "Grieving",
            "Grim",
            "Guard's",
            "Guardian's",
            "Hailstorm",
            "Harmonized",
            "Hateful",
            "Haunted",
            "Heartless",
            "Heinous",
            "Hero",
            "Hero's",
            "Hollow",
            "Holy",
            "Honed",
            "Honor's",
            "Hope's",
            "Hopeless",
            "Howling",
            "Hungering",
            "Improved",
            "Impure",
            "Incarnated",
            "Infused",
            "Inherited",
            "Isolated",
            "Jade Infused",
            "Judgement",
            "Keeper's",
            "Knightly",
            "Knight's",
            "Legionnaire's",
            "Liar's",
            "Lich",
            "Lightning",
            "Lonely",
            "Loyal",
            "Lustful",
            "Lusting",
            "Malevolent",
            "Malicious",
            "Malificent",
            "Malignant",
            "Massive",
            "Mended",
            "Mercenary",
            "Military",
            "Misfortune's",
            "Misty",
            "Moonlit",
            "Mourning",
            "Nightmare",
            "Oathkeeper's",
            "Ominous",
            "Peacekeeper",
            "Peacekeeper's",
            "Phantom",
            "Polished",
            "Possessed",
            "Pride's",
            "Prideful",
            "Primal",
            "Prime",
            "Primitive",
            "Promised",
            "Protector's",
            "Proud",
            "Pure",
            "Putrid",
            "Raging",
            "Recruit's",
            "Refined",
            "Reforged",
            "Reincarnated",
            "Relentless",
            "Remorseful",
            "Renewed",
            "Renovated",
            "Replica",
            "Restored",
            "Retribution",
            "Ritual",
            "Roaring",
            "Ruby Infused",
            "Rune-Forged",
            "Runed",
            "Rusty",
            "Savage",
            "Sentinel",
            "Shadow",
            "Shamanic",
            "Sharpened",
            "Silent",
            "Singed",
            "Singing",
            "Sinister",
            "Skyfall",
            "Smooth",
            "Soldier's",
            "Solitude's",
            "Sorcerer's",
            "Sorrow's",
            "Soul",
            "Soul Infused",
            "Soul-Forged",
            "Soulcursed",
            "Soulless",
            "Spectral",
            "Spectral-Forged",
            "Spiteful",
            "Storm",
            "Storm-Forged",
            "Stormfury",
            "Stormguard",
            "Terror",
            "Thirsting",
            "Thirsty",
            "Thunder",
            "Thunder-Forged",
            "Thunderfury",
            "Thunderguard",
            "Thundersoul",
            "Thunderstorm",
            "Timeworn",
            "Tormented",
            "Trainee's",
            "Treachery's",
            "Twilight",
            "Twilight's",
            "Twisted",
            "Tyrannical",
            "Undead",
            "Unholy",
            "Vanquisher",
            "Vengeance",
            "Vengeful",
            "Venom",
            "Vicious",
            "Victor",
            "Vile",
            "Vindication",
            "Vindicator",
            "Vindictive",
            "Void",
            "Volcanic",
            "Vowed",
            "War",
            "War-Forged",
            "Warden's",
            "Warlord's",
            "Warp",
            "Warped",
            "Warrior",
            "Warrior's",
            "Whistling",
            "Wicked",
            "Wind's",
            "Wind-Forged",
            "Windsong",
            "Woeful",
            "Wrathful",
            "Wretched",
            "Yearning",
            "Zealous",
        ]
        var3 = [
            "Adamantite",
            "Bone",
            "Bronze",
            "Bronzed",
            "Ivory",
            "Ebon",
            "Glass",
            "Golden",
            "Gilded",
            "Iron",
            "Ironbark",
            "Mithril",
            "Obsidian",
            "Silver",
            "Skeletal",
            "Steel",
            "Titanium",
        ]
        var4 = [
            "Mace",
            "Bludgeon",
            "Maul",
            "Crusher",
            "Smasher",
            "Warmace",
            "Hammer",
            "Mace",
            "Flail",
            "Morning Star",
            "Spikes",
            "Pummel",
            "Wacker",
            "Basher",
            "Impaler",
            "Piercer",
        ]
        var5 = [
            "Allegiance",
            "Annihilation",
            "Basher",
            "Betrayer",
            "Bludgeon",
            "Bond",
            "Boon",
            "Breaker",
            "Bringer",
            "Butcher",
            "Call",
            "Carver",
            "Champion",
            "Chopper",
            "Cleaver",
            "Conqueror",
            "Crusader",
            "Crusher",
            "Cry",
            "Cunning",
            "Dawn",
            "Defender",
            "Defiler",
            "Destroyer",
            "Edge",
            "Ender",
            "Etcher",
            "Executioner",
            "Favor",
            "Ferocity",
            "Flail",
            "Foe",
            "Gift",
            "Glory",
            "Guardian",
            "Hammer",
            "Heirloom",
            "Hope",
            "Impaler",
            "Incarnation",
            "Jaws",
            "Last Hope",
            "Last Stand",
            "Legacy",
            "Mace",
            "Maul",
            "Memory",
            "Might",
            "Morning Star",
            "Oath",
            "Pact",
            "Piercer",
            "Pledge",
            "Promise",
            "Prophecy",
            "Protector",
            "Pummel",
            "Ravager",
            "Razor",
            "Reach",
            "Reaper",
            "Reaver",
            "Sculptor",
            "Secret",
            "Slayer",
            "Slicer",
            "Smasher",
            "Soul",
            "Spikes",
            "Terror",
            "Token",
            "Tribute",
            "Vengeance",
            "Voice",
            "Wacker",
            "Warblade",
            "Warmace",
            "Whisper",
            "Wit",
        ]
        var6 = [
            "of Agony",
            "of Ancient Power",
            "of Anguish",
            "of Ashes",
            "of Assassins",
            "of Black Magic",
            "of Blessed Fortune",
            "of Blessings",
            "of Blight",
            "of Blood",
            "of Bloodlust",
            "of Broken Bones",
            "of Broken Dreams",
            "of Broken Families",
            "of Burdens",
            "of Chaos",
            "of Closing Eyes",
            "of Conquered Worlds",
            "of Corruption",
            "of Cruelty",
            "of Cunning",
            "of Dark Magic",
            "of Dark Souls",
            "of Darkness",
            "of Decay",
            "of Deception",
            "of Degradation",
            "of Delusions",
            "of Denial",
            "of Desecration",
            "of Diligence",
            "of Dismay",
            "of Dragonsouls",
            "of Due Diligence",
            "of Echoes",
            "of Ended Dreams",
            "of Ending Hope",
            "of Ending Misery",
            "of Eternal Bloodlust",
            "of Eternal Damnation",
            "of Eternal Glory",
            "of Eternal Justice",
            "of Eternal Rest",
            "of Eternal Sorrow",
            "of Eternal Struggles",
            "of Eternity",
            "of Executions",
            "of Faded Memories",
            "of Fallen Souls",
            "of Fools",
            "of Frost",
            "of Frozen Hells",
            "of Fury",
            "of Giants",
            "of Giantslaying",
            "of Grace",
            "of Grieving Widows",
            "of Hate",
            "of Hatred",
            "of Hell's Games",
            "of Hellish Torment",
            "of Heroes",
            "of Holy Might",
            "of Honor",
            "of Hope",
            "of Horrid Dreams",
            "of Horrors",
            "of Illuminated Dreams",
            "of Illumination",
            "of Immortality",
            "of Inception",
            "of Infinite Trials",
            "of Insanity",
            "of Invocation",
            "of Justice",
            "of Light's Hope",
            "of Lost Comrades",
            "of Lost Hope",
            "of Lost Voices",
            "of Lost Worlds",
            "of Magic",
            "of Mercy",
            "of Misery",
            "of Mountains",
            "of Mourning",
            "of Mystery",
            "of Necromancy",
            "of Nightmares",
            "of Oblivion",
            "of Perdition",
            "of Phantoms",
            "of Power",
            "of Pride",
            "of Pride's Fall",
            "of Putrefaction",
            "of Reckoning",
            "of Redemption",
            "of Regret",
            "of Riddles",
            "of Secrecy",
            "of Secrets",
            "of Shadow Strikes",
            "of Shadows",
            "of Shifting Sands",
            "of Shifting Worlds",
            "of Silence",
            "of Slaughter",
            "of Souls",
            "of Stealth",
            "of Storms",
            "of Subtlety",
            "of Suffering",
            "of Suffering's End",
            "of Summoning",
            "of Terror",
            "of Thunder",
            "of Time-Lost Memories",
            "of Timeless Battles",
            "of Titans",
            "of Torment",
            "of Traitors",
            "of Trembling Hands",
            "of Trials",
            "of Truth",
            "of Twilight's End",
            "of Twisted Visions",
            "of Unholy Blight",
            "of Unholy Might",
            "of Vengeance",
            "of Visions",
            "of Wasted Time",
            "of Widows",
            "of Wizardry",
            "of Woe",
            "of Wraiths",
            "of Zeal",
            "of the Ancients",
            "of the Banished",
            "of the Basilisk",
            "of the Beast",
            "of the Blessed",
            "of the Breaking Storm",
            "of the Brotherhood",
            "of the Burning Sun",
            "of the Caged Mind",
            "of the Cataclysm",
            "of the Champion",
            "of the Claw",
            "of the Corrupted",
            "of the Covenant",
            "of the Crown",
            "of the Damned",
            "of the Daywalker",
            "of the Dead",
            "of the Depth",
            "of the Dreadlord",
            "of the Earth",
            "of the East",
            "of the Emperor",
            "of the Empty Void",
            "of the End",
            "of the Enigma",
            "of the Fallen",
            "of the Falling Sky",
            "of the Flame",
            "of the Forest",
            "of the Forgotten",
            "of the Forsaken",
            "of the Gladiator",
            "of the Harvest",
            "of the Immortal",
            "of the Incoming Storm",
            "of the Insane",
            "of the King",
            "of the Lasting Night",
            "of the Leviathan",
            "of the Light",
            "of the Lion",
            "of the Lionheart",
            "of the Lone Victor",
            "of the Lone Wolf",
            "of the Lost",
            "of the Moon",
            "of the Moonwalker",
            "of the Night Sky",
            "of the Night",
            "of the Nightstalker",
            "of the North",
            "of the Occult",
            "of the Oracle",
            "of the Phoenix",
            "of the Plague",
            "of the Prince",
            "of the Protector",
            "of the Queen",
            "of the Serpent",
            "of the Setting Sun",
            "of the Shadows",
            "of the Sky",
            "of the South",
            "of the Stars",
            "of the Storm",
            "of the Summoner",
            "of the Sun",
            "of the Sunwalker",
            "of the Talon",
            "of the Undying",
            "of the Victor",
            "of the Void",
            "of the West",
            "of the Whispers",
            "of the Wicked",
            "of the Wind",
            "of the Wolf",
            "of the World",
            "of the Wretched",
        ]
        var7 = [
            "Morning Glory",
            "Morning Star",
            "Mourning Star",
            "Blackjack",
            "Tresher",
            "Good Morning",
            "Headache",
            "Migraine",
            "Grimace",
            "Macerator",
            "Abomination",
            "Agatha",
            "Agony",
            "Allegiance",
            "Alpha",
            "Amnesia",
            "Anduril",
            "Apocalypse",
            "Armageddon",
            "Arondite",
            "Ash",
            "Ashes",
            "Ashrune",
            "Back Breaker",
            "Battlestar",
            "Betrayal",
            "Betrayer",
            "Blackout",
            "Blazeguard",
            "Blessing",
            "Blind Justice",
            "Bloodfury",
            "Bloodmoon",
            "Bloodquench",
            "Bloodrage",
            "Bloodspiller",
            "Bloodweep",
            "Bone Warden",
            "Bonesnapper",
            "Braindead",
            "Broken Promise",
            "Brutality",
            "Brutalizer",
            "Cataclysm",
            "Catastrophe",
            "Celeste",
            "Chance",
            "Chaos",
            "Chasm",
            "Chieftain",
            "Comet",
            "Cometfall",
            "Concussion",
            "Convergence",
            "Corpsemaker",
            "Corruption",
            "Cosmos",
            "Crash",
            "Crimson",
            "Crush",
            "Cryptmaker",
            "Cyclone",
            "Darkness",
            "Dawn",
            "Dawnbreaker",
            "Daytime",
            "Deathbringer",
            "Deathraze",
            "Decimation",
            "Demise",
            "Desolation",
            "Despair",
            "Destiny",
            "Destruction",
            "Devastation",
            "Devine",
            "Devotion",
            "Devourer",
            "Disturbance",
            "Divine Light",
            "Dominance",
            "Dominion",
            "Doom",
            "Doombringer",
            "Dragonfist",
            "Dragonmaw",
            "Dragonstrike",
            "Due Diligence",
            "Earthquake",
            "Earthshaker",
            "Earthshaper",
            "Earthwarden",
            "Echo",
            "Eclipse",
            "Emergency",
            "End of Dreams",
            "Endbringer",
            "Enigma",
            "Epilogue",
            "Eternal Rest",
            "Eternity",
            "Eveningstar",
            "Extermination",
            "Extinction",
            "Faithkeeper",
            "Falcon",
            "Falling Star",
            "Fate",
            "Finality",
            "Frenzy",
            "Frostwind",
            "Fury",
            "Fury's Gaze",
            "Galaxy",
            "Gatecrasher",
            "Ghost Reaver",
            "Ghostwalker",
            "Glimmer",
            "Godslayer",
            "Grace",
            "Guiding Star",
            "Harbinger",
            "Harmony",
            "Harvester",
            "Hatred",
            "Heartcrusher",
            "Hell's Scream",
            "Hellfire",
            "Homage",
            "Honor's Call",
            "Hope's End",
            "Humongous",
            "Hurricane",
            "Icebreaker",
            "Infamy",
            "Infinity",
            "Interrogator",
            "Jackhammer",
            "Jawbone",
            "Justice",
            "Justifier",
            "King's Defender",
            "King's Legacy",
            "Kinslayer",
            "Knight's Fall",
            "Knight's Honor",
            "Knightfall",
            "Lament",
            "Last Chance",
            "Last Laugh",
            "Last Rites",
            "Last Word",
            "Last Words",
            "Lazarus",
            "Legacy",
            "Legionaire",
            "Life's Limit",
            "Light's Bane",
            "Lightbane",
            "Lightbringer",
            "Lightning",
            "Limbo",
            "Lockjaw",
            "Magma",
            "Malice",
            "Maneater",
            "Massacre",
            "Mercy",
            "Midnight",
            "Misery's End",
            "Monsoon",
            "Morningstar",
            "Narcoleptic",
            "Nethersbane",
            "Night's Fall",
            "Nightbane",
            "Nightfall",
            "Nightglow",
            "Nightmare",
            "Nighttime",
            "Nirvana",
            "Oathbreaker",
            "Oathkeeper",
            "Oblivion",
            "Old Age",
            "Omega",
            "Orbit",
            "Orenmir",
            "Oxheart",
            "Party Pooper",
            "Patience",
            "Peacekeeper",
            "Peacemaker",
            "Pendulum",
            "Perfect Storm",
            "Persuasion",
            "Piety",
            "Pride",
            "Prophecy",
            "Punisher",
            "Purifier",
            "Rage",
            "Ragnarok",
            "Rapture",
            "Reckoning",
            "Red Dwarf",
            "Reign",
            "Remorse",
            "Requiem",
            "Retirement",
            "Rigormortis",
            "Rising Tide",
            "Savagery",
            "Seism",
            "Seismic",
            "Serenity",
            "Severance",
            "Shadowfury",
            "Shatterskull",
            "Shooting Star",
            "Silence",
            "Skullcrusher",
            "Soul Breaker",
            "Spinefall",
            "Stalker",
            "Stonefist",
            "Storm",
            "Storm Breaker",
            "Storm-Weaver",
            "Stormbringer",
            "Stormcaller",
            "Stormedge",
            "Stormherald",
            "Stormrider",
            "Sucker Punch",
            "Sundown",
            "Supernova",
            "Supremacy",
            "Suspension",
            "Swan Song",
            "Tank",
            "Tenderiser",
            "Termination",
            "The Ambassador",
            "The Chancellor",
            "The Chief",
            "The End",
            "The Light",
            "The Minotaur",
            "The Oculus",
            "The Oracle",
            "The Sundering",
            "The Void",
            "The Warden",
            "Thunder",
            "Trauma",
            "Treachery",
            "Tremor",
            "Trinity",
            "Twilight",
            "Typhoon",
            "Ubiquity",
            "Undoing",
            "Vacancy",
            "Valkyrie",
            "Vanquisher",
            "Vengeance",
            "Warbringer",
            "Warmonger",
            "Whirlwind",
            "Wicked",
            "Widow Maker",
            "Willbreaker",
            "Winter's Bite",
            "Wit's End",
            "Witherbrand",
            "Wolf",
            "Worldbreaker",
            "Worldcarver",
            "Worldslayer",
        ]

        num = randrange(4)
        if num == 0:
            return choice(var1).title()
        elif num == 1:
            return choice(var2) + " " + choice(var4)
        elif num == 2:
            return choice(var2) + " " + choice(var3) + " " + choice(var4)
        elif num == 3:
            return choice(var7) + " " + choice(var5) + " " + choice(var6)

    @staticmethod
    def Spear():
        var1 = [
            "Abomination",
            "Agatha",
            "Allegiance",
            "Alpha",
            "Amnesia",
            "Anduril",
            "Anger's Edge",
            "Angerfang",
            "Anguish",
            "Apocalypse",
            "Appointment",
            "Armageddon",
            "Arondite",
            "Ash",
            "Ashes",
            "Ashrune",
            "Betrayal",
            "Betrayer",
            "Blackfury",
            "Blackout",
            "Blacktalon",
            "Blazefury",
            "Blazeguard",
            "Blind Justice",
            "Blinder",
            "Blindstrike",
            "Blinkstrike",
            "Bloodbound",
            "Bloodfall",
            "Bloodfury",
            "Bloodpike",
            "Bloodrage",
            "Bloodspiller",
            "Bloodweep",
            "Broken Promise",
            "Brutality",
            "Brutalizer",
            "Cataclysm",
            "Catastrophe",
            "Celeste",
            "Chance",
            "Chaos",
            "Checkpoint",
            "Chillspike",
            "Comet",
            "Cometfall",
            "Convergence",
            "Corpsemaker",
            "Corruption",
            "Crimson",
            "Cyclone",
            "Darkness",
            "Dawn",
            "Dawn's Edge",
            "Dawnbreaker",
            "Daytime",
            "Deathbringer",
            "Deathraze",
            "Deathspade",
            "Decimation",
            "Depravity",
            "Desolation",
            "Despair",
            "Destiny",
            "Devastation",
            "Devine",
            "Devotion",
            "Devourer",
            "Disappoint",
            "Divine Light",
            "Dominance",
            "Dominion",
            "Doom",
            "Doom's Tip",
            "Doombringer",
            "Due Diligence",
            "Early Retirement",
            "Echo",
            "Eclipse",
            "Emergency",
            "Endbringer",
            "Enigma",
            "Epilogue",
            "Eternal Rest",
            "Eternity",
            "Extermination",
            "Extinction",
            "Eyegouger",
            "Faithkeeper",
            "Fate",
            "Finality",
            "Freak's Bite",
            "Frenzy",
            "Frostbite",
            "Fury",
            "Fury's Gaze",
            "Ghostwalker",
            "Glimmer",
            "Glory's Reach",
            "Good Point",
            "Grieving Spike",
            "Hail",
            "Harbinger",
            "Harvester",
            "Hatred",
            "Hatred's Point",
            "Hatred's Spike",
            "Headspike",
            "Heartseeker",
            "Hell's Scream",
            "Hellreaver",
            "Homage",
            "Honor's Call",
            "Honor's Reach",
            "Honorbound",
            "Hope's Edge",
            "Hope's End",
            "Hope's Point",
            "Hurricane",
            "Icicle",
            "Infamy",
            "Infinity",
            "Inner Demon",
            "Jaeger",
            "Justice",
            "Justifier",
            "King's Defender",
            "King's Legacy",
            "Kingpin",
            "Kinslayer",
            "Knight's Fall",
            "Knight's Honor",
            "Knightfall",
            "Lament",
            "Last Chance",
            "Last Laugh",
            "Last Rites",
            "Last Words",
            "Lazarus",
            "Legacy",
            "Legionaire",
            "Life's Limit",
            "Light's Bane",
            "Lightbane",
            "Lightbringer",
            "Lightning",
            "Limbo",
            "Long Arm of the Law",
            "Malice",
            "Marrowstrike",
            "Massacre",
            "Mercy",
            "Midnight",
            "Misery's End",
            "Misery's Spike",
            "Narcoleptic",
            "Needle",
            "Needler",
            "Nethersbane",
            "Night's Fall",
            "Night's Reach",
            "Night's Spike",
            "Nightbane",
            "Nightfall",
            "Nighthorror",
            "Nightterror",
            "Nighttime",
            "Nirvana",
            "Oathbinder",
            "Oathbreaker",
            "Oathkeeper",
            "Oblivion",
            "Old Age",
            "Omega",
            "Orbit",
            "Party Pooper",
            "Peacekeeper",
            "Peacemaker",
            "Pendulum",
            "Persuasion",
            "Piece Maker",
            "Piety",
            "Pinpoint",
            "Point of no Return",
            "Pointless",
            "Pride",
            "Prophecy",
            "Purifier",
            "Rage",
            "Rapture",
            "Reckoning",
            "Reign",
            "Remorse",
            "Requiem",
            "Rigormortis",
            "Savagery",
            "Scar",
            "Seism",
            "Severance",
            "Shadow Strike",
            "Shadowfury",
            "Shadowmoon",
            "Shadowpike",
            "Shadowspike",
            "Shadowsteel",
            "Shadowstrike",
            "Shiverspine",
            "Silence",
            "Skirmisher",
            "Slice of Life",
            "Spike of Death",
            "Spike of Eternity",
            "Spike of Infinity",
            "Spike of Life",
            "Spike of Madness",
            "Spike of Misery",
            "Spike of Reason",
            "Spike of Ruin",
            "Spike of Time",
            "Spike",
            "Spinefall",
            "Spite",
            "Stalker",
            "Storm",
            "Stormbringer",
            "Stormcaller",
            "Stormcrow",
            "Stormedge",
            "Stormrider",
            "Supernova",
            "Supremacy",
            "Suspension",
            "Swan Song",
            "Swoosh",
            "Termination",
            "Terror's Reach",
            "The End",
            "The Facelifter",
            "The Oculus",
            "The Oracle",
            "The Surgeon",
            "The Void",
            "The Warden",
            "Thunder",
            "Thunderstrike",
            "Treachery",
            "Tremor",
            "Trickster",
            "Trickster's Tip",
            "Trinity",
            "Twisted",
            "Typhoon",
            "Ubiquity",
            "Undoing",
            "Vacancy",
            "Valkyrie",
            "Vanquisher",
            "Vengeance",
            "Viewpoint",
            "Warbringer",
            "Warmonger",
            "Waypoint",
            "Whirlwind",
            "Wicked",
            "Widow Maker",
            "Willbreaker",
            "Windpiercer",
            "Winter's Bite",
            "Wit's End",
            "Witherbrand",
            "Wolf",
            "Woosh",
        ]
        var2 = [
            "Ancient",
            "Antique",
            "Apocalypse",
            "Apocalyptic",
            "Arcane",
            "Arched",
            "Atuned",
            "Bandit's",
            "Baneful",
            "Banished",
            "Barbarian",
            "Barbaric",
            "Battleworn",
            "Blazefury",
            "Blood Infused",
            "Blood-Forged",
            "Bloodcursed",
            "Bloodied",
            "Bloodlord's",
            "Bloodsurge",
            "Bloodvenom",
            "Bonecarvin",
            "Brutal",
            "Brutality",
            "Burnished",
            "Cataclysm",
            "Cataclysmic",
            "Challenger",
            "Challenger's",
            "Champion",
            "Champion's",
            "Cold-Forged",
            "Conqueror",
            "Conqueror's",
            "Corroded",
            "Corrupted",
            "Crazed",
            "Crying",
            "Cursed",
            "Curved",
            "Dancing",
            "Dark",
            "Darkness",
            "Defender",
            "Defender's",
            "Defiled",
            "Defiling",
            "Deluded",
            "Demonic",
            "Deserted",
            "Desire's",
            "Desolation",
            "Destiny's",
            "Diabolical",
            "Dire",
            "Doom",
            "Doom's",
            "Dragon's",
            "Dragonbreath",
            "Eerie",
            "Enchanted",
            "Engraved",
            "Enlightened",
            "Eternal",
            "Exiled",
            "Extinction",
            "Faith's",
            "Faithful",
            "Fancy",
            "Fearful",
            "Feral",
            "Ferocious",
            "Fierce",
            "Fiery",
            "Fire Infused",
            "Fireguard",
            "Firesoul",
            "Firestorm",
            "Flaming",
            "Flimsy",
            "Forsaken",
            "Fortune's",
            "Foul",
            "Fragile",
            "Frail",
            "Frenzied",
            "Frost",
            "Frozen",
            "Furious",
            "Fusion",
            "Ghastly",
            "Ghost",
            "Ghost-Forged",
            "Ghostly",
            "Gladiator",
            "Gladiator's",
            "Gleaming",
            "Glinting",
            "Greedy",
            "Grieving",
            "Grim",
            "Guard's",
            "Guardian's",
            "Hailstorm",
            "Harmonized",
            "Hateful",
            "Haunted",
            "Heartless",
            "Heinous",
            "Hero",
            "Hero's",
            "Hollow",
            "Holy",
            "Honed",
            "Honor's",
            "Hope's",
            "Hopeless",
            "Howling",
            "Hungering",
            "Improved",
            "Impure",
            "Incarnated",
            "Infused",
            "Inherited",
            "Isolated",
            "Jade Infused",
            "Judgement",
            "Keeper's",
            "Knightly",
            "Knight's",
            "Legionnaire's",
            "Liar's",
            "Lich",
            "Lightning",
            "Lonely",
            "Loyal",
            "Lustful",
            "Lusting",
            "Malevolent",
            "Malicious",
            "Malificent",
            "Malignant",
            "Massive",
            "Mended",
            "Mercenary",
            "Military",
            "Misfortune's",
            "Misty",
            "Moonlit",
            "Mourning",
            "Nightmare",
            "Oathkeeper's",
            "Ominous",
            "Peacekeeper",
            "Peacekeeper's",
            "Phantom",
            "Polished",
            "Possessed",
            "Pride's",
            "Prideful",
            "Primal",
            "Prime",
            "Primitive",
            "Promised",
            "Protector's",
            "Proud",
            "Pure",
            "Putrid",
            "Raging",
            "Recruit's",
            "Refined",
            "Reforged",
            "Reincarnated",
            "Relentless",
            "Remorseful",
            "Renewed",
            "Renovated",
            "Replica",
            "Restored",
            "Retribution",
            "Ritual",
            "Roaring",
            "Ruby Infused",
            "Rune-Forged",
            "Runed",
            "Rusty",
            "Savage",
            "Sentinel",
            "Shadow",
            "Shamanic",
            "Sharpened",
            "Silent",
            "Singed",
            "Singing",
            "Sinister",
            "Skyfall",
            "Smooth",
            "Soldier's",
            "Solitude's",
            "Sorcerer's",
            "Sorrow's",
            "Soul",
            "Soul Infused",
            "Soul-Forged",
            "Soulcursed",
            "Soulless",
            "Spectral",
            "Spectral-Forged",
            "Spiteful",
            "Storm",
            "Storm-Forged",
            "Stormfury",
            "Stormguard",
            "Terror",
            "Thirsting",
            "Thirsty",
            "Thunder",
            "Thunder-Forged",
            "Thunderfury",
            "Thunderguard",
            "Thundersoul",
            "Thunderstorm",
            "Timeworn",
            "Tormented",
            "Trainee's",
            "Treachery's",
            "Twilight",
            "Twilight's",
            "Twisted",
            "Tyrannical",
            "Undead",
            "Unholy",
            "Vanquisher",
            "Vengeance",
            "Vengeful",
            "Venom",
            "Vicious",
            "Victor",
            "Vile",
            "Vindication",
            "Vindicator",
            "Vindictive",
            "Void",
            "Volcanic",
            "Vowed",
            "War",
            "War-Forged",
            "Warden's",
            "Warlord's",
            "Warp",
            "Warped",
            "Warrior",
            "Warrior's",
            "Whistling",
            "Wicked",
            "Wind's",
            "Wind-Forged",
            "Windsong",
            "Woeful",
            "Wrathful",
            "Wretched",
            "Yearning",
            "Zealous",
        ]
        var3 = [
            "Adamantite",
            "Mithril",
            "Obsidian",
            "Silver",
            "Skeletal",
            "Steel",
            "Ebon",
            "Ivory",
            "Ironbark",
            "Oak",
            "Maple",
            "Yew",
            "Ashwood",
            "Warpwood",
            "Ebonsteel",
            "Ebony",
            "Onyx",
            "Shadowsteel",
        ]
        var4 = [
            "Spear",
            "Trident",
            "Halberd",
            "Polearm",
            "Pike",
            "Spike",
            "Ranseur",
            "Javelin",
            "Lance",
            "Piercer",
            "Harpoon",
            "Prick",
            "Pricker",
            "Impaler",
            "Skewer",
            "Skiver",
        ]
        var5 = [
            "Allegiance",
            "Annihilation",
            "Betrayer",
            "Bond",
            "Boon",
            "Breaker",
            "Bringer",
            "Butcher",
            "Call",
            "Carver",
            "Champion",
            "Chopper",
            "Cleaver",
            "Conqueror",
            "Crusader",
            "Cry",
            "Cunning",
            "Dawn",
            "Defender",
            "Defiler",
            "Destroyer",
            "Edge",
            "Ender",
            "Etcher",
            "Executioner",
            "Favor",
            "Ferocity",
            "Foe",
            "Gift",
            "Glory",
            "Guardian",
            "Halberd",
            "Harpoon",
            "Heirloom",
            "Hope",
            "Impaler",
            "Incarnation",
            "Javelin",
            "Jaws",
            "Lance",
            "Last Hope",
            "Last Stand",
            "Legacy",
            "Memory",
            "Might",
            "Oath",
            "Pact",
            "Piercer",
            "Pike",
            "Pledge",
            "Polearm",
            "Prick",
            "Pricker",
            "Promise",
            "Prophecy",
            "Protector",
            "Ranseur",
            "Ravager",
            "Razor",
            "Reach",
            "Reaper",
            "Reaver",
            "Sculptor",
            "Secret",
            "Skewer",
            "Skiver",
            "Slayer",
            "Slicer",
            "Soul",
            "Spear",
            "Spike",
            "Terror",
            "Token",
            "Tribute",
            "Trident",
            "Vengeance",
            "Voice",
            "Warblade",
            "Whisper",
            "Wit",
        ]
        var6 = [
            "of Agony",
            "of Ancient Power",
            "of Anguish",
            "of Ashes",
            "of Assassins",
            "of Black Magic",
            "of Blessed Fortune",
            "of Blessings",
            "of Blight",
            "of Blood",
            "of Bloodlust",
            "of Broken Bones",
            "of Broken Dreams",
            "of Broken Families",
            "of Burdens",
            "of Chaos",
            "of Closing Eyes",
            "of Conquered Worlds",
            "of Corruption",
            "of Cruelty",
            "of Cunning",
            "of Dark Magic",
            "of Dark Souls",
            "of Darkness",
            "of Decay",
            "of Deception",
            "of Degradation",
            "of Delusions",
            "of Denial",
            "of Desecration",
            "of Diligence",
            "of Dismay",
            "of Dragonsouls",
            "of Due Diligence",
            "of Echoes",
            "of Ended Dreams",
            "of Ending Hope",
            "of Ending Misery",
            "of Eternal Bloodlust",
            "of Eternal Damnation",
            "of Eternal Glory",
            "of Eternal Justice",
            "of Eternal Rest",
            "of Eternal Sorrow",
            "of Eternal Struggles",
            "of Eternity",
            "of Executions",
            "of Faded Memories",
            "of Fallen Souls",
            "of Fools",
            "of Frost",
            "of Frozen Hells",
            "of Fury",
            "of Giants",
            "of Giantslaying",
            "of Grace",
            "of Grieving Widows",
            "of Hate",
            "of Hatred",
            "of Hell's Games",
            "of Hellish Torment",
            "of Heroes",
            "of Holy Might",
            "of Honor",
            "of Hope",
            "of Horrid Dreams",
            "of Horrors",
            "of Illuminated Dreams",
            "of Illumination",
            "of Immortality",
            "of Inception",
            "of Infinite Trials",
            "of Insanity",
            "of Invocation",
            "of Justice",
            "of Light's Hope",
            "of Lost Comrades",
            "of Lost Hope",
            "of Lost Voices",
            "of Lost Worlds",
            "of Magic",
            "of Mercy",
            "of Misery",
            "of Mountains",
            "of Mourning",
            "of Mystery",
            "of Necromancy",
            "of Nightmares",
            "of Oblivion",
            "of Perdition",
            "of Phantoms",
            "of Power",
            "of Pride",
            "of Pride's Fall",
            "of Putrefaction",
            "of Reckoning",
            "of Redemption",
            "of Regret",
            "of Riddles",
            "of Secrecy",
            "of Secrets",
            "of Shadow Strikes",
            "of Shadows",
            "of Shifting Sands",
            "of Shifting Worlds",
            "of Silence",
            "of Slaughter",
            "of Souls",
            "of Stealth",
            "of Storms",
            "of Subtlety",
            "of Suffering",
            "of Suffering's End",
            "of Summoning",
            "of Terror",
            "of Thunder",
            "of Time-Lost Memories",
            "of Timeless Battles",
            "of Titans",
            "of Torment",
            "of Traitors",
            "of Trembling Hands",
            "of Trials",
            "of Truth",
            "of Twilight's End",
            "of Twisted Visions",
            "of Unholy Blight",
            "of Unholy Might",
            "of Vengeance",
            "of Visions",
            "of Wasted Time",
            "of Widows",
            "of Wizardry",
            "of Woe",
            "of Wraiths",
            "of Zeal",
            "of the Ancients",
            "of the Banished",
            "of the Basilisk",
            "of the Beast",
            "of the Blessed",
            "of the Breaking Storm",
            "of the Brotherhood",
            "of the Burning Sun",
            "of the Caged Mind",
            "of the Cataclysm",
            "of the Champion",
            "of the Claw",
            "of the Corrupted",
            "of the Covenant",
            "of the Crown",
            "of the Damned",
            "of the Daywalker",
            "of the Dead",
            "of the Depth",
            "of the Dreadlord",
            "of the Earth",
            "of the East",
            "of the Emperor",
            "of the Empty Void",
            "of the End",
            "of the Enigma",
            "of the Fallen",
            "of the Falling Sky",
            "of the Flame",
            "of the Forest",
            "of the Forgotten",
            "of the Forsaken",
            "of the Gladiator",
            "of the Harvest",
            "of the Immortal",
            "of the Incoming Storm",
            "of the Insane",
            "of the King",
            "of the Lasting Night",
            "of the Leviathan",
            "of the Light",
            "of the Lion",
            "of the Lionheart",
            "of the Lone Victor",
            "of the Lone Wolf",
            "of the Lost",
            "of the Moon",
            "of the Moonwalker",
            "of the Night Sky",
            "of the Night",
            "of the Nightstalker",
            "of the North",
            "of the Occult",
            "of the Oracle",
            "of the Phoenix",
            "of the Plague",
            "of the Prince",
            "of the Protector",
            "of the Queen",
            "of the Serpent",
            "of the Setting Sun",
            "of the Shadows",
            "of the Sky",
            "of the South",
            "of the Stars",
            "of the Storm",
            "of the Summoner",
            "of the Sun",
            "of the Sunwalker",
            "of the Talon",
            "of the Undying",
            "of the Victor",
            "of the Void",
            "of the West",
            "of the Whispers",
            "of the Wicked",
            "of the Wind",
            "of the Wolf",
            "of the World",
            "of the Wretched",
        ]
        var7 = [
            "Abomination",
            "Agatha",
            "Allegiance",
            "Alpha",
            "Amnesia",
            "Anduril",
            "Angerfang",
            "Anguish",
            "Apocalypse",
            "Appointment",
            "Armageddon",
            "Arondite",
            "Ash",
            "Ashes",
            "Ashrune",
            "Betrayal",
            "Betrayer",
            "Blackfury",
            "Blackout",
            "Blacktalon",
            "Blazefury",
            "Blazeguard",
            "Blind Justice",
            "Blinder",
            "Blindstrike",
            "Blinkstrike",
            "Bloodbound",
            "Bloodfall",
            "Bloodfury",
            "Bloodpike",
            "Bloodrage",
            "Bloodspiller",
            "Bloodweep",
            "Broken Promise",
            "Brutality",
            "Brutalizer",
            "Cataclysm",
            "Catastrophe",
            "Celeste",
            "Chance",
            "Chaos",
            "Checkpoint",
            "Chillspike",
            "Comet",
            "Cometfall",
            "Convergence",
            "Corpsemaker",
            "Corruption",
            "Crimson",
            "Cyclone",
            "Darkness",
            "Dawn",
            "Dawn's Edge",
            "Dawnbreaker",
            "Daytime",
            "Deathbringer",
            "Deathraze",
            "Deathspade",
            "Decimation",
            "Depravity",
            "Desolation",
            "Despair",
            "Destiny",
            "Devastation",
            "Devine",
            "Devotion",
            "Devourer",
            "Disappoint",
            "Divine Light",
            "Dominance",
            "Dominion",
            "Doom",
            "Doom's Tip",
            "Doombringer",
            "Due Diligence",
            "Echo",
            "Eclipse",
            "Emergency",
            "Endbringer",
            "Enigma",
            "Epilogue",
            "Eternal Rest",
            "Eternity",
            "Extermination",
            "Extinction",
            "Eyegouger",
            "Faithkeeper",
            "Fate",
            "Finality",
            "Freak's Bite",
            "Frenzy",
            "Frostbite",
            "Fury",
            "Fury's Gaze",
            "Ghostwalker",
            "Glimmer",
            "Glory's Reach",
            "Good Point",
            "Grieving Spike",
            "Hail",
            "Harbinger",
            "Harvester",
            "Hatred",
            "Hatred's Point",
            "Hatred's Spike",
            "Headspike",
            "Heartseeker",
            "Hell's Scream",
            "Hellreaver",
            "Homage",
            "Honor's Call",
            "Honor's Reach",
            "Honorbound",
            "Hope's Edge",
            "Hope's End",
            "Hope's Point",
            "Hurricane",
            "Icicle",
            "Infamy",
            "Infinity",
            "Inner Demon",
            "Jaeger",
            "Justice",
            "Justifier",
            "King's Defender",
            "King's Legacy",
            "Kingpin",
            "Kinslayer",
            "Knight's Fall",
            "Knight's Honor",
            "Knightfall",
            "Lament",
            "Last Chance",
            "Last Laugh",
            "Last Rites",
            "Last Words",
            "Lazarus",
            "Legacy",
            "Legionaire",
            "Life's Limit",
            "Light's Bane",
            "Lightbane",
            "Lightbringer",
            "Lightning",
            "Limbo",
            "Malice",
            "Marrowstrike",
            "Massacre",
            "Mercy",
            "Midnight",
            "Misery's End",
            "Misery's Spike",
            "Narcoleptic",
            "Needle",
            "Needler",
            "Nethersbane",
            "Night's Fall",
            "Night's Reach",
            "Night's Spike",
            "Nightbane",
            "Nightfall",
            "Nighthorror",
            "Nightterror",
            "Nighttime",
            "Nirvana",
            "Oathbinder",
            "Oathbreaker",
            "Oathkeeper",
            "Oblivion",
            "Old Age",
            "Omega",
            "Orbit",
            "Party Pooper",
            "Peacekeeper",
            "Peacemaker",
            "Pendulum",
            "Persuasion",
            "Piece Maker",
            "Piety",
            "Pinpoint",
            "Pointless",
            "Pride",
            "Prophecy",
            "Purifier",
            "Rage",
            "Rapture",
            "Reckoning",
            "Reign",
            "Remorse",
            "Requiem",
            "Rigormortis",
            "Savagery",
            "Scar",
            "Seism",
            "Severance",
            "Shadow Strike",
            "Shadowfury",
            "Shadowmoon",
            "Shadowpike",
            "Shadowspike",
            "Shadowsteel",
            "Shadowstrike",
            "Shiverspine",
            "Silence",
            "Skirmisher",
            "Spike",
            "Spinefall",
            "Spite",
            "Stalker",
            "Storm",
            "Stormbringer",
            "Stormcaller",
            "Stormcrow",
            "Stormedge",
            "Stormrider",
            "Supernova",
            "Supremacy",
            "Suspension",
            "Swan Song",
            "Swoosh",
            "Termination",
            "Terror's Reach",
            "The End",
            "The Facelifter",
            "The Oculus",
            "The Oracle",
            "The Surgeon",
            "The Void",
            "The Warden",
            "Thunder",
            "Thunderstrike",
            "Treachery",
            "Tremor",
            "Trickster",
            "Trickster's Tip",
            "Trinity",
            "Twisted",
            "Typhoon",
            "Ubiquity",
            "Undoing",
            "Vacancy",
            "Valkyrie",
            "Vanquisher",
            "Vengeance",
            "Viewpoint",
            "Warbringer",
            "Warmonger",
            "Waypoint",
            "Whirlwind",
            "Wicked",
            "Widow Maker",
            "Willbreaker",
            "Windpiercer",
            "Winter's Bite",
            "Wit's End",
            "Witherbrand",
            "Wolf",
            "Woosh",
        ]

        num = randrange(4)
        if num == 0:
            return choice(var1).title()
        elif num == 1:
            return choice(var2) + " " + choice(var4)
        elif num == 2:
            return choice(var2) + " " + choice(var3) + " " + choice(var4)
        elif num == 3:
            return choice(var7) + " " + choice(var5) + " " + choice(var6)

    @staticmethod
    def Sword():
        var1 = [
            "Shadowfang",
            "Azurewrath",
            "Assurance",
            "ForgetMeNot",
            "Red Obsidian",
            "Abyssal Shard",
            "Aetherius",
            "Agatha",
            "Alpha",
            "Amnesia",
            "Anduril",
            "Anger's Tear",
            "Apocalypse",
            "Armageddon",
            "Arondite",
            "Ashrune",
            "Betrayal",
            "Betrayer",
            "Blackest Heart",
            "Blackout",
            "Blade of a Thousand Cuts",
            "Blade of the Grave",
            "Blazefury",
            "Blazeguard",
            "Blight's Plight",
            "Blind Justice",
            "Blinkstrike",
            "Bloodquench",
            "Bloodweep",
            "Broken Promise",
            "Brutality",
            "Cataclysm",
            "Catastrophe",
            "Celeste",
            "Chaos",
            "Cometfell",
            "Convergence",
            "Corruption",
            "Darkheart",
            "Darkness",
            "Dawn",
            "Dawn of Ruins",
            "Dawnbreaker",
            "Deathbringer",
            "Deathraze",
            "Decimation",
            "Desolation",
            "Despair",
            "Destiny's Song",
            "Devine",
            "Devourer",
            "Dirge",
            "Divine Light",
            "Doomblade",
            "Doombringer",
            "Draughtbane",
            "Due Diligence",
            "Early Retirement",
            "Echo",
            "Piece Maker",
            "Eclipse",
            "Endbringer",
            "Epilogue",
            "Espada",
            "Eternal Harmony",
            "Eternal Rest",
            "Extinction",
            "Faithkeeper",
            "Fallen Champion",
            "Fate",
            "Final Achievement",
            "Fleshrender",
            "Florance",
            "Frenzy",
            "Fury",
            "Ghost Reaver",
            "Ghostwalker",
            "Gladius",
            "Glimmer",
            "Godslayer",
            "Grasscutter",
            "Grieving Blade",
            "Gutrender",
            "Hatred's Bite",
            "Heartseeker",
            "Heartstriker",
            "Hell's Scream",
            "Hellfire",
            "Hellreaver",
            "Hollow Silence",
            "Honor's Call",
            "Hope's End",
            "Infamy",
            "Interrogator",
            "Justice",
            "Justifier",
            "King's Defender",
            "King's Legacy",
            "Kinslayer",
            "Klinge",
            "Knight's Fall",
            "Knightfall",
            "Lament",
            "Last Rites",
            "Last Words",
            "Lazarus",
            "Life's Limit",
            "Lifedrinker",
            "Light's Bane",
            "Lightbane",
            "Lightbringer",
            "Lightning",
            "Limbo",
            "Loyalty",
            "Malice",
            "Mangler",
            "Massacre",
            "Mercy",
            "Misery's End",
            "Morbid Doom",
            "Morbid Will",
            "Mournblade",
            "Narcoleptic",
            "Needle",
            "Nethersbane",
            "Night's Edge",
            "Night's Fall",
            "Nightbane",
            "Nightcrackle",
            "Nightfall",
            "Nirvana",
            "Oathbreaker",
            "Oathkeeper",
            "Oblivion",
            "Omega",
            "Orenmir",
            "Peacekeeper",
            "Perfect Storm",
            "Persuasion",
            "Prick",
            "Purifier",
            "Rage",
            "Ragespike",
            "Ragnarok",
            "Reaper",
            "Reaper's Toll",
            "Reckoning",
            "Reign of Misery",
            "Remorse",
            "Requiem",
            "Requiem of the Lost",
            "Retirement",
            "Righteous Might",
            "Rigormortis",
            "Savagery",
            "Scalpel",
            "Scar",
            "Seethe",
            "Severance",
            "Shadow Strike",
            "Shadowsteel",
            "Silence",
            "Silencer",
            "Silver Saber",
            "Silverlight",
            "Skullcrusher",
            "Slice of Life",
            "Soul Reaper",
            "Soulblade",
            "Soulrapier",
            "Spada",
            "Spike",
            "Spineripper",
            "Spiteblade",
            "Stalker",
            "Starshatterer",
            "Sting",
            "Stinger",
            "Storm",
            "Storm Breaker",
            "Stormbringer",
            "Stormcaller",
            "Storm-Weaver",
            "Striker",
            "Sun Strike",
            "Suspension",
            "Swan Song",
            "The Ambassador",
            "The Black Blade",
            "The End",
            "The Facelifter",
            "The Light",
            "The Oculus",
            "The Stake",
            "The Untamed",
            "The Unyielding",
            "The Void",
            "Thorn",
            "Thunder",
            "Toothpick",
            "Tranquility",
            "Treachery",
            "Trinity",
            "Tyrhung",
            "Unending Tyranny",
            "Unholy Might",
            "Valkyrie",
            "Vanquisher",
            "Vengeance",
            "Venom",
            "Venomshank",
            "Warmonger",
            "Widow Maker",
            "Willbreaker",
            "Winterthorn",
            "Wit's End",
            "Witherbrand",
            "Wolf",
            "Worldbreaker",
            "Worldslayer",
        ]
        var2 = [
            "Massive",
            "Military",
            "Amber Infused",
            "Ancient",
            "Anguish",
            "Annihilation",
            "Antique",
            "Arcane",
            "Arched",
            "Assassination",
            "Atuned",
            "Oathkeeper's",
            "Bandit's",
            "Baneful",
            "Banished",
            "Barbarian",
            "Barbaric",
            "Battleworn",
            "Blazefury",
            "Blood Infused",
            "Blood-Forged",
            "Bloodcursed",
            "Bloodied",
            "Bloodlord's",
            "Bloodsurge",
            "Bloodvenom",
            "Bone Crushing",
            "Bonecarvin",
            "Brutal",
            "Brutality",
            "Burnished",
            "Captain's",
            "Cataclysm",
            "Cataclysmic",
            "Cold-Forged",
            "Corroded",
            "Corrupted",
            "Crazed",
            "Crying",
            "Cursed",
            "Curved",
            "Dancing",
            "Decapitating",
            "Defiled",
            "Demonic",
            "Deserted",
            "Desire's",
            "Desolation",
            "Destiny's",
            "Dire",
            "Doom",
            "Doom's",
            "Dragon's",
            "Dragonbreath",
            "Ebon",
            "Eerie",
            "Enchanted",
            "Engraved",
            "Eternal",
            "Executing",
            "Exiled",
            "Extinction",
            "Faith's",
            "Faithful",
            "Fancy",
            "Fearful",
            "Feral",
            "Fierce",
            "Fiery",
            "Fire Infused",
            "Fireguard",
            "Firesoul",
            "Firestorm",
            "Flaming",
            "Flimsy",
            "Forsaken",
            "Fortune's",
            "Fragile",
            "Frail",
            "Frenzied",
            "Frost",
            "Frozen",
            "Furious",
            "Fusion",
            "Ghastly",
            "Ghost-Forged",
            "Ghostly",
            "Gladiator",
            "Gladiator's",
            "Gleaming",
            "Glinting",
            "Greedy",
            "Grieving",
            "Guard's",
            "Guardian's",
            "Hailstorm",
            "Hateful",
            "Haunted",
            "Heartless",
            "Hollow",
            "Holy",
            "Honed",
            "Honor's",
            "Hope's",
            "Hopeless",
            "Howling",
            "Hungering",
            "Improved",
            "Incarnated",
            "Infused",
            "Inherited",
            "Isolated",
            "Jade Infused",
            "Judgement",
            "Knightly",
            "Legionnaire's",
            "Liar's",
            "Lich",
            "Lightning",
            "Lonely",
            "Loyal",
            "Lustful",
            "Lusting",
            "Mage's",
            "Malevolent",
            "Malicious",
            "Malignant",
            "Mended",
            "Mercenary",
            "Misfortune's",
            "Misty",
            "Moonlit",
            "Mourning",
            "Nightmare",
            "Ominous",
            "Peacekeeper",
            "Phantom",
            "Polished",
            "Possessed",
            "Pride's",
            "Prideful",
            "Primitive",
            "Promised",
            "Protector's",
            "Deluded",
            "Proud",
            "Recruit's",
            "Reforged",
            "Reincarnated",
            "Relentless",
            "Remorseful",
            "Renewed",
            "Renovated",
            "Replica",
            "Restored",
            "Retribution",
            "Ritual",
            "Roaring",
            "Ruby Infused",
            "Rune-Forged",
            "Rusty",
            "Sailor's",
            "Sapphire Infused",
            "Savage",
            "Shadow",
            "Sharpened",
            "Silent",
            "Singed",
            "Singing",
            "Sinister",
            "Skullforge",
            "Skyfall",
            "Smooth",
            "Solitude's",
            "Sorrow's",
            "Soul",
            "Soul Infused",
            "Soul-Forged",
            "Soulcursed",
            "Soulless",
            "Spectral",
            "Spectral-Forged",
            "Spiteful",
            "Storm",
            "Storm-Forged",
            "Stormfury",
            "Stormguard",
            "Terror",
            "Thirsting",
            "Thirsty",
            "Thunder",
            "Thunder-Forged",
            "Thunderfury",
            "Thunderguard",
            "Thundersoul",
            "Thunderstorm",
            "Timeworn",
            "Tormented",
            "Trainee's",
            "Treachery's",
            "Twilight",
            "Twilight's",
            "Twisted",
            "Tyrannical",
            "Undead",
            "Unholy",
            "Vengeance",
            "Vengeful",
            "Venom",
            "Vicious",
            "Vindication",
            "Vindictive",
            "Void",
            "Volcanic",
            "Vowed",
            "War-Forged",
            "Warlord's",
            "Warp",
            "Warped",
            "Whistling",
            "Wicked",
            "Wind's",
            "Wind-Forged",
            "Windsong",
            "Woeful",
            "Wrathful",
            "Wretched",
            "Yearning",
            "Zealous",
        ]
        var3 = [
            "Adamantite",
            "Bronze",
            "Copper",
            "Diamond",
            "Glass",
            "Gold",
            "Iron",
            "Mithril",
            "Obsidian",
            "Silver",
            "Skeletal",
            "Steel",
        ]
        var4 = [
            "Blade",
            "Broadsword",
            "Claymore",
            "Defender",
            "Deflector",
            "Doomblade",
            "Greatsword",
            "Guardian",
            "Katana",
            "Longsword",
            "Mageblade",
            "Protector",
            "Quickblade",
            "Rapier",
            "Reaver",
            "Sabre",
            "Scimitar",
            "Shortsword",
            "Slicer",
            "Spellblade",
            "Swiftblade",
            "Sword",
            "Warblade",
            "Skewer",
            "Carver",
            "Etcher",
            "Sculptor",
            "Razor",
            "Crusader",
        ]
        var5 = [
            "Annihilation",
            "Betrayer",
            "Blade",
            "Blessed Blade",
            "Blood Blade",
            "Bond",
            "Boon",
            "Breaker",
            "Bringer",
            "Broadsword",
            "Butcher",
            "Call",
            "Carver",
            "Champion",
            "Claymore",
            "Conqueror",
            "Crusader",
            "Cry",
            "Cunning",
            "Dark Blade",
            "Dawn",
            "Defender",
            "Defiler",
            "Deflector",
            "Destroyer",
            "Doomblade",
            "Edge",
            "Ender",
            "Etcher",
            "Executioner",
            "Favor",
            "Ferocity",
            "Foe",
            "Gift",
            "Glory",
            "Greatsword",
            "Guardian",
            "Heirloom",
            "Hope",
            "Incarnation",
            "Jaws",
            "Katana",
            "Last Hope",
            "Last Stand",
            "Legacy",
            "Longblade",
            "Longsword",
            "Mageblade",
            "Memory",
            "Might",
            "Oath",
            "Pact",
            "Pledge",
            "Promise",
            "Protector",
            "Quickblade",
            "Rapier",
            "Ravager",
            "Razor",
            "Reach",
            "Reaper",
            "Reaver",
            "Runed Blade",
            "Saber",
            "Sabre",
            "Savagery",
            "Scimitar",
            "Sculptor",
            "Secret",
            "Shortsword",
            "Skewer",
            "Slayer",
            "Slicer",
            "Soul",
            "Spellblade",
            "Spine",
            "Swiftblade",
            "Sword",
            "Terror",
            "Token",
            "Tribute",
            "Vengeance",
            "Voice",
            "Warblade",
            "Warglaive",
            "Whisper",
            "Wit",
        ]
        var6 = [
            "of Agony",
            "of Ancient Power",
            "of Anguish",
            "of Ashes",
            "of Assassins",
            "of Black Magic",
            "of Blessed Fortune",
            "of Blessings",
            "of Blight",
            "of Blood",
            "of Bloodlust",
            "of Broken Bones",
            "of Broken Dreams",
            "of Broken Families",
            "of Burdens",
            "of Chaos",
            "of Closing Eyes",
            "of Conquered Worlds",
            "of Corruption",
            "of Cruelty",
            "of Cunning",
            "of Dark Magic",
            "of Dark Souls",
            "of Darkness",
            "of Decay",
            "of Deception",
            "of Degradation",
            "of Delusions",
            "of Denial",
            "of Desecration",
            "of Diligence",
            "of Dismay",
            "of Dragonsouls",
            "of Due Diligence",
            "of Echoes",
            "of Ended Dreams",
            "of Ending Hope",
            "of Ending Misery",
            "of Eternal Bloodlust",
            "of Eternal Damnation",
            "of Eternal Glory",
            "of Eternal Justice",
            "of Eternal Rest",
            "of Eternal Sorrow",
            "of Eternal Struggles",
            "of Eternity",
            "of Executions",
            "of Faded Memories",
            "of Fallen Souls",
            "of Fools",
            "of Frost",
            "of Frozen Hells",
            "of Fury",
            "of Giants",
            "of Giantslaying",
            "of Grace",
            "of Grieving Widows",
            "of Hate",
            "of Hatred",
            "of Hell's Games",
            "of Hellish Torment",
            "of Heroes",
            "of Holy Might",
            "of Honor",
            "of Hope",
            "of Horrid Dreams",
            "of Horrors",
            "of Illuminated Dreams",
            "of Illumination",
            "of Immortality",
            "of Inception",
            "of Infinite Trials",
            "of Insanity",
            "of Invocation",
            "of Justice",
            "of Light's Hope",
            "of Lost Comrades",
            "of Lost Hope",
            "of Lost Voices",
            "of Lost Worlds",
            "of Magic",
            "of Mercy",
            "of Misery",
            "of Mountains",
            "of Mourning",
            "of Mystery",
            "of Necromancy",
            "of Nightmares",
            "of Oblivion",
            "of Perdition",
            "of Phantoms",
            "of Power",
            "of Pride",
            "of Pride's Fall",
            "of Putrefaction",
            "of Reckoning",
            "of Redemption",
            "of Regret",
            "of Riddles",
            "of Secrecy",
            "of Secrets",
            "of Shadow Strikes",
            "of Shadows",
            "of Shifting Sands",
            "of Shifting Worlds",
            "of Silence",
            "of Slaughter",
            "of Souls",
            "of Stealth",
            "of Storms",
            "of Subtlety",
            "of Suffering",
            "of Suffering's End",
            "of Summoning",
            "of Terror",
            "of Thunder",
            "of Time-Lost Memories",
            "of Timeless Battles",
            "of Titans",
            "of Torment",
            "of Traitors",
            "of Trembling Hands",
            "of Trials",
            "of Truth",
            "of Twilight's End",
            "of Twisted Visions",
            "of Unholy Blight",
            "of Unholy Might",
            "of Vengeance",
            "of Visions",
            "of Wasted Time",
            "of Widows",
            "of Wizardry",
            "of Woe",
            "of Wraiths",
            "of Zeal",
            "of the Ancients",
            "of the Banished",
            "of the Basilisk",
            "of the Beast",
            "of the Blessed",
            "of the Breaking Storm",
            "of the Brotherhood",
            "of the Burning Sun",
            "of the Caged Mind",
            "of the Cataclysm",
            "of the Champion",
            "of the Claw",
            "of the Corrupted",
            "of the Covenant",
            "of the Crown",
            "of the Damned",
            "of the Daywalker",
            "of the Dead",
            "of the Depth",
            "of the Dreadlord",
            "of the Earth",
            "of the East",
            "of the Emperor",
            "of the Empty Void",
            "of the End",
            "of the Enigma",
            "of the Fallen",
            "of the Falling Sky",
            "of the Flame",
            "of the Forest",
            "of the Forgotten",
            "of the Forsaken",
            "of the Gladiator",
            "of the Harvest",
            "of the Immortal",
            "of the Incoming Storm",
            "of the Insane",
            "of the King",
            "of the Lasting Night",
            "of the Leviathan",
            "of the Light",
            "of the Lion",
            "of the Lionheart",
            "of the Lone Victor",
            "of the Lone Wolf",
            "of the Lost",
            "of the Moon",
            "of the Moonwalker",
            "of the Night Sky",
            "of the Night",
            "of the Nightstalker",
            "of the North",
            "of the Occult",
            "of the Oracle",
            "of the Phoenix",
            "of the Plague",
            "of the Prince",
            "of the Protector",
            "of the Queen",
            "of the Serpent",
            "of the Setting Sun",
            "of the Shadows",
            "of the Sky",
            "of the South",
            "of the Stars",
            "of the Storm",
            "of the Summoner",
            "of the Sun",
            "of the Sunwalker",
            "of the Talon",
            "of the Undying",
            "of the Victor",
            "of the Void",
            "of the West",
            "of the Whispers",
            "of the Wicked",
            "of the Wind",
            "of the Wolf",
            "of the World",
            "of the Wretched",
        ]
        var7 = [
            "Felthorn",
            "Aetherius",
            "Agatha",
            "Alpha",
            "Amnesia",
            "Anduril",
            "Apocalypse",
            "Armageddon",
            "Arondite",
            "Ashrune",
            "Betrayal",
            "Betrayer",
            "Blackout",
            "Blazefury",
            "Blazeguard",
            "Blinkstrike",
            "Bloodquench",
            "Bloodweep",
            "Brutality",
            "Celeste",
            "Chaos",
            "Cometfell",
            "Convergence",
            "Darkheart",
            "Dawn",
            "Dawnbreaker",
            "Deathbringer",
            "Deathraze",
            "Decimation",
            "Desolation",
            "Destiny's Song",
            "Dirge",
            "Doomblade",
            "Doombringer",
            "Draughtbane",
            "Due Diligence",
            "Echo",
            "Eclipse",
            "Endbringer",
            "Epilogue",
            "Espada",
            "Extinction",
            "Faithkeeper",
            "Fate",
            "Fleshrender",
            "Florance",
            "Frenzy",
            "Fury",
            "Ghost Reaver",
            "Ghostwalker",
            "Gladius",
            "Glimmer",
            "Godslayer",
            "Grasscutter",
            "Gutrender",
            "Hatred's Bite",
            "Heartseeker",
            "Heartstriker",
            "Hell's Scream",
            "Hellfire",
            "Piece Maker",
            "Hellreaver",
            "Honor's Call",
            "Hope's End",
            "Infamy",
            "Interrogator",
            "Justifier",
            "Kinslayer",
            "Klinge",
            "Knightfall",
            "Lament",
            "Lazarus",
            "Lifedrinker",
            "Light's Bane",
            "Lightbane",
            "Lightbringer",
            "Lightning",
            "Limbo",
            "Loyalty",
            "Malice",
            "Mangler",
            "Massacre",
            "Mercy",
            "Misery",
            "Mournblade",
            "Narcoleptic",
            "Needle",
            "Nethersbane",
            "Night's Edge",
            "Night's Fall",
            "Nightbane",
            "Nightcrackle",
            "Nightfall",
            "Nirvana",
            "Oathbreaker",
            "Oathkeeper",
            "Oblivion",
            "Omega",
            "Orenmir",
            "Peacekeeper",
            "Persuasion",
            "Prick",
            "Purifier",
            "Rage",
            "Ragespike",
            "Ragnarok",
            "Reckoning",
            "Reign",
            "Remorse",
            "Requiem",
            "Retirement",
            "Rigormortis",
            "Savagery",
            "Scalpel",
            "Scar",
            "Seethe",
            "Severance",
            "Shadow Strike",
            "Shadowsteel",
            "Silence",
            "Silencer",
            "Silver Saber",
            "Silverlight",
            "Skullcrusher",
            "Slice of Life",
            "Soul Reaper",
            "Soulblade",
            "Soulrapier",
            "Spada",
            "Spike",
            "Spineripper",
            "Spiteblade",
            "Stalker",
            "Starshatterer",
            "Sting",
            "Stinger",
            "Storm",
            "Storm Breaker",
            "Stormbringer",
            "Stormcaller",
            "Story-Weaver",
            "Striker",
            "Sun Strike",
            "Suspension",
            "Swan Song",
            "The Ambassador",
            "The Black Blade",
            "The End",
            "The Facelifter",
            "The Light",
            "The Oculus",
            "The Stake",
            "The Untamed",
            "The Unyielding",
            "The Void",
            "Thorn",
            "Thunder",
            "Toothpick",
            "Tranquility",
            "Treachery",
            "Trinity",
            "Tyrhung",
            "Unending Tyranny",
            "Unholy Might",
            "Valkyrie",
            "Vanquisher",
            "Vengeance",
            "Venom",
            "Venomshank",
            "Warmonger",
            "Widow Maker",
            "Willbreaker",
            "Winterthorn",
            "Wit's End",
            "Witherbrand",
            "Wolf",
            "Worldbreaker",
            "Worldslayer",
        ]

        num = randrange(4)
        if num == 0:
            return choice(var1).title()
        elif num == 1:
            return choice(var2) + " " + choice(var4)
        elif num == 2:
            return choice(var2) + " " + choice(var3) + " " + choice(var4)
        elif num == 3:
            return choice(var7) + " " + choice(var5) + " " + choice(var6)

    @staticmethod
    def generate(classification=None):
        var1 = var2 = var3 = var4 = var5 = var6 = var7 = []

        if classification is None or classification not in Weapon.WeaponType:
            classification = choice(list(Weapon.WeaponType))
        if classification == Weapon.WeaponType.Axe:
            var1 = [
                "Abomination",
                "Agatha",
                "Allegiance",
                "Alpha",
                "Amnesia",
                "Anduril",
                "Anger's Edge",
                "Apocalypse",
                "Armageddon",
                "Arondite",
                "Ash",
                "Ashes",
                "Ashrune",
                "Betrayal",
                "Betrayer",
                "Blackout",
                "Blazefury",
                "Blazeguard",
                "Blight's Plight",
                "Blind Justice",
                "Blinkstrike",
                "Bloodfury",
                "Bloodmoon",
                "Bloodquench",
                "Bloodrage",
                "Bloodspiller",
                "Bloodweep",
                "Bone Warden",
                "Braindead",
                "Broken Promise",
                "Brutality",
                "Brutalizer",
                "Cataclysm",
                "Catastrophe",
                "Celeste",
                "Chance",
                "Chaos",
                "Chasm",
                "Chieftain",
                "Comet",
                "Cometfall",
                "Convergence",
                "Corpsemaker",
                "Corruption",
                "Crescent Moon",
                "Crimson",
                "Cutting Response",
                "Cyclone",
                "Darkness",
                "Dawn",
                "Dawn's Edge",
                "Dawnbreaker",
                "Daytime",
                "Deathbringer",
                "Deathraze",
                "Deathspade",
                "Decimation",
                "Desolation",
                "Despair",
                "Destiny",
                "Devastation",
                "Devine",
                "Devotion",
                "Devourer",
                "Divine Light",
                "Dominance",
                "Dominion",
                "Doom",
                "Doom's Edge",
                "Doomblade",
                "Doombringer",
                "Due Diligence",
                "Dusk's Edge",
                "Early Retirement",
                "Earthquake",
                "Echo",
                "Eclipse",
                "Edge of Death",
                "Edge of Eternity",
                "Edge of Infinity",
                "Edge of Life",
                "Edge of Madness",
                "Edge of Misery",
                "Edge of Reason",
                "Edge of Ruin",
                "Edge of Time",
                "Emergency",
                "Endbringer",
                "Enigma",
                "Epilogue",
                "Eternal Rest",
                "Eternity",
                "Extermination",
                "Extinction",
                "Faithkeeper",
                "Fate",
                "Finality",
                "Fleshrender",
                "Freak's Bite",
                "Frenzy",
                "Frostbite",
                "Frostwind",
                "Fury",
                "Fury's Gaze",
                "Gatecrasher",
                "Ghost Reaver",
                "Ghostwalker",
                "Glimmer",
                "Godslayer",
                "Grieving Blade",
                "Guillotine",
                "Gutrender",
                "Harbinger",
                "Harvester",
                "Hatred",
                "Hatred's Blade",
                "Heartseeker",
                "Hell's Scream",
                "Hellfire",
                "Hellreaver",
                "Homage",
                "Honor's Call",
                "Hope's Edge",
                "Hope's End",
                "Humongous",
                "Hurricane",
                "Infamy",
                "Infinity",
                "Interrogator",
                "Justice",
                "Justifier",
                "King's Defender",
                "King's Legacy",
                "Kinslayer",
                "Knight's Fall",
                "Knight's Honor",
                "Knightfall",
                "Lament",
                "Last Chance",
                "Last Laugh",
                "Last Rites",
                "Last Words",
                "Lazarus",
                "Legacy",
                "Legionaire",
                "Life's Limit",
                "Light's Bane",
                "Lightbane",
                "Lightbringer",
                "Lightning",
                "Limbo",
                "Magma",
                "Malice",
                "Maneater",
                "Massacre",
                "Mercy",
                "Midnight",
                "Misery's Edge",
                "Misery's End",
                "Monsoon",
                "Mooncleaver",
                "Mournblade",
                "Narcoleptic",
                "Nethersbane",
                "Night's Edge",
                "Night's Fall",
                "Nightbane",
                "Nightfall",
                "Nighttime",
                "Nirvana",
                "Oathbreaker",
                "Oathkeeper",
                "Oblivion",
                "Old Age",
                "Omega",
                "Orbit",
                "Orenmir",
                "Party Pooper",
                "Peacekeeper",
                "Peacemaker",
                "Pendulum",
                "Perfect Storm",
                "Persuasion",
                "Piece Maker",
                "Piety",
                "Pork-Chopper",
                "Pride",
                "Prophecy",
                "Purifier",
                "Rage",
                "Ragnarok",
                "Rapture",
                "Reaper",
                "Reaper's Toll",
                "Reckoning",
                "Red Dwarf",
                "Reign",
                "Remorse",
                "Requiem",
                "Retirement",
                "Righteous Might",
                "Rigormortis",
                "Rising Tide",
                "Savagery",
                "Scar",
                "Scourgeborne",
                "Second Chance",
                "Seism",
                "Severance",
                "Shadow Strike",
                "Shadow's Edge",
                "Shadowfury",
                "Shadowmoon",
                "Shadowsteel",
                "Silence",
                "Skullcleaver",
                "Skullcrusher",
                "Slice of Life",
                "Soul Breaker",
                "Soul Reaper",
                "Spinefall",
                "Stalker",
                "Storm",
                "Storm Breaker",
                "Storm-Weaver",
                "Stormbringer",
                "Stormcaller",
                "Stormedge",
                "Stormrider",
                "Supernova",
                "Supremacy",
                "Suspension",
                "Swan Song",
                "Termination",
                "The Ambassador",
                "The Chancellor",
                "The Chief",
                "The Decapitator",
                "The End",
                "The Facelifter",
                "The Light",
                "The Minotaur",
                "The Oculus",
                "The Oracle",
                "The Sundering",
                "The Void",
                "The Warden",
                "Thunder",
                "Treachery",
                "Tremor",
                "Trickster",
                "Trickster's Edge",
                "Trinity",
                "Twisted",
                "Typhoon",
                "Ubiquity",
                "Undoing",
                "Vacancy",
                "Valkyrie",
                "Vanquisher",
                "Vengeance",
                "Warbringer",
                "Warmonger",
                "Whirlwind",
                "Wicked",
                "Widow Maker",
                "Willbreaker",
                "Windreaper",
                "Windslicer",
                "Winter's Bite",
                "Wit's End",
                "Witherbrand",
                "Wolf",
                "Worldbreaker",
                "Worldcarver",
                "Worldslayer",
            ]
            var2 = [
                "Ancient",
                "Antique",
                "Apocalypse",
                "Apocalyptic",
                "Arcane",
                "Arched",
                "Atuned",
                "Bandit's",
                "Baneful",
                "Banished",
                "Barbarian",
                "Barbaric",
                "Battleworn",
                "Blazefury",
                "Blood Infused",
                "Blood-Forged",
                "Bloodcursed",
                "Bloodied",
                "Bloodlord's",
                "Bloodsurge",
                "Bloodvenom",
                "Bonecarvin",
                "Brutal",
                "Brutality",
                "Burnished",
                "Cataclysm",
                "Cataclysmic",
                "Challenger",
                "Challenger's",
                "Champion",
                "Champion's",
                "Cold-Forged",
                "Conqueror",
                "Conqueror's",
                "Corroded",
                "Corrupted",
                "Crazed",
                "Crying",
                "Cursed",
                "Curved",
                "Dancing",
                "Dark",
                "Darkness",
                "Defender",
                "Defender's",
                "Defiled",
                "Defiling",
                "Deluded",
                "Demonic",
                "Deserted",
                "Desire's",
                "Desolation",
                "Destiny's",
                "Diabolical",
                "Dire",
                "Doom",
                "Doom's",
                "Dragon's",
                "Dragonbreath",
                "Eerie",
                "Enchanted",
                "Engraved",
                "Enlightened",
                "Eternal",
                "Exiled",
                "Extinction",
                "Faith's",
                "Faithful",
                "Fancy",
                "Fearful",
                "Feral",
                "Ferocious",
                "Fierce",
                "Fiery",
                "Fire Infused",
                "Fireguard",
                "Firesoul",
                "Firestorm",
                "Flaming",
                "Flimsy",
                "Forsaken",
                "Fortune's",
                "Foul",
                "Fragile",
                "Frail",
                "Frenzied",
                "Frost",
                "Frozen",
                "Furious",
                "Fusion",
                "Ghastly",
                "Ghost",
                "Ghost-Forged",
                "Ghostly",
                "Gladiator",
                "Gladiator's",
                "Gleaming",
                "Glinting",
                "Greedy",
                "Grieving",
                "Grim",
                "Guard's",
                "Guardian's",
                "Hailstorm",
                "Harmonized",
                "Hateful",
                "Haunted",
                "Heartless",
                "Heinous",
                "Hero",
                "Hero's",
                "Hollow",
                "Holy",
                "Honed",
                "Honor's",
                "Hope's",
                "Hopeless",
                "Howling",
                "Hungering",
                "Improved",
                "Impure",
                "Incarnated",
                "Infused",
                "Inherited",
                "Isolated",
                "Jade Infused",
                "Judgement",
                "Keeper's",
                "Knightly",
                "Knight's",
                "Legionnaire's",
                "Liar's",
                "Lich",
                "Lightning",
                "Lonely",
                "Loyal",
                "Lustful",
                "Lusting",
                "Malevolent",
                "Malicious",
                "Malificent",
                "Malignant",
                "Massive",
                "Mended",
                "Mercenary",
                "Military",
                "Misfortune's",
                "Misty",
                "Moonlit",
                "Mourning",
                "Nightmare",
                "Oathkeeper's",
                "Ominous",
                "Peacekeeper",
                "Peacekeeper's",
                "Phantom",
                "Polished",
                "Possessed",
                "Pride's",
                "Prideful",
                "Primal",
                "Prime",
                "Primitive",
                "Promised",
                "Protector's",
                "Proud",
                "Pure",
                "Putrid",
                "Raging",
                "Recruit's",
                "Refined",
                "Reforged",
                "Reincarnated",
                "Relentless",
                "Remorseful",
                "Renewed",
                "Renovated",
                "Replica",
                "Restored",
                "Retribution",
                "Ritual",
                "Roaring",
                "Ruby Infused",
                "Rune-Forged",
                "Runed",
                "Rusty",
                "Savage",
                "Sentinel",
                "Shadow",
                "Shamanic",
                "Sharpened",
                "Silent",
                "Singed",
                "Singing",
                "Sinister",
                "Skyfall",
                "Smooth",
                "Soldier's",
                "Solitude's",
                "Sorcerer's",
                "Sorrow's",
                "Soul",
                "Soul Infused",
                "Soul-Forged",
                "Soulcursed",
                "Soulless",
                "Spectral",
                "Spectral-Forged",
                "Spiteful",
                "Storm",
                "Storm-Forged",
                "Stormfury",
                "Stormguard",
                "Terror",
                "Thirsting",
                "Thirsty",
                "Thunder",
                "Thunder-Forged",
                "Thunderfury",
                "Thunderguard",
                "Thundersoul",
                "Thunderstorm",
                "Timeworn",
                "Tormented",
                "Trainee's",
                "Treachery's",
                "Twilight",
                "Twilight's",
                "Twisted",
                "Tyrannical",
                "Undead",
                "Unholy",
                "Vanquisher",
                "Vengeance",
                "Vengeful",
                "Venom",
                "Vicious",
                "Victor",
                "Vile",
                "Vindication",
                "Vindicator",
                "Vindictive",
                "Void",
                "Volcanic",
                "Vowed",
                "War",
                "War-Forged",
                "Warden's",
                "Warlord's",
                "Warp",
                "Warped",
                "Warrior",
                "Warrior's",
                "Whistling",
                "Wicked",
                "Wind's",
                "Wind-Forged",
                "Windsong",
                "Woeful",
                "Wrathful",
                "Wretched",
                "Yearning",
                "Zealous",
            ]
            var3 = [
                "Adamantite",
                "Bone",
                "Bronze",
                "Bronzed",
                "Ivory",
                "Ebon",
                "Glass",
                "Golden",
                "Iron",
                "Ironbark",
                "Mithril",
                "Obsidian",
                "Silver",
                "Skeletal",
                "Steel",
                "Titanium",
            ]
            var4 = [
                "Battle Axe",
                "Chopper",
                "Axe",
                "Edge",
                "Crescent",
                "Cleaver",
                "Greataxe",
                "Dualblade",
                "Broadaxe",
                "Reaver",
                "War Axe",
                "Ravager",
                "Maul",
            ]
            var5 = [
                "Allegiance",
                "Annihilation",
                "Axe",
                "Battle Axe",
                "Betrayer",
                "Bond",
                "Boon",
                "Breaker",
                "Bringer",
                "Broadaxe",
                "Butcher",
                "Call",
                "Carver",
                "Champion",
                "Chopper",
                "Cleaver",
                "Conqueror",
                "Crescent",
                "Crusader",
                "Cry",
                "Cunning",
                "Dark Blade",
                "Dawn",
                "Defender",
                "Defiler",
                "Destroyer",
                "Doomblade",
                "Dualblade",
                "Edge",
                "Ender",
                "Etcher",
                "Executioner",
                "Favor",
                "Ferocity",
                "Foe",
                "Gift",
                "Glory",
                "Greataxe",
                "Guardian",
                "Heirloom",
                "Hope",
                "Incarnation",
                "Jaws",
                "Last Hope",
                "Last Stand",
                "Legacy",
                "Maul",
                "Memory",
                "Might",
                "Oath",
                "Pact",
                "Pledge",
                "Promise",
                "Prophecy",
                "Protector",
                "Ravager",
                "Razor",
                "Reach",
                "Reaper",
                "Reaver",
                "Runed Blade",
                "Sculptor",
                "Secret",
                "Slayer",
                "Slicer",
                "Soul",
                "Terror",
                "Token",
                "Tribute",
                "Vengeance",
                "Voice",
                "War Axe",
                "Warblade",
                "Whisper",
                "Wit",
            ]
            var6 = [
                "of Agony",
                "of Ancient Power",
                "of Anguish",
                "of Ashes",
                "of Assassins",
                "of Black Magic",
                "of Blessed Fortune",
                "of Blessings",
                "of Blight",
                "of Blood",
                "of Bloodlust",
                "of Broken Bones",
                "of Broken Dreams",
                "of Broken Families",
                "of Burdens",
                "of Chaos",
                "of Closing Eyes",
                "of Conquered Worlds",
                "of Corruption",
                "of Cruelty",
                "of Cunning",
                "of Dark Magic",
                "of Dark Souls",
                "of Darkness",
                "of Decay",
                "of Deception",
                "of Degradation",
                "of Delusions",
                "of Denial",
                "of Desecration",
                "of Diligence",
                "of Dismay",
                "of Dragonsouls",
                "of Due Diligence",
                "of Echoes",
                "of Ended Dreams",
                "of Ending Hope",
                "of Ending Misery",
                "of Eternal Bloodlust",
                "of Eternal Damnation",
                "of Eternal Glory",
                "of Eternal Justice",
                "of Eternal Rest",
                "of Eternal Sorrow",
                "of Eternal Struggles",
                "of Eternity",
                "of Executions",
                "of Faded Memories",
                "of Fallen Souls",
                "of Fools",
                "of Frost",
                "of Frozen Hells",
                "of Fury",
                "of Giants",
                "of Giantslaying",
                "of Grace",
                "of Grieving Widows",
                "of Hate",
                "of Hatred",
                "of Hell's Games",
                "of Hellish Torment",
                "of Heroes",
                "of Holy Might",
                "of Honor",
                "of Hope",
                "of Horrid Dreams",
                "of Horrors",
                "of Illuminated Dreams",
                "of Illumination",
                "of Immortality",
                "of Inception",
                "of Infinite Trials",
                "of Insanity",
                "of Invocation",
                "of Justice",
                "of Light's Hope",
                "of Lost Comrades",
                "of Lost Hope",
                "of Lost Voices",
                "of Lost Worlds",
                "of Magic",
                "of Mercy",
                "of Misery",
                "of Mountains",
                "of Mourning",
                "of Mystery",
                "of Necromancy",
                "of Nightmares",
                "of Oblivion",
                "of Perdition",
                "of Phantoms",
                "of Power",
                "of Pride",
                "of Pride's Fall",
                "of Putrefaction",
                "of Reckoning",
                "of Redemption",
                "of Regret",
                "of Riddles",
                "of Secrecy",
                "of Secrets",
                "of Shadow Strikes",
                "of Shadows",
                "of Shifting Sands",
                "of Shifting Worlds",
                "of Silence",
                "of Slaughter",
                "of Souls",
                "of Stealth",
                "of Storms",
                "of Subtlety",
                "of Suffering",
                "of Suffering's End",
                "of Summoning",
                "of Terror",
                "of Thunder",
                "of Time-Lost Memories",
                "of Timeless Battles",
                "of Titans",
                "of Torment",
                "of Traitors",
                "of Trembling Hands",
                "of Trials",
                "of Truth",
                "of Twilight's End",
                "of Twisted Visions",
                "of Unholy Blight",
                "of Unholy Might",
                "of Vengeance",
                "of Visions",
                "of Wasted Time",
                "of Widows",
                "of Wizardry",
                "of Woe",
                "of Wraiths",
                "of Zeal",
                "of the Ancients",
                "of the Banished",
                "of the Basilisk",
                "of the Beast",
                "of the Blessed",
                "of the Breaking Storm",
                "of the Brotherhood",
                "of the Burning Sun",
                "of the Caged Mind",
                "of the Cataclysm",
                "of the Champion",
                "of the Claw",
                "of the Corrupted",
                "of the Covenant",
                "of the Crown",
                "of the Damned",
                "of the Daywalker",
                "of the Dead",
                "of the Depth",
                "of the Dreadlord",
                "of the Earth",
                "of the East",
                "of the Emperor",
                "of the Empty Void",
                "of the End",
                "of the Enigma",
                "of the Fallen",
                "of the Falling Sky",
                "of the Flame",
                "of the Forest",
                "of the Forgotten",
                "of the Forsaken",
                "of the Gladiator",
                "of the Harvest",
                "of the Immortal",
                "of the Incoming Storm",
                "of the Insane",
                "of the King",
                "of the Lasting Night",
                "of the Leviathan",
                "of the Light",
                "of the Lion",
                "of the Lionheart",
                "of the Lone Victor",
                "of the Lone Wolf",
                "of the Lost",
                "of the Moon",
                "of the Moonwalker",
                "of the Night Sky",
                "of the Night",
                "of the Nightstalker",
                "of the North",
                "of the Occult",
                "of the Oracle",
                "of the Phoenix",
                "of the Plague",
                "of the Prince",
                "of the Protector",
                "of the Queen",
                "of the Serpent",
                "of the Setting Sun",
                "of the Shadows",
                "of the Sky",
                "of the South",
                "of the Stars",
                "of the Storm",
                "of the Summoner",
                "of the Sun",
                "of the Sunwalker",
                "of the Talon",
                "of the Undying",
                "of the Victor",
                "of the Void",
                "of the West",
                "of the Whispers",
                "of the Wicked",
                "of the Wind",
                "of the Wolf",
                "of the World",
                "of the Wretched",
            ]
            var7 = [
                "Abomination",
                "Agatha",
                "Allegiance",
                "Alpha",
                "Amnesia",
                "Anduril",
                "Anger's Edge",
                "Apocalypse",
                "Armageddon",
                "Arondite",
                "Ash",
                "Ashes",
                "Ashrune",
                "Betrayal",
                "Betrayer",
                "Blackout",
                "Blazefury",
                "Blazeguard",
                "Blind Justice",
                "Blinkstrike",
                "Bloodfury",
                "Bloodmoon",
                "Bloodquench",
                "Bloodrage",
                "Bloodspiller",
                "Bloodweep",
                "Bone Warden",
                "Braindead",
                "Broken Promise",
                "Brutality",
                "Brutalizer",
                "Cataclysm",
                "Catastrophe",
                "Celeste",
                "Chance",
                "Chaos",
                "Chasm",
                "Chieftain",
                "Comet",
                "Cometfall",
                "Convergence",
                "Corpsemaker",
                "Corruption",
                "Crescent Moon",
                "Crimson",
                "Cyclone",
                "Darkness",
                "Dawn",
                "Dawn's Edge",
                "Dawnbreaker",
                "Daytime",
                "Deathbringer",
                "Deathraze",
                "Deathspade",
                "Decimation",
                "Desolation",
                "Despair",
                "Destiny",
                "Devastation",
                "Devine",
                "Devotion",
                "Devourer",
                "Divine Light",
                "Dominance",
                "Dominion",
                "Doom",
                "Doomblade",
                "Doombringer",
                "Due Diligence",
                "Earthquake",
                "Echo",
                "Eclipse",
                "Emergency",
                "Endbringer",
                "Enigma",
                "Epilogue",
                "Eternal Rest",
                "Eternity",
                "Extermination",
                "Extinction",
                "Faithkeeper",
                "Fate",
                "Finality",
                "Fleshrender",
                "Freak's Bite",
                "Frenzy",
                "Frostbite",
                "Frostwind",
                "Fury",
                "Fury's Gaze",
                "Gatecrasher",
                "Ghost Reaver",
                "Ghostwalker",
                "Glimmer",
                "Godslayer",
                "Guillotine",
                "Gutrender",
                "Harbinger",
                "Harvester",
                "Hatred",
                "Heartseeker",
                "Hell's Scream",
                "Hellfire",
                "Hellreaver",
                "Homage",
                "Honor's Call",
                "Hope's Edge",
                "Hope's End",
                "Humongous",
                "Hurricane",
                "Infamy",
                "Infinity",
                "Interrogator",
                "Justice",
                "Justifier",
                "King's Defender",
                "King's Legacy",
                "Kinslayer",
                "Knight's Fall",
                "Knight's Honor",
                "Knightfall",
                "Lament",
                "Last Chance",
                "Last Laugh",
                "Last Rites",
                "Last Words",
                "Lazarus",
                "Legacy",
                "Legionaire",
                "Life's Limit",
                "Light's Bane",
                "Lightbane",
                "Lightbringer",
                "Lightning",
                "Limbo",
                "Magma",
                "Malice",
                "Maneater",
                "Massacre",
                "Mercy",
                "Midnight",
                "Misery's Edge",
                "Misery's End",
                "Monsoon",
                "Mooncleaver",
                "Mournblade",
                "Narcoleptic",
                "Nethersbane",
                "Night's Edge",
                "Night's Fall",
                "Nightbane",
                "Nightfall",
                "Nighttime",
                "Nirvana",
                "Oathbreaker",
                "Oathkeeper",
                "Oblivion",
                "Old Age",
                "Omega",
                "Orbit",
                "Orenmir",
                "Party Pooper",
                "Peacekeeper",
                "Peacemaker",
                "Pendulum",
                "Perfect Storm",
                "Persuasion",
                "Piece Maker",
                "Piety",
                "Pork-Chopper",
                "Pride",
                "Prophecy",
                "Purifier",
                "Rage",
                "Ragnarok",
                "Rapture",
                "Reaper",
                "Reaper's Toll",
                "Reckoning",
                "Red Dwarf",
                "Reign",
                "Remorse",
                "Requiem",
                "Retirement",
                "Rigormortis",
                "Rising Tide",
                "Savagery",
                "Scar",
                "Scourgeborne",
                "Second Chance",
                "Seism",
                "Severance",
                "Shadow Strike",
                "Shadow's Edge",
                "Shadowfury",
                "Shadowmoon",
                "Shadowsteel",
                "Silence",
                "Skullcleaver",
                "Skullcrusher",
                "Slice of Life",
                "Soul Breaker",
                "Soul Reaper",
                "Spinefall",
                "Stalker",
                "Storm",
                "Storm Breaker",
                "Storm-Weaver",
                "Stormbringer",
                "Stormcaller",
                "Stormedge",
                "Stormrider",
                "Supernova",
                "Supremacy",
                "Suspension",
                "Swan Song",
                "Termination",
                "The Ambassador",
                "The Chancellor",
                "The Chief",
                "The Decapitator",
                "The End",
                "The Facelifter",
                "The Light",
                "The Minotaur",
                "The Oculus",
                "The Oracle",
                "The Sundering",
                "The Void",
                "The Warden",
                "Thunder",
                "Treachery",
                "Tremor",
                "Trickster",
                "Trinity",
                "Twisted",
                "Typhoon",
                "Ubiquity",
                "Undoing",
                "Vacancy",
                "Valkyrie",
                "Vanquisher",
                "Vengeance",
                "Warbringer",
                "Warmonger",
                "Whirlwind",
                "Wicked",
                "Widow Maker",
                "Willbreaker",
                "Windreaper",
                "Windslicer",
                "Winter's Bite",
                "Wit's End",
                "Witherbrand",
                "Wolf",
                "Worldbreaker",
                "Worldcarver",
                "Worldslayer",
            ]
        elif classification == Weapon.WeaponType.Bow:
            var1 = [
                "Hornet's Sting",
                "Blackened Sky",
                "Darkened Sky",
                "Steel Hail",
                "Archangel",
                "Archdemon",
                "Arcus",
                "Armadillo",
                "Armageddon",
                "Arrowsong",
                "Arrowspike",
                "Avalance",
                "Back Pain",
                "Backsnipe",
                "Ballista",
                "Barrage",
                "Beesting",
                "Betrayal",
                "Betrayal's Sting",
                "Bolt",
                "Bolt Action",
                "Bon Voyage",
                "Bristleblitz",
                "Bullseye",
                "Calamity",
                "Chimera",
                "Clutch",
                "Comet",
                "Courier",
                "Crier",
                "Curvey",
                "Cyclone",
                "Dash",
                "Dead Air",
                "Death's Kiss",
                "Death's Sigh",
                "Death's Whisper",
                "Decimate",
                "Deliverance",
                "Deluge",
                "Destiny's Song",
                "Devil's Kiss",
                "Devil's Recurve",
                "Devil's Sting",
                "Devil's Whisper",
                "Doomcaster",
                "Drawback",
                "Drawling",
                "Drawstring",
                "Dream Catcher",
                "Eagle",
                "Eagle Strike",
                "Emily's Curve",
                "Euthanasia",
                "Eye of Eternity",
                "Eye of Fidelity",
                "Eye of Precision",
                "Eye of Truth",
                "Falling Star",
                "Featherdraw",
                "Final Breath",
                "Final Voyage",
                "Final Whisper",
                "Final Whistle",
                "Firestarter",
                "Fling",
                "Flux",
                "Fury",
                "Gargoyle",
                "Graviton",
                "Hailstorm",
                "Hamstring",
                "Hamstrung",
                "Harbinger",
                "Hatred's Sting",
                "Hawkeye",
                "Heartbeat",
                "Heartpiercer",
                "Heartstriker",
                "Heartstring",
                "Hedgehog",
                "Hell's Whistle",
                "High-Strung",
                "Hooty Tooty Aim and Shooty",
                "Hope's End",
                "Hornet",
                "Huntress",
                "Hurricane",
                "Hush",
                "Imminent Doom",
                "Impending Doom",
                "Irk",
                "Jugular",
                "Kiss of Death",
                "Lash",
                "Last Kiss",
                "Last Vision",
                "Last Whisper",
                "Lightning",
                "Lightning Strike",
                "Long Shot",
                "Messenger",
                "Meteor",
                "Meteor Strike",
                "Midge",
                "Mirage",
                "Misery's End",
                "Molten Fury",
                "Mosquito",
                "Needle Shooter",
                "Needle Threader",
                "Netherstrand",
                "Penetrator",
                "Perfidy",
                "Phantom",
                "Phantom Strike",
                "Phoenix",
                "Pierce",
                "Pinch",
                "Pique",
                "Pluck",
                "Porcupine",
                "Precise",
                "Precision",
                "Prickle",
                "Prophet",
                "Puncture",
                "Quickstrike",
                "Quillshooter",
                "Quintain",
                "Rain Maker",
                "Razorsong",
                "Razorwind",
                "Recurve",
                "Rigormortis",
                "Salvation",
                "Scorpio",
                "Scorpion",
                "Scorpion Sting",
                "Shadow Strike",
                "Shadow's Bane",
                "Shadow's Strike",
                "Shatter Storm",
                "Shooting Star",
                "Shriek",
                "Silent Messenger",
                "Silentsong",
                "Siren's Call",
                "Siren's Cry",
                "Siren's Song",
                "Sky Piercer",
                "Skyfire",
                "Snatch",
                "Snipe",
                "Snitch",
                "Soulstring",
                "Special Delivery",
                "Spitfire",
                "Splinter",
                "Splintermark",
                "Squawk",
                "Squirm",
                "Star's Fury",
                "Starshot",
                "Starstruck",
                "Sting",
                "Stormsong",
                "Striker's Mark",
                "Stryker",
                "Sudden Death",
                "Surprise",
                "Swiftwind",
                "Swoosh",
                "Talonstrike",
                "Tempest",
                "The Ambassador",
                "The Messenger",
                "Thunder",
                "Thunderstrike",
                "Tiebreaker",
                "Tranquility",
                "Trophy Chord",
                "Trophy Gatherer",
                "Trophy Mark",
                "Truestrike",
                "Tweak",
                "Twisted",
                "Twister",
                "Twitch",
                "Typhoon",
                "Valkyrie",
                "Vehement Chord",
                "Venomstrike",
                "Viper",
                "Vixen",
                "Vulture",
                "Warsong",
                "Wasp",
                "Wasp's Sting",
                "Whelm",
                "Whisper",
                "Whisperwind",
                "Windbreaker",
                "Windforce",
                "Windlass",
                "Windrunner",
                "Windstalker",
                "Windtalker",
                "WithDraw",
            ]
            var2 = [
                "Advanced",
                "Amber Infused",
                "Ancient",
                "Anguish'",
                "Annihilation",
                "Antique",
                "Arcane",
                "Arched",
                "Archer's",
                "Assassination",
                "Atuned",
                "Bandit's",
                "Baneful",
                "Banished",
                "Barbarian",
                "Barbaric",
                "Battleworn",
                "Blazefury",
                "Blessed",
                "Blood Infused",
                "Bloodcursed",
                "Bloodied",
                "Bloodlord's",
                "Bloodsurge",
                "Bloodvenom",
                "Bone Crushing",
                "Bowman's",
                "Brutal",
                "Brutality",
                "Burnished",
                "Cataclysm",
                "Cataclysmic",
                "Charmed",
                "Corrupted",
                "Crazed",
                "Crying",
                "Cursed",
                "Curved",
                "Dancing",
                "Defiled",
                "Deluded",
                "Demonic",
                "Deserted",
                "Desire's",
                "Desolation",
                "Destiny's",
                "Dire",
                "Doom",
                "Doom's",
                "Dragon's",
                "Dragonbreath",
                "Dreadful",
                "Ebon",
                "Eerie",
                "Enchanted",
                "Engraved",
                "Eternal",
                "Ethereal",
                "Executing",
                "Exiled",
                "Expert's",
                "Extinction",
                "Faith's",
                "Faithful",
                "Fancy",
                "Fearful",
                "Feather-Wrapped",
                "Featherdraw",
                "Feral",
                "Fierce",
                "Fiery",
                "Fine",
                "Firestorm",
                "Flimsy",
                "Forsaken",
                "Fortune's",
                "Fragile",
                "Frail",
                "Frenzied",
                "Frost",
                "Frozen",
                "Furious",
                "Fusion",
                "Ghastly",
                "Ghostly",
                "Gladiator",
                "Gladiator's",
                "Grieving",
                "Guard's",
                "Guardian's",
                "Hateful",
                "Haunted",
                "Heavy",
                "Hollow",
                "Holy",
                "Honed",
                "Honor's",
                "Hope's",
                "Hopeless",
                "Howling",
                "Hungering",
                "Improved",
                "Incarnated",
                "Infused",
                "Inherited",
                "Isolated",
                "Jade Infused",
                "Judgement",
                "Liar's",
                "Lich",
                "Lightning",
                "Lonely",
                "Loyal",
                "Lustful",
                "Lusting",
                "Mage's",
                "Malevolent",
                "Malicious",
                "Malignant",
                "Massive",
                "Master Hunter's",
                "Mended",
                "Mercenary",
                "Military",
                "Misfortune's",
                "Mourning",
                "Nightmare",
                "Nightstalker",
                "Ominous",
                "Peacekeeper",
                "Phantom",
                "Possessed",
                "Pride's",
                "Prideful",
                "Primitive",
                "Promised",
                "Protector's",
                "Proud",
                "Ranger's",
                "Recruit's",
                "Reincarnated",
                "Relentless",
                "Remorseful",
                "Renewed",
                "Renovated",
                "Replica",
                "Restored",
                "Retribution",
                "Ritual",
                "Roaring",
                "Savage",
                "Oathkeeper's",
                "Shadow",
                "Shadowleaf",
                "Shrieking",
                "Silent",
                "Singed",
                "Singing",
                "Sinister",
                "Skullforge",
                "Skyfall",
                "Smooth",
                "Solitude's",
                "Sorrow's",
                "Soul",
                "Soul Infused",
                "Soulcursed",
                "Soulless",
                "Spectral",
                "Spiteful",
                "Storm",
                "Storm's",
                "Stormfury",
                "Stormguard",
                "Stout",
                "Striker's",
                "Sturdy",
                "Terror",
                "Thirsting",
                "Thirsty",
                "Thunder",
                "Thunderfury",
                "Thunderguard",
                "Thundersoul",
                "Timeworn",
                "Tormented",
                "Tracking",
                "Trainee's",
                "Trapper's",
                "Treachery's",
                "Twilight",
                "Twilight's",
                "Twisted",
                "Tyrannical",
                "Undead",
                "Unholy",
                "Vengeance",
                "Vengeful",
                "Venom",
                "Vicious",
                "Vindication",
                "Vindictive",
                "Void",
                "Volcanic",
                "Vowed",
                "War-Forged",
                "Warlord's",
                "Warp",
                "Warped",
                "Warsong",
                "Well Crafted",
                "Whistling",
                "Wicked",
                "Wind's",
                "Windsong",
                "Woeful",
                "Wrathful",
                "Wretched",
                "Yearning",
                "Yielding",
                "Zealous",
            ]
            var3 = [
                "Ashwood",
                "Bone",
                "Bronzed",
                "Driftwood",
                "Ebon",
                "Hardwood",
                "Iron",
                "Ironbark",
                "Maple",
                "Oak",
                "Redwood",
                "Skeletal",
                "Steel",
                "Titanium",
                "Warpwood",
                "Willow",
                "Yew",
            ]
            var4 = [
                "Longbow",
                "Shortbow",
                "Crossbow",
                "Speargun",
                "Launcher",
                "Repeater",
                "Shooter",
                "Crossfire",
                "Bolter",
                "Heavy Crossbow",
                "Arbalest",
                "Piercer",
                "Striker",
                "Warbow",
                "Chord",
                "Recurve",
                "Bow",
                "Compound Bow",
                "Hunting Bow",
                "Warp-Bow",
                "Flatbow",
                "Reflex Bow",
                "Composite Bow",
                "Compound Crossbow",
                "Straight Bow",
                "Self Bow",
            ]
            var5 = [
                "Annihilation",
                "Arbalest",
                "Arch",
                "Betrayer",
                "Bite",
                "Bolter",
                "Bond",
                "Boon",
                "Bow",
                "Breaker",
                "Bringer",
                "Call",
                "Champion",
                "Chord",
                "Composite Bow",
                "Compound Bow",
                "Crescent",
                "Crook",
                "Crossbow",
                "Crossfire",
                "Cry",
                "Cunning",
                "Curve",
                "Dawn",
                "Defiler",
                "Destroyer",
                "Eclipse",
                "Ellipse",
                "Ender",
                "Etcher",
                "Executioner",
                "Eye",
                "Favor",
                "Ferocity",
                "Flatbow",
                "Foe",
                "Gift",
                "Glory",
                "Guardian",
                "Heavy Crossbow",
                "Heirloom",
                "Hope",
                "Hunting Bow",
                "Incarnation",
                "Kiss",
                "Last Hope",
                "Last Stand",
                "Launcher",
                "Legacy",
                "Longbow",
                "Memory",
                "Might",
                "Oath",
                "Pact",
                "Piercer",
                "Pique",
                "Pledge",
                "Poke",
                "Prick",
                "Promise",
                "Protector",
                "Ravager",
                "Reach",
                "Recurve",
                "Reflex Bow",
                "Repeater",
                "Savagery",
                "Secret",
                "Self Bow",
                "Shooter",
                "Shortbow",
                "Skewer",
                "Soul",
                "Speargun",
                "Spike",
                "Spine",
                "Straight Bow",
                "Striker",
                "String",
                "Terror",
                "Token",
                "Tribute",
                "Vengeance",
                "Voice",
                "Warbow",
                "Warp-Bow",
                "Whisper",
                "Wit",
            ]
            var6 = [
                "of Agony",
                "of Ancient Power",
                "of Anguish",
                "of Ashes",
                "of Assassins",
                "of Black Magic",
                "of Blessed Fortune",
                "of Blessings",
                "of Blight",
                "of Blood",
                "of Bloodlust",
                "of Broken Bones",
                "of Broken Dreams",
                "of Broken Families",
                "of Burdens",
                "of Chaos",
                "of Closing Eyes",
                "of Conquered Worlds",
                "of Corruption",
                "of Cruelty",
                "of Cunning",
                "of Dark Magic",
                "of Dark Souls",
                "of Darkness",
                "of Decay",
                "of Deception",
                "of Degradation",
                "of Delusions",
                "of Denial",
                "of Desecration",
                "of Diligence",
                "of Dismay",
                "of Dragonsouls",
                "of Due Diligence",
                "of Echoes",
                "of Ended Dreams",
                "of Ending Hope",
                "of Ending Misery",
                "of Eternal Bloodlust",
                "of Eternal Damnation",
                "of Eternal Glory",
                "of Eternal Justice",
                "of Eternal Rest",
                "of Eternal Sorrow",
                "of Eternal Struggles",
                "of Eternity",
                "of Executions",
                "of Faded Memories",
                "of Fallen Souls",
                "of Fools",
                "of Frost",
                "of Frozen Hells",
                "of Fury",
                "of Giants",
                "of Giantslaying",
                "of Grace",
                "of Grieving Widows",
                "of Hate",
                "of Hatred",
                "of Hell's Games",
                "of Hellish Torment",
                "of Heroes",
                "of Holy Might",
                "of Honor",
                "of Hope",
                "of Horrid Dreams",
                "of Horrors",
                "of Illuminated Dreams",
                "of Illumination",
                "of Immortality",
                "of Inception",
                "of Infinite Trials",
                "of Insanity",
                "of Invocation",
                "of Justice",
                "of Light's Hope",
                "of Lost Comrades",
                "of Lost Hope",
                "of Lost Voices",
                "of Lost Worlds",
                "of Magic",
                "of Mercy",
                "of Misery",
                "of Mountains",
                "of Mourning",
                "of Mystery",
                "of Necromancy",
                "of Nightmares",
                "of Oblivion",
                "of Perdition",
                "of Phantoms",
                "of Power",
                "of Pride",
                "of Pride's Fall",
                "of Putrefaction",
                "of Reckoning",
                "of Redemption",
                "of Regret",
                "of Riddles",
                "of Secrecy",
                "of Secrets",
                "of Shadow Strikes",
                "of Shadows",
                "of Shifting Sands",
                "of Shifting Worlds",
                "of Silence",
                "of Slaughter",
                "of Souls",
                "of Stealth",
                "of Storms",
                "of Subtlety",
                "of Suffering",
                "of Suffering's End",
                "of Summoning",
                "of Terror",
                "of Thunder",
                "of Time-Lost Memories",
                "of Timeless Battles",
                "of Titans",
                "of Torment",
                "of Traitors",
                "of Trembling Hands",
                "of Trials",
                "of Truth",
                "of Twilight's End",
                "of Twisted Visions",
                "of Unholy Blight",
                "of Unholy Might",
                "of Vengeance",
                "of Visions",
                "of Wasted Time",
                "of Widows",
                "of Wizardry",
                "of Woe",
                "of Wraiths",
                "of Zeal",
                "of the Ancients",
                "of the Banished",
                "of the Basilisk",
                "of the Beast",
                "of the Blessed",
                "of the Breaking Storm",
                "of the Brotherhood",
                "of the Burning Sun",
                "of the Caged Mind",
                "of the Cataclysm",
                "of the Champion",
                "of the Claw",
                "of the Corrupted",
                "of the Covenant",
                "of the Crown",
                "of the Damned",
                "of the Daywalker",
                "of the Dead",
                "of the Depth",
                "of the Dreadlord",
                "of the Earth",
                "of the East",
                "of the Emperor",
                "of the Empty Void",
                "of the End",
                "of the Enigma",
                "of the Fallen",
                "of the Falling Sky",
                "of the Flame",
                "of the Forest",
                "of the Forgotten",
                "of the Forsaken",
                "of the Gladiator",
                "of the Harvest",
                "of the Immortal",
                "of the Incoming Storm",
                "of the Insane",
                "of the King",
                "of the Lasting Night",
                "of the Leviathan",
                "of the Light",
                "of the Lion",
                "of the Lionheart",
                "of the Lone Victor",
                "of the Lone Wolf",
                "of the Lost",
                "of the Moon",
                "of the Moonwalker",
                "of the Night Sky",
                "of the Night",
                "of the Nightstalker",
                "of the North",
                "of the Occult",
                "of the Oracle",
                "of the Phoenix",
                "of the Plague",
                "of the Prince",
                "of the Protector",
                "of the Queen",
                "of the Serpent",
                "of the Setting Sun",
                "of the Shadows",
                "of the Sky",
                "of the South",
                "of the Stars",
                "of the Storm",
                "of the Summoner",
                "of the Sun",
                "of the Sunwalker",
                "of the Talon",
                "of the Undying",
                "of the Victor",
                "of the Void",
                "of the West",
                "of the Whispers",
                "of the Wicked",
                "of the Wind",
                "of the Wolf",
                "of the World",
                "of the Wretched",
            ]
            var7 = [
                "Archangel",
                "Archdemon",
                "Arcus",
                "Armadillo",
                "Armageddon",
                "Arrowsong",
                "Arrowspike",
                "Avalance",
                "Back Pain",
                "Backsnipe",
                "Ballista",
                "Barrage",
                "Beesting",
                "Betrayal",
                "Betrayal's Sting",
                "Bolt",
                "Bon Voyage",
                "Bristleblitz",
                "Bullseye",
                "Calamity",
                "Chimera",
                "Clutch",
                "Comet",
                "Courier",
                "Crier",
                "Curvey",
                "Cyclone",
                "Dash",
                "Dead Air",
                "Death's Kiss",
                "Death's Sigh",
                "Death's Whisper",
                "Decimate",
                "Deliverance",
                "Deluge",
                "Destiny's Song",
                "Devil's Kiss",
                "Devil's Recurve",
                "Devil's Sting",
                "Devil's Whisper",
                "Doomcaster",
                "Drawback",
                "Drawling",
                "Drawstring",
                "Dream Catcher",
                "Eagle",
                "Eagle Strike",
                "Emily's Curve",
                "Euthanasia",
                "Falling Star",
                "Featherdraw",
                "Firestarter",
                "Fling",
                "Flux",
                "Fury",
                "Gargoyle",
                "Graviton",
                "Hailstorm",
                "Hamstring",
                "Hamstrung",
                "Harbinger",
                "Hatred's Sting",
                "Hawkeye",
                "Heartbeat",
                "Heartpiercer",
                "Heartstriker",
                "Heartstring",
                "Hedgehog",
                "Hell's Whistle",
                "High-Strung",
                "Hope's End",
                "Hornet",
                "Huntress",
                "Hurricane",
                "Hush",
                "Irk",
                "Jugular",
                "Kiss of Death",
                "Lash",
                "Lightning",
                "Long Shot",
                "Messenger",
                "Meteor",
                "Midge",
                "Mirage",
                "Misery's End",
                "Molten Fury",
                "Mosquito",
                "Netherstrand",
                "Penetrator",
                "Perfidy",
                "Phantom",
                "Phantom Strike",
                "Phoenix",
                "Pierce",
                "Pinch",
                "Pique",
                "Pluck",
                "Porcupine",
                "Precise",
                "Precision",
                "Prickle",
                "Prophet",
                "Puncture",
                "Quickstrike",
                "Quintain",
                "Rain Maker",
                "Razorsong",
                "Razorwind",
                "Recurve",
                "Rigormortis",
                "Salvation",
                "Scorpio",
                "Scorpion",
                "Shadow Strike",
                "Shooting Star",
                "Shriek",
                "Silent Messenger",
                "Silentsong",
                "Siren's Call",
                "Siren's Cry",
                "Siren's Song",
                "Sky Piercer",
                "Skyfire",
                "Snatch",
                "Snipe",
                "Snitch",
                "Soulstring",
                "Spitfire",
                "Splinter",
                "Splintermark",
                "Squawk",
                "Squirm",
                "Star's Fury",
                "Starshot",
                "Starstruck",
                "Sting",
                "Stormsong",
                "Stryker",
                "Surprise",
                "Swiftwind",
                "Swoosh",
                "Talonstrike",
                "Tempest",
                "The Ambassador",
                "The Messenger",
                "Thunder",
                "Thunderstrike",
                "Tiebreaker",
                "Tranquility",
                "Truestrike",
                "Tweak",
                "Twisted",
                "Twister",
                "Twitch",
                "Typhoon",
                "Valkyrie",
                "Venomstrike",
                "Viper",
                "Vixen",
                "Vulture",
                "Warsong",
                "Wasp",
                "Whelm",
                "Whisper",
                "Whisperwind",
                "Windbreaker",
                "Windforce",
                "Windlass",
                "Windrunner",
                "Windstalker",
                "Windtalker",
                "WithDraw",
            ]
        elif classification == Weapon.WeaponType.Dagger:
            var1 = [
                "Tie Breaker",
                "Redemption",
                "Laceration",
                "Forever",
                "Silver Slicer",
                "Eternity",
                "Goodbye",
                "Abyssal Shard",
                "Aetherius",
                "Agatha",
                "Wyrmtooth",
                "Alpha",
                "Amnesia",
                "Amnesty",
                "Anarchy",
                "Anduril",
                "Anger's Tear",
                "Angerfang",
                "Apocalypse",
                "Armageddon",
                "Ashrune",
                "Backtwister",
                "Barb",
                "Betrayal",
                "Betrayer",
                "Blackfang",
                "Blackout",
                "Blacktalon",
                "Blade of a Thousand Cuts",
                "Blazefury",
                "Blind Justice",
                "Blindstrike",
                "Blink",
                "Blinkstrike",
                "Blood Weeper",
                "Bloodquench",
                "Bloodsipper",
                "Bloodweep",
                "Bonescraper",
                "Bonespike",
                "Brainpicker",
                "Broken Promise",
                "Brutality",
                "Cataclysm",
                "Catastrophe",
                "Celeste",
                "Chaos",
                "Chisel",
                "Cometfell",
                "Convergence",
                "Crisscross",
                "Crucifix",
                "Darkheart",
                "Darkness",
                "Dawn",
                "Death's Bite",
                "Death's Kiss",
                "Death's Sting",
                "Deathraze",
                "Decimation",
                "Dementia",
                "Desolation",
                "Despair",
                "Destiny's Song",
                "Devine",
                "Dirge",
                "Dissector",
                "Divinity",
                "Doomblade",
                "Doombringer",
                "Doomspike",
                "Dragonclaw",
                "Dragonfang",
                "Dragontooth",
                "Draughtbane",
                "Due Diligence",
                "Dustbringer",
                "Ebony",
                "Echo",
                "Eclipse",
                "Edge of Eternity",
                "Edge of Insanity",
                "Edge of Time",
                "Endbringer",
                "Enigma",
                "Epilogue",
                "Eternal Rest",
                "Extinction",
                "Faithkeeper",
                "Fate",
                "Fear",
                "Felstriker",
                "Fleshrender",
                "Fleshshaper",
                "Flicker",
                "Frenzy",
                "Frightalon",
                "Fury",
                "Garotte",
                "Ghost Reaver",
                "Ghost Shard",
                "Ghostwalker",
                "Gladius",
                "Glimmer",
                "Grasscutter",
                "Grieving Blade",
                "Gutrender",
                "Gutwrencher",
                "Harmony",
                "Hatred's Bite",
                "Heartpierce",
                "Heartrazor",
                "Heartseeker",
                "Heartshiver",
                "Heartstriker",
                "Hell's Scream",
                "Hellfire",
                "Hollow Silence",
                "Honor's Call",
                "Hope's End",
                "Hysteria",
                "Icefall",
                "Incision",
                "Infamy",
                "Infinity",
                "Insanity",
                "Interrogator",
                "Ivory",
                "Justice",
                "Kingsbane",
                "Kingsfall",
                "Kinslayer",
                "Knight's Fall",
                "Knightfall",
                "Lament",
                "Last Rites",
                "Last Words",
                "Lazarus",
                "Lifedrinker",
                "Lightbane",
                "Lightning",
                "Limbo",
                "Lobotomizer",
                "Loyalty",
                "Lynch",
                "Maelstrom",
                "Malice",
                "Mangler",
                "Massacre",
                "Mercy",
                "Meteor",
                "Midnight",
                "Moonlight",
                "Mournblade",
                "Murder",
                "Mutilator",
                "Nail",
                "Narcoleptic",
                "Needle",
                "Nemesis",
                "Nethersbane",
                "Night's Edge",
                "Night's Fall",
                "Nightbane",
                "Nightbite",
                "Nightcrackle",
                "Nightfall",
                "Nightkiss",
                "Nimble",
                "Nirvana",
                "Oathbreaker",
                "Oathkeeper",
                "Oblivion",
                "Omega",
                "Omen",
                "Peacekeeper",
                "Persuasion",
                "Phantom",
                "Phantom Shard",
                "Phantomstrike",
                "Phobia",
                "Piece Maker",
                "Prick",
                "Purify",
                "Quicksilver",
                "Rage",
                "Ragespike",
                "Reaper",
                "Reckoning",
                "Remorse",
                "Requiem",
                "Riddle",
                "Rigormortis",
                "Sacrifice",
                "Sanguine",
                "Savagery",
                "Scalpel",
                "Scar",
                "Scarlet",
                "Seethe",
                "Severance",
                "Shadow Strike",
                "Shadowbite",
                "Shadowfall",
                "Shadowkiss",
                "Shadowrazor",
                "Shadowshiver",
                "Shadowsong",
                "Silence",
                "Silencer",
                "Silver Saber",
                "Silverlight",
                "Siphon",
                "Slander",
                "Slice of Life",
                "Solarflare",
                "Spiderfang",
                "Spike",
                "Spineripper",
                "Spiritsever",
                "Spiteblade",
                "Stalker",
                "Starlight",
                "Starshard",
                "Stickler",
                "Sting",
                "Stinger",
                "Storm",
                "Stormbringer",
                "Stormcaller",
                "Stormtip",
                "Striker",
                "Sun Strike",
                "Sunflare",
                "Sunshard",
                "Suspension",
                "Swan Song",
                "Teaser",
                "The Black Blade",
                "The End",
                "The Facelifter",
                "The Sleeper",
                "The Stake",
                "The Unmaker",
                "The Void",
                "Thorn",
                "Thunder",
                "Timeslicer",
                "Toothpick",
                "Torment",
                "Treachery",
                "Trickster",
                "Trinity",
                "Twilight",
                "Twinkle",
                "Twister",
                "Twitch",
                "Tyrhung",
                "Valkyrie",
                "Vengeance",
                "Venom",
                "Venombite",
                "Venomkiss",
                "Venomshank",
                "Venomtip",
                "Warmonger",
                "Widow Maker",
                "Widowkiller",
                "Widowmaker",
                "Winterthorn",
            ]
            var2 = [
                "Ancient",
                "Anguish'",
                "Annihilation",
                "Antique",
                "Apocalypse",
                "Apocalyptic",
                "Arcane",
                "Arched",
                "Assassination",
                "Atuned",
                "Bandit's",
                "Baneful",
                "Banished",
                "Barbarian",
                "Barbaric",
                "Battleworn",
                "Blazefury",
                "Blood Infused",
                "Blood-Forged",
                "Bloodcursed",
                "Bloodied",
                "Bloodlord's",
                "Bloodsurge",
                "Bloodvenom",
                "Bonecarvin",
                "Brutal",
                "Brutality",
                "Burnished",
                "Cataclysm",
                "Cataclysmic",
                "Cold-Forged",
                "Corroded",
                "Corrupted",
                "Crazed",
                "Crying",
                "Cursed",
                "Curved",
                "Dancing",
                "Dark",
                "Darkness",
                "Defiled",
                "Defiling",
                "Deluded",
                "Deserted",
                "Desire's",
                "Desolation",
                "Destiny's",
                "Diabolical",
                "Dire",
                "Doom",
                "Doom's",
                "Dragon's",
                "Eerie",
                "Enchanted",
                "Engraved",
                "Eternal",
                "Executing",
                "Exiled",
                "Extinction",
                "Faith's",
                "Faithful",
                "Fancy",
                "Fearful",
                "Feral",
                "Ferocious",
                "Fierce",
                "Fiery",
                "Fire Infused",
                "Fireguard",
                "Firesoul",
                "Firestorm",
                "Flaming",
                "Flimsy",
                "Forsaken",
                "Fortune's",
                "Foul",
                "Fragile",
                "Frail",
                "Frenzied",
                "Frost",
                "Frozen",
                "Furious",
                "Fusion",
                "Ghastly",
                "Ghost-Forged",
                "Ghostly",
                "Gladiator",
                "Gladiator's",
                "Gleaming",
                "Glinting",
                "Greedy",
                "Grieving",
                "Grim",
                "Guard's",
                "Guardian's",
                "Hailstorm",
                "Hateful",
                "Haunted",
                "Heartless",
                "Heinous",
                "Hollow",
                "Holy",
                "Honed",
                "Honor's",
                "Hope's",
                "Hopeless",
                "Howling",
                "Hungering",
                "Improved",
                "Impure",
                "Incarnated",
                "Infused",
                "Inherited",
                "Isolated",
                "Jade Infused",
                "Judgement",
                "Knightly",
                "Legionnaire's",
                "Liar's",
                "Lich",
                "Lightning",
                "Lonely",
                "Loyal",
                "Lustful",
                "Lusting",
                "Mage's",
                "Malevolent",
                "Malicious",
                "Malificent",
                "Malignant",
                "Massive",
                "Mended",
                "Mercenary",
                "Military",
                "Misfortune's",
                "Misty",
                "Moonlit",
                "Mourning",
                "Nightmare",
                "Oathkeeper's",
                "Ominous",
                "Peacekeeper's",
                "Phantom",
                "Polished",
                "Possessed",
                "Pride's",
                "Prideful",
                "Primitive",
                "Promised",
                "Protector's",
                "Proud",
                "Pure",
                "Putrid",
                "Raging",
                "Recruit's",
                "Reforged",
                "Reincarnated",
                "Relentless",
                "Remorseful",
                "Renewed",
                "Renovated",
                "Replica",
                "Restored",
                "Retribution",
                "Ritual",
                "Roaring",
                "Ruby Infused",
                "Rune-Forged",
                "Rusty",
                "Savage",
                "Shadow",
                "Sharpened",
                "Silent",
                "Singed",
                "Singing",
                "Sinister",
                "Smooth",
                "Solitude's",
                "Sorrow's",
                "Soul",
                "Soul Infused",
                "Soul-Forged",
                "Soulcursed",
                "Soulless",
                "Spectral",
                "Spectral-Forged",
                "Spiteful",
                "Storm",
                "Storm-Forged",
                "Stormfury",
                "Stormguard",
                "Terror",
                "Thirsting",
                "Thirsty",
                "Thunder",
                "Thunder-Forged",
                "Thunderfury",
                "Thunderguard",
                "Thundersoul",
                "Thunderstorm",
                "Timeworn",
                "Tormented",
                "Trainee's",
                "Treachery's",
                "Twilight",
                "Twilight's",
                "Twisted",
                "Tyrannical",
                "Undead",
                "Unholy",
                "Vengeance",
                "Vengeful",
                "Venom",
                "Vicious",
                "Vile",
                "Vindication",
                "Vindictive",
                "Void",
                "Volcanic",
                "Vowed",
                "War-Forged",
                "Warlord's",
                "Warp",
                "Warped",
                "Whistling",
                "Wicked",
                "Wind's",
                "Wind-Forged",
                "Windsong",
                "Woeful",
                "Wrathful",
                "Wretched",
                "Yearning",
                "Zealous",
            ]
            var3 = [
                "Adamantite",
                "Bronze",
                "Copper",
                "Diamond",
                "Ebon",
                "Ebonsteel",
                "Ebony",
                "Glass",
                "Gold",
                "Iron",
                "Ironbark",
                "Ivory",
                "Mithril",
                "Obsidian",
                "Onyx",
                "Phantomsteel",
                "Shadowsteel",
                "Silver",
                "Skeletal",
                "Steel",
            ]
            var4 = [
                "Bayonet",
                "Blade",
                "Carver",
                "Dagger",
                "Deflector",
                "Dirk",
                "Doomblade",
                "Ebonblade",
                "Etcher",
                "Fang",
                "Guardian",
                "Knife",
                "Kris",
                "Mageblade",
                "Piercer",
                "Protector",
                "Quickblade",
                "Razor",
                "Reaver",
                "Sabre",
                "Scalpel",
                "Sculptor",
                "Shanker",
                "Shiv",
                "Shortblade",
                "Shortsword",
                "Skewer",
                "Slicer",
                "Spellblade",
                "Stiletto",
                "Swiftblade",
            ]
            var5 = [
                "Annihilation",
                "Bayonet",
                "Betrayer",
                "Blade",
                "Blessed Blade",
                "Blood Blade",
                "Bond",
                "Boon",
                "Breaker",
                "Bringer",
                "Butcher",
                "Call",
                "Carver",
                "Champion",
                "Conqueror",
                "Crusader",
                "Cry",
                "Cunning",
                "Dagger",
                "Dark Blade",
                "Dawn",
                "Defender",
                "Defiler",
                "Deflector",
                "Destroyer",
                "Dirk",
                "Doomblade",
                "Ebonblade",
                "Edge",
                "Ender",
                "Etcher",
                "Executioner",
                "Fang",
                "Favor",
                "Ferocity",
                "Foe",
                "Gift",
                "Glory",
                "Guardian",
                "Heirloom",
                "Hope",
                "Incarnation",
                "Jaws",
                "Knife",
                "Kris",
                "Last Hope",
                "Last Stand",
                "Legacy",
                "Mageblade",
                "Memory",
                "Might",
                "Oath",
                "Pact",
                "Piercer",
                "Pledge",
                "Promise",
                "Protector",
                "Quickblade",
                "Ravager",
                "Razor",
                "Reach",
                "Reaper",
                "Reaver",
                "Runed Blade",
                "Saber",
                "Sabre",
                "Savagery",
                "Scalpel",
                "Sculptor",
                "Secret",
                "Shanker",
                "Shiv",
                "Shortblade",
                "Skewer",
                "Slayer",
                "Slicer",
                "Soul",
                "Spellblade",
                "Spine",
                "Stiletto",
                "Swiftblade",
                "Terror",
                "Token",
                "Tribute",
                "Vengeance",
                "Voice",
                "Warblade",
                "Whisper",
                "Wit",
            ]
            var6 = [
                "of Agony",
                "of Ancient Power",
                "of Anguish",
                "of Ashes",
                "of Assassins",
                "of Black Magic",
                "of Blessed Fortune",
                "of Blessings",
                "of Blight",
                "of Blood",
                "of Bloodlust",
                "of Broken Bones",
                "of Broken Dreams",
                "of Broken Families",
                "of Burdens",
                "of Chaos",
                "of Closing Eyes",
                "of Conquered Worlds",
                "of Corruption",
                "of Cruelty",
                "of Cunning",
                "of Dark Magic",
                "of Dark Souls",
                "of Darkness",
                "of Decay",
                "of Deception",
                "of Degradation",
                "of Delusions",
                "of Denial",
                "of Desecration",
                "of Dilusion",
                "of Dismay",
                "of Dragonsouls",
                "of Due Diligence",
                "of Echoes",
                "of Ended Dreams",
                "of Ending Hope",
                "of Ending Misery",
                "of Eternal Bloodlust",
                "of Eternal Damnation",
                "of Eternal Glory",
                "of Eternal Justice",
                "of Eternal Rest",
                "of Eternal Sorrow",
                "of Eternal Struggles",
                "of Eternity",
                "of Executions",
                "of Faded Memories",
                "of Fallen Souls",
                "of Fools",
                "of Frost",
                "of Frozen Hells",
                "of Fury",
                "of Giants",
                "of Giantslaying",
                "of Grace",
                "of Grieving Widows",
                "of Hate",
                "of Hatred",
                "of Hell's Games",
                "of Hellish Torment",
                "of Heroes",
                "of Holy Might",
                "of Honor",
                "of Hope",
                "of Horrid Dreams",
                "of Horrors",
                "of Illuminated Dreams",
                "of Illumination",
                "of Immortality",
                "of Inception",
                "of Infinite Trials",
                "of Insanity",
                "of Invocation",
                "of Justice",
                "of Light's Hope",
                "of Lost Comrades",
                "of Lost Hope",
                "of Lost Voices",
                "of Lost Worlds",
                "of Magic",
                "of Mercy",
                "of Misery",
                "of Mountains",
                "of Mourning",
                "of Mystery",
                "of Necromancy",
                "of Nightmares",
                "of Oblivion",
                "of Perdition",
                "of Phantoms",
                "of Power",
                "of Pride",
                "of Pride's Fall",
                "of Putrefaction",
                "of Reckoning",
                "of Redemption",
                "of Regret",
                "of Riddles",
                "of Secrecy",
                "of Secrets",
                "of Shadow Strikes",
                "of Shadows",
                "of Shifting Sands",
                "of Shifting Worlds",
                "of Silence",
                "of Slaughter",
                "of Souls",
                "of Stealth",
                "of Storms",
                "of Subtlety",
                "of Suffering",
                "of Suffering's End",
                "of Summoning",
                "of Terror",
                "of Thunder",
                "of Time-Lost Memories",
                "of Timeless Battles",
                "of Titans",
                "of Torment",
                "of Traitors",
                "of Trembling Hands",
                "of Trials",
                "of Truth",
                "of Twilight's End",
                "of Twisted Visions",
                "of Unholy Blight",
                "of Unholy Might",
                "of Vengeance",
                "of Visions",
                "of Wasted Time",
                "of Widows",
                "of Wizardry",
                "of Woe",
                "of Wraiths",
                "of Zeal",
                "of the Ancients",
                "of the Banished",
                "of the Basilisk",
                "of the Beast",
                "of the Blessed",
                "of the Breaking Storm",
                "of the Brotherhood",
                "of the Burning Sun",
                "of the Caged Mind",
                "of the Cataclysm",
                "of the Champion",
                "of the Claw",
                "of the Corrupted",
                "of the Covenant",
                "of the Crown",
                "of the Damned",
                "of the Daywalker",
                "of the Dead",
                "of the Depth",
                "of the Dreadlord",
                "of the Earth",
                "of the East",
                "of the Emperor",
                "of the Empty Void",
                "of the End",
                "of the Enigma",
                "of the Fallen",
                "of the Falling Sky",
                "of the Flame",
                "of the Forest",
                "of the Forgotten",
                "of the Forsaken",
                "of the Gladiator",
                "of the Harvest",
                "of the Immortal",
                "of the Incoming Storm",
                "of the Insane",
                "of the King",
                "of the Lasting Night",
                "of the Leviathan",
                "of the Light",
                "of the Lion",
                "of the Lionheart",
                "of the Lone Victor",
                "of the Lone Wolf",
                "of the Lost",
                "of the Moon",
                "of the Moonwalker",
                "of the Night Sky",
                "of the Night",
                "of the Nightstalker",
                "of the North",
                "of the Occult",
                "of the Oracle",
                "of the Phoenix",
                "of the Plague",
                "of the Prince",
                "of the Protector",
                "of the Queen",
                "of the Serpent",
                "of the Setting Sun",
                "of the Shadows",
                "of the Sky",
                "of the South",
                "of the Stars",
                "of the Storm",
                "of the Summoner",
                "of the Sun",
                "of the Sunwalker",
                "of the Talon",
                "of the Undying",
                "of the Victor",
                "of the Void",
                "of the West",
                "of the Whispers",
                "of the Wicked",
                "of the Wind",
                "of the Wolf",
                "of the World",
                "of the Wretched",
            ]
            var7 = [
                "Tie Breaker",
                "Laceration",
                "Forever",
                "Silver Slicer",
                "Eternity",
                "Goodbye",
                "Aetherius",
                "Agatha",
                "Alpha",
                "Amnesia",
                "Amnesty",
                "Anarchy",
                "Anduril",
                "Anger's Tear",
                "Angerfang",
                "Apocalypse",
                "Armageddon",
                "Ashrune",
                "Backtwister",
                "Barb",
                "Betrayal",
                "Betrayer",
                "Blackfang",
                "Blackout",
                "Blacktalon",
                "Blazefury",
                "Blind Justice",
                "Blindstrike",
                "Blink",
                "Blinkstrike",
                "Blood Weeper",
                "Bloodquench",
                "Bloodsipper",
                "Bloodweep",
                "Bonescraper",
                "Bonespike",
                "Brainpicker",
                "Broken Promise",
                "Brutality",
                "Cataclysm",
                "Catastrophe",
                "Celeste",
                "Chaos",
                "Chisel",
                "Cometfell",
                "Convergence",
                "Crisscross",
                "Crucifix",
                "Darkheart",
                "Darkness",
                "Dawn",
                "Death's Bite",
                "Death's Kiss",
                "Death's Sting",
                "Deathraze",
                "Decimation",
                "Dementia",
                "Desolation",
                "Despair",
                "Devine",
                "Dirge",
                "Dissector",
                "Divinity",
                "Doomblade",
                "Doombringer",
                "Doomspike",
                "Dragonclaw",
                "Dragonfang",
                "Dragontooth",
                "Draughtbane",
                "Due Diligence",
                "Dustbringer",
                "Echo",
                "Eclipse",
                "Edge of Eternity",
                "Edge of Insanity",
                "Edge of Time",
                "Endbringer",
                "Enigma",
                "Epilogue",
                "Eternal Rest",
                "Extinction",
                "Faithkeeper",
                "Fate",
                "Fear",
                "Felstriker",
                "Fleshrender",
                "Fleshshaper",
                "Flicker",
                "Frenzy",
                "Frightalon",
                "Fury",
                "Garotte",
                "Ghost Reaver",
                "Ghost Shard",
                "Ghostwalker",
                "Glimmer",
                "Gutrender",
                "Gutwrencher",
                "Harmony",
                "Hatred's Bite",
                "Heartpierce",
                "Heartrazor",
                "Heartseeker",
                "Heartshiver",
                "Heartstriker",
                "Hell's Scream",
                "Hellfire",
                "Honor's Call",
                "Hope's End",
                "Hysteria",
                "Icefall",
                "Incision",
                "Infamy",
                "Infinity",
                "Insanity",
                "Interrogator",
                "Ivory",
                "Justice",
                "Kingsbane",
                "Kingsfall",
                "Kinslayer",
                "Knight's Fall",
                "Knightfall",
                "Lament",
                "Last Rites",
                "Last Words",
                "Lazarus",
                "Lifedrinker",
                "Lightbane",
                "Lightning",
                "Limbo",
                "Lobotomizer",
                "Lynch",
                "Maelstrom",
                "Malice",
                "Mangler",
                "Massacre",
                "Mercy",
                "Meteor",
                "Midnight",
                "Moonlight",
                "Mournblade",
                "Murder",
                "Mutilator",
                "Nail",
                "Narcoleptic",
                "Needle",
                "Nemesis",
                "Nethersbane",
                "Night's Edge",
                "Night's Fall",
                "Nightbane",
                "Nightbite",
                "Nightcrackle",
                "Nightfall",
                "Nightkiss",
                "Nimble",
                "Nirvana",
                "Oathbreaker",
                "Oathkeeper",
                "Oblivion",
                "Omega",
                "Omen",
                "Peacekeeper",
                "Persuasion",
                "Phantom",
                "Phantom Shard",
                "Phantomstrike",
                "Phobia",
                "Piece Maker",
                "Prick",
                "Purify",
                "Quicksilver",
                "Rage",
                "Ragespike",
                "Reaper",
                "Reckoning",
                "Remorse",
                "Requiem",
                "Riddle",
                "Rigormortis",
                "Sacrifice",
                "Sanguine",
                "Savagery",
                "Scalpel",
                "Scar",
                "Scarlet",
                "Seethe",
                "Severance",
                "Shadow Strike",
                "Shadowbite",
                "Shadowfall",
                "Shadowkiss",
                "Shadowrazor",
                "Shadowshiver",
                "Shadowsong",
                "Silence",
                "Silencer",
                "Silver Saber",
                "Silverlight",
                "Siphon",
                "Slander",
                "Slice of Life",
                "Solarflare",
                "Spiderfang",
                "Spike",
                "Spineripper",
                "Spiritsever",
                "Spiteblade",
                "Stalker",
                "Starlight",
                "Starshard",
                "Stickler",
                "Sting",
                "Stinger",
                "Storm",
                "Stormbringer",
                "Stormcaller",
                "Stormtip",
                "Striker",
                "Sun Strike",
                "Sunflare",
                "Sunshard",
                "Suspension",
                "Swan Song",
                "Teaser",
                "The Black Blade",
                "The End",
                "The Facelifter",
                "The Sleeper",
                "The Taker",
                "The Undertaker",
                "The Stake",
                "The Unmaker",
                "The Void",
                "Thorn",
                "Thunder",
                "Timeslicer",
                "Toothpick",
                "Torment",
                "Treachery",
                "Trickster",
                "Trinity",
                "Twilight",
                "Twinkle",
                "Twister",
                "Twitch",
                "Tyrhung",
                "Valkyrie",
                "Vengeance",
                "Venom",
                "Venombite",
                "Venomkiss",
                "Venomshank",
                "Venomtip",
                "Warmonger",
                "Widow Maker",
                "Widowkiller",
                "Widowmaker",
                "Winterthorn",
            ]
        elif classification == Weapon.WeaponType.Hammer:
            var1 = [
                "Abomination",
                "Agatha",
                "Agony",
                "Allegiance",
                "Alpha",
                "Amnesia",
                "Anduril",
                "Apocalypse",
                "Armageddon",
                "Arondite",
                "Ash",
                "Ashes",
                "Ashrune",
                "Back Breaker",
                "Battlestar",
                "Betrayal",
                "Betrayer",
                "Blackout",
                "Blazeguard",
                "Blessing",
                "Blind Justice",
                "Bloodfury",
                "Bloodmoon",
                "Bloodquench",
                "Bloodrage",
                "Bloodspiller",
                "Bloodweep",
                "Bone Warden",
                "Bonesnapper",
                "Braindead",
                "Broken Promise",
                "Brutality",
                "Brutalizer",
                "Cataclysm",
                "Catastrophe",
                "Celeste",
                "Chance",
                "Chaos",
                "Chasm",
                "Chieftain",
                "Comet",
                "Cometfall",
                "Concussion",
                "Convergence",
                "Corpsemaker",
                "Corruption",
                "Cosmos",
                "Crash",
                "Crimson",
                "Crush",
                "Cryptmaker",
                "Cyclone",
                "Darkness",
                "Dawn",
                "Dawnbreaker",
                "Daytime",
                "Deathbringer",
                "Deathraze",
                "Decimation",
                "Demise",
                "Desolation",
                "Despair",
                "Destiny",
                "Destruction",
                "Devastation",
                "Devine",
                "Devotion",
                "Devourer",
                "Disturbance",
                "Divine Light",
                "Dominance",
                "Dominion",
                "Doom",
                "Doombringer",
                "Dragonfist",
                "Dragonmaw",
                "Dragonstrike",
                "Due Diligence",
                "Early Retirement",
                "Earthquake",
                "Earthshaker",
                "Earthshaper",
                "Earthwarden",
                "Echo",
                "Eclipse",
                "Emergency",
                "End of Dreams",
                "Endbringer",
                "Enigma",
                "Epilogue",
                "Eternal Rest",
                "Eternity",
                "Eveningstar",
                "Extermination",
                "Extinction",
                "Faithkeeper",
                "Falcon",
                "Falling Star",
                "Fate",
                "Finality",
                "Frenzy",
                "Frostwind",
                "Fury",
                "Fury's Gaze",
                "Galaxy",
                "Gatecrasher",
                "Ghost Reaver",
                "Ghostwalker",
                "Glimmer",
                "Godslayer",
                "Grace",
                "Guiding Star",
                "Harbinger",
                "Harmony",
                "Harvester",
                "Hatred",
                "Heartcrusher",
                "Hell's Scream",
                "Hellfire",
                "Homage",
                "Honor's Call",
                "Hope's End",
                "Humongous",
                "Hurricane",
                "Icebreaker",
                "Infamy",
                "Infinity",
                "Interrogator",
                "Jackhammer",
                "Jawbone",
                "Justice",
                "Justifier",
                "King's Defender",
                "King's Legacy",
                "Kinslayer",
                "Knight's Fall",
                "Knight's Honor",
                "Knightfall",
                "Lament",
                "Last Chance",
                "Last Laugh",
                "Last Rites",
                "Last Word",
                "Last Words",
                "Lazarus",
                "Legacy",
                "Legionaire",
                "Life's Limit",
                "Light's Bane",
                "Lightbane",
                "Lightbringer",
                "Lightning",
                "Limbo",
                "Lockjaw",
                "Magma",
                "Malice",
                "Maneater",
                "Massacre",
                "Mercy",
                "Midnight",
                "Misery's End",
                "Monsoon",
                "Morningstar",
                "Narcoleptic",
                "Nethersbane",
                "Night's Fall",
                "Nightbane",
                "Nightfall",
                "Nightglow",
                "Nightmare",
                "Nighttime",
                "Nirvana",
                "Oathbreaker",
                "Oathkeeper",
                "Oblivion",
                "Old Age",
                "Omega",
                "Orbit",
                "Orenmir",
                "Oxheart",
                "Party Pooper",
                "Patience",
                "Peacekeeper",
                "Peacemaker",
                "Pendulum",
                "Perfect Storm",
                "Persuasion",
                "Piece Maker",
                "Piety",
                "Pride",
                "Prophecy",
                "Punisher",
                "Purifier",
                "Rage",
                "Ragnarok",
                "Rapture",
                "Reaper's Toll",
                "Reckoning",
                "Red Dwarf",
                "Reign",
                "Remorse",
                "Requiem",
                "Retirement",
                "Righteous Might",
                "Rigormortis",
                "Rising Tide",
                "Savagery",
                "Scar",
                "Scourgeborne",
                "Second Chance",
                "Seism",
                "Seismic",
                "Serenity",
                "Severance",
                "Shadowfury",
                "Shadowmoon",
                "Shatterskull",
                "Shooting Star",
                "Silence",
                "Skullcrusher",
                "Soul Breaker",
                "Spinefall",
                "Stalker",
                "Stonefist",
                "Storm",
                "Storm Breaker",
                "Storm-Weaver",
                "Stormbringer",
                "Stormcaller",
                "Stormedge",
                "Stormherald",
                "Stormrider",
                "Sucker Punch",
                "Sundown",
                "Supernova",
                "Supremacy",
                "Suspension",
                "Swan Song",
                "Tank",
                "Tenderiser",
                "Termination",
                "The Ambassador",
                "The Chancellor",
                "The Chief",
                "The End",
                "The Light",
                "The Minotaur",
                "The Oculus",
                "The Oracle",
                "The Sundering",
                "The Void",
                "The Warden",
                "Thunder",
                "Trauma",
                "Treachery",
                "Tremor",
                "Trinity",
                "Twilight",
                "Typhoon",
                "Ubiquity",
                "Undoing",
                "Vacancy",
                "Valkyrie",
                "Vanquisher",
                "Vengeance",
                "Warbringer",
                "Warmonger",
                "Whirlwind",
                "Wicked",
                "Widow Maker",
                "Willbreaker",
                "Winter's Bite",
                "Wit's End",
                "Witherbrand",
                "Wolf",
                "Worldbreaker",
                "Worldcarver",
                "Worldslayer",
            ]
            var2 = [
                "Ancient",
                "Antique",
                "Apocalypse",
                "Apocalyptic",
                "Arcane",
                "Arched",
                "Atuned",
                "Bandit's",
                "Baneful",
                "Banished",
                "Barbarian",
                "Barbaric",
                "Battleworn",
                "Blazefury",
                "Blood Infused",
                "Blood-Forged",
                "Bloodcursed",
                "Bloodied",
                "Bloodlord's",
                "Bloodsurge",
                "Bloodvenom",
                "Bonecarvin",
                "Brutal",
                "Brutality",
                "Burnished",
                "Cataclysm",
                "Cataclysmic",
                "Challenger",
                "Challenger's",
                "Champion",
                "Champion's",
                "Cold-Forged",
                "Conqueror",
                "Conqueror's",
                "Corroded",
                "Corrupted",
                "Crazed",
                "Crying",
                "Cursed",
                "Curved",
                "Dancing",
                "Dark",
                "Darkness",
                "Defender",
                "Defender's",
                "Defiled",
                "Defiling",
                "Deluded",
                "Demonic",
                "Deserted",
                "Desire's",
                "Desolation",
                "Destiny's",
                "Diabolical",
                "Dire",
                "Doom",
                "Doom's",
                "Dragon's",
                "Dragonbreath",
                "Eerie",
                "Enchanted",
                "Engraved",
                "Enlightened",
                "Eternal",
                "Exiled",
                "Extinction",
                "Faith's",
                "Faithful",
                "Fancy",
                "Fearful",
                "Feral",
                "Ferocious",
                "Fierce",
                "Fiery",
                "Fire Infused",
                "Fireguard",
                "Firesoul",
                "Firestorm",
                "Flaming",
                "Flimsy",
                "Forsaken",
                "Fortune's",
                "Foul",
                "Fragile",
                "Frail",
                "Frenzied",
                "Frost",
                "Frozen",
                "Furious",
                "Fusion",
                "Ghastly",
                "Ghost",
                "Ghost-Forged",
                "Ghostly",
                "Gladiator",
                "Gladiator's",
                "Gleaming",
                "Glinting",
                "Greedy",
                "Grieving",
                "Grim",
                "Guard's",
                "Guardian's",
                "Hailstorm",
                "Harmonized",
                "Hateful",
                "Haunted",
                "Heartless",
                "Heinous",
                "Hero",
                "Hero's",
                "Hollow",
                "Holy",
                "Honed",
                "Honor's",
                "Hope's",
                "Hopeless",
                "Howling",
                "Hungering",
                "Improved",
                "Impure",
                "Incarnated",
                "Infused",
                "Inherited",
                "Isolated",
                "Jade Infused",
                "Judgement",
                "Keeper's",
                "Knightly",
                "Knight's",
                "Legionnaire's",
                "Liar's",
                "Lich",
                "Lightning",
                "Lonely",
                "Loyal",
                "Lustful",
                "Lusting",
                "Malevolent",
                "Malicious",
                "Malificent",
                "Malignant",
                "Massive",
                "Mended",
                "Mercenary",
                "Military",
                "Misfortune's",
                "Misty",
                "Moonlit",
                "Mourning",
                "Nightmare",
                "Oathkeeper's",
                "Ominous",
                "Peacekeeper",
                "Peacekeeper's",
                "Phantom",
                "Polished",
                "Possessed",
                "Pride's",
                "Prideful",
                "Primal",
                "Prime",
                "Primitive",
                "Promised",
                "Protector's",
                "Proud",
                "Pure",
                "Putrid",
                "Raging",
                "Recruit's",
                "Refined",
                "Reforged",
                "Reincarnated",
                "Relentless",
                "Remorseful",
                "Renewed",
                "Renovated",
                "Replica",
                "Restored",
                "Retribution",
                "Ritual",
                "Roaring",
                "Ruby Infused",
                "Rune-Forged",
                "Runed",
                "Rusty",
                "Savage",
                "Sentinel",
                "Shadow",
                "Shamanic",
                "Sharpened",
                "Silent",
                "Singed",
                "Singing",
                "Sinister",
                "Skyfall",
                "Smooth",
                "Soldier's",
                "Solitude's",
                "Sorcerer's",
                "Sorrow's",
                "Soul",
                "Soul Infused",
                "Soul-Forged",
                "Soulcursed",
                "Soulless",
                "Spectral",
                "Spectral-Forged",
                "Spiteful",
                "Storm",
                "Storm-Forged",
                "Stormfury",
                "Stormguard",
                "Terror",
                "Thirsting",
                "Thirsty",
                "Thunder",
                "Thunder-Forged",
                "Thunderfury",
                "Thunderguard",
                "Thundersoul",
                "Thunderstorm",
                "Timeworn",
                "Tormented",
                "Trainee's",
                "Treachery's",
                "Twilight",
                "Twilight's",
                "Twisted",
                "Tyrannical",
                "Undead",
                "Unholy",
                "Vanquisher",
                "Vengeance",
                "Vengeful",
                "Venom",
                "Vicious",
                "Victor",
                "Vile",
                "Vindication",
                "Vindicator",
                "Vindictive",
                "Void",
                "Volcanic",
                "Vowed",
                "War",
                "War-Forged",
                "Warden's",
                "Warlord's",
                "Warp",
                "Warped",
                "Warrior",
                "Warrior's",
                "Whistling",
                "Wicked",
                "Wind's",
                "Wind-Forged",
                "Windsong",
                "Woeful",
                "Wrathful",
                "Wretched",
                "Yearning",
                "Zealous",
            ]
            var3 = [
                "Adamantite",
                "Bone",
                "Bronze",
                "Bronzed",
                "Ivory",
                "Ebon",
                "Glass",
                "Golden",
                "Iron",
                "Ironbark",
                "Mithril",
                "Obsidian",
                "Silver",
                "Skeletal",
                "Steel",
                "Titanium",
            ]
            var4 = [
                "Mace",
                "Bludgeon",
                "Maul",
                "Hammer",
                "Mallet",
                "Crusher",
                "Battlehammer",
                "Greathammer",
                "Smasher",
                "Warmace",
                "Hammer",
                "Mace",
                "Scepter",
                "Pummeler",
            ]
            var5 = [
                "Allegiance",
                "Annihilation",
                "Battlehammer",
                "Betrayer",
                "Bludgeon",
                "Bond",
                "Boon",
                "Breaker",
                "Bringer",
                "Bruiser",
                "Butcher",
                "Call",
                "Champion",
                "Conqueror",
                "Crusader",
                "Crusher",
                "Cry",
                "Cunning",
                "Dawn",
                "Defender",
                "Defiler",
                "Destroyer",
                "Disposer",
                "Ender",
                "Executioner",
                "Favor",
                "Ferocity",
                "Foe",
                "Gift",
                "Glory",
                "Greathammer",
                "Guardian",
                "Hammer",
                "Heirloom",
                "Hope",
                "Incarnation",
                "Jaws",
                "Last Hope",
                "Last Stand",
                "Legacy",
                "Mace",
                "Mallet",
                "Masher",
                "Maul",
                "Memory",
                "Might",
                "Oath",
                "Pact",
                "Pledge",
                "Pounder",
                "Promise",
                "Prophecy",
                "Protector",
                "Pummeler",
                "Queller",
                "Ravager",
                "Reach",
                "Reaper",
                "Scepter",
                "Sculptor",
                "Secret",
                "Slayer",
                "Smasher",
                "Soul",
                "Suppressor",
                "Terror",
                "Token",
                "Tribute",
                "Vengeance",
                "Voice",
                "Warmace",
                "Whisper",
                "Wit",
            ]
            var6 = [
                "of Agony",
                "of Ancient Power",
                "of Anguish",
                "of Ashes",
                "of Assassins",
                "of Black Magic",
                "of Blessed Fortune",
                "of Blessings",
                "of Blight",
                "of Blood",
                "of Bloodlust",
                "of Broken Bones",
                "of Broken Dreams",
                "of Broken Families",
                "of Burdens",
                "of Chaos",
                "of Closing Eyes",
                "of Conquered Worlds",
                "of Corruption",
                "of Cruelty",
                "of Cunning",
                "of Dark Magic",
                "of Dark Souls",
                "of Darkness",
                "of Decay",
                "of Deception",
                "of Degradation",
                "of Delusions",
                "of Denial",
                "of Desecration",
                "of Diligence",
                "of Dismay",
                "of Dragonsouls",
                "of Due Diligence",
                "of Echoes",
                "of Ended Dreams",
                "of Ending Hope",
                "of Ending Misery",
                "of Eternal Bloodlust",
                "of Eternal Damnation",
                "of Eternal Glory",
                "of Eternal Justice",
                "of Eternal Rest",
                "of Eternal Sorrow",
                "of Eternal Struggles",
                "of Eternity",
                "of Executions",
                "of Faded Memories",
                "of Fallen Souls",
                "of Fools",
                "of Frost",
                "of Frozen Hells",
                "of Fury",
                "of Giants",
                "of Giantslaying",
                "of Grace",
                "of Grieving Widows",
                "of Hate",
                "of Hatred",
                "of Hell's Games",
                "of Hellish Torment",
                "of Heroes",
                "of Holy Might",
                "of Honor",
                "of Hope",
                "of Horrid Dreams",
                "of Horrors",
                "of Illuminated Dreams",
                "of Illumination",
                "of Immortality",
                "of Inception",
                "of Infinite Trials",
                "of Insanity",
                "of Invocation",
                "of Justice",
                "of Light's Hope",
                "of Lost Comrades",
                "of Lost Hope",
                "of Lost Voices",
                "of Lost Worlds",
                "of Magic",
                "of Mercy",
                "of Misery",
                "of Mountains",
                "of Mourning",
                "of Mystery",
                "of Necromancy",
                "of Nightmares",
                "of Oblivion",
                "of Perdition",
                "of Phantoms",
                "of Power",
                "of Pride",
                "of Pride's Fall",
                "of Putrefaction",
                "of Reckoning",
                "of Redemption",
                "of Regret",
                "of Riddles",
                "of Secrecy",
                "of Secrets",
                "of Shadow Strikes",
                "of Shadows",
                "of Shifting Sands",
                "of Shifting Worlds",
                "of Silence",
                "of Slaughter",
                "of Souls",
                "of Stealth",
                "of Storms",
                "of Subtlety",
                "of Suffering",
                "of Suffering's End",
                "of Summoning",
                "of Terror",
                "of Thunder",
                "of Time-Lost Memories",
                "of Timeless Battles",
                "of Titans",
                "of Torment",
                "of Traitors",
                "of Trembling Hands",
                "of Trials",
                "of Truth",
                "of Twilight's End",
                "of Twisted Visions",
                "of Unholy Blight",
                "of Unholy Might",
                "of Vengeance",
                "of Visions",
                "of Wasted Time",
                "of Widows",
                "of Wizardry",
                "of Woe",
                "of Wraiths",
                "of Zeal",
                "of the Ancients",
                "of the Banished",
                "of the Basilisk",
                "of the Beast",
                "of the Blessed",
                "of the Breaking Storm",
                "of the Brotherhood",
                "of the Burning Sun",
                "of the Caged Mind",
                "of the Cataclysm",
                "of the Champion",
                "of the Claw",
                "of the Corrupted",
                "of the Covenant",
                "of the Crown",
                "of the Damned",
                "of the Daywalker",
                "of the Dead",
                "of the Depth",
                "of the Dreadlord",
                "of the Earth",
                "of the East",
                "of the Emperor",
                "of the Empty Void",
                "of the End",
                "of the Enigma",
                "of the Fallen",
                "of the Falling Sky",
                "of the Flame",
                "of the Forest",
                "of the Forgotten",
                "of the Forsaken",
                "of the Gladiator",
                "of the Harvest",
                "of the Immortal",
                "of the Incoming Storm",
                "of the Insane",
                "of the King",
                "of the Lasting Night",
                "of the Leviathan",
                "of the Light",
                "of the Lion",
                "of the Lionheart",
                "of the Lone Victor",
                "of the Lone Wolf",
                "of the Lost",
                "of the Moon",
                "of the Moonwalker",
                "of the Night Sky",
                "of the Night",
                "of the Nightstalker",
                "of the North",
                "of the Occult",
                "of the Oracle",
                "of the Phoenix",
                "of the Plague",
                "of the Prince",
                "of the Protector",
                "of the Queen",
                "of the Serpent",
                "of the Setting Sun",
                "of the Shadows",
                "of the Sky",
                "of the South",
                "of the Stars",
                "of the Storm",
                "of the Summoner",
                "of the Sun",
                "of the Sunwalker",
                "of the Talon",
                "of the Undying",
                "of the Victor",
                "of the Void",
                "of the West",
                "of the Whispers",
                "of the Wicked",
                "of the Wind",
                "of the Wolf",
                "of the World",
                "of the Wretched",
            ]
            var7 = [
                "Abomination",
                "Agatha",
                "Agony",
                "Allegiance",
                "Alpha",
                "Amnesia",
                "Anduril",
                "Apocalypse",
                "Armageddon",
                "Arondite",
                "Ash",
                "Ashes",
                "Ashrune",
                "Back Breaker",
                "Battlestar",
                "Betrayal",
                "Betrayer",
                "Blackout",
                "Blazeguard",
                "Blessing",
                "Blind Justice",
                "Bloodfury",
                "Bloodmoon",
                "Bloodquench",
                "Bloodrage",
                "Bloodspiller",
                "Bloodweep",
                "Bone Warden",
                "Bonesnapper",
                "Braindead",
                "Broken Promise",
                "Brutality",
                "Brutalizer",
                "Cataclysm",
                "Catastrophe",
                "Celeste",
                "Chance",
                "Chaos",
                "Chasm",
                "Chieftain",
                "Comet",
                "Cometfall",
                "Concussion",
                "Convergence",
                "Corpsemaker",
                "Corruption",
                "Cosmos",
                "Crash",
                "Crimson",
                "Crush",
                "Cryptmaker",
                "Cyclone",
                "Darkness",
                "Dawn",
                "Dawnbreaker",
                "Daytime",
                "Deathbringer",
                "Deathraze",
                "Decimation",
                "Demise",
                "Desolation",
                "Despair",
                "Destiny",
                "Destruction",
                "Devastation",
                "Devine",
                "Devotion",
                "Devourer",
                "Disturbance",
                "Divine Light",
                "Dominance",
                "Dominion",
                "Doom",
                "Doombringer",
                "Dragonfist",
                "Dragonmaw",
                "Dragonstrike",
                "Due Diligence",
                "Earthquake",
                "Earthshaker",
                "Earthshaper",
                "Earthwarden",
                "Echo",
                "Eclipse",
                "Emergency",
                "End of Dreams",
                "Endbringer",
                "Enigma",
                "Epilogue",
                "Eternal Rest",
                "Eternity",
                "Eveningstar",
                "Extermination",
                "Extinction",
                "Faithkeeper",
                "Falcon",
                "Falling Star",
                "Fate",
                "Finality",
                "Frenzy",
                "Frostwind",
                "Fury",
                "Fury's Gaze",
                "Galaxy",
                "Gatecrasher",
                "Ghost Reaver",
                "Ghostwalker",
                "Glimmer",
                "Godslayer",
                "Grace",
                "Guiding Star",
                "Harbinger",
                "Harmony",
                "Harvester",
                "Hatred",
                "Heartcrusher",
                "Hell's Scream",
                "Hellfire",
                "Homage",
                "Honor's Call",
                "Hope's End",
                "Humongous",
                "Hurricane",
                "Icebreaker",
                "Infamy",
                "Infinity",
                "Interrogator",
                "Jackhammer",
                "Jawbone",
                "Justice",
                "Justifier",
                "King's Defender",
                "King's Legacy",
                "Kinslayer",
                "Knight's Fall",
                "Knight's Honor",
                "Knightfall",
                "Lament",
                "Last Chance",
                "Last Laugh",
                "Last Rites",
                "Last Word",
                "Last Words",
                "Lazarus",
                "Legacy",
                "Legionaire",
                "Life's Limit",
                "Light's Bane",
                "Lightbane",
                "Lightbringer",
                "Lightning",
                "Limbo",
                "Lockjaw",
                "Magma",
                "Malice",
                "Maneater",
                "Massacre",
                "Mercy",
                "Midnight",
                "Misery's End",
                "Monsoon",
                "Morningstar",
                "Narcoleptic",
                "Nethersbane",
                "Night's Fall",
                "Nightbane",
                "Nightfall",
                "Nightglow",
                "Nightmare",
                "Nighttime",
                "Nirvana",
                "Oathbreaker",
                "Oathkeeper",
                "Oblivion",
                "Old Age",
                "Omega",
                "Orbit",
                "Orenmir",
                "Oxheart",
                "Party Pooper",
                "Patience",
                "Peacekeeper",
                "Peacemaker",
                "Pendulum",
                "Perfect Storm",
                "Persuasion",
                "Piety",
                "Pride",
                "Prophecy",
                "Punisher",
                "Purifier",
                "Rage",
                "Ragnarok",
                "Rapture",
                "Reckoning",
                "Red Dwarf",
                "Reign",
                "Remorse",
                "Requiem",
                "Retirement",
                "Rigormortis",
                "Rising Tide",
                "Savagery",
                "Seism",
                "Seismic",
                "Serenity",
                "Severance",
                "Shadowfury",
                "Shatterskull",
                "Shooting Star",
                "Silence",
                "Skullcrusher",
                "Soul Breaker",
                "Spinefall",
                "Stalker",
                "Stonefist",
                "Storm",
                "Storm Breaker",
                "Storm-Weaver",
                "Stormbringer",
                "Stormcaller",
                "Stormedge",
                "Stormherald",
                "Stormrider",
                "Sucker Punch",
                "Sundown",
                "Supernova",
                "Supremacy",
                "Suspension",
                "Swan Song",
                "Tank",
                "Tenderiser",
                "Termination",
                "The Ambassador",
                "The Chancellor",
                "The Chief",
                "The End",
                "The Light",
                "The Minotaur",
                "The Oculus",
                "The Oracle",
                "The Sundering",
                "The Void",
                "The Warden",
                "Thunder",
                "Trauma",
                "Treachery",
                "Tremor",
                "Trinity",
                "Twilight",
                "Typhoon",
                "Ubiquity",
                "Undoing",
                "Vacancy",
                "Valkyrie",
                "Vanquisher",
                "Vengeance",
                "Warbringer",
                "Warmonger",
                "Whirlwind",
                "Wicked",
                "Widow Maker",
                "Willbreaker",
                "Winter's Bite",
                "Wit's End",
                "Witherbrand",
                "Wolf",
                "Worldbreaker",
                "Worldcarver",
                "Worldslayer",
            ]
        elif classification == Weapon.WeaponType.Mace:
            var1 = [
                "Morning Glory",
                "Morning Star",
                "Mourning Star",
                "Blackjack",
                "Tresher",
                "Good Morning",
                "Headache",
                "Migraine",
                "Grimace",
                "Macerator",
                "Abomination",
                "Agatha",
                "Agony",
                "Allegiance",
                "Alpha",
                "Amnesia",
                "Anduril",
                "Apocalypse",
                "Armageddon",
                "Arondite",
                "Ash",
                "Ashes",
                "Ashrune",
                "Back Breaker",
                "Battlestar",
                "Betrayal",
                "Betrayer",
                "Blackout",
                "Blazeguard",
                "Blessing",
                "Blind Justice",
                "Bloodfury",
                "Bloodmoon",
                "Bloodquench",
                "Bloodrage",
                "Bloodspiller",
                "Bloodweep",
                "Bone Warden",
                "Bonesnapper",
                "Braindead",
                "Broken Promise",
                "Brutality",
                "Brutalizer",
                "Cataclysm",
                "Catastrophe",
                "Celeste",
                "Chance",
                "Chaos",
                "Chasm",
                "Chieftain",
                "Comet",
                "Cometfall",
                "Concussion",
                "Convergence",
                "Corpsemaker",
                "Corruption",
                "Cosmos",
                "Crash",
                "Crimson",
                "Crush",
                "Cryptmaker",
                "Cyclone",
                "Darkness",
                "Dawn",
                "Dawnbreaker",
                "Daytime",
                "Deathbringer",
                "Deathraze",
                "Decimation",
                "Demise",
                "Desolation",
                "Despair",
                "Destiny",
                "Destruction",
                "Devastation",
                "Devine",
                "Devotion",
                "Devourer",
                "Disturbance",
                "Divine Light",
                "Dominance",
                "Dominion",
                "Doom",
                "Doombringer",
                "Dragonfist",
                "Dragonmaw",
                "Dragonstrike",
                "Due Diligence",
                "Early Retirement",
                "Earthquake",
                "Earthshaker",
                "Earthshaper",
                "Earthwarden",
                "Echo",
                "Eclipse",
                "Emergency",
                "End of Dreams",
                "Endbringer",
                "Enigma",
                "Epilogue",
                "Eternal Rest",
                "Eternity",
                "Eveningstar",
                "Extermination",
                "Extinction",
                "Faithkeeper",
                "Falcon",
                "Falling Star",
                "Fate",
                "Finality",
                "Frenzy",
                "Frostwind",
                "Fury",
                "Fury's Gaze",
                "Galaxy",
                "Gatecrasher",
                "Ghost Reaver",
                "Ghostwalker",
                "Glimmer",
                "Godslayer",
                "Grace",
                "Guiding Star",
                "Harbinger",
                "Harmony",
                "Harvester",
                "Hatred",
                "Heartcrusher",
                "Hell's Scream",
                "Hellfire",
                "Homage",
                "Honor's Call",
                "Hope's End",
                "Humongous",
                "Hurricane",
                "Icebreaker",
                "Infamy",
                "Infinity",
                "Interrogator",
                "Jackhammer",
                "Jawbone",
                "Justice",
                "Justifier",
                "King's Defender",
                "King's Legacy",
                "Kinslayer",
                "Knight's Fall",
                "Knight's Honor",
                "Knightfall",
                "Lament",
                "Last Chance",
                "Last Laugh",
                "Last Rites",
                "Last Word",
                "Last Words",
                "Lazarus",
                "Legacy",
                "Legionaire",
                "Life's Limit",
                "Light's Bane",
                "Lightbane",
                "Lightbringer",
                "Lightning",
                "Limbo",
                "Lockjaw",
                "Magma",
                "Malice",
                "Maneater",
                "Massacre",
                "Mercy",
                "Midnight",
                "Misery's End",
                "Monsoon",
                "Morningstar",
                "Narcoleptic",
                "Nethersbane",
                "Night's Fall",
                "Nightbane",
                "Nightfall",
                "Nightglow",
                "Nightmare",
                "Nighttime",
                "Nirvana",
                "Oathbreaker",
                "Oathkeeper",
                "Oblivion",
                "Old Age",
                "Omega",
                "Orbit",
                "Orenmir",
                "Oxheart",
                "Party Pooper",
                "Patience",
                "Peacekeeper",
                "Peacemaker",
                "Pendulum",
                "Perfect Storm",
                "Persuasion",
                "Piece Maker",
                "Piety",
                "Pride",
                "Prophecy",
                "Punisher",
                "Purifier",
                "Rage",
                "Ragnarok",
                "Rapture",
                "Reaper's Toll",
                "Reckoning",
                "Red Dwarf",
                "Reign",
                "Remorse",
                "Requiem",
                "Retirement",
                "Righteous Might",
                "Rigormortis",
                "Rising Tide",
                "Savagery",
                "Scar",
                "Scourgeborne",
                "Second Chance",
                "Seism",
                "Seismic",
                "Serenity",
                "Severance",
                "Shadowfury",
                "Shadowmoon",
                "Shatterskull",
                "Shooting Star",
                "Silence",
                "Skullcrusher",
                "Soul Breaker",
                "Spinefall",
                "Stalker",
                "Stonefist",
                "Storm",
                "Storm Breaker",
                "Storm-Weaver",
                "Stormbringer",
                "Stormcaller",
                "Stormedge",
                "Stormherald",
                "Stormrider",
                "Sucker Punch",
                "Sundown",
                "Supernova",
                "Supremacy",
                "Suspension",
                "Swan Song",
                "Tank",
                "Tenderiser",
                "Termination",
                "The Ambassador",
                "The Chancellor",
                "The Chief",
                "The End",
                "The Light",
                "The Minotaur",
                "The Oculus",
                "The Oracle",
                "The Sundering",
                "The Void",
                "The Warden",
                "Thunder",
                "Trauma",
                "Treachery",
                "Tremor",
                "Trinity",
                "Twilight",
                "Typhoon",
                "Ubiquity",
                "Undoing",
                "Vacancy",
                "Valkyrie",
                "Vanquisher",
                "Vengeance",
                "Warbringer",
                "Warmonger",
                "Whirlwind",
                "Wicked",
                "Widow Maker",
                "Willbreaker",
                "Winter's Bite",
                "Wit's End",
                "Witherbrand",
                "Wolf",
                "Worldbreaker",
                "Worldcarver",
                "Worldslayer",
            ]
            var2 = [
                "Ancient",
                "Antique",
                "Apocalypse",
                "Apocalyptic",
                "Arcane",
                "Arched",
                "Atuned",
                "Bandit's",
                "Baneful",
                "Banished",
                "Barbarian",
                "Barbaric",
                "Battleworn",
                "Blazefury",
                "Blood Infused",
                "Blood-Forged",
                "Bloodcursed",
                "Bloodied",
                "Bloodlord's",
                "Bloodsurge",
                "Bloodvenom",
                "Bonecarvin",
                "Brutal",
                "Brutality",
                "Burnished",
                "Cataclysm",
                "Cataclysmic",
                "Challenger",
                "Challenger's",
                "Champion",
                "Champion's",
                "Cold-Forged",
                "Conqueror",
                "Conqueror's",
                "Corroded",
                "Corrupted",
                "Crazed",
                "Crying",
                "Cursed",
                "Curved",
                "Dancing",
                "Dark",
                "Darkness",
                "Defender",
                "Defender's",
                "Defiled",
                "Defiling",
                "Deluded",
                "Demonic",
                "Deserted",
                "Desire's",
                "Desolation",
                "Destiny's",
                "Diabolical",
                "Dire",
                "Doom",
                "Doom's",
                "Dragon's",
                "Dragonbreath",
                "Eerie",
                "Enchanted",
                "Engraved",
                "Enlightened",
                "Eternal",
                "Exiled",
                "Extinction",
                "Faith's",
                "Faithful",
                "Fancy",
                "Fearful",
                "Feral",
                "Ferocious",
                "Fierce",
                "Fiery",
                "Fire Infused",
                "Fireguard",
                "Firesoul",
                "Firestorm",
                "Flaming",
                "Flimsy",
                "Forsaken",
                "Fortune's",
                "Foul",
                "Fragile",
                "Frail",
                "Frenzied",
                "Frost",
                "Frozen",
                "Furious",
                "Fusion",
                "Ghastly",
                "Ghost",
                "Ghost-Forged",
                "Ghostly",
                "Gladiator",
                "Gladiator's",
                "Gleaming",
                "Glinting",
                "Greedy",
                "Grieving",
                "Grim",
                "Guard's",
                "Guardian's",
                "Hailstorm",
                "Harmonized",
                "Hateful",
                "Haunted",
                "Heartless",
                "Heinous",
                "Hero",
                "Hero's",
                "Hollow",
                "Holy",
                "Honed",
                "Honor's",
                "Hope's",
                "Hopeless",
                "Howling",
                "Hungering",
                "Improved",
                "Impure",
                "Incarnated",
                "Infused",
                "Inherited",
                "Isolated",
                "Jade Infused",
                "Judgement",
                "Keeper's",
                "Knightly",
                "Knight's",
                "Legionnaire's",
                "Liar's",
                "Lich",
                "Lightning",
                "Lonely",
                "Loyal",
                "Lustful",
                "Lusting",
                "Malevolent",
                "Malicious",
                "Malificent",
                "Malignant",
                "Massive",
                "Mended",
                "Mercenary",
                "Military",
                "Misfortune's",
                "Misty",
                "Moonlit",
                "Mourning",
                "Nightmare",
                "Oathkeeper's",
                "Ominous",
                "Peacekeeper",
                "Peacekeeper's",
                "Phantom",
                "Polished",
                "Possessed",
                "Pride's",
                "Prideful",
                "Primal",
                "Prime",
                "Primitive",
                "Promised",
                "Protector's",
                "Proud",
                "Pure",
                "Putrid",
                "Raging",
                "Recruit's",
                "Refined",
                "Reforged",
                "Reincarnated",
                "Relentless",
                "Remorseful",
                "Renewed",
                "Renovated",
                "Replica",
                "Restored",
                "Retribution",
                "Ritual",
                "Roaring",
                "Ruby Infused",
                "Rune-Forged",
                "Runed",
                "Rusty",
                "Savage",
                "Sentinel",
                "Shadow",
                "Shamanic",
                "Sharpened",
                "Silent",
                "Singed",
                "Singing",
                "Sinister",
                "Skyfall",
                "Smooth",
                "Soldier's",
                "Solitude's",
                "Sorcerer's",
                "Sorrow's",
                "Soul",
                "Soul Infused",
                "Soul-Forged",
                "Soulcursed",
                "Soulless",
                "Spectral",
                "Spectral-Forged",
                "Spiteful",
                "Storm",
                "Storm-Forged",
                "Stormfury",
                "Stormguard",
                "Terror",
                "Thirsting",
                "Thirsty",
                "Thunder",
                "Thunder-Forged",
                "Thunderfury",
                "Thunderguard",
                "Thundersoul",
                "Thunderstorm",
                "Timeworn",
                "Tormented",
                "Trainee's",
                "Treachery's",
                "Twilight",
                "Twilight's",
                "Twisted",
                "Tyrannical",
                "Undead",
                "Unholy",
                "Vanquisher",
                "Vengeance",
                "Vengeful",
                "Venom",
                "Vicious",
                "Victor",
                "Vile",
                "Vindication",
                "Vindicator",
                "Vindictive",
                "Void",
                "Volcanic",
                "Vowed",
                "War",
                "War-Forged",
                "Warden's",
                "Warlord's",
                "Warp",
                "Warped",
                "Warrior",
                "Warrior's",
                "Whistling",
                "Wicked",
                "Wind's",
                "Wind-Forged",
                "Windsong",
                "Woeful",
                "Wrathful",
                "Wretched",
                "Yearning",
                "Zealous",
            ]
            var3 = [
                "Adamantite",
                "Bone",
                "Bronze",
                "Bronzed",
                "Ivory",
                "Ebon",
                "Glass",
                "Golden",
                "Gilded",
                "Iron",
                "Ironbark",
                "Mithril",
                "Obsidian",
                "Silver",
                "Skeletal",
                "Steel",
                "Titanium",
            ]
            var4 = [
                "Mace",
                "Bludgeon",
                "Maul",
                "Crusher",
                "Smasher",
                "Warmace",
                "Hammer",
                "Mace",
                "Flail",
                "Morning Star",
                "Spikes",
                "Pummel",
                "Wacker",
                "Basher",
                "Impaler",
                "Piercer",
            ]
            var5 = [
                "Allegiance",
                "Annihilation",
                "Basher",
                "Betrayer",
                "Bludgeon",
                "Bond",
                "Boon",
                "Breaker",
                "Bringer",
                "Butcher",
                "Call",
                "Carver",
                "Champion",
                "Chopper",
                "Cleaver",
                "Conqueror",
                "Crusader",
                "Crusher",
                "Cry",
                "Cunning",
                "Dawn",
                "Defender",
                "Defiler",
                "Destroyer",
                "Edge",
                "Ender",
                "Etcher",
                "Executioner",
                "Favor",
                "Ferocity",
                "Flail",
                "Foe",
                "Gift",
                "Glory",
                "Guardian",
                "Hammer",
                "Heirloom",
                "Hope",
                "Impaler",
                "Incarnation",
                "Jaws",
                "Last Hope",
                "Last Stand",
                "Legacy",
                "Mace",
                "Maul",
                "Memory",
                "Might",
                "Morning Star",
                "Oath",
                "Pact",
                "Piercer",
                "Pledge",
                "Promise",
                "Prophecy",
                "Protector",
                "Pummel",
                "Ravager",
                "Razor",
                "Reach",
                "Reaper",
                "Reaver",
                "Sculptor",
                "Secret",
                "Slayer",
                "Slicer",
                "Smasher",
                "Soul",
                "Spikes",
                "Terror",
                "Token",
                "Tribute",
                "Vengeance",
                "Voice",
                "Wacker",
                "Warblade",
                "Warmace",
                "Whisper",
                "Wit",
            ]
            var6 = [
                "of Agony",
                "of Ancient Power",
                "of Anguish",
                "of Ashes",
                "of Assassins",
                "of Black Magic",
                "of Blessed Fortune",
                "of Blessings",
                "of Blight",
                "of Blood",
                "of Bloodlust",
                "of Broken Bones",
                "of Broken Dreams",
                "of Broken Families",
                "of Burdens",
                "of Chaos",
                "of Closing Eyes",
                "of Conquered Worlds",
                "of Corruption",
                "of Cruelty",
                "of Cunning",
                "of Dark Magic",
                "of Dark Souls",
                "of Darkness",
                "of Decay",
                "of Deception",
                "of Degradation",
                "of Delusions",
                "of Denial",
                "of Desecration",
                "of Diligence",
                "of Dismay",
                "of Dragonsouls",
                "of Due Diligence",
                "of Echoes",
                "of Ended Dreams",
                "of Ending Hope",
                "of Ending Misery",
                "of Eternal Bloodlust",
                "of Eternal Damnation",
                "of Eternal Glory",
                "of Eternal Justice",
                "of Eternal Rest",
                "of Eternal Sorrow",
                "of Eternal Struggles",
                "of Eternity",
                "of Executions",
                "of Faded Memories",
                "of Fallen Souls",
                "of Fools",
                "of Frost",
                "of Frozen Hells",
                "of Fury",
                "of Giants",
                "of Giantslaying",
                "of Grace",
                "of Grieving Widows",
                "of Hate",
                "of Hatred",
                "of Hell's Games",
                "of Hellish Torment",
                "of Heroes",
                "of Holy Might",
                "of Honor",
                "of Hope",
                "of Horrid Dreams",
                "of Horrors",
                "of Illuminated Dreams",
                "of Illumination",
                "of Immortality",
                "of Inception",
                "of Infinite Trials",
                "of Insanity",
                "of Invocation",
                "of Justice",
                "of Light's Hope",
                "of Lost Comrades",
                "of Lost Hope",
                "of Lost Voices",
                "of Lost Worlds",
                "of Magic",
                "of Mercy",
                "of Misery",
                "of Mountains",
                "of Mourning",
                "of Mystery",
                "of Necromancy",
                "of Nightmares",
                "of Oblivion",
                "of Perdition",
                "of Phantoms",
                "of Power",
                "of Pride",
                "of Pride's Fall",
                "of Putrefaction",
                "of Reckoning",
                "of Redemption",
                "of Regret",
                "of Riddles",
                "of Secrecy",
                "of Secrets",
                "of Shadow Strikes",
                "of Shadows",
                "of Shifting Sands",
                "of Shifting Worlds",
                "of Silence",
                "of Slaughter",
                "of Souls",
                "of Stealth",
                "of Storms",
                "of Subtlety",
                "of Suffering",
                "of Suffering's End",
                "of Summoning",
                "of Terror",
                "of Thunder",
                "of Time-Lost Memories",
                "of Timeless Battles",
                "of Titans",
                "of Torment",
                "of Traitors",
                "of Trembling Hands",
                "of Trials",
                "of Truth",
                "of Twilight's End",
                "of Twisted Visions",
                "of Unholy Blight",
                "of Unholy Might",
                "of Vengeance",
                "of Visions",
                "of Wasted Time",
                "of Widows",
                "of Wizardry",
                "of Woe",
                "of Wraiths",
                "of Zeal",
                "of the Ancients",
                "of the Banished",
                "of the Basilisk",
                "of the Beast",
                "of the Blessed",
                "of the Breaking Storm",
                "of the Brotherhood",
                "of the Burning Sun",
                "of the Caged Mind",
                "of the Cataclysm",
                "of the Champion",
                "of the Claw",
                "of the Corrupted",
                "of the Covenant",
                "of the Crown",
                "of the Damned",
                "of the Daywalker",
                "of the Dead",
                "of the Depth",
                "of the Dreadlord",
                "of the Earth",
                "of the East",
                "of the Emperor",
                "of the Empty Void",
                "of the End",
                "of the Enigma",
                "of the Fallen",
                "of the Falling Sky",
                "of the Flame",
                "of the Forest",
                "of the Forgotten",
                "of the Forsaken",
                "of the Gladiator",
                "of the Harvest",
                "of the Immortal",
                "of the Incoming Storm",
                "of the Insane",
                "of the King",
                "of the Lasting Night",
                "of the Leviathan",
                "of the Light",
                "of the Lion",
                "of the Lionheart",
                "of the Lone Victor",
                "of the Lone Wolf",
                "of the Lost",
                "of the Moon",
                "of the Moonwalker",
                "of the Night Sky",
                "of the Night",
                "of the Nightstalker",
                "of the North",
                "of the Occult",
                "of the Oracle",
                "of the Phoenix",
                "of the Plague",
                "of the Prince",
                "of the Protector",
                "of the Queen",
                "of the Serpent",
                "of the Setting Sun",
                "of the Shadows",
                "of the Sky",
                "of the South",
                "of the Stars",
                "of the Storm",
                "of the Summoner",
                "of the Sun",
                "of the Sunwalker",
                "of the Talon",
                "of the Undying",
                "of the Victor",
                "of the Void",
                "of the West",
                "of the Whispers",
                "of the Wicked",
                "of the Wind",
                "of the Wolf",
                "of the World",
                "of the Wretched",
            ]
            var7 = [
                "Morning Glory",
                "Morning Star",
                "Mourning Star",
                "Blackjack",
                "Tresher",
                "Good Morning",
                "Headache",
                "Migraine",
                "Grimace",
                "Macerator",
                "Abomination",
                "Agatha",
                "Agony",
                "Allegiance",
                "Alpha",
                "Amnesia",
                "Anduril",
                "Apocalypse",
                "Armageddon",
                "Arondite",
                "Ash",
                "Ashes",
                "Ashrune",
                "Back Breaker",
                "Battlestar",
                "Betrayal",
                "Betrayer",
                "Blackout",
                "Blazeguard",
                "Blessing",
                "Blind Justice",
                "Bloodfury",
                "Bloodmoon",
                "Bloodquench",
                "Bloodrage",
                "Bloodspiller",
                "Bloodweep",
                "Bone Warden",
                "Bonesnapper",
                "Braindead",
                "Broken Promise",
                "Brutality",
                "Brutalizer",
                "Cataclysm",
                "Catastrophe",
                "Celeste",
                "Chance",
                "Chaos",
                "Chasm",
                "Chieftain",
                "Comet",
                "Cometfall",
                "Concussion",
                "Convergence",
                "Corpsemaker",
                "Corruption",
                "Cosmos",
                "Crash",
                "Crimson",
                "Crush",
                "Cryptmaker",
                "Cyclone",
                "Darkness",
                "Dawn",
                "Dawnbreaker",
                "Daytime",
                "Deathbringer",
                "Deathraze",
                "Decimation",
                "Demise",
                "Desolation",
                "Despair",
                "Destiny",
                "Destruction",
                "Devastation",
                "Devine",
                "Devotion",
                "Devourer",
                "Disturbance",
                "Divine Light",
                "Dominance",
                "Dominion",
                "Doom",
                "Doombringer",
                "Dragonfist",
                "Dragonmaw",
                "Dragonstrike",
                "Due Diligence",
                "Earthquake",
                "Earthshaker",
                "Earthshaper",
                "Earthwarden",
                "Echo",
                "Eclipse",
                "Emergency",
                "End of Dreams",
                "Endbringer",
                "Enigma",
                "Epilogue",
                "Eternal Rest",
                "Eternity",
                "Eveningstar",
                "Extermination",
                "Extinction",
                "Faithkeeper",
                "Falcon",
                "Falling Star",
                "Fate",
                "Finality",
                "Frenzy",
                "Frostwind",
                "Fury",
                "Fury's Gaze",
                "Galaxy",
                "Gatecrasher",
                "Ghost Reaver",
                "Ghostwalker",
                "Glimmer",
                "Godslayer",
                "Grace",
                "Guiding Star",
                "Harbinger",
                "Harmony",
                "Harvester",
                "Hatred",
                "Heartcrusher",
                "Hell's Scream",
                "Hellfire",
                "Homage",
                "Honor's Call",
                "Hope's End",
                "Humongous",
                "Hurricane",
                "Icebreaker",
                "Infamy",
                "Infinity",
                "Interrogator",
                "Jackhammer",
                "Jawbone",
                "Justice",
                "Justifier",
                "King's Defender",
                "King's Legacy",
                "Kinslayer",
                "Knight's Fall",
                "Knight's Honor",
                "Knightfall",
                "Lament",
                "Last Chance",
                "Last Laugh",
                "Last Rites",
                "Last Word",
                "Last Words",
                "Lazarus",
                "Legacy",
                "Legionaire",
                "Life's Limit",
                "Light's Bane",
                "Lightbane",
                "Lightbringer",
                "Lightning",
                "Limbo",
                "Lockjaw",
                "Magma",
                "Malice",
                "Maneater",
                "Massacre",
                "Mercy",
                "Midnight",
                "Misery's End",
                "Monsoon",
                "Morningstar",
                "Narcoleptic",
                "Nethersbane",
                "Night's Fall",
                "Nightbane",
                "Nightfall",
                "Nightglow",
                "Nightmare",
                "Nighttime",
                "Nirvana",
                "Oathbreaker",
                "Oathkeeper",
                "Oblivion",
                "Old Age",
                "Omega",
                "Orbit",
                "Orenmir",
                "Oxheart",
                "Party Pooper",
                "Patience",
                "Peacekeeper",
                "Peacemaker",
                "Pendulum",
                "Perfect Storm",
                "Persuasion",
                "Piety",
                "Pride",
                "Prophecy",
                "Punisher",
                "Purifier",
                "Rage",
                "Ragnarok",
                "Rapture",
                "Reckoning",
                "Red Dwarf",
                "Reign",
                "Remorse",
                "Requiem",
                "Retirement",
                "Rigormortis",
                "Rising Tide",
                "Savagery",
                "Seism",
                "Seismic",
                "Serenity",
                "Severance",
                "Shadowfury",
                "Shatterskull",
                "Shooting Star",
                "Silence",
                "Skullcrusher",
                "Soul Breaker",
                "Spinefall",
                "Stalker",
                "Stonefist",
                "Storm",
                "Storm Breaker",
                "Storm-Weaver",
                "Stormbringer",
                "Stormcaller",
                "Stormedge",
                "Stormherald",
                "Stormrider",
                "Sucker Punch",
                "Sundown",
                "Supernova",
                "Supremacy",
                "Suspension",
                "Swan Song",
                "Tank",
                "Tenderiser",
                "Termination",
                "The Ambassador",
                "The Chancellor",
                "The Chief",
                "The End",
                "The Light",
                "The Minotaur",
                "The Oculus",
                "The Oracle",
                "The Sundering",
                "The Void",
                "The Warden",
                "Thunder",
                "Trauma",
                "Treachery",
                "Tremor",
                "Trinity",
                "Twilight",
                "Typhoon",
                "Ubiquity",
                "Undoing",
                "Vacancy",
                "Valkyrie",
                "Vanquisher",
                "Vengeance",
                "Warbringer",
                "Warmonger",
                "Whirlwind",
                "Wicked",
                "Widow Maker",
                "Willbreaker",
                "Winter's Bite",
                "Wit's End",
                "Witherbrand",
                "Wolf",
                "Worldbreaker",
                "Worldcarver",
                "Worldslayer",
            ]
        elif classification == Weapon.WeaponType.Spear:
            var1 = [
                "Abomination",
                "Agatha",
                "Allegiance",
                "Alpha",
                "Amnesia",
                "Anduril",
                "Anger's Edge",
                "Angerfang",
                "Anguish",
                "Apocalypse",
                "Appointment",
                "Armageddon",
                "Arondite",
                "Ash",
                "Ashes",
                "Ashrune",
                "Betrayal",
                "Betrayer",
                "Blackfury",
                "Blackout",
                "Blacktalon",
                "Blazefury",
                "Blazeguard",
                "Blind Justice",
                "Blinder",
                "Blindstrike",
                "Blinkstrike",
                "Bloodbound",
                "Bloodfall",
                "Bloodfury",
                "Bloodpike",
                "Bloodrage",
                "Bloodspiller",
                "Bloodweep",
                "Broken Promise",
                "Brutality",
                "Brutalizer",
                "Cataclysm",
                "Catastrophe",
                "Celeste",
                "Chance",
                "Chaos",
                "Checkpoint",
                "Chillspike",
                "Comet",
                "Cometfall",
                "Convergence",
                "Corpsemaker",
                "Corruption",
                "Crimson",
                "Cyclone",
                "Darkness",
                "Dawn",
                "Dawn's Edge",
                "Dawnbreaker",
                "Daytime",
                "Deathbringer",
                "Deathraze",
                "Deathspade",
                "Decimation",
                "Depravity",
                "Desolation",
                "Despair",
                "Destiny",
                "Devastation",
                "Devine",
                "Devotion",
                "Devourer",
                "Disappoint",
                "Divine Light",
                "Dominance",
                "Dominion",
                "Doom",
                "Doom's Tip",
                "Doombringer",
                "Due Diligence",
                "Early Retirement",
                "Echo",
                "Eclipse",
                "Emergency",
                "Endbringer",
                "Enigma",
                "Epilogue",
                "Eternal Rest",
                "Eternity",
                "Extermination",
                "Extinction",
                "Eyegouger",
                "Faithkeeper",
                "Fate",
                "Finality",
                "Freak's Bite",
                "Frenzy",
                "Frostbite",
                "Fury",
                "Fury's Gaze",
                "Ghostwalker",
                "Glimmer",
                "Glory's Reach",
                "Good Point",
                "Grieving Spike",
                "Hail",
                "Harbinger",
                "Harvester",
                "Hatred",
                "Hatred's Point",
                "Hatred's Spike",
                "Headspike",
                "Heartseeker",
                "Hell's Scream",
                "Hellreaver",
                "Homage",
                "Honor's Call",
                "Honor's Reach",
                "Honorbound",
                "Hope's Edge",
                "Hope's End",
                "Hope's Point",
                "Hurricane",
                "Icicle",
                "Infamy",
                "Infinity",
                "Inner Demon",
                "Jaeger",
                "Justice",
                "Justifier",
                "King's Defender",
                "King's Legacy",
                "Kingpin",
                "Kinslayer",
                "Knight's Fall",
                "Knight's Honor",
                "Knightfall",
                "Lament",
                "Last Chance",
                "Last Laugh",
                "Last Rites",
                "Last Words",
                "Lazarus",
                "Legacy",
                "Legionaire",
                "Life's Limit",
                "Light's Bane",
                "Lightbane",
                "Lightbringer",
                "Lightning",
                "Limbo",
                "Long Arm of the Law",
                "Malice",
                "Marrowstrike",
                "Massacre",
                "Mercy",
                "Midnight",
                "Misery's End",
                "Misery's Spike",
                "Narcoleptic",
                "Needle",
                "Needler",
                "Nethersbane",
                "Night's Fall",
                "Night's Reach",
                "Night's Spike",
                "Nightbane",
                "Nightfall",
                "Nighthorror",
                "Nightterror",
                "Nighttime",
                "Nirvana",
                "Oathbinder",
                "Oathbreaker",
                "Oathkeeper",
                "Oblivion",
                "Old Age",
                "Omega",
                "Orbit",
                "Party Pooper",
                "Peacekeeper",
                "Peacemaker",
                "Pendulum",
                "Persuasion",
                "Piece Maker",
                "Piety",
                "Pinpoint",
                "Point of no Return",
                "Pointless",
                "Pride",
                "Prophecy",
                "Purifier",
                "Rage",
                "Rapture",
                "Reckoning",
                "Reign",
                "Remorse",
                "Requiem",
                "Rigormortis",
                "Savagery",
                "Scar",
                "Seism",
                "Severance",
                "Shadow Strike",
                "Shadowfury",
                "Shadowmoon",
                "Shadowpike",
                "Shadowspike",
                "Shadowsteel",
                "Shadowstrike",
                "Shiverspine",
                "Silence",
                "Skirmisher",
                "Slice of Life",
                "Spike of Death",
                "Spike of Eternity",
                "Spike of Infinity",
                "Spike of Life",
                "Spike of Madness",
                "Spike of Misery",
                "Spike of Reason",
                "Spike of Ruin",
                "Spike of Time",
                "Spike",
                "Spinefall",
                "Spite",
                "Stalker",
                "Storm",
                "Stormbringer",
                "Stormcaller",
                "Stormcrow",
                "Stormedge",
                "Stormrider",
                "Supernova",
                "Supremacy",
                "Suspension",
                "Swan Song",
                "Swoosh",
                "Termination",
                "Terror's Reach",
                "The End",
                "The Facelifter",
                "The Oculus",
                "The Oracle",
                "The Surgeon",
                "The Void",
                "The Warden",
                "Thunder",
                "Thunderstrike",
                "Treachery",
                "Tremor",
                "Trickster",
                "Trickster's Tip",
                "Trinity",
                "Twisted",
                "Typhoon",
                "Ubiquity",
                "Undoing",
                "Vacancy",
                "Valkyrie",
                "Vanquisher",
                "Vengeance",
                "Viewpoint",
                "Warbringer",
                "Warmonger",
                "Waypoint",
                "Whirlwind",
                "Wicked",
                "Widow Maker",
                "Willbreaker",
                "Windpiercer",
                "Winter's Bite",
                "Wit's End",
                "Witherbrand",
                "Wolf",
                "Woosh",
            ]
            var2 = [
                "Ancient",
                "Antique",
                "Apocalypse",
                "Apocalyptic",
                "Arcane",
                "Arched",
                "Atuned",
                "Bandit's",
                "Baneful",
                "Banished",
                "Barbarian",
                "Barbaric",
                "Battleworn",
                "Blazefury",
                "Blood Infused",
                "Blood-Forged",
                "Bloodcursed",
                "Bloodied",
                "Bloodlord's",
                "Bloodsurge",
                "Bloodvenom",
                "Bonecarvin",
                "Brutal",
                "Brutality",
                "Burnished",
                "Cataclysm",
                "Cataclysmic",
                "Challenger",
                "Challenger's",
                "Champion",
                "Champion's",
                "Cold-Forged",
                "Conqueror",
                "Conqueror's",
                "Corroded",
                "Corrupted",
                "Crazed",
                "Crying",
                "Cursed",
                "Curved",
                "Dancing",
                "Dark",
                "Darkness",
                "Defender",
                "Defender's",
                "Defiled",
                "Defiling",
                "Deluded",
                "Demonic",
                "Deserted",
                "Desire's",
                "Desolation",
                "Destiny's",
                "Diabolical",
                "Dire",
                "Doom",
                "Doom's",
                "Dragon's",
                "Dragonbreath",
                "Eerie",
                "Enchanted",
                "Engraved",
                "Enlightened",
                "Eternal",
                "Exiled",
                "Extinction",
                "Faith's",
                "Faithful",
                "Fancy",
                "Fearful",
                "Feral",
                "Ferocious",
                "Fierce",
                "Fiery",
                "Fire Infused",
                "Fireguard",
                "Firesoul",
                "Firestorm",
                "Flaming",
                "Flimsy",
                "Forsaken",
                "Fortune's",
                "Foul",
                "Fragile",
                "Frail",
                "Frenzied",
                "Frost",
                "Frozen",
                "Furious",
                "Fusion",
                "Ghastly",
                "Ghost",
                "Ghost-Forged",
                "Ghostly",
                "Gladiator",
                "Gladiator's",
                "Gleaming",
                "Glinting",
                "Greedy",
                "Grieving",
                "Grim",
                "Guard's",
                "Guardian's",
                "Hailstorm",
                "Harmonized",
                "Hateful",
                "Haunted",
                "Heartless",
                "Heinous",
                "Hero",
                "Hero's",
                "Hollow",
                "Holy",
                "Honed",
                "Honor's",
                "Hope's",
                "Hopeless",
                "Howling",
                "Hungering",
                "Improved",
                "Impure",
                "Incarnated",
                "Infused",
                "Inherited",
                "Isolated",
                "Jade Infused",
                "Judgement",
                "Keeper's",
                "Knightly",
                "Knight's",
                "Legionnaire's",
                "Liar's",
                "Lich",
                "Lightning",
                "Lonely",
                "Loyal",
                "Lustful",
                "Lusting",
                "Malevolent",
                "Malicious",
                "Malificent",
                "Malignant",
                "Massive",
                "Mended",
                "Mercenary",
                "Military",
                "Misfortune's",
                "Misty",
                "Moonlit",
                "Mourning",
                "Nightmare",
                "Oathkeeper's",
                "Ominous",
                "Peacekeeper",
                "Peacekeeper's",
                "Phantom",
                "Polished",
                "Possessed",
                "Pride's",
                "Prideful",
                "Primal",
                "Prime",
                "Primitive",
                "Promised",
                "Protector's",
                "Proud",
                "Pure",
                "Putrid",
                "Raging",
                "Recruit's",
                "Refined",
                "Reforged",
                "Reincarnated",
                "Relentless",
                "Remorseful",
                "Renewed",
                "Renovated",
                "Replica",
                "Restored",
                "Retribution",
                "Ritual",
                "Roaring",
                "Ruby Infused",
                "Rune-Forged",
                "Runed",
                "Rusty",
                "Savage",
                "Sentinel",
                "Shadow",
                "Shamanic",
                "Sharpened",
                "Silent",
                "Singed",
                "Singing",
                "Sinister",
                "Skyfall",
                "Smooth",
                "Soldier's",
                "Solitude's",
                "Sorcerer's",
                "Sorrow's",
                "Soul",
                "Soul Infused",
                "Soul-Forged",
                "Soulcursed",
                "Soulless",
                "Spectral",
                "Spectral-Forged",
                "Spiteful",
                "Storm",
                "Storm-Forged",
                "Stormfury",
                "Stormguard",
                "Terror",
                "Thirsting",
                "Thirsty",
                "Thunder",
                "Thunder-Forged",
                "Thunderfury",
                "Thunderguard",
                "Thundersoul",
                "Thunderstorm",
                "Timeworn",
                "Tormented",
                "Trainee's",
                "Treachery's",
                "Twilight",
                "Twilight's",
                "Twisted",
                "Tyrannical",
                "Undead",
                "Unholy",
                "Vanquisher",
                "Vengeance",
                "Vengeful",
                "Venom",
                "Vicious",
                "Victor",
                "Vile",
                "Vindication",
                "Vindicator",
                "Vindictive",
                "Void",
                "Volcanic",
                "Vowed",
                "War",
                "War-Forged",
                "Warden's",
                "Warlord's",
                "Warp",
                "Warped",
                "Warrior",
                "Warrior's",
                "Whistling",
                "Wicked",
                "Wind's",
                "Wind-Forged",
                "Windsong",
                "Woeful",
                "Wrathful",
                "Wretched",
                "Yearning",
                "Zealous",
            ]
            var3 = [
                "Adamantite",
                "Mithril",
                "Obsidian",
                "Silver",
                "Skeletal",
                "Steel",
                "Ebon",
                "Ivory",
                "Ironbark",
                "Oak",
                "Maple",
                "Yew",
                "Ashwood",
                "Warpwood",
                "Ebonsteel",
                "Ebony",
                "Onyx",
                "Shadowsteel",
            ]
            var4 = [
                "Spear",
                "Trident",
                "Halberd",
                "Polearm",
                "Pike",
                "Spike",
                "Ranseur",
                "Javelin",
                "Lance",
                "Piercer",
                "Harpoon",
                "Prick",
                "Pricker",
                "Impaler",
                "Skewer",
                "Skiver",
            ]
            var5 = [
                "Allegiance",
                "Annihilation",
                "Betrayer",
                "Bond",
                "Boon",
                "Breaker",
                "Bringer",
                "Butcher",
                "Call",
                "Carver",
                "Champion",
                "Chopper",
                "Cleaver",
                "Conqueror",
                "Crusader",
                "Cry",
                "Cunning",
                "Dawn",
                "Defender",
                "Defiler",
                "Destroyer",
                "Edge",
                "Ender",
                "Etcher",
                "Executioner",
                "Favor",
                "Ferocity",
                "Foe",
                "Gift",
                "Glory",
                "Guardian",
                "Halberd",
                "Harpoon",
                "Heirloom",
                "Hope",
                "Impaler",
                "Incarnation",
                "Javelin",
                "Jaws",
                "Lance",
                "Last Hope",
                "Last Stand",
                "Legacy",
                "Memory",
                "Might",
                "Oath",
                "Pact",
                "Piercer",
                "Pike",
                "Pledge",
                "Polearm",
                "Prick",
                "Pricker",
                "Promise",
                "Prophecy",
                "Protector",
                "Ranseur",
                "Ravager",
                "Razor",
                "Reach",
                "Reaper",
                "Reaver",
                "Sculptor",
                "Secret",
                "Skewer",
                "Skiver",
                "Slayer",
                "Slicer",
                "Soul",
                "Spear",
                "Spike",
                "Terror",
                "Token",
                "Tribute",
                "Trident",
                "Vengeance",
                "Voice",
                "Warblade",
                "Whisper",
                "Wit",
            ]
            var6 = [
                "of Agony",
                "of Ancient Power",
                "of Anguish",
                "of Ashes",
                "of Assassins",
                "of Black Magic",
                "of Blessed Fortune",
                "of Blessings",
                "of Blight",
                "of Blood",
                "of Bloodlust",
                "of Broken Bones",
                "of Broken Dreams",
                "of Broken Families",
                "of Burdens",
                "of Chaos",
                "of Closing Eyes",
                "of Conquered Worlds",
                "of Corruption",
                "of Cruelty",
                "of Cunning",
                "of Dark Magic",
                "of Dark Souls",
                "of Darkness",
                "of Decay",
                "of Deception",
                "of Degradation",
                "of Delusions",
                "of Denial",
                "of Desecration",
                "of Diligence",
                "of Dismay",
                "of Dragonsouls",
                "of Due Diligence",
                "of Echoes",
                "of Ended Dreams",
                "of Ending Hope",
                "of Ending Misery",
                "of Eternal Bloodlust",
                "of Eternal Damnation",
                "of Eternal Glory",
                "of Eternal Justice",
                "of Eternal Rest",
                "of Eternal Sorrow",
                "of Eternal Struggles",
                "of Eternity",
                "of Executions",
                "of Faded Memories",
                "of Fallen Souls",
                "of Fools",
                "of Frost",
                "of Frozen Hells",
                "of Fury",
                "of Giants",
                "of Giantslaying",
                "of Grace",
                "of Grieving Widows",
                "of Hate",
                "of Hatred",
                "of Hell's Games",
                "of Hellish Torment",
                "of Heroes",
                "of Holy Might",
                "of Honor",
                "of Hope",
                "of Horrid Dreams",
                "of Horrors",
                "of Illuminated Dreams",
                "of Illumination",
                "of Immortality",
                "of Inception",
                "of Infinite Trials",
                "of Insanity",
                "of Invocation",
                "of Justice",
                "of Light's Hope",
                "of Lost Comrades",
                "of Lost Hope",
                "of Lost Voices",
                "of Lost Worlds",
                "of Magic",
                "of Mercy",
                "of Misery",
                "of Mountains",
                "of Mourning",
                "of Mystery",
                "of Necromancy",
                "of Nightmares",
                "of Oblivion",
                "of Perdition",
                "of Phantoms",
                "of Power",
                "of Pride",
                "of Pride's Fall",
                "of Putrefaction",
                "of Reckoning",
                "of Redemption",
                "of Regret",
                "of Riddles",
                "of Secrecy",
                "of Secrets",
                "of Shadow Strikes",
                "of Shadows",
                "of Shifting Sands",
                "of Shifting Worlds",
                "of Silence",
                "of Slaughter",
                "of Souls",
                "of Stealth",
                "of Storms",
                "of Subtlety",
                "of Suffering",
                "of Suffering's End",
                "of Summoning",
                "of Terror",
                "of Thunder",
                "of Time-Lost Memories",
                "of Timeless Battles",
                "of Titans",
                "of Torment",
                "of Traitors",
                "of Trembling Hands",
                "of Trials",
                "of Truth",
                "of Twilight's End",
                "of Twisted Visions",
                "of Unholy Blight",
                "of Unholy Might",
                "of Vengeance",
                "of Visions",
                "of Wasted Time",
                "of Widows",
                "of Wizardry",
                "of Woe",
                "of Wraiths",
                "of Zeal",
                "of the Ancients",
                "of the Banished",
                "of the Basilisk",
                "of the Beast",
                "of the Blessed",
                "of the Breaking Storm",
                "of the Brotherhood",
                "of the Burning Sun",
                "of the Caged Mind",
                "of the Cataclysm",
                "of the Champion",
                "of the Claw",
                "of the Corrupted",
                "of the Covenant",
                "of the Crown",
                "of the Damned",
                "of the Daywalker",
                "of the Dead",
                "of the Depth",
                "of the Dreadlord",
                "of the Earth",
                "of the East",
                "of the Emperor",
                "of the Empty Void",
                "of the End",
                "of the Enigma",
                "of the Fallen",
                "of the Falling Sky",
                "of the Flame",
                "of the Forest",
                "of the Forgotten",
                "of the Forsaken",
                "of the Gladiator",
                "of the Harvest",
                "of the Immortal",
                "of the Incoming Storm",
                "of the Insane",
                "of the King",
                "of the Lasting Night",
                "of the Leviathan",
                "of the Light",
                "of the Lion",
                "of the Lionheart",
                "of the Lone Victor",
                "of the Lone Wolf",
                "of the Lost",
                "of the Moon",
                "of the Moonwalker",
                "of the Night Sky",
                "of the Night",
                "of the Nightstalker",
                "of the North",
                "of the Occult",
                "of the Oracle",
                "of the Phoenix",
                "of the Plague",
                "of the Prince",
                "of the Protector",
                "of the Queen",
                "of the Serpent",
                "of the Setting Sun",
                "of the Shadows",
                "of the Sky",
                "of the South",
                "of the Stars",
                "of the Storm",
                "of the Summoner",
                "of the Sun",
                "of the Sunwalker",
                "of the Talon",
                "of the Undying",
                "of the Victor",
                "of the Void",
                "of the West",
                "of the Whispers",
                "of the Wicked",
                "of the Wind",
                "of the Wolf",
                "of the World",
                "of the Wretched",
            ]
            var7 = [
                "Abomination",
                "Agatha",
                "Allegiance",
                "Alpha",
                "Amnesia",
                "Anduril",
                "Angerfang",
                "Anguish",
                "Apocalypse",
                "Appointment",
                "Armageddon",
                "Arondite",
                "Ash",
                "Ashes",
                "Ashrune",
                "Betrayal",
                "Betrayer",
                "Blackfury",
                "Blackout",
                "Blacktalon",
                "Blazefury",
                "Blazeguard",
                "Blind Justice",
                "Blinder",
                "Blindstrike",
                "Blinkstrike",
                "Bloodbound",
                "Bloodfall",
                "Bloodfury",
                "Bloodpike",
                "Bloodrage",
                "Bloodspiller",
                "Bloodweep",
                "Broken Promise",
                "Brutality",
                "Brutalizer",
                "Cataclysm",
                "Catastrophe",
                "Celeste",
                "Chance",
                "Chaos",
                "Checkpoint",
                "Chillspike",
                "Comet",
                "Cometfall",
                "Convergence",
                "Corpsemaker",
                "Corruption",
                "Crimson",
                "Cyclone",
                "Darkness",
                "Dawn",
                "Dawn's Edge",
                "Dawnbreaker",
                "Daytime",
                "Deathbringer",
                "Deathraze",
                "Deathspade",
                "Decimation",
                "Depravity",
                "Desolation",
                "Despair",
                "Destiny",
                "Devastation",
                "Devine",
                "Devotion",
                "Devourer",
                "Disappoint",
                "Divine Light",
                "Dominance",
                "Dominion",
                "Doom",
                "Doom's Tip",
                "Doombringer",
                "Due Diligence",
                "Echo",
                "Eclipse",
                "Emergency",
                "Endbringer",
                "Enigma",
                "Epilogue",
                "Eternal Rest",
                "Eternity",
                "Extermination",
                "Extinction",
                "Eyegouger",
                "Faithkeeper",
                "Fate",
                "Finality",
                "Freak's Bite",
                "Frenzy",
                "Frostbite",
                "Fury",
                "Fury's Gaze",
                "Ghostwalker",
                "Glimmer",
                "Glory's Reach",
                "Good Point",
                "Grieving Spike",
                "Hail",
                "Harbinger",
                "Harvester",
                "Hatred",
                "Hatred's Point",
                "Hatred's Spike",
                "Headspike",
                "Heartseeker",
                "Hell's Scream",
                "Hellreaver",
                "Homage",
                "Honor's Call",
                "Honor's Reach",
                "Honorbound",
                "Hope's Edge",
                "Hope's End",
                "Hope's Point",
                "Hurricane",
                "Icicle",
                "Infamy",
                "Infinity",
                "Inner Demon",
                "Jaeger",
                "Justice",
                "Justifier",
                "King's Defender",
                "King's Legacy",
                "Kingpin",
                "Kinslayer",
                "Knight's Fall",
                "Knight's Honor",
                "Knightfall",
                "Lament",
                "Last Chance",
                "Last Laugh",
                "Last Rites",
                "Last Words",
                "Lazarus",
                "Legacy",
                "Legionaire",
                "Life's Limit",
                "Light's Bane",
                "Lightbane",
                "Lightbringer",
                "Lightning",
                "Limbo",
                "Malice",
                "Marrowstrike",
                "Massacre",
                "Mercy",
                "Midnight",
                "Misery's End",
                "Misery's Spike",
                "Narcoleptic",
                "Needle",
                "Needler",
                "Nethersbane",
                "Night's Fall",
                "Night's Reach",
                "Night's Spike",
                "Nightbane",
                "Nightfall",
                "Nighthorror",
                "Nightterror",
                "Nighttime",
                "Nirvana",
                "Oathbinder",
                "Oathbreaker",
                "Oathkeeper",
                "Oblivion",
                "Old Age",
                "Omega",
                "Orbit",
                "Party Pooper",
                "Peacekeeper",
                "Peacemaker",
                "Pendulum",
                "Persuasion",
                "Piece Maker",
                "Piety",
                "Pinpoint",
                "Pointless",
                "Pride",
                "Prophecy",
                "Purifier",
                "Rage",
                "Rapture",
                "Reckoning",
                "Reign",
                "Remorse",
                "Requiem",
                "Rigormortis",
                "Savagery",
                "Scar",
                "Seism",
                "Severance",
                "Shadow Strike",
                "Shadowfury",
                "Shadowmoon",
                "Shadowpike",
                "Shadowspike",
                "Shadowsteel",
                "Shadowstrike",
                "Shiverspine",
                "Silence",
                "Skirmisher",
                "Spike",
                "Spinefall",
                "Spite",
                "Stalker",
                "Storm",
                "Stormbringer",
                "Stormcaller",
                "Stormcrow",
                "Stormedge",
                "Stormrider",
                "Supernova",
                "Supremacy",
                "Suspension",
                "Swan Song",
                "Swoosh",
                "Termination",
                "Terror's Reach",
                "The End",
                "The Facelifter",
                "The Oculus",
                "The Oracle",
                "The Surgeon",
                "The Void",
                "The Warden",
                "Thunder",
                "Thunderstrike",
                "Treachery",
                "Tremor",
                "Trickster",
                "Trickster's Tip",
                "Trinity",
                "Twisted",
                "Typhoon",
                "Ubiquity",
                "Undoing",
                "Vacancy",
                "Valkyrie",
                "Vanquisher",
                "Vengeance",
                "Viewpoint",
                "Warbringer",
                "Warmonger",
                "Waypoint",
                "Whirlwind",
                "Wicked",
                "Widow Maker",
                "Willbreaker",
                "Windpiercer",
                "Winter's Bite",
                "Wit's End",
                "Witherbrand",
                "Wolf",
                "Woosh",
            ]
        elif classification == Weapon.WeaponType.Sword:
            var1 = [
                "Shadowfang",
                "Azurewrath",
                "Assurance",
                "ForgetMeNot",
                "Red Obsidian",
                "Abyssal Shard",
                "Aetherius",
                "Agatha",
                "Alpha",
                "Amnesia",
                "Anduril",
                "Anger's Tear",
                "Apocalypse",
                "Armageddon",
                "Arondite",
                "Ashrune",
                "Betrayal",
                "Betrayer",
                "Blackest Heart",
                "Blackout",
                "Blade of a Thousand Cuts",
                "Blade of the Grave",
                "Blazefury",
                "Blazeguard",
                "Blight's Plight",
                "Blind Justice",
                "Blinkstrike",
                "Bloodquench",
                "Bloodweep",
                "Broken Promise",
                "Brutality",
                "Cataclysm",
                "Catastrophe",
                "Celeste",
                "Chaos",
                "Cometfell",
                "Convergence",
                "Corruption",
                "Darkheart",
                "Darkness",
                "Dawn",
                "Dawn of Ruins",
                "Dawnbreaker",
                "Deathbringer",
                "Deathraze",
                "Decimation",
                "Desolation",
                "Despair",
                "Destiny's Song",
                "Devine",
                "Devourer",
                "Dirge",
                "Divine Light",
                "Doomblade",
                "Doombringer",
                "Draughtbane",
                "Due Diligence",
                "Early Retirement",
                "Echo",
                "Piece Maker",
                "Eclipse",
                "Endbringer",
                "Epilogue",
                "Espada",
                "Eternal Harmony",
                "Eternal Rest",
                "Extinction",
                "Faithkeeper",
                "Fallen Champion",
                "Fate",
                "Final Achievement",
                "Fleshrender",
                "Florance",
                "Frenzy",
                "Fury",
                "Ghost Reaver",
                "Ghostwalker",
                "Gladius",
                "Glimmer",
                "Godslayer",
                "Grasscutter",
                "Grieving Blade",
                "Gutrender",
                "Hatred's Bite",
                "Heartseeker",
                "Heartstriker",
                "Hell's Scream",
                "Hellfire",
                "Hellreaver",
                "Hollow Silence",
                "Honor's Call",
                "Hope's End",
                "Infamy",
                "Interrogator",
                "Justice",
                "Justifier",
                "King's Defender",
                "King's Legacy",
                "Kinslayer",
                "Klinge",
                "Knight's Fall",
                "Knightfall",
                "Lament",
                "Last Rites",
                "Last Words",
                "Lazarus",
                "Life's Limit",
                "Lifedrinker",
                "Light's Bane",
                "Lightbane",
                "Lightbringer",
                "Lightning",
                "Limbo",
                "Loyalty",
                "Malice",
                "Mangler",
                "Massacre",
                "Mercy",
                "Misery's End",
                "Morbid Doom",
                "Morbid Will",
                "Mournblade",
                "Narcoleptic",
                "Needle",
                "Nethersbane",
                "Night's Edge",
                "Night's Fall",
                "Nightbane",
                "Nightcrackle",
                "Nightfall",
                "Nirvana",
                "Oathbreaker",
                "Oathkeeper",
                "Oblivion",
                "Omega",
                "Orenmir",
                "Peacekeeper",
                "Perfect Storm",
                "Persuasion",
                "Prick",
                "Purifier",
                "Rage",
                "Ragespike",
                "Ragnarok",
                "Reaper",
                "Reaper's Toll",
                "Reckoning",
                "Reign of Misery",
                "Remorse",
                "Requiem",
                "Requiem of the Lost",
                "Retirement",
                "Righteous Might",
                "Rigormortis",
                "Savagery",
                "Scalpel",
                "Scar",
                "Seethe",
                "Severance",
                "Shadow Strike",
                "Shadowsteel",
                "Silence",
                "Silencer",
                "Silver Saber",
                "Silverlight",
                "Skullcrusher",
                "Slice of Life",
                "Soul Reaper",
                "Soulblade",
                "Soulrapier",
                "Spada",
                "Spike",
                "Spineripper",
                "Spiteblade",
                "Stalker",
                "Starshatterer",
                "Sting",
                "Stinger",
                "Storm",
                "Storm Breaker",
                "Stormbringer",
                "Stormcaller",
                "Storm-Weaver",
                "Striker",
                "Sun Strike",
                "Suspension",
                "Swan Song",
                "The Ambassador",
                "The Black Blade",
                "The End",
                "The Facelifter",
                "The Light",
                "The Oculus",
                "The Stake",
                "The Untamed",
                "The Unyielding",
                "The Void",
                "Thorn",
                "Thunder",
                "Toothpick",
                "Tranquility",
                "Treachery",
                "Trinity",
                "Tyrhung",
                "Unending Tyranny",
                "Unholy Might",
                "Valkyrie",
                "Vanquisher",
                "Vengeance",
                "Venom",
                "Venomshank",
                "Warmonger",
                "Widow Maker",
                "Willbreaker",
                "Winterthorn",
                "Wit's End",
                "Witherbrand",
                "Wolf",
                "Worldbreaker",
                "Worldslayer",
            ]
            var2 = [
                "Massive",
                "Military",
                "Amber Infused",
                "Ancient",
                "Anguish",
                "Annihilation",
                "Antique",
                "Arcane",
                "Arched",
                "Assassination",
                "Atuned",
                "Oathkeeper's",
                "Bandit's",
                "Baneful",
                "Banished",
                "Barbarian",
                "Barbaric",
                "Battleworn",
                "Blazefury",
                "Blood Infused",
                "Blood-Forged",
                "Bloodcursed",
                "Bloodied",
                "Bloodlord's",
                "Bloodsurge",
                "Bloodvenom",
                "Bone Crushing",
                "Bonecarvin",
                "Brutal",
                "Brutality",
                "Burnished",
                "Captain's",
                "Cataclysm",
                "Cataclysmic",
                "Cold-Forged",
                "Corroded",
                "Corrupted",
                "Crazed",
                "Crying",
                "Cursed",
                "Curved",
                "Dancing",
                "Decapitating",
                "Defiled",
                "Demonic",
                "Deserted",
                "Desire's",
                "Desolation",
                "Destiny's",
                "Dire",
                "Doom",
                "Doom's",
                "Dragon's",
                "Dragonbreath",
                "Ebon",
                "Eerie",
                "Enchanted",
                "Engraved",
                "Eternal",
                "Executing",
                "Exiled",
                "Extinction",
                "Faith's",
                "Faithful",
                "Fancy",
                "Fearful",
                "Feral",
                "Fierce",
                "Fiery",
                "Fire Infused",
                "Fireguard",
                "Firesoul",
                "Firestorm",
                "Flaming",
                "Flimsy",
                "Forsaken",
                "Fortune's",
                "Fragile",
                "Frail",
                "Frenzied",
                "Frost",
                "Frozen",
                "Furious",
                "Fusion",
                "Ghastly",
                "Ghost-Forged",
                "Ghostly",
                "Gladiator",
                "Gladiator's",
                "Gleaming",
                "Glinting",
                "Greedy",
                "Grieving",
                "Guard's",
                "Guardian's",
                "Hailstorm",
                "Hateful",
                "Haunted",
                "Heartless",
                "Hollow",
                "Holy",
                "Honed",
                "Honor's",
                "Hope's",
                "Hopeless",
                "Howling",
                "Hungering",
                "Improved",
                "Incarnated",
                "Infused",
                "Inherited",
                "Isolated",
                "Jade Infused",
                "Judgement",
                "Knightly",
                "Legionnaire's",
                "Liar's",
                "Lich",
                "Lightning",
                "Lonely",
                "Loyal",
                "Lustful",
                "Lusting",
                "Mage's",
                "Malevolent",
                "Malicious",
                "Malignant",
                "Mended",
                "Mercenary",
                "Misfortune's",
                "Misty",
                "Moonlit",
                "Mourning",
                "Nightmare",
                "Ominous",
                "Peacekeeper",
                "Phantom",
                "Polished",
                "Possessed",
                "Pride's",
                "Prideful",
                "Primitive",
                "Promised",
                "Protector's",
                "Deluded",
                "Proud",
                "Recruit's",
                "Reforged",
                "Reincarnated",
                "Relentless",
                "Remorseful",
                "Renewed",
                "Renovated",
                "Replica",
                "Restored",
                "Retribution",
                "Ritual",
                "Roaring",
                "Ruby Infused",
                "Rune-Forged",
                "Rusty",
                "Sailor's",
                "Sapphire Infused",
                "Savage",
                "Shadow",
                "Sharpened",
                "Silent",
                "Singed",
                "Singing",
                "Sinister",
                "Skullforge",
                "Skyfall",
                "Smooth",
                "Solitude's",
                "Sorrow's",
                "Soul",
                "Soul Infused",
                "Soul-Forged",
                "Soulcursed",
                "Soulless",
                "Spectral",
                "Spectral-Forged",
                "Spiteful",
                "Storm",
                "Storm-Forged",
                "Stormfury",
                "Stormguard",
                "Terror",
                "Thirsting",
                "Thirsty",
                "Thunder",
                "Thunder-Forged",
                "Thunderfury",
                "Thunderguard",
                "Thundersoul",
                "Thunderstorm",
                "Timeworn",
                "Tormented",
                "Trainee's",
                "Treachery's",
                "Twilight",
                "Twilight's",
                "Twisted",
                "Tyrannical",
                "Undead",
                "Unholy",
                "Vengeance",
                "Vengeful",
                "Venom",
                "Vicious",
                "Vindication",
                "Vindictive",
                "Void",
                "Volcanic",
                "Vowed",
                "War-Forged",
                "Warlord's",
                "Warp",
                "Warped",
                "Whistling",
                "Wicked",
                "Wind's",
                "Wind-Forged",
                "Windsong",
                "Woeful",
                "Wrathful",
                "Wretched",
                "Yearning",
                "Zealous",
            ]
            var3 = [
                "Adamantite",
                "Bronze",
                "Copper",
                "Diamond",
                "Glass",
                "Gold",
                "Iron",
                "Mithril",
                "Obsidian",
                "Silver",
                "Skeletal",
                "Steel",
            ]
            var4 = [
                "Blade",
                "Broadsword",
                "Claymore",
                "Defender",
                "Deflector",
                "Doomblade",
                "Greatsword",
                "Guardian",
                "Katana",
                "Longsword",
                "Mageblade",
                "Protector",
                "Quickblade",
                "Rapier",
                "Reaver",
                "Sabre",
                "Scimitar",
                "Shortsword",
                "Slicer",
                "Spellblade",
                "Swiftblade",
                "Sword",
                "Warblade",
                "Skewer",
                "Carver",
                "Etcher",
                "Sculptor",
                "Razor",
                "Crusader",
            ]
            var5 = [
                "Annihilation",
                "Betrayer",
                "Blade",
                "Blessed Blade",
                "Blood Blade",
                "Bond",
                "Boon",
                "Breaker",
                "Bringer",
                "Broadsword",
                "Butcher",
                "Call",
                "Carver",
                "Champion",
                "Claymore",
                "Conqueror",
                "Crusader",
                "Cry",
                "Cunning",
                "Dark Blade",
                "Dawn",
                "Defender",
                "Defiler",
                "Deflector",
                "Destroyer",
                "Doomblade",
                "Edge",
                "Ender",
                "Etcher",
                "Executioner",
                "Favor",
                "Ferocity",
                "Foe",
                "Gift",
                "Glory",
                "Greatsword",
                "Guardian",
                "Heirloom",
                "Hope",
                "Incarnation",
                "Jaws",
                "Katana",
                "Last Hope",
                "Last Stand",
                "Legacy",
                "Longblade",
                "Longsword",
                "Mageblade",
                "Memory",
                "Might",
                "Oath",
                "Pact",
                "Pledge",
                "Promise",
                "Protector",
                "Quickblade",
                "Rapier",
                "Ravager",
                "Razor",
                "Reach",
                "Reaper",
                "Reaver",
                "Runed Blade",
                "Saber",
                "Sabre",
                "Savagery",
                "Scimitar",
                "Sculptor",
                "Secret",
                "Shortsword",
                "Skewer",
                "Slayer",
                "Slicer",
                "Soul",
                "Spellblade",
                "Spine",
                "Swiftblade",
                "Sword",
                "Terror",
                "Token",
                "Tribute",
                "Vengeance",
                "Voice",
                "Warblade",
                "Warglaive",
                "Whisper",
                "Wit",
            ]
            var6 = [
                "of Agony",
                "of Ancient Power",
                "of Anguish",
                "of Ashes",
                "of Assassins",
                "of Black Magic",
                "of Blessed Fortune",
                "of Blessings",
                "of Blight",
                "of Blood",
                "of Bloodlust",
                "of Broken Bones",
                "of Broken Dreams",
                "of Broken Families",
                "of Burdens",
                "of Chaos",
                "of Closing Eyes",
                "of Conquered Worlds",
                "of Corruption",
                "of Cruelty",
                "of Cunning",
                "of Dark Magic",
                "of Dark Souls",
                "of Darkness",
                "of Decay",
                "of Deception",
                "of Degradation",
                "of Delusions",
                "of Denial",
                "of Desecration",
                "of Diligence",
                "of Dismay",
                "of Dragonsouls",
                "of Due Diligence",
                "of Echoes",
                "of Ended Dreams",
                "of Ending Hope",
                "of Ending Misery",
                "of Eternal Bloodlust",
                "of Eternal Damnation",
                "of Eternal Glory",
                "of Eternal Justice",
                "of Eternal Rest",
                "of Eternal Sorrow",
                "of Eternal Struggles",
                "of Eternity",
                "of Executions",
                "of Faded Memories",
                "of Fallen Souls",
                "of Fools",
                "of Frost",
                "of Frozen Hells",
                "of Fury",
                "of Giants",
                "of Giantslaying",
                "of Grace",
                "of Grieving Widows",
                "of Hate",
                "of Hatred",
                "of Hell's Games",
                "of Hellish Torment",
                "of Heroes",
                "of Holy Might",
                "of Honor",
                "of Hope",
                "of Horrid Dreams",
                "of Horrors",
                "of Illuminated Dreams",
                "of Illumination",
                "of Immortality",
                "of Inception",
                "of Infinite Trials",
                "of Insanity",
                "of Invocation",
                "of Justice",
                "of Light's Hope",
                "of Lost Comrades",
                "of Lost Hope",
                "of Lost Voices",
                "of Lost Worlds",
                "of Magic",
                "of Mercy",
                "of Misery",
                "of Mountains",
                "of Mourning",
                "of Mystery",
                "of Necromancy",
                "of Nightmares",
                "of Oblivion",
                "of Perdition",
                "of Phantoms",
                "of Power",
                "of Pride",
                "of Pride's Fall",
                "of Putrefaction",
                "of Reckoning",
                "of Redemption",
                "of Regret",
                "of Riddles",
                "of Secrecy",
                "of Secrets",
                "of Shadow Strikes",
                "of Shadows",
                "of Shifting Sands",
                "of Shifting Worlds",
                "of Silence",
                "of Slaughter",
                "of Souls",
                "of Stealth",
                "of Storms",
                "of Subtlety",
                "of Suffering",
                "of Suffering's End",
                "of Summoning",
                "of Terror",
                "of Thunder",
                "of Time-Lost Memories",
                "of Timeless Battles",
                "of Titans",
                "of Torment",
                "of Traitors",
                "of Trembling Hands",
                "of Trials",
                "of Truth",
                "of Twilight's End",
                "of Twisted Visions",
                "of Unholy Blight",
                "of Unholy Might",
                "of Vengeance",
                "of Visions",
                "of Wasted Time",
                "of Widows",
                "of Wizardry",
                "of Woe",
                "of Wraiths",
                "of Zeal",
                "of the Ancients",
                "of the Banished",
                "of the Basilisk",
                "of the Beast",
                "of the Blessed",
                "of the Breaking Storm",
                "of the Brotherhood",
                "of the Burning Sun",
                "of the Caged Mind",
                "of the Cataclysm",
                "of the Champion",
                "of the Claw",
                "of the Corrupted",
                "of the Covenant",
                "of the Crown",
                "of the Damned",
                "of the Daywalker",
                "of the Dead",
                "of the Depth",
                "of the Dreadlord",
                "of the Earth",
                "of the East",
                "of the Emperor",
                "of the Empty Void",
                "of the End",
                "of the Enigma",
                "of the Fallen",
                "of the Falling Sky",
                "of the Flame",
                "of the Forest",
                "of the Forgotten",
                "of the Forsaken",
                "of the Gladiator",
                "of the Harvest",
                "of the Immortal",
                "of the Incoming Storm",
                "of the Insane",
                "of the King",
                "of the Lasting Night",
                "of the Leviathan",
                "of the Light",
                "of the Lion",
                "of the Lionheart",
                "of the Lone Victor",
                "of the Lone Wolf",
                "of the Lost",
                "of the Moon",
                "of the Moonwalker",
                "of the Night Sky",
                "of the Night",
                "of the Nightstalker",
                "of the North",
                "of the Occult",
                "of the Oracle",
                "of the Phoenix",
                "of the Plague",
                "of the Prince",
                "of the Protector",
                "of the Queen",
                "of the Serpent",
                "of the Setting Sun",
                "of the Shadows",
                "of the Sky",
                "of the South",
                "of the Stars",
                "of the Storm",
                "of the Summoner",
                "of the Sun",
                "of the Sunwalker",
                "of the Talon",
                "of the Undying",
                "of the Victor",
                "of the Void",
                "of the West",
                "of the Whispers",
                "of the Wicked",
                "of the Wind",
                "of the Wolf",
                "of the World",
                "of the Wretched",
            ]
            var7 = [
                "Felthorn",
                "Aetherius",
                "Agatha",
                "Alpha",
                "Amnesia",
                "Anduril",
                "Apocalypse",
                "Armageddon",
                "Arondite",
                "Ashrune",
                "Betrayal",
                "Betrayer",
                "Blackout",
                "Blazefury",
                "Blazeguard",
                "Blinkstrike",
                "Bloodquench",
                "Bloodweep",
                "Brutality",
                "Celeste",
                "Chaos",
                "Cometfell",
                "Convergence",
                "Darkheart",
                "Dawn",
                "Dawnbreaker",
                "Deathbringer",
                "Deathraze",
                "Decimation",
                "Desolation",
                "Destiny's Song",
                "Dirge",
                "Doomblade",
                "Doombringer",
                "Draughtbane",
                "Due Diligence",
                "Echo",
                "Eclipse",
                "Endbringer",
                "Epilogue",
                "Espada",
                "Extinction",
                "Faithkeeper",
                "Fate",
                "Fleshrender",
                "Florance",
                "Frenzy",
                "Fury",
                "Ghost Reaver",
                "Ghostwalker",
                "Gladius",
                "Glimmer",
                "Godslayer",
                "Grasscutter",
                "Gutrender",
                "Hatred's Bite",
                "Heartseeker",
                "Heartstriker",
                "Hell's Scream",
                "Hellfire",
                "Piece Maker",
                "Hellreaver",
                "Honor's Call",
                "Hope's End",
                "Infamy",
                "Interrogator",
                "Justifier",
                "Kinslayer",
                "Klinge",
                "Knightfall",
                "Lament",
                "Lazarus",
                "Lifedrinker",
                "Light's Bane",
                "Lightbane",
                "Lightbringer",
                "Lightning",
                "Limbo",
                "Loyalty",
                "Malice",
                "Mangler",
                "Massacre",
                "Mercy",
                "Misery",
                "Mournblade",
                "Narcoleptic",
                "Needle",
                "Nethersbane",
                "Night's Edge",
                "Night's Fall",
                "Nightbane",
                "Nightcrackle",
                "Nightfall",
                "Nirvana",
                "Oathbreaker",
                "Oathkeeper",
                "Oblivion",
                "Omega",
                "Orenmir",
                "Peacekeeper",
                "Persuasion",
                "Prick",
                "Purifier",
                "Rage",
                "Ragespike",
                "Ragnarok",
                "Reckoning",
                "Reign",
                "Remorse",
                "Requiem",
                "Retirement",
                "Rigormortis",
                "Savagery",
                "Scalpel",
                "Scar",
                "Seethe",
                "Severance",
                "Shadow Strike",
                "Shadowsteel",
                "Silence",
                "Silencer",
                "Silver Saber",
                "Silverlight",
                "Skullcrusher",
                "Slice of Life",
                "Soul Reaper",
                "Soulblade",
                "Soulrapier",
                "Spada",
                "Spike",
                "Spineripper",
                "Spiteblade",
                "Stalker",
                "Starshatterer",
                "Sting",
                "Stinger",
                "Storm",
                "Storm Breaker",
                "Stormbringer",
                "Stormcaller",
                "Story-Weaver",
                "Striker",
                "Sun Strike",
                "Suspension",
                "Swan Song",
                "The Ambassador",
                "The Black Blade",
                "The End",
                "The Facelifter",
                "The Light",
                "The Oculus",
                "The Stake",
                "The Untamed",
                "The Unyielding",
                "The Void",
                "Thorn",
                "Thunder",
                "Toothpick",
                "Tranquility",
                "Treachery",
                "Trinity",
                "Tyrhung",
                "Unending Tyranny",
                "Unholy Might",
                "Valkyrie",
                "Vanquisher",
                "Vengeance",
                "Venom",
                "Venomshank",
                "Warmonger",
                "Widow Maker",
                "Willbreaker",
                "Winterthorn",
                "Wit's End",
                "Witherbrand",
                "Wolf",
                "Worldbreaker",
                "Worldslayer",
            ]

        num = randrange(4)
        if num == 0:
            return choice(var1).title()
        elif num == 1:
            return choice(var2) + " " + choice(var4)
        elif num == 2:
            return choice(var2) + " " + choice(var3) + " " + choice(var4)
        elif num == 3:
            return choice(var7) + " " + choice(var5) + " " + choice(var6)
